=== modified file 'Makefile'
--- Makefile	2011-05-18 15:45:07 +0000
+++ Makefile	2011-09-06 11:01:30 +0000
@@ -42,7 +42,9 @@
 	set -e
 	# Generate a stream for PQM to watch.
 	-$(RM) -f selftest.log
+	echo `date` ": selftest starts" 1>&2
 	$(PYTHON) -Werror -Wignore::ImportWarning -O ./bzr selftest --subunit $(tests) | tee selftest.log
+	echo `date` ": selftest ends" 1>&2
 	# An empty log file should catch errors in the $(PYTHON)
 	# command above (the '|' swallow any errors since 'make'
 	# sees the 'tee' exit code for the whole line

=== modified file 'bzrlib/_dirstate_helpers_pyx.pyx'
--- bzrlib/_dirstate_helpers_pyx.pyx	2011-04-22 14:12:22 +0000
+++ bzrlib/_dirstate_helpers_pyx.pyx	2011-08-30 14:45:41 +0000
@@ -1793,6 +1793,7 @@
                 advance_entry = -1
                 advance_path = -1
                 result = None
+                changed = None
                 path_handled = 0
                 if current_entry is None:
                     # unversioned -  the check for path_handled when the path

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2011-08-27 16:59:43 +0000
+++ bzrlib/branch.py	2011-09-05 14:16:12 +0000
@@ -1739,6 +1739,14 @@
         """True if this format supports tags stored in the branch"""
         return False  # by default
 
+    def tags_are_versioned(self):
+        """Whether the tag container for this branch versions tags."""
+        return False
+
+    def supports_tags_referencing_ghosts(self):
+        """True if tags can reference ghost revisions."""
+        return True
+
 
 class MetaDirBranchFormatFactory(registry._LazyObjectGetter):
     """A factory for a BranchFormat object, permitting simple lazy registration.
@@ -3044,6 +3052,7 @@
     :ivar local_branch: target branch if there is a Master, else None
     :ivar target_branch: Target/destination branch object. (write locked)
     :ivar tag_conflicts: A list of tag conflicts, see BasicTags.merge_to
+    :ivar tag_updates: A dict with new tags, see BasicTags.merge_to
     """
 
     @deprecated_method(deprecated_in((2, 3, 0)))
@@ -3055,11 +3064,18 @@
         return self.new_revno - self.old_revno
 
     def report(self, to_file):
+        tag_conflicts = getattr(self, "tag_conflicts", None)
+        tag_updates = getattr(self, "tag_updates", None)
         if not is_quiet():
-            if self.old_revid == self.new_revid:
-                to_file.write('No revisions to pull.\n')
-            else:
+            if self.old_revid != self.new_revid:
                 to_file.write('Now on revision %d.\n' % self.new_revno)
+            if tag_updates:
+                to_file.write('%d tag(s) updated.\n' % len(tag_updates))
+            if self.old_revid == self.new_revid and not tag_updates:
+                if not tag_conflicts:
+                    to_file.write('No revisions or tags to pull.\n')
+                else:
+                    to_file.write('No revisions to pull.\n')
         self._show_tag_conficts(to_file)
 
 
@@ -3091,11 +3107,22 @@
         return self.new_revno - self.old_revno
 
     def report(self, to_file):
-        """Write a human-readable description of the result."""
-        if self.old_revid == self.new_revid:
-            note('No new revisions to push.')
-        else:
-            note('Pushed up to revision %d.' % self.new_revno)
+        # TODO: This function gets passed a to_file, but then
+        # ignores it and calls note() instead. This is also
+        # inconsistent with PullResult(), which writes to stdout.
+        # -- JRV20110901, bug #838853
+        tag_conflicts = getattr(self, "tag_conflicts", None)
+        tag_updates = getattr(self, "tag_updates", None)
+        if not is_quiet():
+            if self.old_revid != self.new_revid:
+                note('Pushed up to revision %d.' % self.new_revno)
+            if tag_updates:
+                note('%d tag(s) updated.' % len(tag_updates))
+            if self.old_revid == self.new_revid and not tag_updates:
+                if not tag_conflicts:
+                    note('No new revisions or tags to push.')
+                else:
+                    note('No new revisions to push.')
         self._show_tag_conficts(to_file)
 
 
@@ -3409,8 +3436,8 @@
             self._update_revisions(stop_revision, overwrite=overwrite,
                     graph=graph)
         if self.source._push_should_merge_tags():
-            result.tag_conflicts = self.source.tags.merge_to(self.target.tags,
-                overwrite)
+            result.tag_updates, result.tag_conflicts = (
+                self.source.tags.merge_to(self.target.tags, overwrite))
         result.new_revno, result.new_revid = self.target.last_revision_info()
         return result
 
@@ -3499,8 +3526,9 @@
             # TODO: The old revid should be specified when merging tags, 
             # so a tags implementation that versions tags can only 
             # pull in the most recent changes. -- JRV20090506
-            result.tag_conflicts = self.source.tags.merge_to(self.target.tags,
-                overwrite, ignore_master=not merge_tags_to_master)
+            result.tag_updates, result.tag_conflicts = (
+                self.source.tags.merge_to(self.target.tags, overwrite,
+                    ignore_master=not merge_tags_to_master))
             result.new_revno, result.new_revid = self.target.last_revision_info()
             if _hook_master:
                 result.master_branch = _hook_master

=== modified file 'bzrlib/bugtracker.py'
--- bzrlib/bugtracker.py	2011-02-25 12:12:39 +0000
+++ bzrlib/bugtracker.py	2011-09-01 15:26:30 +0000
@@ -48,8 +48,14 @@
 
     bzr commit --fixes <tracker>:<id>
 
+or::
+
+    bzr commit --fixes <id>
+
 where "<tracker>" is an identifier for the bug tracker, and "<id>" is the
 identifier for that bug within the bugtracker, usually the bug number.
+If "<tracker>" is not specified the ``bugtracker`` set in the branch
+or global configuration is used.
 
 Bazaar knows about a few bug trackers that have many users. If
 you use one of these bug trackers then there is no setup required to

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2011-08-25 03:20:44 +0000
+++ bzrlib/builtins.py	2011-09-06 13:35:07 +0000
@@ -977,7 +977,7 @@
     branches have diverged.
 
     If there is no default location set, the first pull will set it (use
-    --no-remember to avoid settting it). After that, you can omit the
+    --no-remember to avoid setting it). After that, you can omit the
     location to use the default.  To change the default, use --remember. The
     value will only be saved if the remote location can be accessed.
 
@@ -1076,8 +1076,7 @@
                 view_info=view_info)
             result = tree_to.pull(
                 branch_from, overwrite, revision_id, change_reporter,
-                possible_transports=possible_transports, local=local,
-                show_base=show_base)
+                local=local, show_base=show_base)
         else:
             result = branch_to.pull(
                 branch_from, overwrite, revision_id, local=local)
@@ -1114,7 +1113,7 @@
     After that you will be able to do a push without '--overwrite'.
 
     If there is no default push location set, the first push will set it (use
-    --no-remember to avoid settting it).  After that, you can omit the
+    --no-remember to avoid setting it).  After that, you can omit the
     location to use the default.  To change the default, use --remember. The
     value will only be saved if the remote location can be accessed.
     """
@@ -3237,15 +3236,31 @@
     aliases = ['ci', 'checkin']
 
     def _iter_bug_fix_urls(self, fixes, branch):
+        default_bugtracker  = None
         # Configure the properties for bug fixing attributes.
         for fixed_bug in fixes:
             tokens = fixed_bug.split(':')
-            if len(tokens) != 2:
+            if len(tokens) == 1:
+                if default_bugtracker is None:
+                    branch_config = branch.get_config()
+                    default_bugtracker = branch_config.get_user_option(
+                        "bugtracker")
+                if default_bugtracker is None:
+                    raise errors.BzrCommandError(
+                        "No tracker specified for bug %s. Use the form "
+                        "'tracker:id' or specify a default bug tracker "
+                        "using the `bugtracker` option.\nSee "
+                        "\"bzr help bugs\" for more information on this "
+                        "feature. Commit refused." % fixed_bug)
+                tag = default_bugtracker
+                bug_id = tokens[0]
+            elif len(tokens) != 2:
                 raise errors.BzrCommandError(
                     "Invalid bug %s. Must be in the form of 'tracker:id'. "
                     "See \"bzr help bugs\" for more information on this "
                     "feature.\nCommit refused." % fixed_bug)
-            tag, bug_id = tokens
+            else:
+                tag, bug_id = tokens
             try:
                 yield bugtracker.get_bug_url(tag, branch, bug_id)
             except errors.UnknownBugTrackerAbbreviation:
@@ -3787,6 +3802,9 @@
                                 param_name='starting_with', short_name='s',
                                 help=
                                 'Load only the tests starting with TESTID.'),
+                     Option('sync',
+                            help="By default we disable fsync and fdatasync"
+                                 " while running the test suite.")
                      ]
     encoding_type = 'replace'
 
@@ -3800,7 +3818,8 @@
             first=False, list_only=False,
             randomize=None, exclude=None, strict=False,
             load_list=None, debugflag=None, starting_with=None, subunit=False,
-            parallel=None, lsprof_tests=False):
+            parallel=None, lsprof_tests=False,
+            sync=False):
         from bzrlib import tests
 
         if testspecs_list is not None:
@@ -3835,6 +3854,8 @@
             exclude_pattern = None
         else:
             exclude_pattern = '(' + '|'.join(exclude) + ')'
+        if not sync:
+            self._disable_fsync()
         selftest_kwargs = {"verbose": verbose,
                           "pattern": pattern,
                           "stop_on_failure": one,
@@ -3862,6 +3883,15 @@
             cleanup()
         return int(not result)
 
+    def _disable_fsync(self):
+        """Change the 'os' functionality to not synchronize."""
+        self._orig_fsync = getattr(os, 'fsync', None)
+        if self._orig_fsync is not None:
+            os.fsync = lambda filedes: None
+        self._orig_fdatasync = getattr(os, 'fdatasync', None)
+        if self._orig_fdatasync is not None:
+            os.fdatasync = lambda filedes: None
+
 
 class cmd_version(Command):
     __doc__ = """Show version of bzr."""
@@ -3950,7 +3980,7 @@
     Use bzr resolve when you have fixed a problem.  See also bzr conflicts.
 
     If there is no default branch set, the first merge will set it (use
-    --no-remember to avoid settting it). After that, you can omit the branch
+    --no-remember to avoid setting it). After that, you can omit the branch
     to use the default.  To change the default, use --remember. The value will
     only be saved if the remote location can be accessed.
 
@@ -5397,7 +5427,7 @@
 
     Both the submit branch and the public branch follow the usual behavior with
     respect to --remember: If there is no default location set, the first send
-    will set it (use --no-remember to avoid settting it). After that, you can
+    will set it (use --no-remember to avoid setting it). After that, you can
     omit the location to use the default.  To change the default, use
     --remember. The value will only be saved if the location can be accessed.
 
@@ -5622,10 +5652,20 @@
                 if tag_name is None:
                     raise errors.BzrCommandError(
                         "Please specify a tag name.")
-            if (not force) and branch.tags.has_tag(tag_name):
+            try:
+                existing_target = branch.tags.lookup_tag(tag_name)
+            except errors.NoSuchTag:
+                existing_target = None
+            if not force and existing_target not in (None, revision_id):
                 raise errors.TagAlreadyExists(tag_name)
-            branch.tags.set_tag(tag_name, revision_id)
-            note('Created tag %s.' % tag_name)
+            if existing_target == revision_id:
+                note('Tag %s already exists for that revision.' % tag_name)
+            else:
+                branch.tags.set_tag(tag_name, revision_id)
+                if existing_target is None:
+                    note('Created tag %s.' % tag_name)
+                else:
+                    note('Updated tag %s.' % tag_name)
 
 
 class cmd_tags(Command):

=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2011-07-15 14:27:20 +0000
+++ bzrlib/commands.py	2011-09-01 11:27:37 +0000
@@ -465,7 +465,7 @@
             usage help (e.g. Purpose, Usage, Options) with a
             message explaining how to obtain full help.
         """
-        if self.l10n and not i18n.installed():
+        if self.l10n:
             i18n.install()  # Install i18n only for get_help_text for now.
         doc = self.help()
         if doc:

=== modified file 'bzrlib/commit.py'
--- bzrlib/commit.py	2011-06-28 17:25:26 +0000
+++ bzrlib/commit.py	2011-08-31 17:11:32 +0000
@@ -464,7 +464,8 @@
         # Merge local tags to remote
         if self.bound_branch:
             self._set_progress_stage("Merging tags to master branch")
-            tag_conflicts = self.branch.tags.merge_to(self.master_branch.tags)
+            tag_updates, tag_conflicts = self.branch.tags.merge_to(
+                self.master_branch.tags)
             if tag_conflicts:
                 warning_lines = ['    ' + name for name, _, _ in tag_conflicts]
                 note("Conflicting tags in bound branch:\n" +

=== modified file 'bzrlib/config.py'
--- bzrlib/config.py	2011-09-06 10:50:55 +0000
+++ bzrlib/config.py	2011-09-07 15:21:39 +0000
@@ -1397,7 +1397,7 @@
             return (self.branch._transport.get_bytes("email")
                     .decode(osutils.get_user_encoding())
                     .rstrip("\r\n"))
-        except errors.NoSuchFile, e:
+        except (errors.NoSuchFile, errors.PermissionDenied), e:
             pass
 
         return self._get_best_value('_get_user_id')
@@ -2278,6 +2278,11 @@
             return f
         except errors.NoSuchFile:
             return StringIO()
+        except errors.PermissionDenied, e:
+            trace.warning("Permission denied while trying to open "
+                "configuration file %s.", urlutils.unescape_for_display(
+                urlutils.join(self._transport.base, self._filename), "utf-8"))
+            return StringIO()
 
     def _external_url(self):
         return urlutils.join(self._transport.external_url(), self._filename)
@@ -2704,7 +2709,12 @@
         """Load the store from the associated file."""
         if self.is_loaded():
             return
-        content = self.transport.get_bytes(self.file_name)
+        try:
+            content = self.transport.get_bytes(self.file_name)
+        except errors.PermissionDenied:
+            trace.warning("Permission denied while trying to load "
+                          "configuration store %s.", self.external_url())
+            raise
         self._load_from_string(content)
         for hook in ConfigHooks['load']:
             hook(self)
@@ -2753,8 +2763,8 @@
         # We need a loaded store
         try:
             self.load()
-        except errors.NoSuchFile:
-            # If the file doesn't exist, there is no sections
+        except (errors.NoSuchFile, errors.PermissionDenied):
+            # If the file can't be read, there is no sections
             return
         cobj = self._config_obj
         if cobj.scalars:
@@ -2881,8 +2891,8 @@
 class SectionMatcher(object):
     """Select sections into a given Store.
 
-    This intended to be used to postpone getting an iterable of sections from a
-    store.
+    This is intended to be used to postpone getting an iterable of sections
+    from a store.
     """
 
     def __init__(self, store):
@@ -2897,10 +2907,26 @@
             if self.match(s):
                 yield s
 
-    def match(self, secion):
+    def match(self, section):
+        """Does the proposed section match.
+
+        :param section: A Section object.
+
+        :returns: True if the section matches, False otherwise.
+        """
         raise NotImplementedError(self.match)
 
 
+class NameMatcher(SectionMatcher):
+
+    def __init__(self, store, section_id):
+        super(NameMatcher, self).__init__(store)
+        self.section_id = section_id
+
+    def match(self, section):
+        return section.id == self.section_id
+
+
 class LocationSection(Section):
 
     def __init__(self, section, length, extra_path):

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2011-08-21 13:49:30 +0000
+++ bzrlib/errors.py	2011-09-07 10:17:23 +0000
@@ -20,7 +20,10 @@
 from bzrlib import (
     osutils,
     symbol_versioning,
+    i18n,
+    trace,
     )
+from bzrlib.i18n import gettext
 from bzrlib.patches import (
     MalformedHunkHeader,
     MalformedLine,
@@ -140,7 +143,11 @@
         """Return format string for this exception or None"""
         fmt = getattr(self, '_fmt', None)
         if fmt is not None:
-            return fmt
+            i18n.install()
+            unicode_fmt = unicode(fmt) #_fmt strings should be ascii
+            if type(fmt) == unicode:
+                trace.mutter("Unicode strings in error.fmt are deprecated")
+            return gettext(unicode_fmt)
         fmt = getattr(self, '__doc__', None)
         if fmt is not None:
             symbol_versioning.warn("%s uses its docstring as a format, "
@@ -2349,6 +2356,14 @@
     """
 
 
+class GhostTagsNotSupported(BzrError):
+
+    _fmt = "Ghost tags not supported by format %(format)r."
+
+    def __init__(self, format):
+        self.format = format
+
+
 class BinaryFile(BzrError):
 
     _fmt = "File is binary but should be text."
@@ -2784,7 +2799,7 @@
     _fmt = "Container has multiple records with the same name: %(name)s"
 
     def __init__(self, name):
-        self.name = name
+        self.name = name.decode("utf-8")
 
 
 class NoDestinationAddress(InternalBzrError):

=== modified file 'bzrlib/export_pot.py'
--- bzrlib/export_pot.py	2011-05-28 12:17:22 +0000
+++ bzrlib/export_pot.py	2011-08-31 10:23:47 +0000
@@ -28,6 +28,7 @@
     errors,
     help_topics,
     plugin,
+    help,
     )
 from bzrlib.trace import (
     mutter,
@@ -234,7 +235,11 @@
                     outf,
                     'dummy/help_topics/'+key+'/detail.txt',
                     1, doc)
-
+        elif callable(doc): # help topics from files
+            _poentry_per_paragraph(
+                    outf,
+                    'en/help_topics/'+key+'.txt',
+                    1, doc(key))
         summary = topic_registry.get_summary(key)
         if summary is not None:
             _poentry(outf, 'dummy/help_topics/'+key+'/summary.txt',
@@ -246,5 +251,4 @@
     _standard_options(outf)
     _command_helps(outf)
     _error_messages(outf)
-    # disable exporting help topics until we decide  how to translate it.
-    #_help_topics(outf)
+    _help_topics(outf)

=== modified file 'bzrlib/help_topics/__init__.py'
--- bzrlib/help_topics/__init__.py	2011-08-24 18:42:15 +0000
+++ bzrlib/help_topics/__init__.py	2011-09-07 16:32:11 +0000
@@ -40,6 +40,7 @@
     config,
     osutils,
     registry,
+    i18n,
     )
 
 
@@ -879,6 +880,8 @@
         result += _format_see_also(additional_see_also)
         if plain:
             result = help_as_plain_text(result)
+        i18n.install()
+        result = i18n.gettext_per_paragraph(result)
         return result
 
     def get_help_topic(self):

=== modified file 'bzrlib/help_topics/en/log-formats.txt'
--- bzrlib/help_topics/en/log-formats.txt	2010-01-03 01:41:00 +0000
+++ bzrlib/help_topics/en/log-formats.txt	2011-08-31 11:39:56 +0000
@@ -19,6 +19,7 @@
   branch nick             yes            -             -
   foreign vcs properties  yes            yes           -
   preferred levels        all            1             1
+  digital signature       optional       -             -
 
 The default format is ``long``. To change this, define the ``log_format``
 setting in the ``[DEFAULT]`` section of ``bazaar.conf`` like this (say)::

=== modified file 'bzrlib/i18n.py'
--- bzrlib/i18n.py	2011-08-25 10:33:14 +0000
+++ bzrlib/i18n.py	2011-09-01 10:43:23 +0000
@@ -72,6 +72,8 @@
 
 def install(lang=None):
     global _translations
+    if installed():
+        return
     if lang is None:
         lang = _get_current_locale()
     if lang is not None:

=== modified file 'bzrlib/option.py'
--- bzrlib/option.py	2011-06-27 15:42:09 +0000
+++ bzrlib/option.py	2011-09-01 15:45:57 +0000
@@ -25,6 +25,7 @@
 from bzrlib import (
     errors,
     revisionspec,
+    i18n,
     )
 """)
 
@@ -429,9 +430,23 @@
 
     DEFAULT_VALUE = object()
 
+    def __init__(self):
+        optparse.OptionParser.__init__(self)
+        self.formatter = GettextIndentedHelpFormatter()
+
     def error(self, message):
         raise errors.BzrCommandError(message)
 
+class GettextIndentedHelpFormatter(optparse.IndentedHelpFormatter):
+    """Adds gettext() call to format_option()"""
+    def __init__(self):
+        optparse.IndentedHelpFormatter.__init__(self)
+
+    def format_option(self, option):
+        """code taken from Python's optparse.py"""
+        if option.help:
+            option.help = i18n.gettext(option.help)
+        return optparse.IndentedHelpFormatter.format_option(self, option)
 
 def get_optparser(options):
     """Generate an optparse parser for bzrlib-style options"""

=== modified file 'bzrlib/pack.py'
--- bzrlib/pack.py	2011-04-08 14:45:25 +0000
+++ bzrlib/pack.py	2011-09-07 11:46:16 +0000
@@ -333,7 +333,7 @@
                 # risk that the same unicode string has been encoded two
                 # different ways.
                 if name_tuple in all_names:
-                    raise errors.DuplicateRecordNameError(name_tuple)
+                    raise errors.DuplicateRecordNameError(name_tuple[0])
                 all_names.add(name_tuple)
         excess_bytes = self.reader_func(1)
         if excess_bytes != '':

=== modified file 'bzrlib/plugins/weave_fmt/workingtree.py'
--- bzrlib/plugins/weave_fmt/workingtree.py	2011-06-28 11:29:03 +0000
+++ bzrlib/plugins/weave_fmt/workingtree.py	2011-08-30 17:32:29 +0000
@@ -30,9 +30,11 @@
 from bzrlib.decorators import needs_read_lock
 from bzrlib.transport.local import LocalTransport
 from bzrlib.workingtree import (
-    InventoryWorkingTree,
     WorkingTreeFormat,
     )
+from bzrlib.workingtree_3 import (
+    PreDirStateWorkingTree,
+    )
 
 
 def get_conflicted_stem(path):
@@ -135,7 +137,7 @@
         return wt
 
 
-class WorkingTree2(InventoryWorkingTree):
+class WorkingTree2(PreDirStateWorkingTree):
     """This is the Format 2 working tree.
 
     This was the first weave based working tree.
@@ -143,8 +145,8 @@
      - uses the branch last-revision.
     """
 
-    def __init__(self, *args, **kwargs):
-        super(WorkingTree2, self).__init__(*args, **kwargs)
+    def __init__(self, basedir, *args, **kwargs):
+        super(WorkingTree2, self).__init__(basedir, *args, **kwargs)
         # WorkingTree2 has more of a constraint that self._inventory must
         # exist. Because this is an older format, we don't mind the overhead
         # caused by the extra computation here.
@@ -158,6 +160,7 @@
         """Return the references needed to perform a check of this tree."""
         return [('trees', self.last_revision())]
 
+
     def lock_tree_write(self):
         """See WorkingTree.lock_tree_write().
 

=== modified file 'bzrlib/remote.py'
--- bzrlib/remote.py	2011-08-26 11:35:50 +0000
+++ bzrlib/remote.py	2011-09-06 11:01:30 +0000
@@ -1509,12 +1509,13 @@
         # We need to accumulate additional repositories here, to pass them in
         # on various RPC's.
         #
+        # Make the check before we lock: this raises an exception.
+        self._check_fallback_repository(repository)
         if self.is_locked():
             # We will call fallback.unlock() when we transition to the unlocked
             # state, so always add a lock here. If a caller passes us a locked
             # repository, they are responsible for unlocking it later.
             repository.lock_read()
-        self._check_fallback_repository(repository)
         self._fallback_repositories.append(repository)
         # If self._real_repository was parameterised already (e.g. because a
         # _real_branch had its get_stacked_on_url method called), then the

=== modified file 'bzrlib/revisiontree.py'
--- bzrlib/revisiontree.py	2011-06-16 11:58:04 +0000
+++ bzrlib/revisiontree.py	2011-08-29 19:06:57 +0000
@@ -36,6 +36,10 @@
         self._revision_id = revision_id
         self._rules_searcher = None
 
+    def has_versioned_directories(self):
+        """See `Tree.has_versioned_directories`."""
+        return self._repository._format.supports_versioned_directories
+
     def supports_tree_reference(self):
         return getattr(self._repository._format, "supports_tree_reference",
             False)

=== modified file 'bzrlib/smart/repository.py'
--- bzrlib/smart/repository.py	2010-11-26 06:31:54 +0000
+++ bzrlib/smart/repository.py	2011-09-02 23:13:18 +0000
@@ -238,7 +238,7 @@
                 next_revs = set()
                 break
             # don't query things we've already queried
-            next_revs.difference_update(queried_revs)
+            next_revs = next_revs.difference(queried_revs)
             first_loop_done = True
 
         # sorting trivially puts lexographically similar revision ids together.

=== modified file 'bzrlib/tag.py'
--- bzrlib/tag.py	2011-05-18 16:42:48 +0000
+++ bzrlib/tag.py	2011-09-05 14:16:12 +0000
@@ -47,6 +47,63 @@
     def __init__(self, branch):
         self.branch = branch
 
+    def get_tag_dict(self):
+        """Return a dictionary mapping tags to revision ids.
+        """
+        raise NotImplementedError(self.get_tag_dict)
+
+    def get_reverse_tag_dict(self):
+        """Return a dictionary mapping revision ids to list of tags.
+        """
+        raise NotImplementedError(self.get_reverse_tag_dict)
+
+    def merge_to(self, to_tags, overwrite=False, ignore_master=False):
+        """Merge new tags from this tags container into another.
+
+        :param to_tags: Tags container to merge into
+        :param overwrite: Whether to overwrite existing, divergent, tags.
+        :param ignore_master: Do not modify the tags in the target's master
+            branch (if any).  Default is false (so the master will be updated).
+            New in bzr 2.3.
+        :return: Tuple with tag updates as dictionary and tag conflicts
+        """
+        raise NotImplementedError(self.merge_to)
+
+    def set_tag(self, tag_name, revision):
+        """Set a tag.
+
+        :param tag_name: Tag name
+        :param revision: Revision id
+        :raise GhostTagsNotSupported: if revision is not present in
+            the branch repository
+        """
+        raise NotImplementedError(self.set_tag)
+
+    def lookup_tag(self, tag_name):
+        """Look up a tag.
+
+        :param tag_name: Tag to look up
+        :raise NoSuchTag: Raised when tag does not exist
+        :return: Matching revision id
+        """
+        raise NotImplementedError(self.lookup_tag)
+
+    def delete_tag(self, tag_name):
+        """Delete a tag.
+
+        :param tag_name: Tag to delete
+        :raise NoSuchTag: Raised when tag does not exist
+        """
+        raise NotImplementedError(self.delete_tag)
+
+    def rename_revisions(self, rename_map):
+        """Replace revision ids according to a rename map.
+
+        :param rename_map: Dictionary mapping old revision ids to
+            new revision ids.
+        """
+        raise NotImplementedError(self.rename_revisions)
+
     def has_tag(self, tag_name):
         return self.get_tag_dict().has_key(tag_name)
 
@@ -68,7 +125,7 @@
 
     def merge_to(self, to_tags, overwrite=False, ignore_master=False):
         # we never have anything to copy
-        pass
+        return {}, []
 
     def rename_revisions(self, rename_map):
         # No tags, so nothing to rename
@@ -201,7 +258,10 @@
             branch (if any).  Default is false (so the master will be updated).
             New in bzr 2.3.
 
-        :returns: A set of tags that conflicted, each of which is
+        :returns: Tuple with tag_updates and tag_conflicts.
+            tag_updates is a dictionary with new tags, None is used for
+            removed tags
+            tag_conflicts is a set of tags that conflicted, each of which is
             (tagname, source_target, dest_target), or None if no copying was
             done.
         """
@@ -211,15 +271,15 @@
     def _merge_to_operation(self, operation, to_tags, overwrite, ignore_master):
         add_cleanup = operation.add_cleanup
         if self.branch == to_tags.branch:
-            return
+            return {}, []
         if not self.branch.supports_tags():
             # obviously nothing to copy
-            return
+            return {}, []
         source_dict = self.get_tag_dict()
         if not source_dict:
             # no tags in the source, and we don't want to clobber anything
             # that's in the destination
-            return
+            return {}, []
         # We merge_to both master and child individually.
         #
         # It's possible for master and child to have differing sets of
@@ -239,25 +299,27 @@
             master = to_tags.branch.get_master_branch()
         if master is not None:
             add_cleanup(master.lock_write().unlock)
-        conflicts = self._merge_to(to_tags, source_dict, overwrite)
+        updates, conflicts = self._merge_to(to_tags, source_dict, overwrite)
         if master is not None:
-            conflicts += self._merge_to(master.tags, source_dict,
-                overwrite)
+            extra_updates, extra_conflicts = self._merge_to(master.tags,
+                source_dict, overwrite)
+            updates.update(extra_updates)
+            conflicts += extra_conflicts
         # We use set() to remove any duplicate conflicts from the master
         # branch.
-        return set(conflicts)
+        return updates, set(conflicts)
 
     def _merge_to(self, to_tags, source_dict, overwrite):
         dest_dict = to_tags.get_tag_dict()
-        result, conflicts = self._reconcile_tags(source_dict, dest_dict,
-                                                 overwrite)
+        result, updates, conflicts = self._reconcile_tags(source_dict,
+            dest_dict, overwrite)
         if result != dest_dict:
             to_tags._set_tag_dict(result)
-        return conflicts
+        return updates, conflicts
 
     def rename_revisions(self, rename_map):
         """Rename revisions in this tags dictionary.
-        
+
         :param rename_map: Dictionary mapping old revids to new revids
         """
         reverse_tags = self.get_reverse_tag_dict()
@@ -275,19 +337,21 @@
         * different definitions => if overwrite is False, keep destination
           value and give a warning, otherwise use the source value
 
-        :returns: (result_dict,
+        :returns: (result_dict, updates,
             [(conflicting_tag, source_target, dest_target)])
         """
         conflicts = []
+        updates = {}
         result = dict(dest_dict) # copy
         for name, target in source_dict.items():
             if name not in result or overwrite:
                 result[name] = target
+                updates[name] = target
             elif result[name] == target:
                 pass
             else:
                 conflicts.append((name, target, result[name]))
-        return result, conflicts
+        return result, updates, conflicts
 
 
 def _merge_tags_if_possible(from_branch, to_branch, ignore_master=False):

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2011-08-20 22:42:34 +0000
+++ bzrlib/tests/__init__.py	2011-09-06 11:01:30 +0000
@@ -2561,7 +2561,16 @@
         real branch.
         """
         root = TestCaseWithMemoryTransport.TEST_ROOT
-        wt = bzrdir.BzrDir.create_standalone_workingtree(root)
+        try:
+            # Make sure we get a readable and accessible home for .bzr.log
+            # and/or config files, and not fallback to weird defaults (see
+            # http://pad.lv/825027).
+            self.assertIs(None, os.environ.get('BZR_HOME', None))
+            os.environ['BZR_HOME'] = root
+            wt = bzrdir.BzrDir.create_standalone_workingtree(root)
+            del os.environ['BZR_HOME']
+        except Exception, e:
+            self.fail("Fail to initialize the safety net: %r\nExiting\n" % (e,))
         # Hack for speed: remember the raw bytes of the dirstate file so that
         # we don't need to re-open the wt to check it hasn't changed.
         TestCaseWithMemoryTransport._SAFETY_NET_PRISTINE_DIRSTATE = (

=== modified file 'bzrlib/tests/blackbox/test_commit.py'
--- bzrlib/tests/blackbox/test_commit.py	2011-08-17 10:56:42 +0000
+++ bzrlib/tests/blackbox/test_commit.py	2011-09-02 07:38:52 +0000
@@ -596,6 +596,25 @@
             'commit -m add-b --fixes=xxx:123',
             working_dir='tree')
 
+    def test_fixes_bug_with_default_tracker(self):
+        """commit --fixes=234 uses the default bug tracker."""
+        tree = self.make_branch_and_tree('tree')
+        self.build_tree(['tree/hello.txt'])
+        tree.add('hello.txt')
+        self.run_bzr_error(
+            ["bzr: ERROR: No tracker specified for bug 123. Use the form "
+            "'tracker:id' or specify a default bug tracker using the "
+            "`bugtracker` option.\n"
+            "See \"bzr help bugs\" for more information on this feature. "
+            "Commit refused."],
+            'commit -m add-b --fixes=123',
+            working_dir='tree')
+        tree.branch.get_config().set_user_option("bugtracker", "lp")
+        self.run_bzr('commit -m hello --fixes=234 tree/hello.txt')
+        last_rev = tree.branch.repository.get_revision(tree.last_revision())
+        self.assertEqual('https://launchpad.net/bugs/234 fixed',
+                         last_rev.properties['bugs'])
+
     def test_fixes_invalid_bug_number(self):
         tree = self.make_branch_and_tree('tree')
         self.build_tree(['tree/hello.txt'])
@@ -613,10 +632,10 @@
         self.build_tree(['tree/hello.txt'])
         tree.add('hello.txt')
         self.run_bzr_error(
-            [r"Invalid bug orange. Must be in the form of 'tracker:id'\. "
-             r"See \"bzr help bugs\" for more information on this feature.\n"
-             r"Commit refused\."],
-            'commit -m add-b --fixes=orange',
+            [r"Invalid bug orange:apples:bananas. Must be in the form of "
+             r"'tracker:id'\. See \"bzr help bugs\" for more information on "
+             r"this feature.\nCommit refused\."],
+            'commit -m add-b --fixes=orange:apples:bananas',
             working_dir='tree')
 
     def test_no_author(self):

=== modified file 'bzrlib/tests/blackbox/test_non_ascii.py'
--- bzrlib/tests/blackbox/test_non_ascii.py	2011-08-04 00:17:53 +0000
+++ bzrlib/tests/blackbox/test_non_ascii.py	2011-09-02 00:53:06 +0000
@@ -267,7 +267,7 @@
 
         expected = osutils.pathjoin(osutils.getcwd(), dirname1)
         self.assertEqual(u'Using saved parent location: %s/\n'
-                'No revisions to pull.\n' % (expected,), txt)
+                'No revisions or tags to pull.\n' % (expected,), txt)
 
         self.build_tree_contents(
             [(osutils.pathjoin(dirname1, 'a'), 'and yet more\n')])

=== modified file 'bzrlib/tests/blackbox/test_pull.py'
--- bzrlib/tests/blackbox/test_pull.py	2011-08-10 14:02:04 +0000
+++ bzrlib/tests/blackbox/test_pull.py	2011-08-31 16:48:52 +0000
@@ -318,7 +318,7 @@
         # it is legal to attempt to pull an already-merged bundle
         out, err = self.run_bzr('pull ../bundle')
         self.assertEqual(err, '')
-        self.assertEqual(out, 'No revisions to pull.\n')
+        self.assertEqual(out, 'No revisions or tags to pull.\n')
 
     def test_pull_verbose_no_files(self):
         """Pull --verbose should not list modified files"""
@@ -384,6 +384,15 @@
         self.assertNotContainsRe(
             out, r'revno: 1\ncommitter: .*\nbranch nick: source')
 
+    def test_pull_smart_bound_branch(self):
+        self.setup_smart_server_with_call_log()
+        parent = self.make_branch_and_tree('parent')
+        parent.commit(message='first commit')
+        child = parent.bzrdir.sprout('child').open_workingtree()
+        child.commit(message='second commit')
+        checkout = parent.branch.create_checkout('checkout')
+        self.run_bzr(['pull', self.get_url('child')], working_dir='checkout')
+
     def test_pull_smart_stacked_streaming_acceptance(self):
         """'bzr pull -r 123' works on stacked, smart branches, even when the
         revision specified by the revno is only present in the fallback
@@ -524,3 +533,13 @@
         out = self.run_bzr(['pull','-d','to','from'],retcode=1)
         self.assertEqual(out,
             ('No revisions to pull.\nConflicting tags:\n    mytag\n', ''))
+
+    def test_pull_tag_notification(self):
+        """pulling tags with conflicts will change the exit code"""
+        # create a branch, see that --show-base fails
+        from_tree = self.make_branch_and_tree('from')
+        from_tree.branch.tags.set_tag("mytag", "somerevid")
+        to_tree = self.make_branch_and_tree('to')
+        out = self.run_bzr(['pull', '-d', 'to', 'from'])
+        self.assertEqual(out,
+            ('1 tag(s) updated.\n', ''))

=== modified file 'bzrlib/tests/blackbox/test_push.py'
--- bzrlib/tests/blackbox/test_push.py	2011-08-16 15:03:03 +0000
+++ bzrlib/tests/blackbox/test_push.py	2011-08-31 17:22:53 +0000
@@ -157,7 +157,9 @@
         self.run_bzr('push -d tree pushed-to')
         path = t.branch.get_push_location()
         out, err = self.run_bzr('push', working_dir="tree")
-        self.assertEqual('Using saved push location: %s\nNo new revisions to push.\n' % urlutils.local_path_from_url(path), err)
+        self.assertEqual('Using saved push location: %s\n'
+                         'No new revisions or tags to push.\n' %
+                         urlutils.local_path_from_url(path), err)
         out, err = self.run_bzr('push -q', working_dir="tree")
         self.assertEqual('', out)
         self.assertEqual('', err)

=== modified file 'bzrlib/tests/blackbox/test_tags.py'
--- bzrlib/tests/blackbox/test_tags.py	2011-06-10 15:06:41 +0000
+++ bzrlib/tests/blackbox/test_tags.py	2011-09-06 10:07:53 +0000
@@ -17,7 +17,6 @@
 """Tests for commands related to tags"""
 
 from bzrlib import (
-    branchbuilder,
     tag,
     transform,
     )
@@ -75,10 +74,25 @@
         # can also delete an existing tag
         out, err = self.run_bzr('tag --delete -d branch tag2')
         # cannot replace an existing tag normally
-        out, err = self.run_bzr('tag -d branch NEWTAG', retcode=3)
+        out, err = self.run_bzr('tag -d branch NEWTAG -r0', retcode=3)
         self.assertContainsRe(err, 'Tag NEWTAG already exists\\.')
         # ... but can if you use --force
-        out, err = self.run_bzr('tag -d branch NEWTAG --force')
+        out, err = self.run_bzr('tag -d branch NEWTAG --force -r0')
+        self.assertEquals("Updated tag NEWTAG.\n", err)
+
+    def test_tag_same_revision(self):
+        t = self.make_branch_and_tree('branch')
+        t.commit(allow_pointless=True, message='initial commit',
+            rev_id='first-revid')
+        t.commit(allow_pointless=True, message='second commit',
+            rev_id='second-revid')
+        out, err = self.run_bzr('tag -rrevid:first-revid -d branch NEWTAG')
+        out, err = self.run_bzr('tag -rrevid:first-revid -d branch NEWTAG')
+        self.assertContainsRe(err,
+            'Tag NEWTAG already exists for that revision\\.')
+        out, err = self.run_bzr('tag -rrevid:second-revid -d branch NEWTAG',
+            retcode=3)
+        self.assertContainsRe(err, 'Tag NEWTAG already exists\\.')
 
     def test_tag_delete_requires_name(self):
         out, err = self.run_bzr('tag -d branch', retcode=3)

=== modified file 'bzrlib/tests/commands/test_pull.py'
--- bzrlib/tests/commands/test_pull.py	2010-04-09 03:58:14 +0000
+++ bzrlib/tests/commands/test_pull.py	2011-08-30 08:46:10 +0000
@@ -54,5 +54,5 @@
         # We don't care about the ouput but 'outf' should be defined
         pull.outf = tests.StringIOWrapper()
         pull.run(self.get_url('remote'), directory='local')
-        self.assertEquals(1, len(self.connections))
+        self.assertEquals(2, len(self.connections))
 

=== modified file 'bzrlib/tests/matchers.py'
--- bzrlib/tests/matchers.py	2011-08-16 13:26:27 +0000
+++ bzrlib/tests/matchers.py	2011-08-31 23:17:41 +0000
@@ -33,6 +33,7 @@
     ]
 
 from bzrlib import (
+    osutils,
     revision as _mod_revision,
     )
 
@@ -54,7 +55,7 @@
         self.lockable_thing = lockable_thing
 
     def __str__(self):
-        return ('ReturnsUnlockable(lockable_thing=%s)' % 
+        return ('ReturnsUnlockable(lockable_thing=%s)' %
             self.lockable_thing)
 
     def match(self, lock_method):
@@ -131,16 +132,46 @@
         """Get the (path, file_id) pairs for the current tree."""
         tree.lock_read()
         try:
-            return [(path, ie.file_id) for path, ie
-                    in tree.iter_entries_by_dir()]
+            for path, ie in tree.iter_entries_by_dir():
+                if ie.parent_id is None:
+                    yield (u"", ie.file_id)
+                else:
+                    yield (path+ie.kind_character(), ie.file_id)
         finally:
             tree.unlock()
 
+    @staticmethod
+    def _strip_unreferenced_directories(entries):
+        """Strip all directories that don't (in)directly contain any files.
+
+        :param entries: List of path strings or (path, ie) tuples to process
+        """
+        directories = []
+        for entry in entries:
+            if isinstance(entry, basestring):
+                path = entry
+            else:
+                path = entry[0]
+            if not path or path[-1] == "/":
+                # directory
+                directories.append((path, entry))
+            else:
+                # Yield the referenced parent directories
+                for dirpath, direntry in directories:
+                    if osutils.is_inside(dirpath, path):
+                        yield direntry
+                directories = []
+                yield entry
+
     def __str__(self):
-        return ('HasLayout(%r)' % self.entries)
+        return 'HasLayout(%r)' % self.entries
 
     def match(self, tree):
-        actual = self.get_tree_layout(tree)
+        actual = list(self.get_tree_layout(tree))
         if self.entries and isinstance(self.entries[0], basestring):
             actual = [path for (path, fileid) in actual]
-        return Equals(actual).match(self.entries)
+        if not tree.has_versioned_directories():
+            entries = list(self._strip_unreferenced_directories(self.entries))
+        else:
+            entries = self.entries
+        return Equals(entries).match(actual)

=== modified file 'bzrlib/tests/per_branch/test_branch.py'
--- bzrlib/tests/per_branch/test_branch.py	2011-07-23 16:33:38 +0000
+++ bzrlib/tests/per_branch/test_branch.py	2011-08-27 00:01:40 +0000
@@ -622,7 +622,9 @@
 class TestChildSubmitFormats(per_branch.TestCaseWithBranch):
 
     def test_get_child_submit_format_default(self):
-        self.assertEqual(None, self.get_branch().get_child_submit_format())
+        submit_format = self.get_branch().get_child_submit_format()
+        self.assertTrue(submit_format is None or
+                        isinstance(submit_format, str))
 
     def test_get_child_submit_format(self):
         branch = self.get_branch()

=== modified file 'bzrlib/tests/per_branch/test_create_checkout.py'
--- bzrlib/tests/per_branch/test_create_checkout.py	2011-05-13 12:51:05 +0000
+++ bzrlib/tests/per_branch/test_create_checkout.py	2011-08-27 00:00:54 +0000
@@ -16,9 +16,6 @@
 
 """Tests for the Branch.create_checkout"""
 
-from bzrlib import (
-    branch,
-    )
 from bzrlib.tests import per_branch
 
 

=== modified file 'bzrlib/tests/per_branch/test_pull.py'
--- bzrlib/tests/per_branch/test_pull.py	2011-08-09 14:18:05 +0000
+++ bzrlib/tests/per_branch/test_pull.py	2011-09-02 00:53:06 +0000
@@ -117,7 +117,7 @@
         self.assertEqual('P1', result.old_revid)
         self.assertEqual(2, result.new_revno)
         self.assertEqual('M1', result.new_revid)
-        self.assertEqual(None, result.tag_conflicts)
+        self.assertEqual([], result.tag_conflicts)
 
     def test_pull_overwrite(self):
         tree_a = self.make_branch_and_tree('tree_a')

=== modified file 'bzrlib/tests/per_branch/test_push.py'
--- bzrlib/tests/per_branch/test_push.py	2011-07-23 16:33:38 +0000
+++ bzrlib/tests/per_branch/test_push.py	2011-08-31 22:53:09 +0000
@@ -251,7 +251,7 @@
         self.addCleanup(repo.lock_read().unlock)
         # We should have pushed 'C', but not 'B', since it isn't in the
         # ancestry
-        self.assertEqual([('A',), ('C',)], sorted(repo.revisions.keys()))
+        self.assertEqual(['A', 'C'], sorted(repo.all_revision_ids()))
 
     def test_push_with_default_stacking_does_not_create_broken_branch(self):
         """Pushing a new standalone branch works even when there's a default

=== modified file 'bzrlib/tests/per_branch/test_tags.py'
--- bzrlib/tests/per_branch/test_tags.py	2010-11-18 00:43:57 +0000
+++ bzrlib/tests/per_branch/test_tags.py	2011-09-05 21:17:59 +0000
@@ -22,9 +22,8 @@
 
 from bzrlib import (
     branch,
-    bzrdir,
+    bzrdir as _mod_bzrdir,
     errors,
-    repository,
     tests,
     )
 from bzrlib.tests import per_branch
@@ -41,13 +40,22 @@
             raise tests.TestSkipped(
                 "format %s doesn't support tags" % branch._format)
 
+    def make_branch_with_revisions(self, relpath, revisions):
+        builder = self.make_branch_builder(relpath)
+        builder.start_series()
+        for revid in revisions:
+            builder.build_commit(rev_id=revid)
+        builder.finish_series()
+        return builder.get_branch()
+
     def test_tags_initially_empty(self):
         b = self.make_branch('b')
         tags = b.tags.get_tag_dict()
         self.assertEqual(tags, {})
 
     def test_make_and_lookup_tag(self):
-        b = self.make_branch('b')
+        b = self.make_branch_with_revisions('b',
+            ['target-revid-1', 'target-revid-2'])
         b.tags.set_tag('tag-name', 'target-revid-1')
         b.tags.set_tag('other-name', 'target-revid-2')
         # then reopen the branch and see they're still there
@@ -64,16 +72,26 @@
         self.assertFalse(b.tags.has_tag('imaginary'))
 
     def test_reverse_tag_dict(self):
-        b = self.make_branch('b')
+        b = self.make_branch_with_revisions('b',
+            ['target-revid-1', 'target-revid-2'])
         b.tags.set_tag('tag-name', 'target-revid-1')
         b.tags.set_tag('other-name', 'target-revid-2')
         # then reopen the branch and check reverse map id->tags list
         b = branch.Branch.open('b')
-        self.assertEqual(b.tags.get_reverse_tag_dict(),
+        self.assertEqual(dict(b.tags.get_reverse_tag_dict()),
             {'target-revid-1': ['tag-name'],
              'target-revid-2': ['other-name'],
             })
 
+    def test_ghost_tag(self):
+        b = self.make_branch('b')
+        if not b._format.supports_tags_referencing_ghosts():
+            self.assertRaises(errors.GhostTagsNotSupported,
+                b.tags.set_tag, "ghost", "idontexist")
+        else:
+            b.tags.set_tag("ghost", "idontexist")
+            self.assertEquals("idontexist", b.tags.lookup_tag("ghost"))
+
     def test_no_such_tag(self):
         b = self.make_branch('b')
         try:
@@ -85,8 +103,8 @@
             self.fail("didn't get expected exception")
 
     def test_merge_tags(self):
-        b1 = self.make_branch('b1')
-        b2 = self.make_branch('b2')
+        b1 = self.make_branch_with_revisions('b1', ['revid', 'revid-1'])
+        b2 = self.make_branch_with_revisions('b2', ['revid-2'])
         # if there are tags in the source and not the destination, then they
         # just go across
         b1.tags.set_tag('tagname', 'revid')
@@ -95,32 +113,34 @@
         # if a tag is in the destination and not in the source, it is not
         # removed when we merge them
         b2.tags.set_tag('in-destination', 'revid')
-        result = b1.tags.merge_to(b2.tags)
-        self.assertEquals(list(result), [])
+        updates, conflicts = b1.tags.merge_to(b2.tags)
+        self.assertEquals(list(conflicts), [])
+        self.assertEquals(updates, {})
         self.assertEquals(b2.tags.lookup_tag('in-destination'), 'revid')
         # if there's a conflicting tag, it's reported -- the command line
         # interface will say "these tags couldn't be copied"
         b1.tags.set_tag('conflicts', 'revid-1')
         b2.tags.set_tag('conflicts', 'revid-2')
-        result = b1.tags.merge_to(b2.tags)
-        self.assertEquals(list(result),
+        updates, conflicts = b1.tags.merge_to(b2.tags)
+        self.assertEquals(list(conflicts),
             [('conflicts', 'revid-1', 'revid-2')])
         # and it keeps the same value
+        self.assertEquals(updates, {})
         self.assertEquals(b2.tags.lookup_tag('conflicts'), 'revid-2')
 
     def test_unicode_tag(self):
-        b1 = self.make_branch('b')
         tag_name = u'\u3070'
         # in anticipation of the planned change to treating revision ids as
         # just 8bit strings
         revid = ('revid' + tag_name).encode('utf-8')
+        b1 = self.make_branch_with_revisions('b', [revid])
         b1.tags.set_tag(tag_name, revid)
         self.assertEquals(b1.tags.lookup_tag(tag_name), revid)
 
     def test_delete_tag(self):
-        b = self.make_branch('b')
         tag_name = u'\N{GREEK SMALL LETTER ALPHA}'
         revid = ('revid' + tag_name).encode('utf-8')
+        b = self.make_branch_with_revisions('b', [revid])
         b.tags.set_tag(tag_name, revid)
         # now try to delete it
         b.tags.delete_tag(tag_name)
@@ -147,9 +167,10 @@
         # Open the same branch twice.  Read-lock one, and then mutate the tags
         # in the second.  The read-locked branch never re-reads the tags, so it
         # never observes the changed/new tags.
-        b1 = self.make_branch('b')
+        b1 = self.make_branch_with_revisions('b',
+            ['rev-1', 'rev-1-changed', 'rev-2'])
         b1.tags.set_tag('one', 'rev-1')
-        b2 = b1.bzrdir.open_branch()
+        b2 = _mod_bzrdir.BzrDir.open('b').open_branch()
         b1.lock_read()
         self.assertEqual({'one': 'rev-1'}, b1.tags.get_tag_dict())
         # Add a tag and modify a tag in b2.  b1 is read-locked and has already
@@ -166,7 +187,8 @@
     def test_unlocked_does_not_cache_tags(self):
         """Unlocked branches do not cache tags."""
         # Open the same branch twice.
-        b1 = self.make_branch('b')
+        b1 = self.make_branch_with_revisions('b',
+            ['rev-1', 'rev-1-changed', 'rev-2'])
         b1.tags.set_tag('one', 'rev-1')
         b2 = b1.bzrdir.open_branch()
         self.assertEqual({'one': 'rev-1'}, b1.tags.get_tag_dict())
@@ -182,7 +204,8 @@
         returns a copy of the cached data so that callers cannot accidentally
         corrupt the cache.
         """
-        b = self.make_branch('b')
+        b = self.make_branch_with_revisions('b',
+            ['rev-1', 'rev-2', 'rev-3'])
         b.tags.set_tag('one', 'rev-1')
         self.addCleanup(b.lock_read().unlock)
         # The first time the data returned will not be in the cache
@@ -196,7 +219,7 @@
         self.assertEqual({'one': 'rev-1'}, b.tags.get_tag_dict())
 
     def make_write_locked_branch_with_one_tag(self):
-        b = self.make_branch('b')
+        b = self.make_branch_with_revisions('b', ['rev-1'])
         b.tags.set_tag('one', 'rev-1')
         self.addCleanup(b.lock_write().unlock)
         # Populate the cache
@@ -294,9 +317,10 @@
         child.bind(master)
         child.update()
         master.tags.set_tag('foo', 'rev-2')
-        tag_conflicts = other.tags.merge_to(child.tags, overwrite=True)
+        tag_updates, tag_conflicts = other.tags.merge_to(child.tags, overwrite=True)
         self.assertEquals('rev-1', child.tags.lookup_tag('foo'))
         self.assertEquals('rev-1', master.tags.lookup_tag('foo'))
+        self.assertEquals({"foo": "rev-1"}, tag_updates)
         self.assertLength(0, tag_conflicts)
 
     def test_merge_to_overwrite_conflict_in_child_and_master(self):
@@ -310,9 +334,11 @@
         child = self.make_branch('child')
         child.bind(master)
         child.update()
-        tag_conflicts = other.tags.merge_to(child.tags, overwrite=True)
+        tag_updates, tag_conflicts = other.tags.merge_to(
+            child.tags, overwrite=True)
         self.assertEquals('rev-1', child.tags.lookup_tag('foo'))
         self.assertEquals('rev-1', master.tags.lookup_tag('foo'))
+        self.assertEquals({u'foo': 'rev-1'}, tag_updates)
         self.assertLength(0, tag_conflicts)
 
     def test_merge_to_conflict_in_child_only(self):
@@ -327,13 +353,14 @@
         child.bind(master)
         child.update()
         master.tags.delete_tag('foo')
-        tag_conflicts = other.tags.merge_to(child.tags)
+        tag_updates, tag_conflicts = other.tags.merge_to(child.tags)
         # Conflict in child, so it is unchanged.
         self.assertEquals('rev-2', child.tags.lookup_tag('foo'))
         # No conflict in the master, so the 'foo' tag equals other's value here.
         self.assertEquals('rev-1', master.tags.lookup_tag('foo'))
         # The conflict is reported.
         self.assertEquals([(u'foo', 'rev-1', 'rev-2')], list(tag_conflicts))
+        self.assertEquals({u'foo': 'rev-1'}, tag_updates)
 
     def test_merge_to_conflict_in_master_only(self):
         """When new_tags.merge_to(child.tags) conflicts with the master but not
@@ -346,12 +373,13 @@
         child.bind(master)
         child.update()
         master.tags.set_tag('foo', 'rev-2')
-        tag_conflicts = other.tags.merge_to(child.tags)
+        tag_updates, tag_conflicts = other.tags.merge_to(child.tags)
         # No conflict in the child, so the 'foo' tag equals other's value here.
         self.assertEquals('rev-1', child.tags.lookup_tag('foo'))
         # Conflict in master, so it is unchanged.
         self.assertEquals('rev-2', master.tags.lookup_tag('foo'))
         # The conflict is reported.
+        self.assertEquals({u'foo': 'rev-1'}, tag_updates)
         self.assertEquals([(u'foo', 'rev-1', 'rev-2')], list(tag_conflicts))
 
     def test_merge_to_same_conflict_in_master_and_child(self):
@@ -365,12 +393,13 @@
         child = self.make_branch('child')
         child.bind(master)
         child.update()
-        tag_conflicts = other.tags.merge_to(child.tags)
+        tag_updates, tag_conflicts = other.tags.merge_to(child.tags)
         # Both master and child conflict, so both stay as rev-2
         self.assertEquals('rev-2', child.tags.lookup_tag('foo'))
         self.assertEquals('rev-2', master.tags.lookup_tag('foo'))
         # The conflict is reported exactly once, even though it occurs in both
         # master and child.
+        self.assertEquals({}, tag_updates)
         self.assertEquals([(u'foo', 'rev-1', 'rev-2')], list(tag_conflicts))
 
     def test_merge_to_different_conflict_in_master_and_child(self):
@@ -387,11 +416,12 @@
         # We use the private method _set_tag_dict because normally bzr tries to
         # avoid this scenario.
         child.tags._set_tag_dict({'foo': 'rev-3'})
-        tag_conflicts = other.tags.merge_to(child.tags)
+        tag_updates, tag_conflicts = other.tags.merge_to(child.tags)
         # Both master and child conflict, so both stay as they were.
         self.assertEquals('rev-3', child.tags.lookup_tag('foo'))
         self.assertEquals('rev-2', master.tags.lookup_tag('foo'))
         # Both conflicts are reported.
+        self.assertEquals({}, tag_updates)
         self.assertEquals(
             [(u'foo', 'rev-1', 'rev-2'), (u'foo', 'rev-1', 'rev-3')],
             sorted(tag_conflicts))
@@ -455,7 +485,7 @@
             get_tag_name, 'get tag name foo')
         self.assertEquals("foo", self.branch.automatic_tag_name(
             self.branch.last_revision()))
-    
+
     def test_uses_first_return(self):
         get_tag_name_1 = lambda br, revid: "foo1"
         get_tag_name_2 = lambda br, revid: "foo2"

=== modified file 'bzrlib/tests/per_interbranch/test_pull.py'
--- bzrlib/tests/per_interbranch/test_pull.py	2010-06-17 09:23:19 +0000
+++ bzrlib/tests/per_interbranch/test_pull.py	2011-09-02 00:53:06 +0000
@@ -99,7 +99,7 @@
         self.assertEqual('P1', result.old_revid)
         self.assertEqual(2, result.new_revno)
         self.assertEqual('M1', result.new_revid)
-        self.assertEqual(None, result.tag_conflicts)
+        self.assertEqual([], result.tag_conflicts)
 
     def test_pull_overwrite(self):
         tree_a = self.make_from_branch_and_tree('tree_a')

=== modified file 'bzrlib/tests/per_repository/test_commit_builder.py'
--- bzrlib/tests/per_repository/test_commit_builder.py	2011-08-16 12:59:04 +0000
+++ bzrlib/tests/per_repository/test_commit_builder.py	2011-08-31 22:53:32 +0000
@@ -218,7 +218,7 @@
         # on deserialisation, but thats all the current contract guarantees
         # anyway.
         self.assertEqual(revision_id,
-            tree.branch.repository.get_inventory(revision_id).revision_id)
+            tree.branch.repository.revision_tree(revision_id).get_revision_id())
 
     def test_commit_without_root_errors(self):
         tree = self.make_branch_and_tree(".")

=== modified file 'bzrlib/tests/per_repository/test_repository.py'
--- bzrlib/tests/per_repository/test_repository.py	2011-08-19 22:34:02 +0000
+++ bzrlib/tests/per_repository/test_repository.py	2011-08-31 22:52:58 +0000
@@ -347,7 +347,7 @@
             return
         try:
             made_repo.set_make_working_trees(False)
-        except NotImplementedError:
+        except errors.UnsupportedOperation:
             # the repository does not support having its tree-making flag
             # toggled.
             return
@@ -369,7 +369,7 @@
             repo.sign_revision('A', gpg.LoopbackGPGStrategy(None))
         except errors.UnsupportedOperation:
             self.assertFalse(repo._format.supports_revision_signatures)
-            raise TestNotApplicable("signatures not supported by repository format")
+            raise tests.TestNotApplicable("signatures not supported by repository format")
         repo.commit_write_group()
         repo.unlock()
         old_signature = repo.get_signature_text('A')
@@ -811,7 +811,7 @@
         repo = self.make_repository('repo')
         try:
             repo.set_make_working_trees(True)
-        except errors.RepositoryUpgradeRequired, e:
+        except (errors.RepositoryUpgradeRequired, errors.UnsupportedOperation), e:
             raise tests.TestNotApplicable('Format does not support this flag.')
         self.assertTrue(repo.make_working_trees())
 
@@ -819,7 +819,7 @@
         repo = self.make_repository('repo')
         try:
             repo.set_make_working_trees(False)
-        except errors.RepositoryUpgradeRequired, e:
+        except (errors.RepositoryUpgradeRequired, errors.UnsupportedOperation), e:
             raise tests.TestNotApplicable('Format does not support this flag.')
         self.assertFalse(repo.make_working_trees())
 

=== modified file 'bzrlib/tests/per_repository_reference/__init__.py'
--- bzrlib/tests/per_repository_reference/__init__.py	2011-05-04 03:43:03 +0000
+++ bzrlib/tests/per_repository_reference/__init__.py	2011-08-30 10:54:28 +0000
@@ -66,18 +66,37 @@
 
 class TestIncompatibleStacking(TestCaseWithRepository):
 
-    def test_add_fallback_repository_rejects_incompatible(self):
-        # Repository.add_fallback_repository raises IncompatibleRepositories if
-        # you take two repositories in different serializations and try to
-        # stack them.
-        if self.make_repository('test')._format.supports_chks:
+    def make_repo_and_incompatible_fallback(self):
+        referring = self.make_repository('referring')
+        if referring._format.supports_chks:
             different_fmt = '1.9'
         else:
             different_fmt = '2a'
-        repo = self.make_repository('repo', format=different_fmt)
-        referring = self.make_repository('referring')
-        self.assertRaises(errors.IncompatibleRepositories,
-                referring.add_fallback_repository, repo)
+        fallback = self.make_repository('fallback', format=different_fmt)
+        return referring, fallback
+
+    def test_add_fallback_repository_rejects_incompatible(self):
+        # Repository.add_fallback_repository raises IncompatibleRepositories
+        # if you take two repositories in different serializations and try to
+        # stack them.
+        referring, fallback = self.make_repo_and_incompatible_fallback()
+        self.assertRaises(errors.IncompatibleRepositories,
+                referring.add_fallback_repository, fallback)
+
+    def test_add_fallback_doesnt_leave_fallback_locked(self):
+        # Bug #835035. If the referring repository is locked, it wants to lock
+        # the fallback repository. But if they are incompatible, the referring
+        # repository won't take ownership of the fallback, and thus should not
+        # leave the repository in a locked state.
+        referring, fallback = self.make_repo_and_incompatible_fallback()
+        self.addCleanup(referring.lock_read().unlock)
+        # Assert precondition.
+        self.assertFalse(fallback.is_locked())
+        # Assert action.
+        self.assertRaises(errors.IncompatibleRepositories,
+                referring.add_fallback_repository, fallback)
+        # Assert postcondition.
+        self.assertFalse(fallback.is_locked())
 
 
 def external_reference_test_scenarios():

=== modified file 'bzrlib/tests/per_tree/test_tree.py'
--- bzrlib/tests/per_tree/test_tree.py	2011-08-05 13:34:40 +0000
+++ bzrlib/tests/per_tree/test_tree.py	2011-08-29 19:06:57 +0000
@@ -323,3 +323,11 @@
         if kind == "SHA1":
             expected = osutils.sha_strings('file content')
             self.assertEqual(expected, data)
+
+
+class TestHasVersionedDirectories(TestCaseWithTree):
+
+    def test_has_versioned_directories(self):
+        work_tree = self.make_branch_and_tree('tree')
+        tree = self._convert_tree(work_tree)
+        self.assertSubset([tree.has_versioned_directories()], (True, False))

=== modified file 'bzrlib/tests/per_workingtree/test_add.py'
--- bzrlib/tests/per_workingtree/test_add.py	2011-08-16 13:15:28 +0000
+++ bzrlib/tests/per_workingtree/test_add.py	2011-08-29 21:53:33 +0000
@@ -101,8 +101,8 @@
         tree.add(['dir/subdir/foo'], ['foo-id'])
         root_id = tree.get_root_id()
 
-        self.assertTreeLayout([('', root_id), ('dir', 'dir-id'),
-                               ('dir/subdir', 'subdir-id'),
+        self.assertTreeLayout([('', root_id), ('dir/', 'dir-id'),
+                               ('dir/subdir/', 'subdir-id'),
                                ('dir/subdir/foo', 'foo-id')], tree)
 
     def test_add_multiple(self):
@@ -113,7 +113,7 @@
         root_id = tree.get_root_id()
 
         self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
-                               ('dir', 'dir-id'), ('dir/subdir', 'subdir-id'),
+                               ('dir/', 'dir-id'), ('dir/subdir/', 'subdir-id'),
                                ('dir/subdir/foo', 'foo-id')], tree)
 
     def test_add_invalid(self):

=== modified file 'bzrlib/tests/per_workingtree/test_move.py'
--- bzrlib/tests/per_workingtree/test_move.py	2011-08-16 13:15:28 +0000
+++ bzrlib/tests/per_workingtree/test_move.py	2011-08-29 21:53:33 +0000
@@ -126,12 +126,12 @@
                           tree.move, ['d', 'c', 'b'], 'a')
         if osutils.lexists('a/c'):
             # If 'c' was actually moved, then 'd' should have also been moved
-            self.assertTreeLayout([('', root_id), ('a', 'a-id'),
+            self.assertTreeLayout([('', root_id), ('a/', 'a-id'),
                                    ('a/c', 'c-id'),  ('a/d', 'd-id')], tree)
         else:
-            self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('c', 'c-id'),
+            self.assertTreeLayout([('', root_id), ('a/', 'a-id'), ('c', 'c-id'),
                                    ('d', 'd-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('c', 'c-id'),
+        self.assertTreeLayout([('', root_id), ('a/', 'a-id'), ('c', 'c-id'),
                                ('d', 'd-id')], tree.basis_tree())
         tree._validate()
 
@@ -145,7 +145,7 @@
         tree.remove(['a/b'], keep_files=False)
         self.assertEqual([('b', 'a/b')], tree.move(['b'], 'a'))
         self.assertTreeLayout([('', root_id),
-                               ('a', 'a-id'),
+                               ('a/', 'a-id'),
                                ('a/b', 'b-id'),
                               ], tree)
         tree._validate()
@@ -156,16 +156,16 @@
         tree.add(['a', 'b', 'b/c'], ['a-id', 'b-id', 'c-id'])
         tree.commit('initial', rev_id='rev-1')
         root_id = tree.get_root_id()
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id'),
                                ('b/c', 'c-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id'),
                                ('b/c', 'c-id')], tree.basis_tree())
         a_contents = tree.get_file_text('a-id')
         self.assertEqual([('a', 'b/a')],
             tree.move(['a'], 'b'))
-        self.assertTreeLayout([('', root_id), ('b', 'b-id'), ('b/a', 'a-id'),
+        self.assertTreeLayout([('', root_id), ('b/', 'b-id'), ('b/a', 'a-id'),
                                ('b/c', 'c-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id'),
                                ('b/c', 'c-id')], tree.basis_tree())
         self.assertPathDoesNotExist('a')
         self.assertFileEqual(a_contents, 'b/a')
@@ -180,9 +180,9 @@
         c_contents = tree.get_file_text('c-id')
         self.assertEqual([('b/c', 'c')],
             tree.move(['b/c'], ''))
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id'),
                                ('c', 'c-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id'),
                                ('b/c', 'c-id')], tree.basis_tree())
         self.assertPathDoesNotExist('b/c')
         self.assertFileEqual(c_contents, 'c')
@@ -200,13 +200,13 @@
         # 'c' may or may not have been moved, but either way the tree should
         # maintain a consistent state.
         if osutils.lexists('c'):
-            self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
+            self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id'),
                                    ('c', 'c-id')], tree)
         else:
             self.assertPathExists('b/c')
-            self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
+            self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id'),
                                    ('b/c', 'c-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id'),
                                ('c', 'c-id')], tree.basis_tree())
         tree._validate()
 
@@ -238,15 +238,15 @@
         root_id = tree.get_root_id()
         os.rename('a', 'b/a')
 
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree)
         # We don't need after=True as long as source is missing and target
         # exists.
         self.assertEqual([('a', 'b/a')],
             tree.move(['a'], 'b'))
-        self.assertTreeLayout([('', root_id), ('b', 'b-id'), ('b/a', 'a-id')],
+        self.assertTreeLayout([('', root_id), ('b/', 'b-id'), ('b/a', 'a-id')],
                               tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree.basis_tree())
         tree._validate()
 
@@ -258,14 +258,14 @@
         root_id = tree.get_root_id()
         os.rename('a', 'b/a')
 
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree)
         # Passing after=True should work as well
         self.assertEqual([('a', 'b/a')],
             tree.move(['a'], 'b', after=True))
-        self.assertTreeLayout([('', root_id), ('b', 'b-id'), ('b/a', 'a-id')],
+        self.assertTreeLayout([('', root_id), ('b/', 'b-id'), ('b/a', 'a-id')],
                               tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree.basis_tree())
         tree._validate()
 
@@ -279,7 +279,7 @@
         # Passing after when the file hasn't been move raises an exception
         self.assertRaises(errors.BzrMoveFailedError,
                           tree.move, ['a'], 'b', after=True)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree.basis_tree())
         tree._validate()
 
@@ -303,20 +303,20 @@
         finally:
             ba_file.close()
 
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree)
         self.assertRaises(errors.RenameFailedFilesExist,
                           tree.move, ['a'], 'b', after=False)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree)
         self.assertFileEqual(a_text, 'a')
         self.assertFileEqual(ba_text, 'b/a')
         # But you can pass after=True
         self.assertEqual([('a', 'b/a')],
             tree.move(['a'], 'b', after=True))
-        self.assertTreeLayout([('', root_id), ('b', 'b-id'), ('b/a', 'a-id')],
+        self.assertTreeLayout([('', root_id), ('b/', 'b-id'), ('b/a', 'a-id')],
                               tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree.basis_tree())
         # But it shouldn't actually move anything
         self.assertFileEqual(a_text, 'a')
@@ -333,11 +333,11 @@
 
         self.assertEqual([('a', 'e/a')],
             tree.move(['a'], 'e'))
-        self.assertTreeLayout([('', root_id), ('e', 'e-id'), ('e/a', 'a-id'),
-                               ('e/a/b', 'b-id'), ('e/a/c', 'c-id'),
+        self.assertTreeLayout([('', root_id), ('e/', 'e-id'), ('e/a/', 'a-id'),
+                               ('e/a/b', 'b-id'), ('e/a/c/', 'c-id'),
                                ('e/a/c/d', 'd-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('e', 'e-id'),
-                               ('a/b', 'b-id'), ('a/c', 'c-id'),
+        self.assertTreeLayout([('', root_id), ('a/', 'a-id'), ('e/', 'e-id'),
+                               ('a/b', 'b-id'), ('a/c/', 'c-id'),
                                ('a/c/d', 'd-id')], tree.basis_tree())
         tree._validate()
 
@@ -355,9 +355,9 @@
         self.assertEqual([('c/b', 'b')],
                          tree.move(['c/b'], ''))
         self.assertTreeLayout([('', root_id),
-                               ('b', 'b-id'),
-                               ('c', 'c-id'),
-                               ('b/d', 'd-id'),
+                               ('b/', 'b-id'),
+                               ('c/', 'c-id'),
+                               ('b/d/', 'd-id'),
                               ], tree)
         tree._validate()
 
@@ -370,25 +370,18 @@
         root_id = tree.get_root_id()
 
         tree.rename_one('a/b', 'a/c/b')
-        if self.workingtree_format.supports_versioned_directories:
-            self.assertTreeLayout([('', root_id),
-                                   ('a', 'a-id'),
-                                   ('d', 'd-id'),
-                                   ('a/c', 'c-id'),
-                                   ('a/c/b', 'b-id'),
-                                  ], tree)
-        else:
-            self.assertTreeLayout([('', root_id),
-                                   ('a', 'a-id'),
-                                   ('a/c', 'c-id'),
-                                   ('a/c/b', 'b-id'),
-                                  ], tree)
+        self.assertTreeLayout([('', root_id),
+                               ('a/', 'a-id'),
+                               ('d/', 'd-id'),
+                               ('a/c/', 'c-id'),
+                               ('a/c/b', 'b-id'),
+                              ], tree)
         self.assertEqual([('a', 'd/a')],
                          tree.move(['a'], 'd'))
         self.assertTreeLayout([('', root_id),
-                               ('d', 'd-id'),
-                               ('d/a', 'a-id'),
-                               ('d/a/c', 'c-id'),
+                               ('d/', 'd-id'),
+                               ('d/a/', 'a-id'),
+                               ('d/a/c/', 'c-id'),
                                ('d/a/c/b', 'b-id'),
                               ], tree)
         tree._validate()
@@ -406,8 +399,8 @@
         self.assertEqual([('a', 'b/a')],
                          tree.move(['a'], 'b'))
         self.assertTreeLayout([('', root_id),
-                               ('b', 'b-id'),
-                               ('b/a', 'a-id'),
+                               ('b/', 'b-id'),
+                               ('b/a/', 'a-id'),
                                ('b/a/c', 'ac-id'),
                               ], tree)
         tree._validate()
@@ -425,8 +418,8 @@
         self.assertEqual([('a', 'b/a')],
                          tree.move(['a'], 'b'))
         self.assertTreeLayout([('', root_id),
-                               ('b', 'b-id'),
-                               ('b/a', 'a-id'),
+                               ('b/', 'b-id'),
+                               ('b/a/', 'a-id'),
                                ('b/a/b', 'ab-id'),
                                ('b/a/c', 'ac-id'),
                                ('b/a/d', 'ad-id'),
@@ -444,18 +437,18 @@
         self.assertEqual([('a/b', 'b')],
                          tree.move(['a/b'], ''))
         self.assertTreeLayout([('', root_id),
-                               ('a', 'a-id'),
+                               ('a/', 'a-id'),
                                ('b', 'b-id'),
                                ('d', 'd-id'),
-                               ('e', 'e-id'),
+                               ('e/', 'e-id'),
                                ('a/c', 'c-id'),
                               ], tree)
         self.assertEqual([('d', 'a/d')],
                          tree.move(['d'], 'a'))
         self.assertTreeLayout([('', root_id),
-                               ('a', 'a-id'),
+                               ('a/', 'a-id'),
                                ('b', 'b-id'),
-                               ('e', 'e-id'),
+                               ('e/', 'e-id'),
                                ('a/c', 'c-id'),
                                ('a/d', 'd-id'),
                               ], tree)
@@ -463,8 +456,8 @@
                          tree.move(['a'], 'e'))
         self.assertTreeLayout([('', root_id),
                                ('b', 'b-id'),
-                               ('e', 'e-id'),
-                               ('e/a', 'a-id'),
+                               ('e/', 'e-id'),
+                               ('e/a/', 'a-id'),
                                ('e/a/c', 'c-id'),
                                ('e/a/d', 'd-id'),
                               ], tree)
@@ -480,16 +473,16 @@
 
         tree.rename_one('a/b', 'a/d')
         self.assertTreeLayout([('', root_id),
-                               ('a', 'a-id'),
-                               ('d', 'd-id'),
+                               ('a/', 'a-id'),
+                               ('d/', 'd-id'),
                                ('a/c', 'c-id'),
                                ('a/d', 'b-id'),
                               ], tree)
         self.assertEqual([('a', 'd/a')],
                          tree.move(['a'], 'd'))
         self.assertTreeLayout([('', root_id),
-                               ('d', 'd-id'),
-                               ('d/a', 'a-id'),
+                               ('d/', 'd-id'),
+                               ('d/a/', 'a-id'),
                                ('d/a/c', 'c-id'),
                                ('d/a/d', 'b-id'),
                               ], tree)
@@ -507,8 +500,8 @@
         tree.rename_one('a/d', 'a/b')
         tree.rename_one('a/bb', 'a/d')
         self.assertTreeLayout([('', root_id),
-                               ('a', 'a-id'),
-                               ('e', 'e-id'),
+                               ('a/', 'a-id'),
+                               ('e/', 'e-id'),
                                ('a/b', 'd-id'),
                                ('a/c', 'c-id'),
                                ('a/d', 'b-id'),
@@ -516,8 +509,8 @@
         self.assertEqual([('a', 'e/a')],
                          tree.move(['a'], 'e'))
         self.assertTreeLayout([('', root_id),
-                               ('e', 'e-id'),
-                               ('e/a', 'a-id'),
+                               ('e/', 'e-id'),
+                               ('e/a/', 'a-id'),
                                ('e/a/b', 'd-id'),
                                ('e/a/c', 'c-id'),
                                ('e/a/d', 'b-id'),
@@ -534,16 +527,16 @@
 
         self.assertEqual([('a/b', 'c/b')],
             tree.move(['a/b'], 'c'))
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('c', 'c-id'),
+        self.assertTreeLayout([('', root_id), ('a/', 'a-id'), ('c/', 'c-id'),
                                ('c/b', 'b-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('c', 'c-id'),
+        self.assertTreeLayout([('', root_id), ('a/', 'a-id'), ('c/', 'c-id'),
                                ('a/b', 'b-id')], tree.basis_tree())
 
         self.assertEqual([('c/b', 'b')],
             tree.move(['c/b'], ''))
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
-                               ('c', 'c-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('c', 'c-id'),
+        self.assertTreeLayout([('', root_id), ('a/', 'a-id'), ('b', 'b-id'),
+                               ('c/', 'c-id')], tree)
+        self.assertTreeLayout([('', root_id), ('a/', 'a-id'), ('c/', 'c-id'),
                                ('a/b', 'b-id')], tree.basis_tree())
         tree._validate()
 

=== modified file 'bzrlib/tests/per_workingtree/test_readonly.py'
--- bzrlib/tests/per_workingtree/test_readonly.py	2011-05-08 13:07:11 +0000
+++ bzrlib/tests/per_workingtree/test_readonly.py	2011-08-31 22:52:43 +0000
@@ -26,6 +26,8 @@
     )
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
 
+from bzrlib.workingtree import InventoryWorkingTree
+
 
 class TestReadonly(TestCaseWithWorkingTree):
 
@@ -77,6 +79,8 @@
         """Even if the tree is unclean, we should still handle readonly dirs."""
         # First create a tree
         tree = self.create_basic_tree()
+        if not isinstance(tree, InventoryWorkingTree):
+            raise tests.TestNotApplicable("requires inventory working tree")
 
         # XXX: *Ugly* *ugly* hack, we need the hashcache to think it is out of
         # date, but we don't want to actually wait 3 seconds doing nothing.

=== modified file 'bzrlib/tests/per_workingtree/test_rename_one.py'
--- bzrlib/tests/per_workingtree/test_rename_one.py	2011-08-16 13:15:28 +0000
+++ bzrlib/tests/per_workingtree/test_rename_one.py	2011-08-29 21:53:33 +0000
@@ -81,9 +81,9 @@
 
         a_contents = tree.get_file_text('a-id')
         tree.rename_one('a', 'foo')
-        self.assertTreeLayout([('', root_id), ('b', 'b-id'), ('foo', 'a-id')],
+        self.assertTreeLayout([('', root_id), ('b/', 'b-id'), ('foo', 'a-id')],
                               tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree.basis_tree())
         self.assertPathDoesNotExist('a')
         self.assertFileEqual(a_contents, 'foo')
@@ -97,9 +97,9 @@
 
         a_contents = tree.get_file_text('a-id')
         tree.rename_one('a', 'b/foo')
-        self.assertTreeLayout([('', root_id), ('b', 'b-id'), ('b/foo', 'a-id')],
+        self.assertTreeLayout([('', root_id), ('b/', 'b-id'), ('b/foo', 'a-id')],
                               tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree.basis_tree())
         self.assertPathDoesNotExist('tree/a')
         self.assertFileEqual(a_contents, 'tree/b/foo')
@@ -110,15 +110,15 @@
         tree.add(['a', 'b', 'b/c'], ['a-id', 'b-id', 'c-id'])
         tree.commit('initial', rev_id='rev-1')
         root_id = tree.get_root_id()
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id'),
                                ('b/c', 'c-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id'),
                                ('b/c', 'c-id')], tree.basis_tree())
         a_contents = tree.get_file_text('a-id')
         tree.rename_one('a', 'b/d')
-        self.assertTreeLayout([('', root_id), ('b', 'b-id'), ('b/c', 'c-id'),
+        self.assertTreeLayout([('', root_id), ('b/', 'b-id'), ('b/c', 'c-id'),
                                ('b/d', 'a-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id'),
                                ('b/c', 'c-id')], tree.basis_tree())
         self.assertPathDoesNotExist('a')
         self.assertFileEqual(a_contents, 'b/d')
@@ -131,9 +131,9 @@
         root_id = tree.get_root_id()
         c_contents = tree.get_file_text('c-id')
         tree.rename_one('b/c', 'd')
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id'),
                                ('d', 'c-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id'),
                                ('b/c', 'c-id')], tree.basis_tree())
         self.assertPathDoesNotExist('b/c')
         self.assertFileEqual(c_contents, 'd')
@@ -147,9 +147,9 @@
         # Target already exists
         self.assertRaises(errors.RenameFailedFilesExist,
                           tree.rename_one, 'a', 'b/a')
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id'),
                                ('c', 'c-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id'),
                                ('c', 'c-id')], tree.basis_tree())
 
     def test_rename_one_onto_existing(self):
@@ -187,14 +187,14 @@
         root_id = tree.get_root_id()
         os.rename('a', 'b/foo')
 
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree)
         # We don't need after=True as long as source is missing and target
         # exists.
         tree.rename_one('a', 'b/foo')
-        self.assertTreeLayout([('', root_id), ('b', 'b-id'),
+        self.assertTreeLayout([('', root_id), ('b/', 'b-id'),
                                ('b/foo', 'a-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree.basis_tree())
 
     def test_rename_one_after_with_after(self):
@@ -205,13 +205,13 @@
         root_id = tree.get_root_id()
         os.rename('a', 'b/foo')
 
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree)
         # Passing after=True should work as well
         tree.rename_one('a', 'b/foo', after=True)
-        self.assertTreeLayout([('', root_id), ('b', 'b-id'),
+        self.assertTreeLayout([('', root_id), ('b/', 'b-id'),
                                ('b/foo', 'a-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree.basis_tree())
 
     def test_rename_one_after_dest_versioned(self):
@@ -269,13 +269,13 @@
         os.rename('a', 'b/foo')
         tree.remove(['a'])
 
-        self.assertTreeLayout([('', root_id), ('b', 'b-id')], tree)
+        self.assertTreeLayout([('', root_id), ('b/', 'b-id')], tree)
         # We don't need after=True as long as source is missing and target
         # exists.
         tree.rename_one('a', 'b/foo')
-        self.assertTreeLayout([('', root_id), ('b', 'b-id'),
+        self.assertTreeLayout([('', root_id), ('b/', 'b-id'),
                                ('b/foo', 'a-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree.basis_tree())
 
     def test_rename_one_after_no_target(self):
@@ -288,9 +288,9 @@
         # Passing after when the file hasn't been rename_one raises an exception
         self.assertRaises(errors.BzrMoveFailedError,
                           tree.rename_one, 'a', 'b/foo', after=True)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree.basis_tree())
 
     def test_rename_one_after_source_and_dest(self):
@@ -313,19 +313,19 @@
         finally:
             foo_file.close()
 
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree)
         self.assertRaises(errors.RenameFailedFilesExist,
                           tree.rename_one, 'a', 'b/foo', after=False)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree)
         self.assertFileEqual(a_text, 'a')
         self.assertFileEqual(foo_text, 'b/foo')
         # But you can pass after=True
         tree.rename_one('a', 'b/foo', after=True)
-        self.assertTreeLayout([('', root_id), ('b', 'b-id'),
+        self.assertTreeLayout([('', root_id), ('b/', 'b-id'),
                                ('b/foo', 'a-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
+        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b/', 'b-id')],
                               tree.basis_tree())
         # But it shouldn't actually move anything
         self.assertFileEqual(a_text, 'a')
@@ -340,11 +340,11 @@
         root_id = tree.get_root_id()
 
         tree.rename_one('a', 'e/f')
-        self.assertTreeLayout([('', root_id), ('e', 'e-id'), ('e/f', 'a-id'),
-                               ('e/f/b', 'b-id'), ('e/f/c', 'c-id'),
+        self.assertTreeLayout([('', root_id), ('e/', 'e-id'), ('e/f/', 'a-id'),
+                               ('e/f/b', 'b-id'), ('e/f/c/', 'c-id'),
                                ('e/f/c/d', 'd-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('e', 'e-id'),
-                               ('a/b', 'b-id'), ('a/c', 'c-id'),
+        self.assertTreeLayout([('', root_id), ('a/', 'a-id'), ('e/', 'e-id'),
+                               ('a/b', 'b-id'), ('a/c/', 'c-id'),
                                ('a/c/d', 'd-id')], tree.basis_tree())
 
     def test_rename_one_moved(self):
@@ -356,15 +356,15 @@
         root_id = tree.get_root_id()
 
         tree.rename_one('a/b', 'c/foo')
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('c', 'c-id'),
+        self.assertTreeLayout([('', root_id), ('a/', 'a-id'), ('c/', 'c-id'),
                                ('c/foo', 'b-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('c', 'c-id'),
+        self.assertTreeLayout([('', root_id), ('a/', 'a-id'), ('c/', 'c-id'),
                                ('a/b', 'b-id')], tree.basis_tree())
 
         tree.rename_one('c/foo', 'bar')
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('bar', 'b-id'),
-                               ('c', 'c-id')], tree)
-        self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('c', 'c-id'),
+        self.assertTreeLayout([('', root_id), ('a/', 'a-id'), ('bar', 'b-id'),
+                               ('c/', 'c-id')], tree)
+        self.assertTreeLayout([('', root_id), ('a/', 'a-id'), ('c/', 'c-id'),
                                ('a/b', 'b-id')], tree.basis_tree())
 
     def test_rename_to_denormalised_fails(self):

=== modified file 'bzrlib/tests/per_workingtree/test_workingtree.py'
--- bzrlib/tests/per_workingtree/test_workingtree.py	2011-08-17 15:38:20 +0000
+++ bzrlib/tests/per_workingtree/test_workingtree.py	2011-08-31 22:52:43 +0000
@@ -940,6 +940,9 @@
             case_sensitive = True
         tree = self.make_branch_and_tree('test')
         self.assertEqual(case_sensitive, tree.case_sensitive)
+        if not isinstance(tree, InventoryWorkingTree):
+            raise TestNotApplicable("get_format_string is only available "
+                                    "on bzr working trees")
         # now we cheat, and make a file that matches the case-sensitive name
         t = tree.bzrdir.get_workingtree_transport(None)
         try:

=== modified file 'bzrlib/tests/test_branch.py'
--- bzrlib/tests/test_branch.py	2011-05-26 08:04:46 +0000
+++ bzrlib/tests/test_branch.py	2011-09-02 00:53:06 +0000
@@ -709,5 +709,5 @@
         r.new_revid = "same-revid"
         f = StringIO()
         r.report(f)
-        self.assertEqual("No revisions to pull.\n", f.getvalue())
+        self.assertEqual("No revisions or tags to pull.\n", f.getvalue())
 

=== modified file 'bzrlib/tests/test_config.py'
--- bzrlib/tests/test_config.py	2011-09-02 15:42:10 +0000
+++ bzrlib/tests/test_config.py	2011-09-07 15:21:39 +0000
@@ -33,18 +33,14 @@
     errors,
     osutils,
     mail_client,
-    mergetools,
     ui,
     urlutils,
-    registry,
     remote,
     tests,
     trace,
-    transport,
     )
 from bzrlib.symbol_versioning import (
     deprecated_in,
-    deprecated_method,
     )
 from bzrlib.transport import remote as transport_remote
 from bzrlib.tests import (
@@ -1969,6 +1965,29 @@
         conf = config.TransportConfig(t, 'foo.conf')
         self.assertRaises(errors.ParseConfigError, conf._get_configobj)
 
+    def test_load_permission_denied(self):
+        """Ensure we get an empty config file if the file is inaccessible."""
+        warnings = []
+        def warning(*args):
+            warnings.append(args[0] % args[1:])
+        self.overrideAttr(trace, 'warning', warning)
+
+        class DenyingTransport(object):
+
+            def __init__(self, base):
+                self.base = base
+
+            def get_bytes(self, relpath):
+                raise errors.PermissionDenied(relpath, "")
+
+        cfg = config.TransportConfig(
+            DenyingTransport("nonexisting://"), 'control.conf')
+        self.assertIs(None, cfg.get_option('non-existant', 'SECTION'))
+        self.assertEquals(
+            warnings,
+            [u'Permission denied while trying to open configuration file '
+             u'nonexisting:///control.conf.'])
+
     def test_get_value(self):
         """Test that retreiving a value from a section is possible"""
         bzrdir_config = config.TransportConfig(self.get_transport('.'),
@@ -2605,9 +2624,6 @@
     scenarios = [(key, {'get_store': builder}) for key, builder
                  in config.test_store_builder_registry.iteritems()]
 
-    def setUp(self):
-        super(TestReadonlyStore, self).setUp()
-
     def test_building_delays_load(self):
         store = self.get_store(self)
         self.assertEquals(False, store.is_loaded())
@@ -2678,6 +2694,25 @@
         store = config.IniFileStore(t, 'foo.conf')
         self.assertRaises(errors.ParseConfigError, store.load)
 
+    def test_load_permission_denied(self):
+        """Ensure we get warned when trying to load an inaccessible file."""
+        warnings = []
+        def warning(*args):
+            warnings.append(args[0] % args[1:])
+        self.overrideAttr(trace, 'warning', warning)
+
+        t = self.get_transport()
+
+        def get_bytes(relpath):
+            raise errors.PermissionDenied(relpath, "")
+        t.get_bytes = get_bytes
+        store = config.IniFileStore(t, 'foo.conf')
+        self.assertRaises(errors.PermissionDenied, store.load)
+        self.assertEquals(
+            warnings,
+            [u'Permission denied while trying to load configuration store %s.'
+             % store.external_url()])
+
 
 class TestIniConfigContent(tests.TestCaseWithTransport):
     """Simulate loading a IniBasedConfig with content of various encodings.
@@ -3023,12 +3058,13 @@
     # FIXME: It may be worth looking into removing the lock dir when it's not
     # needed anymore and look at possible fallouts for concurrent lockers. This
     # will matter if/when we use config files outside of bazaar directories
-    # (.bazaar or .bzr) -- vila 20110-04-11
+    # (.bazaar or .bzr) -- vila 20110-04-111
 
 
 class TestSectionMatcher(TestStore):
 
-    scenarios = [('location', {'matcher': config.LocationMatcher})]
+    scenarios = [('location', {'matcher': config.LocationMatcher}),
+                 ('id', {'matcher': config.NameMatcher}),]
 
     def get_store(self, file_name):
         return config.IniFileStore(self.get_readonly_transport(), file_name)
@@ -3143,6 +3179,35 @@
         self.assertEquals(expected_location, matcher.location)
 
 
+class TestNameMatcher(TestStore):
+
+    def setUp(self):
+        super(TestNameMatcher, self).setUp()
+        self.store = config.IniFileStore(self.get_readonly_transport(),
+                                         'foo.conf')
+        self.store._load_from_string('''
+[foo]
+option=foo
+[foo/baz]
+option=foo/baz
+[bar]
+option=bar
+''')
+
+    def get_matching_sections(self, name):
+        matcher = config.NameMatcher(self.store, name)
+        return list(matcher.get_sections())
+
+    def test_matching(self):
+        sections = self.get_matching_sections('foo')
+        self.assertLength(1, sections)
+        self.assertSectionContent(('foo', {'option': 'foo'}), sections[0])
+
+    def test_not_matching(self):
+        sections = self.get_matching_sections('baz')
+        self.assertLength(0, sections)
+
+
 class TestStackGet(tests.TestCase):
 
     # FIXME: This should be parametrized for all known Stack or dedicated

=== modified file 'bzrlib/tests/test_gpg.py'
--- bzrlib/tests/test_gpg.py	2011-08-04 14:39:42 +0000
+++ bzrlib/tests/test_gpg.py	2011-09-07 13:31:04 +0000
@@ -391,6 +391,7 @@
 
     def test_verify_invalid(self):
         self.requireFeature(features.gpgme)
+        self.import_keys()
         content = """-----BEGIN PGP SIGNED MESSAGE-----
 Hash: SHA1
 
@@ -415,6 +416,7 @@
 
     def test_verify_expired_but_valid(self):
         self.requireFeature(features.gpgme)
+        self.import_keys()
         content = """-----BEGIN PGP SIGNED MESSAGE-----
 Hash: SHA1
  
@@ -441,6 +443,7 @@
 
     def test_verify_unknown_key(self):
         self.requireFeature(features.gpgme)
+        self.import_keys()
         content = """-----BEGIN PGP SIGNED MESSAGE-----
 Hash: SHA1
 

=== modified file 'bzrlib/tests/test_help.py'
--- bzrlib/tests/test_help.py	2011-08-11 10:19:32 +0000
+++ bzrlib/tests/test_help.py	2011-09-02 16:34:17 +0000
@@ -347,10 +347,10 @@
             }}zz{{:Usage:   bzr WithSeeAlso
             }}
             zz{{:Options:
-              --usage        Show usage message and options.
-              -v, --verbose  Display more information.
-              -q, --quiet    Only display errors and warnings.
-              -h, --help     Show help message.
+              --usage        zz{{Show usage message and options.}}
+              -v, --verbose  zz{{Display more information.}}
+              -q, --quiet    zz{{Only display errors and warnings.}}
+              -h, --help     zz{{Show help message.}}
             }}
             zz{{:See also: bar, foo}}
             ''',
@@ -365,10 +365,10 @@
             }}zz{{:Usage:   bzr Demo
             }}
             zz{{:Options:
-              --usage        Show usage message and options.
-              -v, --verbose  Display more information.
-              -q, --quiet    Only display errors and warnings.
-              -h, --help     Show help message.
+              --usage        zz{{Show usage message and options.}}
+              -v, --verbose  zz{{Display more information.}}
+              -q, --quiet    zz{{Only display errors and warnings.}}
+              -h, --help     zz{{Show help message.}}
             }}
             ''',
                            cmd_Demo())
@@ -381,9 +381,9 @@
         helptext = cmd.get_help_text(['gam'])
         self.assertEndsWith(
             helptext,
-            '  -v, --verbose  Display more information.\n'
-            '  -q, --quiet    Only display errors and warnings.\n'
-            '  -h, --help     Show help message.\n'
+            '  -v, --verbose  zz{{Display more information.}}\n'
+            '  -q, --quiet    zz{{Only display errors and warnings.}}\n'
+            '  -h, --help     zz{{Show help message.}}\n'
             '}}\n'
             'zz{{:See also: bar, foo, gam}}\n')
 
@@ -395,10 +395,10 @@
         self.assertEndsWith(
             helptext,
             'zz{{:Options:\n'
-            '  --usage        Show usage message and options.\n'
-            '  -v, --verbose  Display more information.\n'
-            '  -q, --quiet    Only display errors and warnings.\n'
-            '  -h, --help     Show help message.\n'
+            '  --usage        zz{{Show usage message and options.}}\n'
+            '  -v, --verbose  zz{{Display more information.}}\n'
+            '  -q, --quiet    zz{{Only display errors and warnings.}}\n'
+            '  -h, --help     zz{{Show help message.}}\n'
             '}}\n'
             'zz{{:See also: gam}}\n')
 
@@ -427,10 +427,10 @@
             }}zz{{:Usage:   bzr Demo
             }}
             zz{{:Options:
-              --usage        Show usage message and options.
-              -v, --verbose  Display more information.
-              -q, --quiet    Only display errors and warnings.
-              -h, --help     Show help message.
+              --usage        zz{{Show usage message and options.}}
+              -v, --verbose  zz{{Display more information.}}
+              -q, --quiet    zz{{Only display errors and warnings.}}
+              -h, --help     zz{{Show help message.}}
             }}
             Description:
               zz{{zz{{Blah blah blah.}}
@@ -470,10 +470,10 @@
 
             }}
             zz{{:Options:
-              --usage        Show usage message and options.
-              -v, --verbose  Display more information.
-              -q, --quiet    Only display errors and warnings.
-              -h, --help     Show help message.
+              --usage        zz{{Show usage message and options.}}
+              -v, --verbose  zz{{Display more information.}}
+              -q, --quiet    zz{{Only display errors and warnings.}}
+              -h, --help     zz{{Show help message.}}
             }}
             Description:
               zz{{zz{{Blah blah blah.}}

=== modified file 'bzrlib/tests/test_i18n.py'
--- bzrlib/tests/test_i18n.py	2011-08-25 10:33:14 +0000
+++ bzrlib/tests/test_i18n.py	2011-09-07 16:32:11 +0000
@@ -16,7 +16,11 @@
 
 """Tests for bzrlib.i18n"""
 
-from bzrlib import i18n, tests
+from bzrlib import (i18n, 
+                    tests, 
+                    errors, 
+                    workingtree,
+                    )
 
 
 class ZzzTranslations(object):
@@ -28,7 +32,7 @@
     _null_translation = i18n._gettext.NullTranslations()
 
     def zzz(self, s):
-        return u'zz{{%s}}' % s
+        return u'zz\xe5{{%s}}' % s
 
     def ugettext(self, s):
         return self.zzz(self._null_translation.ugettext(s))
@@ -47,18 +51,18 @@
         trans = ZzzTranslations()
 
         t = trans.zzz('msg')
-        self._check_exact(u'zz{{msg}}', t)
+        self._check_exact(u'zz\xe5{{msg}}', t)
 
         t = trans.ugettext('msg')
-        self._check_exact(u'zz{{msg}}', t)
+        self._check_exact(u'zz\xe5{{msg}}', t)
 
         t = trans.ungettext('msg1', 'msg2', 0)
-        self._check_exact(u'zz{{msg2}}', t)
+        self._check_exact(u'zz\xe5{{msg2}}', t)
         t = trans.ungettext('msg1', 'msg2', 2)
-        self._check_exact(u'zz{{msg2}}', t)
+        self._check_exact(u'zz\xe5{{msg2}}', t)
 
         t = trans.ungettext('msg1', 'msg2', 1)
-        self._check_exact(u'zz{{msg1}}', t)
+        self._check_exact(u'zz\xe5{{msg1}}', t)
 
 
 class TestGetText(tests.TestCase):
@@ -68,11 +72,11 @@
         self.overrideAttr(i18n, '_translations', ZzzTranslations())
 
     def test_oneline(self):
-        self.assertEqual(u"zz{{spam ham eggs}}",
+        self.assertEqual(u"zz\xe5{{spam ham eggs}}",
                          i18n.gettext("spam ham eggs"))
 
     def test_multiline(self):
-        self.assertEqual(u"zz{{spam\nham\n\neggs\n}}",
+        self.assertEqual(u"zz\xe5{{spam\nham\n\neggs\n}}",
                          i18n.gettext("spam\nham\n\neggs\n"))
 
 
@@ -83,11 +87,11 @@
         self.overrideAttr(i18n, '_translations', ZzzTranslations())
 
     def test_oneline(self):
-        self.assertEqual(u"zz{{spam ham eggs}}",
+        self.assertEqual(u"zz\xe5{{spam ham eggs}}",
                          i18n.gettext_per_paragraph("spam ham eggs"))
 
     def test_multiline(self):
-        self.assertEqual(u"zz{{spam\nham}}\n\nzz{{eggs\n}}",
+        self.assertEqual(u"zz\xe5{{spam\nham}}\n\nzz\xe5{{eggs\n}}",
                          i18n.gettext_per_paragraph("spam\nham\n\neggs\n"))
 
 
@@ -104,3 +108,31 @@
         self.overrideEnv('LC_MESSAGES', None)
         self.overrideEnv('LANG', None)
         i18n.install()
+
+class TestTranslate(tests.TestCaseWithTransport):
+
+    def setUp(self):
+        super(TestTranslate, self).setUp()
+        self.overrideAttr(i18n, '_translations', ZzzTranslations())
+
+    def test_error_message_translation(self):
+        """do errors get translated?"""
+        err = None
+        tree = self.make_branch_and_tree('.')
+        self.overrideAttr(i18n, '_translations', ZzzTranslations())
+        try:
+            workingtree.WorkingTree.open('./foo')
+        except errors.NotBranchError,e:
+            err = str(e)
+        self.assertContainsRe(err, 
+                              u"zz\xe5{{Not a branch: .*}}".encode("utf-8"))
+
+    def test_topic_help_translation(self):
+        """does topic help get translated?"""
+        from bzrlib import help
+        i18n.install()
+        self.overrideAttr(i18n, '_translations', ZzzTranslations())
+        from StringIO import StringIO
+        out = StringIO()
+        help.help("authentication", out)
+        self.assertContainsRe(out.getvalue(), "zz\xe5{{Authentication Settings")

=== modified file 'bzrlib/tests/test_import_tariff.py'
--- bzrlib/tests/test_import_tariff.py	2011-06-06 11:57:09 +0000
+++ bzrlib/tests/test_import_tariff.py	2011-08-30 09:30:27 +0000
@@ -167,6 +167,7 @@
             'bzrlib.cmd_version_info',
             'bzrlib.externalcommand',
             'bzrlib.filters',
+            'bzrlib.hashcache',
             # foreign branch plugins import the foreign_vcs_registry from 
             # bzrlib.foreign so it can't be blacklisted
             'bzrlib.gpg',
@@ -235,6 +236,7 @@
             'bzrlib._dirstate_helpers_pyx',
             'bzrlib.externalcommand',
             'bzrlib.filters',
+            'bzrlib.hashcache',
             # foreign branch plugins import the foreign_vcs_registry from 
             # bzrlib.foreign so it can't be blacklisted
             'bzrlib.gpg',

=== modified file 'bzrlib/tests/test_matchers.py'
--- bzrlib/tests/test_matchers.py	2011-08-16 13:26:27 +0000
+++ bzrlib/tests/test_matchers.py	2011-08-31 23:17:41 +0000
@@ -116,11 +116,11 @@
         t = self.make_branch_and_tree('.')
         self.build_tree(['a', 'b/', 'b/c'])
         t.add(['a', 'b', 'b/c'], ['a-id', 'b-id', 'c-id'])
-        self.assertThat(t, HasLayout(['', 'a', 'b', 'b/c']))
+        self.assertThat(t, HasLayout(['', 'a', 'b/', 'b/c']))
         self.assertThat(t, HasLayout(
             [('', t.get_root_id()),
              ('a', 'a-id'),
-             ('b', 'b-id'),
+             ('b/', 'b-id'),
              ('b/c', 'c-id')]))
 
     def test_mismatch(self):
@@ -130,5 +130,19 @@
         mismatch = HasLayout(['a']).match(t)
         self.assertIsNot(None, mismatch)
         self.assertEquals(
-            "[u'', u'a', u'b', u'b/c'] != ['a']",
+            "['a'] != [u'', u'a', u'b/', u'b/c']",
+            mismatch.describe())
+
+    def test_no_dirs(self):
+        # Some tree/repository formats do not support versioned directories
+        t = self.make_branch_and_tree('.')
+        t.has_versioned_directories = lambda: False
+        self.build_tree(['a', 'b/', 'b/c'])
+        t.add(['a', 'b', 'b/c'], ['a-id', 'b-id', 'c-id'])
+        self.assertIs(None, HasLayout(['', 'a', 'b/', 'b/c']).match(t))
+        self.assertIs(None, HasLayout(['', 'a', 'b/', 'b/c', 'd/']).match(t))
+        mismatch = HasLayout([u'', u'a', u'd/']).match(t)
+        self.assertIsNot(None, mismatch)
+        self.assertEquals(
+            "[u'', u'a'] != [u'', u'a', u'b/', u'b/c']",
             mismatch.describe())

=== modified file 'bzrlib/tests/test_tag.py'
--- bzrlib/tests/test_tag.py	2011-08-06 07:32:51 +0000
+++ bzrlib/tests/test_tag.py	2011-08-31 17:11:32 +0000
@@ -109,12 +109,14 @@
         self.assertRaises(errors.NoSuchTag, a.tags.lookup_tag, 'tag-2')
         # conflicting merge
         a.tags.set_tag('tag-2', 'z')
-        conflicts = a.tags.merge_to(b.tags)
+        updates, conflicts = a.tags.merge_to(b.tags)
+        self.assertEqual({}, updates)
         self.assertEqual(list(conflicts), [('tag-2', 'z', 'y')])
         self.assertEqual('y', b.tags.lookup_tag('tag-2'))
         # overwrite conflicts
-        conflicts = a.tags.merge_to(b.tags, overwrite=True)
+        updates, conflicts = a.tags.merge_to(b.tags, overwrite=True)
         self.assertEqual(list(conflicts), [])
+        self.assertEqual({u'tag-1': 'x', u'tag-2': 'z'}, updates)
         self.assertEqual('z', b.tags.lookup_tag('tag-2'))
 
 

=== modified file 'bzrlib/tests/test_transport.py'
--- bzrlib/tests/test_transport.py	2011-08-15 14:31:55 +0000
+++ bzrlib/tests/test_transport.py	2011-08-31 10:16:44 +0000
@@ -760,6 +760,10 @@
             self.assertEquals(f.read(), 'foo')
         self.assertEquals(len(calls), 1, calls)
 
+    def test_missing_directory(self):
+        t = self.get_transport('.')
+        self.assertRaises(errors.NoSuchFile, t.open_write_stream, 'dir/foo')
+
 
 class TestWin32LocalTransport(tests.TestCase):
 

=== modified file 'bzrlib/tests/test_urlutils.py'
--- bzrlib/tests/test_urlutils.py	2011-08-15 13:12:36 +0000
+++ bzrlib/tests/test_urlutils.py	2011-09-04 23:18:43 +0000
@@ -457,6 +457,12 @@
         self.assertEqual(('file:///C:', '/foo'), extract('file://', '/C:/foo'))
         self.assertEqual(('file:///d|', '/path'), extract('file://', '/d|/path'))
         self.assertRaises(InvalidURL, extract, 'file://', '/path')
+        # Root drives without slash treated as invalid, see bug #841322
+        self.assertEqual(('file:///C:', '/'), extract('file://', '/C:/'))
+        self.assertRaises(InvalidURL, extract, 'file://', '/C:')
+        # Invalid without drive separator or following forward slash
+        self.assertRaises(InvalidURL, extract, 'file://', '/C')
+        self.assertRaises(InvalidURL, extract, 'file://', '/C:ool')
 
     def test_split(self):
         # Test bzrlib.urlutils.split()

=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2011-08-28 15:33:21 +0000
+++ bzrlib/transport/__init__.py	2011-09-04 23:25:09 +0000
@@ -310,8 +310,7 @@
     def __init__(self, base):
         super(Transport, self).__init__()
         self.base = base
-        self._segment_parameters = urlutils.split_segment_parameters(
-            base.rstrip("/"))[1]
+        self._segment_parameters = urlutils.split_segment_parameters(base)[1]
 
     def _translate_error(self, e, path, raise_generic=True):
         """Translate an IOError or OSError into an appropriate bzr error.

=== modified file 'bzrlib/transport/http/__init__.py'
--- bzrlib/transport/http/__init__.py	2011-08-19 22:34:02 +0000
+++ bzrlib/transport/http/__init__.py	2011-09-03 16:30:53 +0000
@@ -20,7 +20,6 @@
 """
 
 from cStringIO import StringIO
-import mimetools
 import re
 import urlparse
 import urllib
@@ -35,14 +34,9 @@
     urlutils,
     )
 from bzrlib.smart import medium
-from bzrlib.symbol_versioning import (
-        deprecated_method,
-        )
 from bzrlib.trace import mutter
 from bzrlib.transport import (
     ConnectedTransport,
-    _CoalescedOffset,
-    Transport,
     )
 
 # TODO: This is not used anymore by HttpTransport_urllib
@@ -612,7 +606,7 @@
             t = self._http_transport_ref()
             code, body_filelike = t._post(bytes)
             if code != 200:
-                raise InvalidHttpResponse(
+                raise errors.InvalidHttpResponse(
                     t._remote_path('.bzr/smart'),
                     'Expected 200 response code, got %r' % (code,))
         except (errors.InvalidHttpResponse, errors.ConnectionReset), e:

=== modified file 'bzrlib/transport/http/_urllib.py'
--- bzrlib/transport/http/_urllib.py	2011-06-14 01:26:41 +0000
+++ bzrlib/transport/http/_urllib.py	2011-09-03 16:30:53 +0000
@@ -14,14 +14,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from cStringIO import StringIO
-import urllib
-import urlparse
-
 from bzrlib import (
     errors,
     trace,
-    urlutils,
     )
 from bzrlib.transport import http
 # TODO: handle_response should be integrated into the http/__init__.py

=== modified file 'bzrlib/transport/http/_urllib2_wrappers.py'
--- bzrlib/transport/http/_urllib2_wrappers.py	2011-08-10 22:34:25 +0000
+++ bzrlib/transport/http/_urllib2_wrappers.py	2011-09-03 16:30:53 +0000
@@ -70,7 +70,6 @@
     osutils,
     trace,
     transport,
-    ui,
     urlutils,
     )
 

=== modified file 'bzrlib/transport/http/response.py'
--- bzrlib/transport/http/response.py	2011-07-27 11:57:32 +0000
+++ bzrlib/transport/http/response.py	2011-09-03 16:30:53 +0000
@@ -28,7 +28,6 @@
 
 from bzrlib import (
     errors,
-    trace,
     osutils,
     )
 

=== modified file 'bzrlib/transport/http/wsgi.py'
--- bzrlib/transport/http/wsgi.py	2011-03-05 02:26:26 +0000
+++ bzrlib/transport/http/wsgi.py	2011-09-03 16:30:53 +0000
@@ -22,7 +22,7 @@
 
 from cStringIO import StringIO
 
-from bzrlib.smart import protocol, medium
+from bzrlib.smart import medium
 from bzrlib.transport import chroot, get_transport
 from bzrlib.urlutils import local_path_to_url
 

=== modified file 'bzrlib/transport/local.py'
--- bzrlib/transport/local.py	2011-08-15 14:31:55 +0000
+++ bzrlib/transport/local.py	2011-08-31 01:35:15 +0000
@@ -330,7 +330,10 @@
     def open_write_stream(self, relpath, mode=None):
         """See Transport.open_write_stream."""
         abspath = self._abspath(relpath)
-        handle = osutils.open_file(abspath, 'wb')
+        try:
+            handle = osutils.open_file(abspath, 'wb')
+        except (IOError, OSError),e:
+            self._translate_error(e, abspath)
         handle.truncate()
         if mode is not None:
             self._check_mode_and_size(abspath, handle.fileno(), mode)

=== modified file 'bzrlib/tree.py'
--- bzrlib/tree.py	2011-08-05 13:34:40 +0000
+++ bzrlib/tree.py	2011-08-29 19:06:57 +0000
@@ -58,6 +58,14 @@
     trees or versioned trees.
     """
 
+    def has_versioned_directories(self):
+        """Whether this tree can contain explicitly versioned directories.
+
+        This defaults to True, but some implementations may want to override
+        it.
+        """
+        return True
+
     def changes_from(self, other, want_unchanged=False, specific_files=None,
         extra_trees=None, require_versioned=False, include_root=False,
         want_unversioned=False):

=== modified file 'bzrlib/urlutils.py'
--- bzrlib/urlutils.py	2011-08-15 13:12:36 +0000
+++ bzrlib/urlutils.py	2011-09-04 23:22:47 +0000
@@ -388,7 +388,7 @@
     """On win32 the drive letter needs to be added to the url base."""
     # Strip off the drive letter
     # path is currently /C:/foo
-    if len(path) < 3 or path[2] not in ':|' or path[3] != '/':
+    if len(path) < 4 or path[2] not in ':|' or path[3] != '/':
         raise errors.InvalidURL(url_base + path,
             'win32 file:/// paths need a drive letter')
     url_base += path[0:3] # file:// + /C:

=== modified file 'bzrlib/vf_repository.py'
--- bzrlib/vf_repository.py	2011-08-25 07:51:37 +0000
+++ bzrlib/vf_repository.py	2011-09-06 11:01:30 +0000
@@ -918,11 +918,13 @@
         """
         if not self._format.supports_external_lookups:
             raise errors.UnstackableRepositoryFormat(self._format, self.base)
+        # This can raise an exception, so should be done before we lock the
+        # fallback repository.
+        self._check_fallback_repository(repository)
         if self.is_locked():
             # This repository will call fallback.unlock() when we transition to
             # the unlocked state, so we make sure to increment the lock count
             repository.lock_read()
-        self._check_fallback_repository(repository)
         self._fallback_repositories.append(repository)
         self.texts.add_fallback_versioned_files(repository.texts)
         self.inventories.add_fallback_versioned_files(repository.inventories)

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2011-08-04 13:30:30 +0000
+++ bzrlib/workingtree.py	2011-09-01 10:55:26 +0000
@@ -54,7 +54,6 @@
     generate_ids,
     globbing,
     graph as _mod_graph,
-    hashcache,
     ignores,
     inventory,
     merge,
@@ -194,27 +193,6 @@
         self.basedir = realpath(basedir)
         self._control_files = _control_files
         self._transport = self._control_files._transport
-        # update the whole cache up front and write to disk if anything changed;
-        # in the future we might want to do this more selectively
-        # two possible ways offer themselves : in self._unlock, write the cache
-        # if needed, or, when the cache sees a change, append it to the hash
-        # cache file, and have the parser take the most recent entry for a
-        # given path only.
-        wt_trans = self.bzrdir.get_workingtree_transport(None)
-        cache_filename = wt_trans.local_abspath('stat-cache')
-        self._hashcache = hashcache.HashCache(basedir, cache_filename,
-            self.bzrdir._get_file_mode(),
-            self._content_filter_stack_provider())
-        hc = self._hashcache
-        hc.read()
-        # is this scan needed ? it makes things kinda slow.
-        #hc.scan()
-
-        if hc.needs_write:
-            mutter("write hc")
-            hc.write()
-
-        self._detect_case_handling()
         self._rules_searcher = None
         self.views = self._make_views()
 
@@ -238,17 +216,6 @@
         """
         return self.bzrdir.is_control_filename(filename)
 
-    def _detect_case_handling(self):
-        wt_trans = self.bzrdir.get_workingtree_transport(None)
-        try:
-            wt_trans.stat(self._format.case_sensitive_filename)
-        except errors.NoSuchFile:
-            self.case_sensitive = True
-        else:
-            self.case_sensitive = False
-
-        self._setup_directory_is_tree_reference()
-
     branch = property(
         fget=lambda self: self._branch,
         doc="""The branch this WorkingTree is connected to.
@@ -257,6 +224,10 @@
             the working tree has been constructed from.
             """)
 
+    def has_versioned_directories(self):
+        """See `Tree.has_versioned_directories`."""
+        return self._format.supports_versioned_directories
+
     def break_lock(self):
         """Break a lock if one is present from another instance.
 
@@ -1062,7 +1033,6 @@
             stream.write(bytes)
         finally:
             stream.close()
-        # TODO: update the hashcache here ?
 
     def extras(self):
         """Yield all unversioned files in this WorkingTree.
@@ -1576,20 +1546,6 @@
             last_rev = parent_trees[0][0]
         return nb_conflicts
 
-    def _write_hashcache_if_dirty(self):
-        """Write out the hashcache if it is dirty."""
-        if self._hashcache.needs_write:
-            try:
-                self._hashcache.write()
-            except OSError, e:
-                if e.errno not in (errno.EPERM, errno.EACCES):
-                    raise
-                # TODO: jam 20061219 Should this be a warning? A single line
-                #       warning might be sufficient to let the user know what
-                #       is going on.
-                mutter('Could not write hashcache for %s\nError: %s',
-                              self._hashcache.cache_file_name(), e)
-
     def set_conflicts(self, arg):
         raise errors.UnsupportedOperation(self.set_conflicts, self)
 
@@ -1827,6 +1783,8 @@
             branch=branch, _control_files=_control_files, _internal=_internal,
             _format=_format, _bzrdir=_bzrdir)
 
+        self._detect_case_handling()
+
         if _inventory is None:
             # This will be acquired on lock_read() or lock_write()
             self._inventory_is_modified = False
@@ -1851,6 +1809,17 @@
         self._inventory = inv
         self._inventory_is_modified = dirty
 
+    def _detect_case_handling(self):
+        wt_trans = self.bzrdir.get_workingtree_transport(None)
+        try:
+            wt_trans.stat(self._format.case_sensitive_filename)
+        except errors.NoSuchFile:
+            self.case_sensitive = True
+        else:
+            self.case_sensitive = False
+
+        self._setup_directory_is_tree_reference()
+
     def _serialize(self, inventory, out_file):
         xml5.serializer_v5.write_inventory(self._inventory, out_file,
             working=True)
@@ -2160,12 +2129,6 @@
             mode=self.bzrdir._get_file_mode())
         self._inventory_is_modified = False
 
-    @needs_read_lock
-    def get_file_sha1(self, file_id, path=None, stat_value=None):
-        if not path:
-            path = self._inventory.id2path(file_id)
-        return self._hashcache.get_sha1(path, stat_value)
-
     def get_file_mtime(self, file_id, path=None):
         """See Tree.get_file_mtime."""
         if not path:

=== modified file 'bzrlib/workingtree_3.py'
--- bzrlib/workingtree_3.py	2011-06-28 11:29:03 +0000
+++ bzrlib/workingtree_3.py	2011-08-30 17:32:29 +0000
@@ -18,11 +18,15 @@
 
 """
 
+import errno
+
 from bzrlib import (
     bzrdir,
     errors,
+    hashcache,
     inventory,
     revision as _mod_revision,
+    trace,
     transform,
     )
 from bzrlib.decorators import (
@@ -36,7 +40,53 @@
     WorkingTreeFormat,
     )
 
-class WorkingTree3(InventoryWorkingTree):
+
+class PreDirStateWorkingTree(InventoryWorkingTree):
+
+    def __init__(self, basedir='.', *args, **kwargs):
+        super(PreDirStateWorkingTree, self).__init__(basedir, *args, **kwargs)
+        # update the whole cache up front and write to disk if anything changed;
+        # in the future we might want to do this more selectively
+        # two possible ways offer themselves : in self._unlock, write the cache
+        # if needed, or, when the cache sees a change, append it to the hash
+        # cache file, and have the parser take the most recent entry for a
+        # given path only.
+        wt_trans = self.bzrdir.get_workingtree_transport(None)
+        cache_filename = wt_trans.local_abspath('stat-cache')
+        self._hashcache = hashcache.HashCache(basedir, cache_filename,
+            self.bzrdir._get_file_mode(),
+            self._content_filter_stack_provider())
+        hc = self._hashcache
+        hc.read()
+        # is this scan needed ? it makes things kinda slow.
+        #hc.scan()
+
+        if hc.needs_write:
+            trace.mutter("write hc")
+            hc.write()
+
+    def _write_hashcache_if_dirty(self):
+        """Write out the hashcache if it is dirty."""
+        if self._hashcache.needs_write:
+            try:
+                self._hashcache.write()
+            except OSError, e:
+                if e.errno not in (errno.EPERM, errno.EACCES):
+                    raise
+                # TODO: jam 20061219 Should this be a warning? A single line
+                #       warning might be sufficient to let the user know what
+                #       is going on.
+                trace.mutter('Could not write hashcache for %s\nError: %s',
+                              self._hashcache.cache_file_name(), e)
+
+    @needs_read_lock
+    def get_file_sha1(self, file_id, path=None, stat_value=None):
+        if not path:
+            path = self._inventory.id2path(file_id)
+        return self._hashcache.get_sha1(path, stat_value)
+
+
+class WorkingTree3(PreDirStateWorkingTree):
     """This is the Format 3 working tree.
 
     This differs from the base WorkingTree by:

=== modified file 'doc/developers/configuration.txt'
--- doc/developers/configuration.txt	2011-08-19 14:10:32 +0000
+++ doc/developers/configuration.txt	2011-09-07 15:21:39 +0000
@@ -86,13 +86,25 @@
 all data needed for the selection and uses it while processing the sections in
 ``get_sections``.
 
-Only ``ReadOnlySection`` objects are manipulated here but a ``SectionMatcher``
-can return dedicated ``Section`` to provide additional context (the
-``LocationSection`` add an ``extra_path`` attribute to implement the
-``appendpath`` policy for example).
+Only ``ReadOnlySection`` objects are manipulated here but a
+``SectionMatcher`` can return dedicated ``Section`` objects to provide
+additional context (the ``LocationSection`` add an ``extra_path`` attribute
+to implement the ``appendpath`` policy for example). If no sections match,
+an empty list is returned.
 
 .. FIXME: Replace the appendpath example if/when it's deprecated ;)
 
+Specific section matchers can be implemented by overriding ``get_sections``
+or just ``match``.
+
+``bzrlib`` provides:
+
+* ``LocationMatcher(store, location)``: To select all sections that match
+  ``location``.
+
+* ``NameMatcher(store, unique_id)``: To select a single section matching
+  ``unique_id``.
+
 Stacks
 ------
 

=== modified file 'doc/developers/releasing.txt'
--- doc/developers/releasing.txt	2011-08-04 11:46:39 +0000
+++ doc/developers/releasing.txt	2011-09-06 09:11:54 +0000
@@ -357,6 +357,15 @@
    ``BZR_DISABLE_PLUGINS`` or ``BZR_PLUGIN_PATH=-site`` to disable one or
    all plugins.
 
+   Until <http://pad.lv/839461> is fixed, you may encounter issues if you
+   cut a release for old stable branches (<= 2.2) and use a more recent
+   OS/distro. If that's the case, check the bug status and use the following
+   workaround if no fix is available::
+
+     export TTPATH=<local branch of lp:testtools -r 0.9.2>
+     export SUPATH=<local branch of lp:subunit -r 0.0.6>
+     PYTHONPATH=$TTPATH:$SUPATH/python PATH=$SUPATH/filters:${PATH} BZR_PLUGIN_PATH=-site make check-dist-tarball PYTHON=python2.6 | subunit2pyunit
+
    Remember that PQM has just tested everything too, this step is
    particularly testing that the pyrex extensions, which are updated
    by your local pyrex version when you run make dist, are in good
@@ -435,9 +444,15 @@
    targeted at packagers and installer builders (see
    <https://bugs.launchpad.net/launchpad/+bug/645084>).  This is the cue
    for platform maintainers and plugin authors to update their code.  This
-   is done before the general public announcement of the release.
-
-#. Pause for a few days.
+   is done before the general public announcement of the release. 
+
+   The freeze announcement generally guess the date of the official public
+   announcement, for the most recent stable series (the one supported by the
+   installers and most of the distributions) it's generally a few days after
+   the freeze. For older series supported only via SRUs for Ubuntu, we don't
+   control the process as tightly so guessing the date is not appropriate.
+
+#. Pause for a few days. 
 
 
 Publishing the release
@@ -474,7 +489,8 @@
    Once the installers are available, the mail can be sent to the
    ``bazaar-announce`` list too.
 
-   For stable releases, it should also be cc'd to ``info-gnu@gnu.org``,
+   For stable releases (excluding SRUs which are for older stable releases),
+   it should also be cc'd to ``info-gnu@gnu.org``,
    ``python-announce-list@python.org``, ``bug-directory@gnu.org``.
 
    In all cases, it is good to set ``Reply-To: bazaar@lists.canonical.com``,
@@ -486,7 +502,9 @@
 
       The Bazaar team is happy to announce availability of a new
       release of the bzr adaptive version control system.
-      Bazaar is part of the GNU system <http://gnu.org/>.
+
+      Bazaar <http://bazaar.canonical.com/> is part of the GNU project
+      <http://gnu.org/> to produce a free operating system.
 
       <<Summary paragraph from news>>
 
@@ -508,8 +526,9 @@
    This should be done for beta releases and stable releases. If you do not
    have a Freshmeat account yet, ask one of the existing admins.
 
-   The purpose here is to point users to the latest stable release while still
-   publishing announcements for beta releases.
+   The purpose here is to point users to the latest stable release
+   (i.e. SRUs are excluded) while still publishing announcements for beta
+   releases.
 
    There are several kinds of modifications that could be done there via the
    ``Administration`` box in the lower right area of the page:
@@ -542,7 +561,7 @@
        python setup.py register
 
    Remember to check the results afterward -- this should be done for
-   stable releases but not for beta releases.
+   stable releases but not for beta releases nor SRUs.
 
    To be able to register the release you must create an account on
    <http://pypi.python.org/pypi> and have one of the existing owners of

=== modified file 'doc/en/_templates/index.html'
--- doc/en/_templates/index.html	2011-02-03 01:02:16 +0000
+++ doc/en/_templates/index.html	2011-08-30 09:27:59 +0000
@@ -7,7 +7,7 @@
 
   <table class="contentstable" align="center" style="margin-left: 30px"><tr>
     <td width="50%">
-        <p class="biglink"><a class="biglink" href="{{ pathto("whats-new/whats-new-in-2.4") }}">What's New in Bazaar 2.4?</a><br/>
+        <p class="biglink"><a class="biglink" href="{{ pathto("whats-new/whats-new-in-2.5") }}">What's New in Bazaar 2.5?</a><br/>
         <span class="linkdescr">what's new in this release</span>
       </p>
         <p class="biglink"><a class="biglink" href="{{ pathto("user-guide/index") }}">User Guide</a><br/>

=== modified file 'doc/en/release-notes/bzr-2.3.txt'
--- doc/en/release-notes/bzr-2.3.txt	2011-08-20 18:29:34 +0000
+++ doc/en/release-notes/bzr-2.3.txt	2011-09-02 23:13:18 +0000
@@ -87,6 +87,11 @@
 .. Improvements to existing commands, especially improved performance 
    or memory usage, or better results.
 
+* Tweak an RPC implementation for ``Repository.get_parent_map``, it was
+  doing an inefficient ``small_set.difference_update(large_set)`` when we
+  can do ``small_set = small_set.difference(large_set)``. This speeds up
+  discovery time by about 10%. (John Arbash Meinel)
+
 Bug Fixes
 *********
 

=== modified file 'doc/en/release-notes/bzr-2.4.txt'
--- doc/en/release-notes/bzr-2.4.txt	2011-08-29 12:59:56 +0000
+++ doc/en/release-notes/bzr-2.4.txt	2011-09-06 11:01:30 +0000
@@ -38,6 +38,10 @@
 * ``dirstate.fdatasync`` and ``repository.fdatasync`` can now properly be
   disabled. (Vincent Ladeuil, #824513)
 
+* Disable ``os.fsync`` and ``os.fdatasync`` by default when running
+  ``bzr selftest``. You can use ``--sync`` to re-enable them.
+  (John Arbash Meinel, #837293)
+
 * Fix i18n use when no environment variables are set. (Jelmer Vernooij, #810701)
 
 * Avoid UnicodeDecode error when reporting EINVAL from transports.
@@ -70,6 +74,10 @@
    suite.  This can include new facilities for writing tests, fixes to 
    spurious test failures and changes to the way things should be tested.
 
+* The test suite should now be able to run under weird environments where
+  ``/etc/passwd`` doesn't contain the ``uid`` for the user running selftest
+  or where ``fakeroot`` is used but ``/root`` is inacessible.
+  (Vincent Ladeuil, #825027)
 
 bzr 2.4.0
 #########

=== modified file 'doc/en/release-notes/bzr-2.5.txt'
--- doc/en/release-notes/bzr-2.5.txt	2011-08-26 11:35:50 +0000
+++ doc/en/release-notes/bzr-2.5.txt	2011-09-07 18:12:33 +0000
@@ -75,6 +75,10 @@
 * ``config.Option`` can now declare ``default_from_env``, a list of
   environment variables to get a default value from. (Vincent Ladeuil)
 
+* ``config.NameMatcher`` can be used to implement config stores and stacks
+  that need to provide specific option values for arbitrary unique IDs (svn
+  repository UUIDs, etc).  (Vincent Ladeuil, #843638)
+
 * New builtin ``bzr branches`` command, which lists all colocated branches
   in a directory. (Jelmer Vernooij, #826820)
 
@@ -92,6 +96,9 @@
 * bzr now ships with translations for command help.  (Jonathan
   Riddell, INADA Naoki, #83941)
 
+* bzr now ships with translations for command errors. (Jonathan
+  Riddell, INADA Naoki)
+
 Improvements
 ************
 
@@ -102,6 +109,13 @@
   Entering an empty commit message in the message editor still triggers
   an error. (Jelmer Vernooij)
 
+* ``bzr pull`` will now mention how many tags it has updated.
+  (Jelmer Vernooij, #164450)
+
+* ``bzr tag`` no longer errors if a tag already exists but refers to the
+  same revision, and will mention when a tag has been updated
+  rather than created. (Jelmer Vernooij, #381203)
+
 * ``bzr uncommit`` will now remove tags that refer to removed revisions.
   The ``--keep-tags`` option can be used to prevent this behaviour.
   (Jelmer Vernooij, #605814)
@@ -111,12 +125,23 @@
 
 * Install translation .mo files. (Jonathan Riddell)
 
+* Do not run i18n initialisation twice. (Jonathan Riddell)
+
+* Support a ``bugtracker`` option which is used by ``bzr commit --fixes``
+  if no bug tracker was specified on the command line.
+  (Jelmer Vernooij, #334860)
+
 Bug Fixes
 *********
 
 .. Fixes for situations where bzr would previously crash or give incorrect
    or undesirable results.
 
+* The pull command will now always use separate connections for the
+  case where the destination is a heavyweight checkout of some remote
+  branch on the same host as the source branch.
+  (Martin von Gagern, #483661)
+
 * A call to CHKInventory's filter-method will not result in a
   DuplicateFileId error, if you move a subfolder and change a file in
   that subfolder.
@@ -131,6 +156,14 @@
 * Decode ``BZR_HOME`` with fs encoding on posix platforms to avoid unicode
   errors.  (Vincent Ladeuil, #822571)
 
+* Fix fallout from URL handling changes in 2.5 that caused an IndexError to be
+  raised whenever a transport at the drive root was opened on windows.
+  (Martin [gz], #841322)
+
+* Rather than an error being raised, a warning is now printed when the
+  current user does not have permission to read a configuration file.
+  (Jelmer Vernooij, #837324)
+
 * TreeTransformBase.fixup_new_roots no longer forces trees to have a root, so
   operations that use it, like merge, can now create trees without a root.
   (Aaron Bentley)
@@ -200,6 +233,13 @@
   value in SI format (i.e. "20MB", "1GB") into its integer equivalent. 
   (Shannon Weyrick)
 
+* ``Tags`` containers can now declare whether they support versioned
+  tags and whether tags can refer to ghost tags.
+  (Jelmer Vernooij)
+
+* ``Tags.merge_to`` now returns a dictionary with the updated tags
+  and a set of conflicts, rather than just conflicts. (Jelmer Vernooij)
+
 * ``Transport`` now has a ``_parsed_url`` attribute instead of
   separate ``_user``, ``_password``, ``_port``, ``_scheme``, ``_host``
   and ``_path`` attributes. Proxies are provided for the moment but
@@ -249,6 +289,9 @@
   allowing it to be used for modules with side-effects.
   (Vincent Ladeuil, #712474)
 
+* Output time stamps while running ``make check`` to get better timings from
+  pqm.  (Vincent Ladeuil, #837926)
+
 * `TestCaseWithMemoryTransport` is faster now: `_check_safety_net` now
   just compares the bytes in the dirstate file to its pristine state,
   rather than opening the WorkingTree and calling ``last_revision()``.

=== modified file 'doc/en/user-guide/installing_bazaar.txt'
--- doc/en/user-guide/installing_bazaar.txt	2010-08-13 19:08:57 +0000
+++ doc/en/user-guide/installing_bazaar.txt	2011-08-30 09:27:59 +0000
@@ -33,7 +33,7 @@
 If you wish to install Bazaar from scratch rather than using a
 pre-built package, the steps are:
 
-  1. If it is not installed already, install Python 2.4 or later.
+  1. If it is not installed already, install Python 2.6 or later.
 
   2. Download the ``bazaar-xxx.tar.gz`` file (where xxx is the version
      number) from http://wiki.bazaar.canonical.com/Download or from Launchpad

=== modified file 'po/bzr.pot'
--- po/bzr.pot	2011-08-24 14:14:42 +0000
+++ po/bzr.pot	2011-09-07 14:32:52 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: bzr\n"
 "Report-Msgid-Bugs-To: <bazaar@canonical.com>\n"
-"POT-Creation-Date: 2011-08-24 15:14+0100\n"
+"POT-Creation-Date: 2011-09-07 15:32+0100\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -327,7 +327,7 @@
 #: bzrlib/builtins.py:979
 msgid ""
 "If there is no default location set, the first pull will set it (use\n"
-"--no-remember to avoid settting it). After that, you can omit the\n"
+"--no-remember to avoid setting it). After that, you can omit the\n"
 "location to use the default.  To change the default, use --remember. The\n"
 "value will only be saved if the remote location can be accessed."
 msgstr ""
@@ -357,72 +357,72 @@
 "master branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1097
+#: bzrlib/builtins.py:1096
 msgid "Update a mirror of this branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1099
+#: bzrlib/builtins.py:1098
 msgid ""
 "The target branch will not have its working tree populated because this\n"
 "is both expensive, and is not supported on remote file systems."
 msgstr ""
 
-#: bzrlib/builtins.py:1102
+#: bzrlib/builtins.py:1101
 msgid ""
 "Some smart servers or protocols *may* put the working tree in place in\n"
 "the future."
 msgstr ""
 
-#: bzrlib/builtins.py:1105
+#: bzrlib/builtins.py:1104
 msgid ""
 "This command only works on branches that have not diverged.  Branches are\n"
 "considered diverged if the destination branch's most recent commit is one\n"
 "that has not been merged (directly or indirectly) by the source branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1109
+#: bzrlib/builtins.py:1108
 msgid ""
 "If branches have diverged, you can use 'bzr push --overwrite' to replace\n"
 "the other branch completely, discarding its unmerged changes."
 msgstr ""
 
-#: bzrlib/builtins.py:1112
+#: bzrlib/builtins.py:1111
 msgid ""
 "If you want to ensure you have the different changes in the other branch,\n"
 "do a merge (see bzr help merge) from the other branch, and commit that.\n"
 "After that you will be able to do a push without '--overwrite'."
 msgstr ""
 
-#: bzrlib/builtins.py:1116
+#: bzrlib/builtins.py:1115
 msgid ""
 "If there is no default push location set, the first push will set it (use\n"
-"--no-remember to avoid settting it).  After that, you can omit the\n"
+"--no-remember to avoid setting it).  After that, you can omit the\n"
 "location to use the default.  To change the default, use --remember. The\n"
 "value will only be saved if the remote location can be accessed."
 msgstr ""
 
 # help of 'directory' option of 'push' command
-#: bzrlib/builtins.py:1128
+#: bzrlib/builtins.py:1127
 msgid ""
 "Branch to push from, rather than the one containing the working directory."
 msgstr ""
 
 # help of 'use-existing-dir' option of 'push' command
-#: bzrlib/builtins.py:1131
+#: bzrlib/builtins.py:1130
 msgid ""
 "By default push will fail if the target directory exists, but does not "
 "already have a control directory.  This flag will allow push to proceed."
 msgstr ""
 
 # help of 'stacked' option of 'push' command
-#: bzrlib/builtins.py:1136
+#: bzrlib/builtins.py:1135
 msgid ""
 "Create a stacked branch that references the public location of the parent "
 "branch."
 msgstr ""
 
 # help of 'stacked-on' option of 'push' command
-#: bzrlib/builtins.py:1139
+#: bzrlib/builtins.py:1138
 msgid ""
 "Create a stacked branch that refers to another branch for the commit "
 "history. Only the work not present in the referenced branch is included in "
@@ -430,22 +430,22 @@
 msgstr ""
 
 # help of 'strict' option of 'push' command
-#: bzrlib/builtins.py:1144
+#: bzrlib/builtins.py:1143
 msgid ""
 "Refuse to push if there are uncommitted changes in the working tree, --no-"
 "strict disables the check."
 msgstr ""
 
 # help of 'no-tree' option of 'push' command
-#: bzrlib/builtins.py:1147
+#: bzrlib/builtins.py:1146
 msgid "Don't populate the working tree, even for protocols that support it."
 msgstr ""
 
-#: bzrlib/builtins.py:1212
+#: bzrlib/builtins.py:1211
 msgid "Create a new branch that is a copy of an existing branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1214
+#: bzrlib/builtins.py:1213
 msgid ""
 "If the TO_LOCATION is omitted, the last component of the FROM_LOCATION will\n"
 "be used.  In other words, \"branch ../foo/bar\" will attempt to create ./"
@@ -456,65 +456,65 @@
 "create ./foo-bar."
 msgstr ""
 
-#: bzrlib/builtins.py:1221
+#: bzrlib/builtins.py:1220
 msgid ""
 "To retrieve the branch as of a particular revision, supply the --revision\n"
 "parameter, as in \"branch foo/bar -r 5\"."
 msgstr ""
 
-#: bzrlib/builtins.py:1224
+#: bzrlib/builtins.py:1223
 msgid "The synonyms 'clone' and 'get' for this command are deprecated."
 msgstr ""
 
 # help of 'no-tree' option of 'branch' command
-#: bzrlib/builtins.py:1234
+#: bzrlib/builtins.py:1233
 msgid "Create a branch without a working-tree."
 msgstr ""
 
 # help of 'switch' option of 'branch' command
-#: bzrlib/builtins.py:1236
+#: bzrlib/builtins.py:1235
 msgid "Switch the checkout in the current directory to the new branch."
 msgstr ""
 
 # help of 'stacked' option of 'branch' command
-#: bzrlib/builtins.py:1239
+#: bzrlib/builtins.py:1238
 msgid ""
 "Create a stacked branch referring to the source branch. The new branch will "
 "depend on the availability of the source branch for all operations."
 msgstr ""
 
 # help of 'standalone' option of 'branch' command
-#: bzrlib/builtins.py:1243
+#: bzrlib/builtins.py:1242
 msgid "Do not use a shared repository, even if available."
 msgstr ""
 
 # help of 'use-existing-dir' option of 'branch' command
-#: bzrlib/builtins.py:1245
+#: bzrlib/builtins.py:1244
 msgid ""
 "By default branch will fail if the target directory exists, but does not "
 "already have a control directory.  This flag will allow branch to proceed."
 msgstr ""
 
 # help of 'bind' option of 'branch' command
-#: bzrlib/builtins.py:1250
+#: bzrlib/builtins.py:1249
 msgid "Bind new branch to from location."
 msgstr ""
 
-#: bzrlib/builtins.py:1342
+#: bzrlib/builtins.py:1341
 msgid "List the branches available at the current location."
 msgstr ""
 
-#: bzrlib/builtins.py:1344
+#: bzrlib/builtins.py:1343
 msgid ""
 "This command will print the names of all the branches at the current "
 "location."
 msgstr ""
 
-#: bzrlib/builtins.py:1359
+#: bzrlib/builtins.py:1358
 msgid "Create a new checkout of an existing branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1361
+#: bzrlib/builtins.py:1360
 msgid ""
 "If BRANCH_LOCATION is omitted, checkout will reconstitute a working tree "
 "for\n"
@@ -524,7 +524,7 @@
 "location using SFTP."
 msgstr ""
 
-#: bzrlib/builtins.py:1366
+#: bzrlib/builtins.py:1365
 msgid ""
 "If the TO_LOCATION is omitted, the last component of the BRANCH_LOCATION "
 "will\n"
@@ -536,7 +536,7 @@
 "create ./foo-bar."
 msgstr ""
 
-#: bzrlib/builtins.py:1373
+#: bzrlib/builtins.py:1372
 msgid ""
 "To retrieve the branch as of a particular revision, supply the --revision\n"
 "parameter, as in \"checkout foo/bar -r 5\". Note that this will be "
@@ -547,7 +547,7 @@
 msgstr ""
 
 # help of 'lightweight' option of 'checkout' command
-#: bzrlib/builtins.py:1383
+#: bzrlib/builtins.py:1382
 msgid ""
 "Perform a lightweight checkout.  Lightweight checkouts depend on access to "
 "the branch for every operation.  Normal checkouts can perform common "
@@ -556,103 +556,103 @@
 msgstr ""
 
 # help of 'files-from' option of 'branch' command
-#: bzrlib/builtins.py:1390
+#: bzrlib/builtins.py:1389
 msgid "Get file contents from this tree."
 msgstr ""
 
 # help of 'hardlink' option of 'branch' command
-#: bzrlib/builtins.py:1392
+#: bzrlib/builtins.py:1391
 msgid "Hard-link working tree files where possible."
 msgstr ""
 
-#: bzrlib/builtins.py:1433
+#: bzrlib/builtins.py:1432
 msgid ""
 "Show list of renamed files.\n"
 "    "
 msgstr ""
 
-#: bzrlib/builtins.py:1463
+#: bzrlib/builtins.py:1462
 msgid "Update a tree to have the latest code committed to its branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1465
+#: bzrlib/builtins.py:1464
 msgid ""
 "This will perform a merge into the working tree, and may generate\n"
 "conflicts. If you have any local changes, you will still\n"
 "need to commit them after the update for the update to be complete."
 msgstr ""
 
-#: bzrlib/builtins.py:1469
+#: bzrlib/builtins.py:1468
 msgid ""
 "If you want to discard your local changes, you can just do a\n"
 "'bzr revert' instead of 'bzr commit' after the update."
 msgstr ""
 
-#: bzrlib/builtins.py:1472
+#: bzrlib/builtins.py:1471
 msgid ""
 "If you want to restore a file that has been removed locally, use\n"
 "'bzr revert' instead of 'bzr update'."
 msgstr ""
 
-#: bzrlib/builtins.py:1475
+#: bzrlib/builtins.py:1474
 msgid ""
 "If the tree's branch is bound to a master branch, it will also update\n"
 "the branch from the master."
 msgstr ""
 
-#: bzrlib/builtins.py:1556
+#: bzrlib/builtins.py:1555
 msgid "Show information about a working tree, branch or repository."
 msgstr ""
 
-#: bzrlib/builtins.py:1558
+#: bzrlib/builtins.py:1557
 msgid ""
 "This command will show all known locations and formats associated to the\n"
 "tree, branch or repository."
 msgstr ""
 
-#: bzrlib/builtins.py:1561
+#: bzrlib/builtins.py:1560
 msgid ""
 "In verbose mode, statistical information is included with each report.\n"
 "To see extended statistic information, use a verbosity level of 2 or\n"
 "higher by specifying the verbose option multiple times, e.g. -vv."
 msgstr ""
 
-#: bzrlib/builtins.py:1565
+#: bzrlib/builtins.py:1564
 msgid "Branches and working trees will also report any missing revisions."
 msgstr ""
 
-#: bzrlib/builtins.py:1569
+#: bzrlib/builtins.py:1568
 msgid "  Display information on the format and related locations:"
 msgstr ""
 
-#: bzrlib/builtins.py:1571
+#: bzrlib/builtins.py:1570
 msgid "    bzr info"
 msgstr ""
 
-#: bzrlib/builtins.py:1573
+#: bzrlib/builtins.py:1572
 msgid ""
 "  Display the above together with extended format information and\n"
 "  basic statistics (like the number of files in the working tree and\n"
 "  number of revisions in the branch and repository):"
 msgstr ""
 
-#: bzrlib/builtins.py:1577
+#: bzrlib/builtins.py:1576
 msgid "    bzr info -v"
 msgstr ""
 
-#: bzrlib/builtins.py:1579
+#: bzrlib/builtins.py:1578
 msgid "  Display the above together with number of committers to the branch:"
 msgstr ""
 
-#: bzrlib/builtins.py:1581
+#: bzrlib/builtins.py:1580
 msgid "    bzr info -vv"
 msgstr ""
 
-#: bzrlib/builtins.py:1600
+#: bzrlib/builtins.py:1599
 msgid "Remove files or directories."
 msgstr ""
 
-#: bzrlib/builtins.py:1602
+#: bzrlib/builtins.py:1601
 msgid ""
 "This makes Bazaar stop tracking changes to the specified files. Bazaar will\n"
 "delete them if they can easily be recovered using revert otherwise they\n"
@@ -662,25 +662,25 @@
 msgstr ""
 
 # help of 'new' option of 'remove' command
-#: bzrlib/builtins.py:1610
+#: bzrlib/builtins.py:1609
 msgid "Only remove files that have never been committed."
 msgstr ""
 
 # help of 'file-deletion-strategy' option of 'remove' command
-#: bzrlib/builtins.py:1612
+#: bzrlib/builtins.py:1611
 msgid "The file deletion mode to be used."
 msgstr ""
 
 # title of 'file-deletion-strategy' option of 'remove' command
-#: bzrlib/builtins.py:1613
+#: bzrlib/builtins.py:1612
 msgid "Deletion Strategy"
 msgstr ""
 
-#: bzrlib/builtins.py:1704
+#: bzrlib/builtins.py:1703
 msgid "Reconcile bzr metadata in a branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1706
+#: bzrlib/builtins.py:1705
 msgid ""
 "This can correct data mismatches that may have been caused by\n"
 "previous ghost operations or bzr upgrades. You should only\n"
@@ -688,7 +688,7 @@
 "advises you to run it."
 msgstr ""
 
-#: bzrlib/builtins.py:1711
+#: bzrlib/builtins.py:1710
 msgid ""
 "If a second branch is provided, cross-branch reconciliation is\n"
 "also attempted, which will check that data like the tree root\n"
@@ -696,27 +696,27 @@
 "correctly in both branches."
 msgstr ""
 
-#: bzrlib/builtins.py:1716
+#: bzrlib/builtins.py:1715
 msgid ""
 "At the same time it is run it may recompress data resulting in\n"
 "a potential saving in disk space or performance gain."
 msgstr ""
 
-#: bzrlib/builtins.py:1719
+#: bzrlib/builtins.py:1718
 msgid "The branch *MUST* be on a listable system such as local disk or sftp."
 msgstr ""
 
-#: bzrlib/builtins.py:1783
+#: bzrlib/builtins.py:1782
 msgid "Make a directory into a versioned branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1785
+#: bzrlib/builtins.py:1784
 msgid ""
 "Use this to create an empty branch, or before importing an\n"
 "existing project."
 msgstr ""
 
-#: bzrlib/builtins.py:1788
+#: bzrlib/builtins.py:1787
 msgid ""
 "If there is a repository in a parent directory of the location, then\n"
 "the history of the branch will be stored in the repository.  Otherwise\n"
@@ -724,17 +724,17 @@
 "in the .bzr directory."
 msgstr ""
 
-#: bzrlib/builtins.py:1793
+#: bzrlib/builtins.py:1792
 msgid ""
 "If there is already a branch at the location but it has no working tree,\n"
 "the tree can be populated with 'bzr checkout'."
 msgstr ""
 
-#: bzrlib/builtins.py:1796
+#: bzrlib/builtins.py:1795
 msgid "Recipe for importing a tree of files::"
 msgstr ""
 
-#: bzrlib/builtins.py:1798
+#: bzrlib/builtins.py:1797
 msgid ""
 "    cd ~/project\n"
 "    bzr init\n"
@@ -744,30 +744,30 @@
 msgstr ""
 
 # help of 'create-prefix' option of 'init' command
-#: bzrlib/builtins.py:1809
+#: bzrlib/builtins.py:1808
 msgid "Create the path leading up to the branch if it does not already exist."
 msgstr ""
 
 # help of 'format' option of 'init' command
-#: bzrlib/builtins.py:1812
+#: bzrlib/builtins.py:1811
 msgid "Specify a format for this branch. See \"help formats\"."
 msgstr ""
 
 # help of 'append-revisions-only' option of 'init' command
-#: bzrlib/builtins.py:1820
+#: bzrlib/builtins.py:1819
 msgid "Never change revnos or the existing log.  Append revisions to it only."
 msgstr ""
 
 # help of 'no-tree' option of 'init' command
-#: bzrlib/builtins.py:1823
+#: bzrlib/builtins.py:1822
 msgid "Create a branch without a working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:1900
+#: bzrlib/builtins.py:1899
 msgid "Create a shared repository for branches to share storage space."
 msgstr ""
 
-#: bzrlib/builtins.py:1902
+#: bzrlib/builtins.py:1901
 msgid ""
 "New branches created under the repository directory will store their\n"
 "revisions in the repository, not in the branch directory.  For branches\n"
@@ -775,7 +775,7 @@
 "speeds up the creation of new branches."
 msgstr ""
 
-#: bzrlib/builtins.py:1907
+#: bzrlib/builtins.py:1906
 msgid ""
 "If the --no-trees option is given then the branches in the repository\n"
 "will not have working trees by default.  They will still exist as \n"
@@ -785,23 +785,23 @@
 "branches, such as on a server."
 msgstr ""
 
-#: bzrlib/builtins.py:1914
+#: bzrlib/builtins.py:1913
 msgid ""
 ":Examples:\n"
 "    Create a shared repository holding just branches::"
 msgstr ""
 
-#: bzrlib/builtins.py:1917
+#: bzrlib/builtins.py:1916
 msgid ""
 "        bzr init-repo --no-trees repo\n"
 "        bzr init repo/trunk"
 msgstr ""
 
-#: bzrlib/builtins.py:1920
+#: bzrlib/builtins.py:1919
 msgid "    Make a lightweight checkout elsewhere::"
 msgstr ""
 
-#: bzrlib/builtins.py:1922
+#: bzrlib/builtins.py:1921
 msgid ""
 "        bzr checkout --lightweight repo/trunk trunk-checkout\n"
 "        cd trunk-checkout\n"
@@ -809,26 +809,26 @@
 msgstr ""
 
 # help of 'format' option of 'init-repository' command
-#: bzrlib/builtins.py:1930
+#: bzrlib/builtins.py:1929
 msgid ""
 "Specify a format for this repository. See \"bzr help formats\" for details."
 msgstr ""
 
 # title of 'format' option of 'init-repository' command
-#: bzrlib/builtins.py:1934
+#: bzrlib/builtins.py:1933
 msgid "Repository format"
 msgstr ""
 
 # help of 'no-trees' option of 'init-repository' command
-#: bzrlib/builtins.py:1936
+#: bzrlib/builtins.py:1935
 msgid "Branches in the repository will default to not having a working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:1960
+#: bzrlib/builtins.py:1959
 msgid "Show differences in the working tree, between revisions or branches."
 msgstr ""
 
-#: bzrlib/builtins.py:1962
+#: bzrlib/builtins.py:1961
 msgid ""
 "If no arguments are given, all changes for the current tree are listed.\n"
 "If files are given, only the changes in those files are listed.\n"
@@ -838,13 +838,13 @@
 "given."
 msgstr ""
 
-#: bzrlib/builtins.py:1969
+#: bzrlib/builtins.py:1968
 msgid ""
 "\"bzr diff -p1\" is equivalent to \"bzr diff --prefix old/:new/\", and\n"
 "produces patches suitable for \"patch -p1\"."
 msgstr ""
 
-#: bzrlib/builtins.py:1972
+#: bzrlib/builtins.py:1971
 msgid ""
 "Note that when using the -r argument with a range of revisions, the\n"
 "differences are computed between the two specified revisions.  That\n"
@@ -854,7 +854,7 @@
 "in the range."
 msgstr ""
 
-#: bzrlib/builtins.py:1979
+#: bzrlib/builtins.py:1978
 msgid ""
 ":Exit values:\n"
 "    1 - changed\n"
@@ -863,113 +863,113 @@
 "    0 - no change"
 msgstr ""
 
-#: bzrlib/builtins.py:1985
+#: bzrlib/builtins.py:1984
 msgid ""
 ":Examples:\n"
 "    Shows the difference in the working tree versus the last commit::"
 msgstr ""
 
-#: bzrlib/builtins.py:1988
+#: bzrlib/builtins.py:1987
 msgid "        bzr diff"
 msgstr ""
 
-#: bzrlib/builtins.py:1990
+#: bzrlib/builtins.py:1989
 msgid "    Difference between the working tree and revision 1::"
 msgstr ""
 
-#: bzrlib/builtins.py:1992
+#: bzrlib/builtins.py:1991
 msgid "        bzr diff -r1"
 msgstr ""
 
-#: bzrlib/builtins.py:1994
+#: bzrlib/builtins.py:1993
 msgid "    Difference between revision 3 and revision 1::"
 msgstr ""
 
-#: bzrlib/builtins.py:1996
+#: bzrlib/builtins.py:1995
 msgid "        bzr diff -r1..3"
 msgstr ""
 
-#: bzrlib/builtins.py:1998
+#: bzrlib/builtins.py:1997
 msgid "    Difference between revision 3 and revision 1 for branch xxx::"
 msgstr ""
 
-#: bzrlib/builtins.py:2000
+#: bzrlib/builtins.py:1999
 msgid "        bzr diff -r1..3 xxx"
 msgstr ""
 
-#: bzrlib/builtins.py:2002
+#: bzrlib/builtins.py:2001
 msgid "    The changes introduced by revision 2 (equivalent to -r1..2)::"
 msgstr ""
 
-#: bzrlib/builtins.py:2004
+#: bzrlib/builtins.py:2003
 msgid "        bzr diff -c2"
 msgstr ""
 
-#: bzrlib/builtins.py:2006
+#: bzrlib/builtins.py:2005
 msgid ""
 "    To see the changes introduced by revision X::\n"
 "    \n"
 "        bzr diff -cX"
 msgstr ""
 
-#: bzrlib/builtins.py:2010
+#: bzrlib/builtins.py:2009
 msgid ""
 "    Note that in the case of a merge, the -c option shows the changes\n"
 "    compared to the left hand parent. To see the changes against\n"
 "    another parent, use::"
 msgstr ""
 
-#: bzrlib/builtins.py:2014
+#: bzrlib/builtins.py:2013
 msgid "        bzr diff -r<chosen_parent>..X"
 msgstr ""
 
-#: bzrlib/builtins.py:2016
+#: bzrlib/builtins.py:2015
 msgid ""
 "    The changes between the current revision and the previous revision\n"
 "    (equivalent to -c-1 and -r-2..-1)"
 msgstr ""
 
-#: bzrlib/builtins.py:2019
+#: bzrlib/builtins.py:2018
 msgid "        bzr diff -r-2.."
 msgstr ""
 
-#: bzrlib/builtins.py:2021
+#: bzrlib/builtins.py:2020
 msgid "    Show just the differences for file NEWS::"
 msgstr ""
 
-#: bzrlib/builtins.py:2023
+#: bzrlib/builtins.py:2022
 msgid "        bzr diff NEWS"
 msgstr ""
 
-#: bzrlib/builtins.py:2025
+#: bzrlib/builtins.py:2024
 msgid "    Show the differences in working tree xxx for file NEWS::"
 msgstr ""
 
-#: bzrlib/builtins.py:2027
+#: bzrlib/builtins.py:2026
 msgid "        bzr diff xxx/NEWS"
 msgstr ""
 
-#: bzrlib/builtins.py:2029
+#: bzrlib/builtins.py:2028
 msgid "    Show the differences from branch xxx to this working tree:"
 msgstr ""
 
-#: bzrlib/builtins.py:2031
+#: bzrlib/builtins.py:2030
 msgid "        bzr diff --old xxx"
 msgstr ""
 
-#: bzrlib/builtins.py:2033
+#: bzrlib/builtins.py:2032
 msgid "    Show the differences between two branches for file NEWS::"
 msgstr ""
 
-#: bzrlib/builtins.py:2035
+#: bzrlib/builtins.py:2034
 msgid "        bzr diff --old xxx --new yyy NEWS"
 msgstr ""
 
-#: bzrlib/builtins.py:2037
+#: bzrlib/builtins.py:2036
 msgid "    Same as 'bzr diff' but prefix paths with old/ and new/::"
 msgstr ""
 
-#: bzrlib/builtins.py:2039
+#: bzrlib/builtins.py:2038
 msgid ""
 "        bzr diff --prefix old/:new/\n"
 "        \n"
@@ -979,63 +979,63 @@
 msgstr ""
 
 # help of 'diff-options' option of 'diff' command
-#: bzrlib/builtins.py:2049
+#: bzrlib/builtins.py:2048
 msgid "Pass these options to the external diff program."
 msgstr ""
 
 # help of 'prefix' option of 'diff' command
-#: bzrlib/builtins.py:2052
+#: bzrlib/builtins.py:2051
 msgid ""
 "Set prefixes added to old and new filenames, as two values separated by a "
 "colon. (eg \"old/:new/\")."
 msgstr ""
 
 # help of 'old' option of 'diff' command
-#: bzrlib/builtins.py:2055
+#: bzrlib/builtins.py:2054
 msgid "Branch/tree to compare from."
 msgstr ""
 
 # help of 'new' option of 'diff' command
-#: bzrlib/builtins.py:2059
+#: bzrlib/builtins.py:2058
 msgid "Branch/tree to compare to."
 msgstr ""
 
 # help of 'using' option of 'diff' command
-#: bzrlib/builtins.py:2065
+#: bzrlib/builtins.py:2064
 msgid "Use this command to compare files."
 msgstr ""
 
 # help of 'format' option of 'diff' command
-#: bzrlib/builtins.py:2070
+#: bzrlib/builtins.py:2069
 msgid "Diff format to use."
 msgstr ""
 
 # title of 'format' option of 'diff' command
-#: bzrlib/builtins.py:2072
+#: bzrlib/builtins.py:2071
 msgid "Diff format"
 msgstr ""
 
-#: bzrlib/builtins.py:2122
+#: bzrlib/builtins.py:2121
 msgid ""
 "List files deleted in the working tree.\n"
 "    "
 msgstr ""
 
-#: bzrlib/builtins.py:2200
+#: bzrlib/builtins.py:2199
 msgid "Show the tree root directory."
 msgstr ""
 
-#: bzrlib/builtins.py:2202
+#: bzrlib/builtins.py:2201
 msgid ""
 "The root is the nearest enclosing directory with a .bzr control\n"
 "directory."
 msgstr ""
 
-#: bzrlib/builtins.py:2230
+#: bzrlib/builtins.py:2229
 msgid "Show historical log for a branch or subset of a branch."
 msgstr ""
 
-#: bzrlib/builtins.py:2232
+#: bzrlib/builtins.py:2231
 msgid ""
 "log is bzr's default tool for exploring the history of a branch.\n"
 "The branch to use is taken from the first parameter. If no parameters\n"
@@ -1043,14 +1043,14 @@
 "Here are some simple examples::"
 msgstr ""
 
-#: bzrlib/builtins.py:2237
+#: bzrlib/builtins.py:2236
 msgid ""
 "  bzr log                       log the current branch\n"
 "  bzr log foo.py                log a file in its branch\n"
 "  bzr log http://server/branch  log a branch on a server"
 msgstr ""
 
-#: bzrlib/builtins.py:2241
+#: bzrlib/builtins.py:2240
 msgid ""
 "The filtering, ordering and information shown for each revision can\n"
 "be controlled as explained below. By default, all revisions are\n"
@@ -1060,11 +1060,11 @@
 "were merged."
 msgstr ""
 
-#: bzrlib/builtins.py:2248
+#: bzrlib/builtins.py:2247
 msgid ":Output control:"
 msgstr ""
 
-#: bzrlib/builtins.py:2250
+#: bzrlib/builtins.py:2249
 msgid ""
 "  The log format controls how information about each revision is\n"
 "  displayed. The standard log formats are called ``long``, ``short``\n"
@@ -1072,13 +1072,13 @@
 "  for more details on log formats."
 msgstr ""
 
-#: bzrlib/builtins.py:2255
+#: bzrlib/builtins.py:2254
 msgid ""
 "  The following options can be used to control what information is\n"
 "  displayed::"
 msgstr ""
 
-#: bzrlib/builtins.py:2258
+#: bzrlib/builtins.py:2257
 msgid ""
 "    -l N        display a maximum of N revisions\n"
 "    -n N        display N levels of revisions (0 for all, 1 for collapsed)\n"
@@ -1087,25 +1087,25 @@
 "    --show-ids  display revision-ids (and file-ids), not just revnos"
 msgstr ""
 
-#: bzrlib/builtins.py:2264
+#: bzrlib/builtins.py:2263
 msgid ""
 "  Note that the default number of levels to display is a function of the\n"
 "  log format. If the -n option is not used, the standard log formats show\n"
 "  just the top level (mainline)."
 msgstr ""
 
-#: bzrlib/builtins.py:2268
+#: bzrlib/builtins.py:2267
 msgid ""
 "  Status summaries are shown using status flags like A, M, etc. To see\n"
 "  the changes explained using words like ``added`` and ``modified``\n"
 "  instead, use the -vv option."
 msgstr ""
 
-#: bzrlib/builtins.py:2272
+#: bzrlib/builtins.py:2271
 msgid ":Ordering control:"
 msgstr ""
 
-#: bzrlib/builtins.py:2274
+#: bzrlib/builtins.py:2273
 msgid ""
 "  To display revisions from oldest to newest, use the --forward option.\n"
 "  In most cases, using this option will have little impact on the total\n"
@@ -1113,17 +1113,17 @@
 "  display revisions like --reverse does when it can."
 msgstr ""
 
-#: bzrlib/builtins.py:2279
+#: bzrlib/builtins.py:2278
 msgid ":Revision filtering:"
 msgstr ""
 
-#: bzrlib/builtins.py:2281
+#: bzrlib/builtins.py:2280
 msgid ""
 "  The -r option can be used to specify what revision or range of revisions\n"
 "  to filter against. The various forms are shown below::"
 msgstr ""
 
-#: bzrlib/builtins.py:2284
+#: bzrlib/builtins.py:2283
 msgid ""
 "    -rX      display revision X\n"
 "    -rX..    display revision X and later\n"
@@ -1131,13 +1131,13 @@
 "    -rX..Y   display from X to Y inclusive"
 msgstr ""
 
-#: bzrlib/builtins.py:2289
+#: bzrlib/builtins.py:2288
 msgid ""
 "  See ``bzr help revisionspec`` for details on how to specify X and Y.\n"
 "  Some common examples are given below::"
 msgstr ""
 
-#: bzrlib/builtins.py:2292
+#: bzrlib/builtins.py:2291
 msgid ""
 "    -r-1                show just the tip\n"
 "    -r-10..             show the last 10 mainline revisions\n"
@@ -1147,7 +1147,7 @@
 "    -rdate:yesterday..  show changes since yesterday"
 msgstr ""
 
-#: bzrlib/builtins.py:2299
+#: bzrlib/builtins.py:2298
 msgid ""
 "  When logging a range of revisions using -rX..Y, log starts at\n"
 "  revision Y and searches back in history through the primary\n"
@@ -1157,73 +1157,73 @@
 "  a nested merge revision and the log will be truncated accordingly."
 msgstr ""
 
-#: bzrlib/builtins.py:2306
+#: bzrlib/builtins.py:2305
 msgid ":Path filtering:"
 msgstr ""
 
-#: bzrlib/builtins.py:2308
+#: bzrlib/builtins.py:2307
 msgid ""
 "  If parameters are given and the first one is not a branch, the log\n"
 "  will be filtered to show only those revisions that changed the\n"
 "  nominated files or directories."
 msgstr ""
 
-#: bzrlib/builtins.py:2312
+#: bzrlib/builtins.py:2311
 msgid ""
 "  Filenames are interpreted within their historical context. To log a\n"
 "  deleted file, specify a revision range so that the file existed at\n"
 "  the end or start of the range."
 msgstr ""
 
-#: bzrlib/builtins.py:2316
+#: bzrlib/builtins.py:2315
 msgid ""
 "  Historical context is also important when interpreting pathnames of\n"
 "  renamed files/directories. Consider the following example:"
 msgstr ""
 
-#: bzrlib/builtins.py:2319
+#: bzrlib/builtins.py:2318
 msgid ""
 "  * revision 1: add tutorial.txt\n"
 "  * revision 2: modify tutorial.txt\n"
 "  * revision 3: rename tutorial.txt to guide.txt; add tutorial.txt"
 msgstr ""
 
-#: bzrlib/builtins.py:2323
+#: bzrlib/builtins.py:2322
 msgid "  In this case:"
 msgstr ""
 
-#: bzrlib/builtins.py:2325
+#: bzrlib/builtins.py:2324
 msgid "  * ``bzr log guide.txt`` will log the file added in revision 1"
 msgstr ""
 
-#: bzrlib/builtins.py:2327
+#: bzrlib/builtins.py:2326
 msgid "  * ``bzr log tutorial.txt`` will log the new file added in revision 3"
 msgstr ""
 
-#: bzrlib/builtins.py:2329
+#: bzrlib/builtins.py:2328
 msgid ""
 "  * ``bzr log -r2 -p tutorial.txt`` will show the changes made to\n"
 "    the original file in revision 2."
 msgstr ""
 
-#: bzrlib/builtins.py:2332
+#: bzrlib/builtins.py:2331
 msgid ""
 "  * ``bzr log -r2 -p guide.txt`` will display an error message as there\n"
 "    was no file called guide.txt in revision 2."
 msgstr ""
 
-#: bzrlib/builtins.py:2335
+#: bzrlib/builtins.py:2334
 msgid ""
 "  Renames are always followed by log. By design, there is no need to\n"
 "  explicitly ask for this (and no way to stop logging a file back\n"
 "  until it was last renamed)."
 msgstr ""
 
-#: bzrlib/builtins.py:2339
+#: bzrlib/builtins.py:2338
 msgid ":Other filtering:"
 msgstr ""
 
-#: bzrlib/builtins.py:2341
+#: bzrlib/builtins.py:2340
 msgid ""
 "  The --match option can be used for finding revisions that match a\n"
 "  regular expression in a commit message, committer, author or bug.\n"
@@ -1232,11 +1232,11 @@
 "  --match-message can be used to only match a specific field."
 msgstr ""
 
-#: bzrlib/builtins.py:2347
+#: bzrlib/builtins.py:2346
 msgid ":Tips & tricks:"
 msgstr ""
 
-#: bzrlib/builtins.py:2349
+#: bzrlib/builtins.py:2348
 msgid ""
 "  GUI tools and IDEs are often better at exploring history than command\n"
 "  line tools: you may prefer qlog or viz from qbzr or bzr-gtk, the\n"
@@ -1245,11 +1245,11 @@
 "  <http://wiki.bazaar.canonical.com/IDEIntegration>.  "
 msgstr ""
 
-#: bzrlib/builtins.py:2355
+#: bzrlib/builtins.py:2354
 msgid "  You may find it useful to add the aliases below to ``bazaar.conf``::"
 msgstr ""
 
-#: bzrlib/builtins.py:2357
+#: bzrlib/builtins.py:2356
 msgid ""
 "    [ALIASES]\n"
 "    tip = log -r-1\n"
@@ -1257,20 +1257,20 @@
 "    show = log -v -p"
 msgstr ""
 
-#: bzrlib/builtins.py:2362
+#: bzrlib/builtins.py:2361
 msgid ""
 "  ``bzr tip`` will then show the latest revision while ``bzr top``\n"
 "  will show the last 10 mainline revisions. To see the details of a\n"
 "  particular revision X,  ``bzr show -rX``."
 msgstr ""
 
-#: bzrlib/builtins.py:2366
+#: bzrlib/builtins.py:2365
 msgid ""
 "  If you are interested in looking deeper into a particular merge X,\n"
 "  use ``bzr log -n0 -rX``."
 msgstr ""
 
-#: bzrlib/builtins.py:2369
+#: bzrlib/builtins.py:2368
 msgid ""
 "  ``bzr log -v`` on a branch with lots of history is currently\n"
 "  very slow. A fix for this issue is currently under development.\n"
@@ -1278,7 +1278,7 @@
 "  be given when using the -v option."
 msgstr ""
 
-#: bzrlib/builtins.py:2374
+#: bzrlib/builtins.py:2373
 msgid ""
 "  bzr has a generic full-text matching plugin, bzr-search, that can be\n"
 "  used to find revisions matching user names, commit messages, etc.\n"
@@ -1286,7 +1286,7 @@
 "  a list of words but not others."
 msgstr ""
 
-#: bzrlib/builtins.py:2379
+#: bzrlib/builtins.py:2378
 msgid ""
 "  When exploring non-mainline history on large projects with deep\n"
 "  history, the performance of log can be greatly improved by installing\n"
@@ -1295,132 +1295,132 @@
 msgstr ""
 
 # help of 'forward' option of 'log' command
-#: bzrlib/builtins.py:2388
+#: bzrlib/builtins.py:2387
 msgid "Show from oldest to newest."
 msgstr ""
 
 # help of 'verbose' option of 'log' command
-#: bzrlib/builtins.py:2391
+#: bzrlib/builtins.py:2390
 msgid "Show files changed in each revision."
 msgstr ""
 
 # help of 'change' option of 'log' command
-#: bzrlib/builtins.py:2397
+#: bzrlib/builtins.py:2396
 msgid "Show just the specified revision. See also \"help revisionspec\"."
 msgstr ""
 
 # help of 'authors' option of 'log' command
-#: bzrlib/builtins.py:2401
+#: bzrlib/builtins.py:2400
 msgid "What names to list as authors - first, all or committer."
 msgstr ""
 
 # title of 'authors' option of 'log' command
-#: bzrlib/builtins.py:2402
+#: bzrlib/builtins.py:2401
 msgid "Authors"
 msgstr ""
 
 # help of 'levels' option of 'log' command
-#: bzrlib/builtins.py:2407
+#: bzrlib/builtins.py:2406
 msgid "Number of levels to display - 0 for all, 1 for flat."
 msgstr ""
 
 # help of 'limit' option of 'log' command
-#: bzrlib/builtins.py:2417
+#: bzrlib/builtins.py:2416
 msgid "Limit the output to the first N revisions."
 msgstr ""
 
 # help of 'show-diff' option of 'log' command
-#: bzrlib/builtins.py:2422
+#: bzrlib/builtins.py:2421
 msgid "Show changes made in each revision as a patch."
 msgstr ""
 
 # help of 'include-merges' option of 'log' command
-#: bzrlib/builtins.py:2424
+#: bzrlib/builtins.py:2423
 msgid "Show merged revisions like --levels 0 does."
 msgstr ""
 
 # help of 'exclude-common-ancestry' option of 'log' command
-#: bzrlib/builtins.py:2426
+#: bzrlib/builtins.py:2425
 msgid ""
 "Display only the revisions that are not part of both ancestries (require -"
 "rX..Y)"
 msgstr ""
 
 # help of 'signatures' option of 'log' command
-#: bzrlib/builtins.py:2430
+#: bzrlib/builtins.py:2429
 msgid "Show digital signature validity"
 msgstr ""
 
 # help of 'match' option of 'log' command
-#: bzrlib/builtins.py:2433
+#: bzrlib/builtins.py:2432
 msgid "Show revisions whose properties match this expression."
 msgstr ""
 
 # help of 'match-message' option of 'log' command
-#: bzrlib/builtins.py:2437
+#: bzrlib/builtins.py:2436
 msgid "Show revisions whose message matches this expression."
 msgstr ""
 
 # help of 'match-committer' option of 'log' command
-#: bzrlib/builtins.py:2441
+#: bzrlib/builtins.py:2440
 msgid "Show revisions whose committer matches this expression."
 msgstr ""
 
 # help of 'match-author' option of 'log' command
-#: bzrlib/builtins.py:2445
+#: bzrlib/builtins.py:2444
 msgid "Show revisions whose authors match this expression."
 msgstr ""
 
 # help of 'match-bugs' option of 'log' command
-#: bzrlib/builtins.py:2449
+#: bzrlib/builtins.py:2448
 msgid "Show revisions whose bugs match this expression."
 msgstr ""
 
-#: bzrlib/builtins.py:2690
+#: bzrlib/builtins.py:2689
 msgid ""
 "List files in a tree.\n"
 "    "
 msgstr ""
 
 # help of 'recursive' option of 'ls' command
-#: bzrlib/builtins.py:2699
+#: bzrlib/builtins.py:2698
 msgid "Recurse into subdirectories."
 msgstr ""
 
 # help of 'from-root' option of 'ls' command
-#: bzrlib/builtins.py:2701
+#: bzrlib/builtins.py:2700
 msgid "Print paths relative to the root of the branch."
 msgstr ""
 
 # help of 'unknown' option of 'ls' command
-#: bzrlib/builtins.py:2703
+#: bzrlib/builtins.py:2702
 msgid "Print unknown files."
 msgstr ""
 
 # help of 'versioned' option of 'ls' command
-#: bzrlib/builtins.py:2704
+#: bzrlib/builtins.py:2703
 msgid "Print versioned files."
 msgstr ""
 
 # help of 'ignored' option of 'ls' command
-#: bzrlib/builtins.py:2707
+#: bzrlib/builtins.py:2706
 msgid "Print ignored files."
 msgstr ""
 
 # help of 'kind' option of 'ls' command
-#: bzrlib/builtins.py:2709
+#: bzrlib/builtins.py:2708
 msgid "List entries of a particular kind: file, directory, symlink."
 msgstr ""
 
-#: bzrlib/builtins.py:2821
+#: bzrlib/builtins.py:2820
 msgid "Ignore specified files or patterns."
 msgstr ""
 
-#: bzrlib/builtins.py:2823
+#: bzrlib/builtins.py:2822
 msgid "See ``bzr help patterns`` for details on the syntax of patterns."
 msgstr ""
 
-#: bzrlib/builtins.py:2825
+#: bzrlib/builtins.py:2824
 msgid ""
 "If a .bzrignore file does not exist, the ignore command\n"
 "will create one and add the specified files or patterns to the newly\n"
@@ -1429,7 +1429,7 @@
 "the use of the ignore command will require an explicit add command."
 msgstr ""
 
-#: bzrlib/builtins.py:2831
+#: bzrlib/builtins.py:2830
 msgid ""
 "To remove patterns from the ignore list, edit the .bzrignore file.\n"
 "After adding, editing or deleting that file either indirectly by\n"
@@ -1437,7 +1437,7 @@
 "it."
 msgstr ""
 
-#: bzrlib/builtins.py:2836
+#: bzrlib/builtins.py:2835
 msgid ""
 "Bazaar also supports a global ignore file ~/.bazaar/ignore. On Windows\n"
 "the global ignore file can be found in the application data directory as\n"
@@ -1446,20 +1446,20 @@
 "can be edited directly using an editor."
 msgstr ""
 
-#: bzrlib/builtins.py:2842
+#: bzrlib/builtins.py:2841
 msgid ""
 "Patterns prefixed with '!' are exceptions to ignore patterns and take\n"
 "precedence over regular ignores.  Such exceptions are used to specify\n"
 "files that should be versioned which would otherwise be ignored."
 msgstr ""
 
-#: bzrlib/builtins.py:2846
+#: bzrlib/builtins.py:2845
 msgid ""
 "Patterns prefixed with '!!' act as regular ignore patterns, but have\n"
 "precedence over the '!' exception patterns."
 msgstr ""
 
-#: bzrlib/builtins.py:2849
+#: bzrlib/builtins.py:2848
 msgid ""
 ":Notes: \n"
 "    \n"
@@ -1467,63 +1467,63 @@
 "  the shell on Unix."
 msgstr ""
 
-#: bzrlib/builtins.py:2854
+#: bzrlib/builtins.py:2853
 msgid ""
 "* Ignore patterns starting with \"#\" act as comments in the ignore file.\n"
 "  To ignore patterns that begin with that character, use the \"RE:\" prefix."
 msgstr ""
 
-#: bzrlib/builtins.py:2857
+#: bzrlib/builtins.py:2856
 msgid ""
 ":Examples:\n"
 "    Ignore the top level Makefile::"
 msgstr ""
 
-#: bzrlib/builtins.py:2860
+#: bzrlib/builtins.py:2859
 msgid "        bzr ignore ./Makefile"
 msgstr ""
 
-#: bzrlib/builtins.py:2862
+#: bzrlib/builtins.py:2861
 msgid "    Ignore .class files in all directories...::"
 msgstr ""
 
-#: bzrlib/builtins.py:2864
+#: bzrlib/builtins.py:2863
 msgid "        bzr ignore \"*.class\""
 msgstr ""
 
-#: bzrlib/builtins.py:2866
+#: bzrlib/builtins.py:2865
 msgid "    ...but do not ignore \"special.class\"::"
 msgstr ""
 
-#: bzrlib/builtins.py:2868
+#: bzrlib/builtins.py:2867
 msgid "        bzr ignore \"!special.class\""
 msgstr ""
 
-#: bzrlib/builtins.py:2870
+#: bzrlib/builtins.py:2869
 msgid "    Ignore files whose name begins with the \"#\" character::"
 msgstr ""
 
-#: bzrlib/builtins.py:2872
+#: bzrlib/builtins.py:2871
 msgid "        bzr ignore \"RE:^#\""
 msgstr ""
 
-#: bzrlib/builtins.py:2874
+#: bzrlib/builtins.py:2873
 msgid "    Ignore .o files under the lib directory::"
 msgstr ""
 
-#: bzrlib/builtins.py:2876
+#: bzrlib/builtins.py:2875
 msgid "        bzr ignore \"lib/**/*.o\""
 msgstr ""
 
-#: bzrlib/builtins.py:2880
+#: bzrlib/builtins.py:2879
 msgid "        bzr ignore \"RE:lib/.*\\.o\""
 msgstr ""
 
-#: bzrlib/builtins.py:2882
+#: bzrlib/builtins.py:2881
 msgid "    Ignore everything but the \"debian\" toplevel directory::"
 msgstr ""
 
-#: bzrlib/builtins.py:2884
+#: bzrlib/builtins.py:2883
 msgid ""
 "        bzr ignore \"RE:(?!debian/).*\"\n"
 "    \n"
@@ -1536,61 +1536,61 @@
 msgstr ""
 
 # help of 'default-rules' option of 'ignore' command
-#: bzrlib/builtins.py:2898
+#: bzrlib/builtins.py:2897
 msgid "Display the default ignore rules that bzr uses."
 msgstr ""
 
-#: bzrlib/builtins.py:2946
+#: bzrlib/builtins.py:2945
 msgid "List ignored files and the patterns that matched them."
 msgstr ""
 
-#: bzrlib/builtins.py:2948
+#: bzrlib/builtins.py:2947
 msgid ""
 "List all the ignored files and the ignore pattern that caused the file to\n"
 "be ignored."
 msgstr ""
 
-#: bzrlib/builtins.py:2951
+#: bzrlib/builtins.py:2950
 msgid "Alternatively, to list just the files::"
 msgstr ""
 
-#: bzrlib/builtins.py:2953
+#: bzrlib/builtins.py:2952
 msgid "    bzr ls --ignored"
 msgstr ""
 
-#: bzrlib/builtins.py:2994
+#: bzrlib/builtins.py:2993
 msgid "Export current or past revision to a destination directory or archive."
 msgstr ""
 
-#: bzrlib/builtins.py:2996
+#: bzrlib/builtins.py:2995
 msgid "If no revision is specified this exports the last committed revision."
 msgstr ""
 
-#: bzrlib/builtins.py:2998
+#: bzrlib/builtins.py:2997
 msgid ""
 "Format may be an \"exporter\" name, such as tar, tgz, tbz2.  If none is\n"
 "given, try to find the format with the extension. If no extension\n"
 "is found exports to a directory (equivalent to --format=dir)."
 msgstr ""
 
-#: bzrlib/builtins.py:3002
+#: bzrlib/builtins.py:3001
 msgid ""
 "If root is supplied, it will be used as the root directory inside\n"
 "container formats (tar, zip, etc). If it is not supplied it will default\n"
 "to the exported filename. The root option has no effect for 'dir' format."
 msgstr ""
 
-#: bzrlib/builtins.py:3006
+#: bzrlib/builtins.py:3005
 msgid ""
 "If branch is omitted then the branch containing the current working\n"
 "directory will be used."
 msgstr ""
 
-#: bzrlib/builtins.py:3009
+#: bzrlib/builtins.py:3008
 msgid "Note: Export of tree with non-ASCII filenames to zip is not supported."
 msgstr ""
 
-#: bzrlib/builtins.py:3011
+#: bzrlib/builtins.py:3010
 msgid ""
 "  =================       =========================\n"
 "  Supported formats       Autodetected by extension\n"
@@ -1604,51 +1604,51 @@
 msgstr ""
 
 # help of 'format' option of 'export' command
-#: bzrlib/builtins.py:3025
+#: bzrlib/builtins.py:3024
 msgid "Type of file to export to."
 msgstr ""
 
 # help of 'filters' option of 'export' command
-#: bzrlib/builtins.py:3028
+#: bzrlib/builtins.py:3027
 msgid "Apply content filters to export the convenient form."
 msgstr ""
 
 # help of 'root' option of 'export' command
-#: bzrlib/builtins.py:3032
+#: bzrlib/builtins.py:3031
 msgid "Name of the root directory inside the exported file."
 msgstr ""
 
 # help of 'per-file-timestamps' option of 'export' command
-#: bzrlib/builtins.py:3034
+#: bzrlib/builtins.py:3033
 msgid ""
 "Set modification time of files to that of the last revision in which it was "
 "changed."
 msgstr ""
 
-#: bzrlib/builtins.py:3058
+#: bzrlib/builtins.py:3057
 msgid "Write the contents of a file as of a given revision to standard output."
 msgstr ""
 
-#: bzrlib/builtins.py:3060
+#: bzrlib/builtins.py:3059
 msgid "If no revision is nominated, the last revision is used."
 msgstr ""
 
-#: bzrlib/builtins.py:3062
+#: bzrlib/builtins.py:3061
 msgid ""
 "Note: Take care to redirect standard output when using this command on a\n"
 "binary file."
 msgstr ""
 
 # help of 'filters' option of 'cat' command
-#: bzrlib/builtins.py:3069
+#: bzrlib/builtins.py:3068
 msgid "Apply content filters to display the convenience form."
 msgstr ""
 
-#: bzrlib/builtins.py:3140
+#: bzrlib/builtins.py:3139
 msgid "Commit changes into a new revision."
 msgstr ""
 
-#: bzrlib/builtins.py:3142
+#: bzrlib/builtins.py:3141
 msgid ""
 "An explanatory message needs to be given for each commit. This is\n"
 "often done by using the --message option (getting the message from the\n"
@@ -1658,44 +1658,44 @@
 "boilerplate text loaded into the editor, use the --show-diff option."
 msgstr ""
 
-#: bzrlib/builtins.py:3149
+#: bzrlib/builtins.py:3148
 msgid ""
 "By default, the entire tree is committed and the person doing the\n"
 "commit is assumed to be the author. These defaults can be overridden\n"
 "as explained below."
 msgstr ""
 
-#: bzrlib/builtins.py:3153
+#: bzrlib/builtins.py:3152
 msgid ":Selective commits:"
 msgstr ""
 
-#: bzrlib/builtins.py:3155
+#: bzrlib/builtins.py:3154
 msgid ""
 "  If selected files are specified, only changes to those files are\n"
 "  committed.  If a directory is specified then the directory and\n"
 "  everything within it is committed."
 msgstr ""
 
-#: bzrlib/builtins.py:3159
+#: bzrlib/builtins.py:3158
 msgid ""
 "  When excludes are given, they take precedence over selected files.\n"
 "  For example, to commit only changes within foo, but not changes\n"
 "  within foo/bar::"
 msgstr ""
 
-#: bzrlib/builtins.py:3163
+#: bzrlib/builtins.py:3162
 msgid "    bzr commit foo -x foo/bar"
 msgstr ""
 
-#: bzrlib/builtins.py:3165
+#: bzrlib/builtins.py:3164
 msgid "  A selective commit after a merge is not yet supported."
 msgstr ""
 
-#: bzrlib/builtins.py:3167
+#: bzrlib/builtins.py:3166
 msgid ":Custom authors:"
 msgstr ""
 
-#: bzrlib/builtins.py:3169
+#: bzrlib/builtins.py:3168
 msgid ""
 "  If the author of the change is not the same person as the committer,\n"
 "  you can specify the author's name using the --author option. The\n"
@@ -1705,11 +1705,11 @@
 "  author."
 msgstr ""
 
-#: bzrlib/builtins.py:3176
+#: bzrlib/builtins.py:3175
 msgid ":Checks:"
 msgstr ""
 
-#: bzrlib/builtins.py:3178
+#: bzrlib/builtins.py:3177
 msgid ""
 "  A common mistake is to forget to add a new file or directory before\n"
 "  running the commit command. The --strict option checks for unknown\n"
@@ -1718,18 +1718,18 @@
 "  for details."
 msgstr ""
 
-#: bzrlib/builtins.py:3184
+#: bzrlib/builtins.py:3183
 msgid ":Things to note:"
 msgstr ""
 
-#: bzrlib/builtins.py:3186
+#: bzrlib/builtins.py:3185
 msgid ""
 "  If you accidentially commit the wrong changes or make a spelling\n"
 "  mistake in the commit message say, you can use the uncommit command\n"
 "  to undo it. See ``bzr help uncommit`` for details."
 msgstr ""
 
-#: bzrlib/builtins.py:3190
+#: bzrlib/builtins.py:3189
 msgid ""
 "  Hooks can also be configured to run after a commit. This allows you\n"
 "  to trigger updates to external systems like bug trackers. The --fixes\n"
@@ -1738,100 +1738,100 @@
 msgstr ""
 
 # help of 'exclude' option of 'commit' command
-#: bzrlib/builtins.py:3200
+#: bzrlib/builtins.py:3199
 msgid "Do not consider changes made to a given path."
 msgstr ""
 
 # help of 'message' option of 'commit' command
-#: bzrlib/builtins.py:3203
+#: bzrlib/builtins.py:3202
 msgid "Description of the new revision."
 msgstr ""
 
 # help of 'unchanged' option of 'commit' command
-#: bzrlib/builtins.py:3206
+#: bzrlib/builtins.py:3205
 msgid "Commit even if nothing has changed."
 msgstr ""
 
 # help of 'file' option of 'commit' command
-#: bzrlib/builtins.py:3210
+#: bzrlib/builtins.py:3209
 msgid "Take commit message from this file."
 msgstr ""
 
 # help of 'strict' option of 'commit' command
-#: bzrlib/builtins.py:3212
+#: bzrlib/builtins.py:3211
 msgid "Refuse to commit if there are unknown files in the working tree."
 msgstr ""
 
 # help of 'commit-time' option of 'commit' command
-#: bzrlib/builtins.py:3215
+#: bzrlib/builtins.py:3214
 msgid ""
 "Manually set a commit time using commit date format, e.g. '2009-10-10 "
 "08:00:00 +0100'."
 msgstr ""
 
 # help of 'fixes' option of 'commit' command
-#: bzrlib/builtins.py:3218
+#: bzrlib/builtins.py:3217
 msgid "Mark a bug as being fixed by this revision (see \"bzr help bugs\")."
 msgstr ""
 
 # help of 'author' option of 'commit' command
-#: bzrlib/builtins.py:3221
+#: bzrlib/builtins.py:3220
 msgid "Set the author's name, if it's different from the committer."
 msgstr ""
 
 # help of 'local' option of 'commit' command
-#: bzrlib/builtins.py:3224
+#: bzrlib/builtins.py:3223
 msgid ""
 "Perform a local commit in a bound branch.  Local commits are not pushed to "
 "the master branch until a normal commit is performed."
 msgstr ""
 
 # help of 'show-diff' option of 'commit' command
-#: bzrlib/builtins.py:3230
+#: bzrlib/builtins.py:3229
 msgid ""
 "When no message is supplied, show the diff along with the status summary in "
 "the message editor."
 msgstr ""
 
 # help of 'lossy' option of 'commit' command
-#: bzrlib/builtins.py:3233
+#: bzrlib/builtins.py:3232
 msgid ""
 "When committing to a foreign version control system do not push data that "
 "can not be natively represented."
 msgstr ""
 
-#: bzrlib/builtins.py:3391
+#: bzrlib/builtins.py:3406
 msgid ""
 "Validate working tree structure, branch consistency and repository history."
 msgstr ""
 
-#: bzrlib/builtins.py:3393
+#: bzrlib/builtins.py:3408
 msgid ""
 "This command checks various invariants about branch and repository storage\n"
 "to detect data corruption or bzr bugs."
 msgstr ""
 
-#: bzrlib/builtins.py:3396
+#: bzrlib/builtins.py:3411
 msgid ""
 "The working tree and branch checks will only give output if a problem is\n"
 "detected. The output fields of the repository check are:"
 msgstr ""
 
-#: bzrlib/builtins.py:3399
+#: bzrlib/builtins.py:3414
 msgid ""
 "revisions\n"
 "    This is just the number of revisions checked.  It doesn't\n"
 "    indicate a problem."
 msgstr ""
 
-#: bzrlib/builtins.py:3403
+#: bzrlib/builtins.py:3418
 msgid ""
 "versionedfiles\n"
 "    This is just the number of versionedfiles checked.  It\n"
 "    doesn't indicate a problem."
 msgstr ""
 
-#: bzrlib/builtins.py:3407
+#: bzrlib/builtins.py:3422
 msgid ""
 "unreferenced ancestors\n"
 "    Texts that are ancestors of other texts, but\n"
@@ -1839,14 +1839,14 @@
 "    subtle problem that Bazaar can work around."
 msgstr ""
 
-#: bzrlib/builtins.py:3412
+#: bzrlib/builtins.py:3427
 msgid ""
 "unique file texts\n"
 "    This is the total number of unique file contents\n"
 "    seen in the checked revisions.  It does not indicate a problem."
 msgstr ""
 
-#: bzrlib/builtins.py:3416
+#: bzrlib/builtins.py:3431
 msgid ""
 "repeated file texts\n"
 "    This is the total number of repeated texts seen\n"
@@ -1855,61 +1855,61 @@
 "    indicate a problem."
 msgstr ""
 
-#: bzrlib/builtins.py:3422
+#: bzrlib/builtins.py:3437
 msgid ""
 "If no restrictions are specified, all Bazaar data that is found at the "
 "given\n"
 "location will be checked."
 msgstr ""
 
-#: bzrlib/builtins.py:3425
+#: bzrlib/builtins.py:3440
 msgid ":Examples:"
 msgstr ""
 
-#: bzrlib/builtins.py:3427
+#: bzrlib/builtins.py:3442
 msgid "    Check the tree and branch at 'foo'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3429
+#: bzrlib/builtins.py:3444
 msgid "        bzr check --tree --branch foo"
 msgstr ""
 
-#: bzrlib/builtins.py:3431
+#: bzrlib/builtins.py:3446
 msgid "    Check only the repository at 'bar'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3433
+#: bzrlib/builtins.py:3448
 msgid "        bzr check --repo bar"
 msgstr ""
 
-#: bzrlib/builtins.py:3435
+#: bzrlib/builtins.py:3450
 msgid "    Check everything at 'baz'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3437
+#: bzrlib/builtins.py:3452
 msgid "        bzr check baz"
 msgstr ""
 
 # help of 'branch' option of 'check' command
-#: bzrlib/builtins.py:3443
+#: bzrlib/builtins.py:3458
 msgid "Check the branch related to the current directory."
 msgstr ""
 
 # help of 'repo' option of 'check' command
-#: bzrlib/builtins.py:3445
+#: bzrlib/builtins.py:3460
 msgid "Check the repository related to the current directory."
 msgstr ""
 
 # help of 'tree' option of 'check' command
-#: bzrlib/builtins.py:3447
+#: bzrlib/builtins.py:3462
 msgid "Check the working tree related to the current directory."
 msgstr ""
 
-#: bzrlib/builtins.py:3461
+#: bzrlib/builtins.py:3476
 msgid "Upgrade a repository, branch or working tree to a newer format."
 msgstr ""
 
-#: bzrlib/builtins.py:3463
+#: bzrlib/builtins.py:3478
 msgid ""
 "When the default format has changed after a major new release of\n"
 "Bazaar, you may be informed during certain operations that you\n"
@@ -1918,7 +1918,7 @@
 "with older repositories or with older versions of Bazaar."
 msgstr ""
 
-#: bzrlib/builtins.py:3469
+#: bzrlib/builtins.py:3484
 msgid ""
 "If you wish to upgrade to a particular format rather than the\n"
 "current default, that can be specified using the --format option.\n"
@@ -1928,7 +1928,7 @@
 "2.x default) so downgrading is not always possible."
 msgstr ""
 
-#: bzrlib/builtins.py:3476
+#: bzrlib/builtins.py:3491
 msgid ""
 "A backup.bzr.~#~ directory is created at the start of the conversion\n"
 "process (where # is a number). By default, this is left there on\n"
@@ -1939,7 +1939,7 @@
 "afterwards."
 msgstr ""
 
-#: bzrlib/builtins.py:3484
+#: bzrlib/builtins.py:3499
 msgid ""
 "If the location given is a shared repository, dependent branches\n"
 "are also converted provided the repository converts successfully.\n"
@@ -1947,132 +1947,132 @@
 "tried."
 msgstr ""
 
-#: bzrlib/builtins.py:3489
+#: bzrlib/builtins.py:3504
 msgid ""
 "For more information on upgrades, see the Bazaar Upgrade Guide,\n"
 "http://doc.bazaar.canonical.com/latest/en/upgrade-guide/."
 msgstr ""
 
 # help of 'format' option of 'upgrade' command
-#: bzrlib/builtins.py:3497
+#: bzrlib/builtins.py:3512
 msgid "Upgrade to a specific format.  See \"bzr help formats\" for details."
 msgstr ""
 
 # title of 'format' option of 'init' command
-#: bzrlib/builtins.py:3501
+#: bzrlib/builtins.py:3516
 msgid "Branch format"
 msgstr ""
 
 # help of 'clean' option of 'upgrade' command
-#: bzrlib/builtins.py:3503
+#: bzrlib/builtins.py:3518
 msgid "Remove the backup.bzr directory if successful."
 msgstr ""
 
-#: bzrlib/builtins.py:3520
+#: bzrlib/builtins.py:3535
 msgid "Show or set bzr user id."
 msgstr ""
 
-#: bzrlib/builtins.py:3522
+#: bzrlib/builtins.py:3537
 msgid ""
 ":Examples:\n"
 "    Show the email of the current user::"
 msgstr ""
 
-#: bzrlib/builtins.py:3525
+#: bzrlib/builtins.py:3540
 msgid "        bzr whoami --email"
 msgstr ""
 
-#: bzrlib/builtins.py:3527
+#: bzrlib/builtins.py:3542
 msgid "    Set the current user::"
 msgstr ""
 
-#: bzrlib/builtins.py:3529
+#: bzrlib/builtins.py:3544
 msgid "        bzr whoami \"Frank Chu <fchu@example.com>\""
 msgstr ""
 
 # help of 'email' option of 'whoami' command
-#: bzrlib/builtins.py:3533
+#: bzrlib/builtins.py:3548
 msgid "Display email address only."
 msgstr ""
 
 # help of 'branch' option of 'whoami' command
-#: bzrlib/builtins.py:3535
+#: bzrlib/builtins.py:3550
 msgid "Set identity for the current branch instead of globally."
 msgstr ""
 
-#: bzrlib/builtins.py:3581
+#: bzrlib/builtins.py:3596
 msgid "Print or set the branch nickname."
 msgstr ""
 
-#: bzrlib/builtins.py:3583
+#: bzrlib/builtins.py:3598
 msgid ""
 "If unset, the tree root directory name is used as the nickname.\n"
 "To print the current nickname, execute with no argument."
 msgstr ""
 
-#: bzrlib/builtins.py:3586
+#: bzrlib/builtins.py:3601
 msgid ""
 "Bound branches use the nickname of its master branch unless it is set\n"
 "locally."
 msgstr ""
 
-#: bzrlib/builtins.py:3606
+#: bzrlib/builtins.py:3621
 msgid "Set/unset and display aliases."
 msgstr ""
 
-#: bzrlib/builtins.py:3608
+#: bzrlib/builtins.py:3623
 msgid ""
 ":Examples:\n"
 "    Show the current aliases::"
 msgstr ""
 
-#: bzrlib/builtins.py:3611
+#: bzrlib/builtins.py:3626
 msgid "        bzr alias"
 msgstr ""
 
-#: bzrlib/builtins.py:3613
+#: bzrlib/builtins.py:3628
 msgid "    Show the alias specified for 'll'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3615
+#: bzrlib/builtins.py:3630
 msgid "        bzr alias ll"
 msgstr ""
 
-#: bzrlib/builtins.py:3617
+#: bzrlib/builtins.py:3632
 msgid "    Set an alias for 'll'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3619
+#: bzrlib/builtins.py:3634
 msgid "        bzr alias ll=\"log --line -r-10..-1\""
 msgstr ""
 
-#: bzrlib/builtins.py:3621
+#: bzrlib/builtins.py:3636
 msgid "    To remove an alias for 'll'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3623
+#: bzrlib/builtins.py:3638
 msgid "        bzr alias --remove ll"
 msgstr ""
 
 # help of 'remove' option of 'alias' command
-#: bzrlib/builtins.py:3628
+#: bzrlib/builtins.py:3643
 msgid "Remove the alias."
 msgstr ""
 
-#: bzrlib/builtins.py:3867
+#: bzrlib/builtins.py:3897
 msgid "Show version of bzr."
 msgstr ""
 
 # help of 'short' option of 'version' command
-#: bzrlib/builtins.py:3871
+#: bzrlib/builtins.py:3901
 msgid "Print just the version number."
 msgstr ""
 
-#: bzrlib/builtins.py:3918
+#: bzrlib/builtins.py:3948
 msgid "Perform a three-way merge."
 msgstr ""
 
-#: bzrlib/builtins.py:3920
+#: bzrlib/builtins.py:3950
 msgid ""
 "The source of the merge can be specified either in the form of a branch,\n"
 "or in the form of a path to a file containing a merge directive generated\n"
@@ -2083,20 +2083,20 @@
 "the current working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:3928
+#: bzrlib/builtins.py:3958
 msgid ""
 "When merging from a branch, by default bzr will try to merge in all new\n"
 "work from the other branch, automatically determining an appropriate base\n"
 "revision.  If this fails, you may need to give an explicit base."
 msgstr ""
 
-#: bzrlib/builtins.py:3932
+#: bzrlib/builtins.py:3962
 msgid ""
 "To pick a different ending revision, pass \"--revision OTHER\".  bzr will\n"
 "try to merge in all new work up to and including revision OTHER."
 msgstr ""
 
-#: bzrlib/builtins.py:3935
+#: bzrlib/builtins.py:3965
 msgid ""
 "If you specify two values, \"--revision BASE..OTHER\", only revisions BASE\n"
 "through OTHER, excluding BASE but including OTHER, will be merged.  If this\n"
@@ -2107,30 +2107,30 @@
 "changes from the other branch is not stored in the commit."
 msgstr ""
 
-#: bzrlib/builtins.py:3943
+#: bzrlib/builtins.py:3973
 msgid "Revision numbers are always relative to the source branch."
 msgstr ""
 
-#: bzrlib/builtins.py:3950
+#: bzrlib/builtins.py:3980
 msgid "Use bzr resolve when you have fixed a problem.  See also bzr conflicts."
 msgstr ""
 
-#: bzrlib/builtins.py:3952
+#: bzrlib/builtins.py:3982
 msgid ""
 "If there is no default branch set, the first merge will set it (use\n"
-"--no-remember to avoid settting it). After that, you can omit the branch\n"
+"--no-remember to avoid setting it). After that, you can omit the branch\n"
 "to use the default.  To change the default, use --remember. The value will\n"
 "only be saved if the remote location can be accessed."
 msgstr ""
 
-#: bzrlib/builtins.py:3957
+#: bzrlib/builtins.py:3987
 msgid ""
 "The results of the merge are placed into the destination working\n"
 "directory, where they can be reviewed (with bzr diff), tested, and then\n"
 "committed to record the result of the merge."
 msgstr ""
 
-#: bzrlib/builtins.py:3961
+#: bzrlib/builtins.py:3991
 msgid ""
 "merge refuses to run if there are any uncommitted changes, unless\n"
 "--force is given.  If --force is given, then the changes from the source \n"
@@ -2139,60 +2139,60 @@
 "merge revision which has more than two parents."
 msgstr ""
 
-#: bzrlib/builtins.py:3967
+#: bzrlib/builtins.py:3997
 msgid ""
 "If one would like to merge changes from the working tree of the other\n"
 "branch without merging any committed revisions, the --uncommitted option\n"
 "can be given."
 msgstr ""
 
-#: bzrlib/builtins.py:3971
+#: bzrlib/builtins.py:4001
 msgid ""
 "To select only some changes to merge, use \"merge -i\", which will prompt\n"
 "you to apply each diff hunk and file change, similar to \"shelve\"."
 msgstr ""
 
-#: bzrlib/builtins.py:3974
+#: bzrlib/builtins.py:4004
 msgid ""
 ":Examples:\n"
 "    To merge all new revisions from bzr.dev::"
 msgstr ""
 
-#: bzrlib/builtins.py:3977
+#: bzrlib/builtins.py:4007
 msgid "        bzr merge ../bzr.dev"
 msgstr ""
 
-#: bzrlib/builtins.py:3979
+#: bzrlib/builtins.py:4009
 msgid "    To merge changes up to and including revision 82 from bzr.dev::"
 msgstr ""
 
-#: bzrlib/builtins.py:3981
+#: bzrlib/builtins.py:4011
 msgid "        bzr merge -r 82 ../bzr.dev"
 msgstr ""
 
-#: bzrlib/builtins.py:3983
+#: bzrlib/builtins.py:4013
 msgid "    To merge the changes introduced by 82, without previous changes::"
 msgstr ""
 
-#: bzrlib/builtins.py:3985
+#: bzrlib/builtins.py:4015
 msgid "        bzr merge -r 81..82 ../bzr.dev"
 msgstr ""
 
-#: bzrlib/builtins.py:3987
+#: bzrlib/builtins.py:4017
 msgid "    To apply a merge directive contained in /tmp/merge::"
 msgstr ""
 
-#: bzrlib/builtins.py:3989
+#: bzrlib/builtins.py:4019
 msgid "        bzr merge /tmp/merge"
 msgstr ""
 
-#: bzrlib/builtins.py:3991
+#: bzrlib/builtins.py:4021
 msgid ""
 "    To create a merge revision with three parents from two branches\n"
 "    feature1a and feature1b:"
 msgstr ""
 
-#: bzrlib/builtins.py:3994
+#: bzrlib/builtins.py:4024
 msgid ""
 "        bzr merge ../feature1a\n"
 "        bzr merge ../feature1b --force\n"
@@ -2200,18 +2200,18 @@
 msgstr ""
 
 # help of 'force' option of 'merge' command
-#: bzrlib/builtins.py:4006
+#: bzrlib/builtins.py:4036
 msgid "Merge even if the destination tree has uncommitted changes."
 msgstr ""
 
 # help of 'uncommitted' option of 'merge' command
-#: bzrlib/builtins.py:4012
+#: bzrlib/builtins.py:4042
 msgid ""
 "Apply uncommitted changes from a working copy, instead of branch changes."
 msgstr ""
 
 # help of 'pull' option of 'merge' command
-#: bzrlib/builtins.py:4014
+#: bzrlib/builtins.py:4044
 msgid ""
 "If the destination is already completely merged into the source, pull from "
 "the source rather than merging.  When this happens, you do not need to "
@@ -2219,77 +2219,77 @@
 msgstr ""
 
 # help of 'directory' option of 'merge' command
-#: bzrlib/builtins.py:4019
+#: bzrlib/builtins.py:4049
 msgid ""
 "Branch to merge into, rather than the one containing the working directory."
 msgstr ""
 
 # help of 'preview' option of 'merge' command
-#: bzrlib/builtins.py:4021
+#: bzrlib/builtins.py:4051
 msgid "Instead of merging, show a diff of the merge."
 msgstr ""
 
 # help of 'interactive' option of 'merge' command
-#: bzrlib/builtins.py:4023
+#: bzrlib/builtins.py:4053
 msgid "Select changes interactively."
 msgstr ""
 
-#: bzrlib/builtins.py:4307
+#: bzrlib/builtins.py:4337
 msgid "Redo a merge."
 msgstr ""
 
-#: bzrlib/builtins.py:4309
+#: bzrlib/builtins.py:4339
 msgid ""
 "Use this if you want to try a different merge technique while resolving\n"
 "conflicts.  Some merge techniques are better than others, and remerge\n"
 "lets you try different ones on different files."
 msgstr ""
 
-#: bzrlib/builtins.py:4313
+#: bzrlib/builtins.py:4343
 msgid ""
 "The options for remerge have the same meaning and defaults as the ones for\n"
 "merge.  The difference is that remerge can (only) be run when there is a\n"
 "pending merge, and it lets you specify particular files."
 msgstr ""
 
-#: bzrlib/builtins.py:4317
+#: bzrlib/builtins.py:4347
 msgid ""
 ":Examples:\n"
 "    Re-do the merge of all conflicted files, and show the base text in\n"
 "    conflict regions, in addition to the usual THIS and OTHER texts::"
 msgstr ""
 
-#: bzrlib/builtins.py:4321
+#: bzrlib/builtins.py:4351
 msgid "        bzr remerge --show-base"
 msgstr ""
 
-#: bzrlib/builtins.py:4323
+#: bzrlib/builtins.py:4353
 msgid ""
 "    Re-do the merge of \"foobar\", using the weave merge algorithm, with\n"
 "    additional processing to reduce the size of conflict regions::"
 msgstr ""
 
-#: bzrlib/builtins.py:4326
+#: bzrlib/builtins.py:4356
 msgid "        bzr remerge --merge-type weave --reprocess foobar"
 msgstr ""
 
 # help of 'show-base' option of 'merge' command
-#: bzrlib/builtins.py:4333
+#: bzrlib/builtins.py:4363
 msgid "Show base revision text in conflicts."
 msgstr ""
 
-#: bzrlib/builtins.py:4401
+#: bzrlib/builtins.py:4431
 msgid "Revert files to a previous revision."
 msgstr ""
 
-#: bzrlib/builtins.py:4403
+#: bzrlib/builtins.py:4433
 msgid ""
 "Giving a list of files will revert only those files.  Otherwise, all files\n"
 "will be reverted.  If the revision is not specified with '--revision', the\n"
 "last committed revision is used."
 msgstr ""
 
-#: bzrlib/builtins.py:4407
+#: bzrlib/builtins.py:4437
 msgid ""
 "To remove only some changes, without reverting to a prior version, use\n"
 "merge instead.  For example, \"merge . -r -2..-3\" (don't forget the \".\")\n"
@@ -2298,14 +2298,14 @@
 "certain changes on a hunk-by-hunk basis, see the shelve command."
 msgstr ""
 
-#: bzrlib/builtins.py:4413
+#: bzrlib/builtins.py:4443
 msgid ""
 "By default, any files that have been manually changed will be backed up\n"
 "first.  (Files changed only by merge are not backed up.)  Backup files have\n"
 "'.~#~' appended to their name, where # is a number."
 msgstr ""
 
-#: bzrlib/builtins.py:4417
+#: bzrlib/builtins.py:4447
 msgid ""
 "When you provide files, you can use their current pathname or the pathname\n"
 "from the target revision.  So you can use revert to \"undelete\" a file by\n"
@@ -2313,7 +2313,7 @@
 "reverted."
 msgstr ""
 
-#: bzrlib/builtins.py:4422
+#: bzrlib/builtins.py:4452
 msgid ""
 "If you have newly added files since the target revision, they will be\n"
 "removed.  If the files to be removed have been changed, backups will be\n"
@@ -2321,7 +2321,7 @@
 "deleted."
 msgstr ""
 
-#: bzrlib/builtins.py:4427
+#: bzrlib/builtins.py:4457
 msgid ""
 "The working tree contains a list of revisions that have been merged but\n"
 "not yet committed. These revisions will be included as additional parents\n"
@@ -2333,7 +2333,7 @@
 "reverting any files."
 msgstr ""
 
-#: bzrlib/builtins.py:4436
+#: bzrlib/builtins.py:4466
 msgid ""
 "Using \"bzr revert --forget-merges\", it is possible to apply all of the\n"
 "changes from a branch in a single revision.  To do this, perform the merge\n"
@@ -2348,35 +2348,35 @@
 msgstr ""
 
 # help of 'no-backup' option of 'revert' command
-#: bzrlib/builtins.py:4450
+#: bzrlib/builtins.py:4480
 msgid "Do not save backups of reverted files."
 msgstr ""
 
 # help of 'forget-merges' option of 'revert' command
-#: bzrlib/builtins.py:4452
+#: bzrlib/builtins.py:4482
 msgid "Remove pending merge marker, without changing any files."
 msgstr ""
 
-#: bzrlib/builtins.py:4483
+#: bzrlib/builtins.py:4513
 msgid ""
 "Show help on a command or other topic.\n"
 "    "
 msgstr ""
 
 # help of 'long' option of 'help' command
-#: bzrlib/builtins.py:4488
+#: bzrlib/builtins.py:4518
 msgid "Show help on all commands."
 msgstr ""
 
-#: bzrlib/builtins.py:4517
+#: bzrlib/builtins.py:4547
 msgid "Show unmerged/unpulled revisions between two branches."
 msgstr ""
 
-#: bzrlib/builtins.py:4519
+#: bzrlib/builtins.py:4549
 msgid "OTHER_BRANCH may be local or remote."
 msgstr ""
 
-#: bzrlib/builtins.py:4521
+#: bzrlib/builtins.py:4551
 msgid ""
 "To filter on a range of revisions, you can use the command -r begin..end\n"
 "-r revision requests a specific revision, -r ..end or -r begin.. are\n"
@@ -2387,100 +2387,100 @@
 "    0 - no missing revisions"
 msgstr ""
 
-#: bzrlib/builtins.py:4531
+#: bzrlib/builtins.py:4561
 msgid ""
 "    Determine the missing revisions between this and the branch at the\n"
 "    remembered pull location::"
 msgstr ""
 
-#: bzrlib/builtins.py:4534
+#: bzrlib/builtins.py:4564
 msgid "        bzr missing"
 msgstr ""
 
-#: bzrlib/builtins.py:4536
+#: bzrlib/builtins.py:4566
 msgid "    Determine the missing revisions between this and another branch::"
 msgstr ""
 
-#: bzrlib/builtins.py:4538
+#: bzrlib/builtins.py:4568
 msgid "        bzr missing http://server/branch"
 msgstr ""
 
-#: bzrlib/builtins.py:4540
+#: bzrlib/builtins.py:4570
 msgid ""
 "    Determine the missing revisions up to a specific revision on the other\n"
 "    branch::"
 msgstr ""
 
-#: bzrlib/builtins.py:4543
+#: bzrlib/builtins.py:4573
 msgid "        bzr missing -r ..-10"
 msgstr ""
 
-#: bzrlib/builtins.py:4545
+#: bzrlib/builtins.py:4575
 msgid ""
 "    Determine the missing revisions up to a specific revision on this\n"
 "    branch::"
 msgstr ""
 
-#: bzrlib/builtins.py:4548
+#: bzrlib/builtins.py:4578
 msgid "        bzr missing --my-revision ..-10"
 msgstr ""
 
 # help of 'reverse' option of 'missing' command
-#: bzrlib/builtins.py:4555
+#: bzrlib/builtins.py:4585
 msgid "Reverse the order of revisions."
 msgstr ""
 
 # help of 'mine-only' option of 'missing' command
-#: bzrlib/builtins.py:4557
+#: bzrlib/builtins.py:4587
 msgid "Display changes in the local branch only."
 msgstr ""
 
 # help of 'this' option of 'missing' command
-#: bzrlib/builtins.py:4558
+#: bzrlib/builtins.py:4588
 msgid "Same as --mine-only."
 msgstr ""
 
 # help of 'theirs-only' option of 'missing' command
-#: bzrlib/builtins.py:4560
+#: bzrlib/builtins.py:4590
 msgid "Display changes in the remote branch only."
 msgstr ""
 
 # help of 'other' option of 'missing' command
-#: bzrlib/builtins.py:4561
+#: bzrlib/builtins.py:4591
 msgid "Same as --theirs-only."
 msgstr ""
 
 # help of 'revision' option of 'missing' command
-#: bzrlib/builtins.py:4566
+#: bzrlib/builtins.py:4596
 msgid ""
 "Filter on other branch revisions (inclusive). See \"help revisionspec\" for "
 "details."
 msgstr ""
 
 # help of 'my-revision' option of 'missing' command
-#: bzrlib/builtins.py:4570
+#: bzrlib/builtins.py:4600
 msgid ""
 "Filter on local branch revisions (inclusive). See \"help revisionspec\" for "
 "details."
 msgstr ""
 
 # help of 'include-merges' option of 'missing' command
-#: bzrlib/builtins.py:4573
+#: bzrlib/builtins.py:4603
 msgid "Show all revisions in addition to the mainline ones."
 msgstr ""
 
-#: bzrlib/builtins.py:4689
+#: bzrlib/builtins.py:4719
 msgid "Compress the data within a repository."
 msgstr ""
 
-#: bzrlib/builtins.py:4691
+#: bzrlib/builtins.py:4721
 msgid ""
 "This operation compresses the data within a bazaar repository. As\n"
 "bazaar supports automatic packing of repository, this operation is\n"
 "normally not required to be done manually."
 msgstr ""
 
-#: bzrlib/builtins.py:4695
+#: bzrlib/builtins.py:4725
 msgid ""
 "During the pack operation, bazaar takes a backup of existing repository\n"
 "data, i.e. pack files. This backup is eventually removed by bazaar\n"
@@ -2489,7 +2489,7 @@
 "used."
 msgstr ""
 
-#: bzrlib/builtins.py:4701
+#: bzrlib/builtins.py:4731
 msgid ""
 "Warning: If you use --clean-obsolete-packs and your machine crashes\n"
 "during or immediately after repacking, you may be left with a state\n"
@@ -2498,25 +2498,25 @@
 msgstr ""
 
 # help of 'clean-obsolete-packs' option of 'pack' command
-#: bzrlib/builtins.py:4710
+#: bzrlib/builtins.py:4740
 msgid "Delete obsolete packs to save disk space."
 msgstr ""
 
-#: bzrlib/builtins.py:4724
+#: bzrlib/builtins.py:4754
 msgid "List the installed plugins."
 msgstr ""
 
-#: bzrlib/builtins.py:4726
+#: bzrlib/builtins.py:4756
 msgid ""
 "This command displays the list of installed plugins including\n"
 "version of plugin and a short description of each."
 msgstr ""
 
-#: bzrlib/builtins.py:4729
+#: bzrlib/builtins.py:4759
 msgid "--verbose shows the path where each plugin is located."
 msgstr ""
 
-#: bzrlib/builtins.py:4731
+#: bzrlib/builtins.py:4761
 msgid ""
 "A plugin is an external component for Bazaar that extends the\n"
 "revision control system, by adding or replacing code in Bazaar.\n"
@@ -2525,7 +2525,7 @@
 "customizing log output."
 msgstr ""
 
-#: bzrlib/builtins.py:4737
+#: bzrlib/builtins.py:4767
 msgid ""
 "See the Bazaar Plugin Guide <http://doc.bazaar.canonical.com/plugins/en/>\n"
 "for further information on plugins including where to find them and how to\n"
@@ -2533,94 +2533,94 @@
 "plugins using the Python programming language."
 msgstr ""
 
-#: bzrlib/builtins.py:4753
+#: bzrlib/builtins.py:4783
 msgid "Show testament (signing-form) of a revision."
 msgstr ""
 
 # help of 'long' option of 'testament' command
-#: bzrlib/builtins.py:4756
+#: bzrlib/builtins.py:4786
 msgid "Produce long-format testament."
 msgstr ""
 
 # help of 'strict' option of 'testament' command
-#: bzrlib/builtins.py:4758
+#: bzrlib/builtins.py:4788
 msgid "Produce a strict-format testament."
 msgstr ""
 
-#: bzrlib/builtins.py:4784
+#: bzrlib/builtins.py:4814
 msgid "Show the origin of each line in a file."
 msgstr ""
 
-#: bzrlib/builtins.py:4786
+#: bzrlib/builtins.py:4816
 msgid ""
 "This prints out the given file with an annotation on the left side\n"
 "indicating which revision, author and date introduced the change."
 msgstr ""
 
-#: bzrlib/builtins.py:4789
+#: bzrlib/builtins.py:4819
 msgid ""
 "If the origin is the same for a run of consecutive lines, it is\n"
 "shown only at the top, unless the --all option is given."
 msgstr ""
 
 # help of 'all' option of 'annotate' command
-#: bzrlib/builtins.py:4797
+#: bzrlib/builtins.py:4827
 msgid "Show annotations on all lines."
 msgstr ""
 
 # help of 'long' option of 'annotate' command
-#: bzrlib/builtins.py:4798
+#: bzrlib/builtins.py:4828
 msgid "Show commit date in annotations."
 msgstr ""
 
-#: bzrlib/builtins.py:4901
+#: bzrlib/builtins.py:4931
 msgid ""
 "Convert the current branch into a checkout of the supplied branch.\n"
 "If no branch is supplied, rebind to the last bound location."
 msgstr ""
 
-#: bzrlib/builtins.py:4904
+#: bzrlib/builtins.py:4934
 msgid ""
 "Once converted into a checkout, commits must succeed on the master branch\n"
 "before they will be applied to the local branch."
 msgstr ""
 
-#: bzrlib/builtins.py:4907
+#: bzrlib/builtins.py:4937
 msgid ""
 "Bound branches use the nickname of its master branch unless it is set\n"
 "locally, in which case binding will update the local nickname to be\n"
 "that of the master."
 msgstr ""
 
-#: bzrlib/builtins.py:4942
+#: bzrlib/builtins.py:4972
 msgid "Convert the current checkout into a regular branch."
 msgstr ""
 
-#: bzrlib/builtins.py:4944
+#: bzrlib/builtins.py:4974
 msgid ""
 "After unbinding, the local branch is considered independent and subsequent\n"
 "commits will be local only."
 msgstr ""
 
-#: bzrlib/builtins.py:4959
+#: bzrlib/builtins.py:4989
 msgid "Remove the last committed revision."
 msgstr ""
 
-#: bzrlib/builtins.py:4961
+#: bzrlib/builtins.py:4991
 msgid ""
 "--verbose will print out what is being removed.\n"
 "--dry-run will go through all the motions, but not actually\n"
 "remove anything."
 msgstr ""
 
-#: bzrlib/builtins.py:4965
+#: bzrlib/builtins.py:4995
 msgid ""
 "If --revision is specified, uncommit revisions to leave the branch at the\n"
 "specified revision.  For example, \"bzr uncommit -r 15\" will leave the\n"
 "branch at revision 15."
 msgstr ""
 
-#: bzrlib/builtins.py:4969
+#: bzrlib/builtins.py:4999
 msgid ""
 "Uncommit leaves the working tree ready for a new commit.  The only change\n"
 "it may make is to restore any pending merges that were present before\n"
@@ -2628,43 +2628,48 @@
 msgstr ""
 
 # help of 'dry-run' option of 'uncommit' command
-#: bzrlib/builtins.py:4980
+#: bzrlib/builtins.py:5010
 msgid "Don't actually make changes."
 msgstr ""
 
 # help of 'force' option of 'uncommit' command
-#: bzrlib/builtins.py:4981
+#: bzrlib/builtins.py:5011
 msgid "Say yes to all questions."
 msgstr ""
 
+# help of 'keep-tags' option of 'uncommit' command
+#: bzrlib/builtins.py:5013
+msgid "Keep tags that point to removed revisions."
+msgstr ""
+
 # help of 'local' option of 'uncommit' command
-#: bzrlib/builtins.py:4983
+#: bzrlib/builtins.py:5015
 msgid "Only remove the commits from the local branch when in a checkout."
 msgstr ""
 
-#: bzrlib/builtins.py:5068
+#: bzrlib/builtins.py:5101
 msgid "Break a dead lock."
 msgstr ""
 
-#: bzrlib/builtins.py:5070
+#: bzrlib/builtins.py:5103
 msgid ""
 "This command breaks a lock on a repository, branch, working directory or\n"
 "config file."
 msgstr ""
 
-#: bzrlib/builtins.py:5073
+#: bzrlib/builtins.py:5106
 msgid ""
 "CAUTION: Locks should only be broken when you are sure that the process\n"
 "holding the lock has been stopped."
 msgstr ""
 
-#: bzrlib/builtins.py:5076
+#: bzrlib/builtins.py:5109
 msgid ""
 "You can get information on what locks are open via the 'bzr info\n"
 "[location]' command."
 msgstr ""
 
-#: bzrlib/builtins.py:5079
+#: bzrlib/builtins.py:5112
 msgid ""
 ":Examples:\n"
 "    bzr break-lock\n"
@@ -2673,36 +2678,36 @@
 msgstr ""
 
 # help of 'config' option of 'break-lock' command
-#: bzrlib/builtins.py:5088
+#: bzrlib/builtins.py:5121
 msgid "LOCATION is the directory where the config lock is."
 msgstr ""
 
 # help of 'force' option of 'break-lock' command
-#: bzrlib/builtins.py:5090
+#: bzrlib/builtins.py:5123
 msgid "Do not ask for confirmation before breaking the lock."
 msgstr ""
 
-#: bzrlib/builtins.py:5126
+#: bzrlib/builtins.py:5159
 msgid "Run the bzr server."
 msgstr ""
 
 # help of 'inet' option of 'serve' command
-#: bzrlib/builtins.py:5132
+#: bzrlib/builtins.py:5165
 msgid "Serve on stdin/out for use from inetd or sshd."
 msgstr ""
 
 # title of 'protocol' option of 'serve' command
-#: bzrlib/builtins.py:5133
+#: bzrlib/builtins.py:5166
 msgid "protocol"
 msgstr ""
 
 # help of 'protocol' option of 'serve' command
-#: bzrlib/builtins.py:5134
+#: bzrlib/builtins.py:5167
 msgid "Protocol to serve."
 msgstr ""
 
 # help of 'port' option of 'serve' command
-#: bzrlib/builtins.py:5138
+#: bzrlib/builtins.py:5171
 msgid ""
 "Listen for connections on nominated port of the form [hostname:]portnumber.  "
 "Passing 0 as the port number will result in a dynamically allocated port.  "
@@ -2710,12 +2715,12 @@
 msgstr ""
 
 # help of 'directory' option of 'serve' command
-#: bzrlib/builtins.py:5144
+#: bzrlib/builtins.py:5177
 msgid "Serve contents of this directory."
 msgstr ""
 
 # help of 'allow-writes' option of 'serve' command
-#: bzrlib/builtins.py:5146
+#: bzrlib/builtins.py:5179
 msgid ""
 "By default the server is a readonly server.  Supplying --allow-writes "
 "enables write access to the contents of the served directory and below.  "
@@ -2724,83 +2729,83 @@
 "uncontrolled write access to your file system."
 msgstr ""
 
-#: bzrlib/builtins.py:5191
+#: bzrlib/builtins.py:5224
 msgid "Combine a tree into its containing tree."
 msgstr ""
 
-#: bzrlib/builtins.py:5193
+#: bzrlib/builtins.py:5226
 msgid "This command requires the target tree to be in a rich-root format."
 msgstr ""
 
-#: bzrlib/builtins.py:5195
+#: bzrlib/builtins.py:5228
 msgid ""
 "The TREE argument should be an independent tree, inside another tree, but\n"
 "not part of it.  (Such trees can be produced by \"bzr split\", but also by\n"
 "running \"bzr branch\" with the target inside a tree.)"
 msgstr ""
 
-#: bzrlib/builtins.py:5199
+#: bzrlib/builtins.py:5232
 msgid ""
 "The result is a combined tree, with the subtree no longer an independent\n"
 "part.  This is marked as a merge of the subtree into the containing tree,\n"
 "and all history is preserved."
 msgstr ""
 
-#: bzrlib/builtins.py:5237
+#: bzrlib/builtins.py:5270
 msgid "Split a subdirectory of a tree into a separate tree."
 msgstr ""
 
-#: bzrlib/builtins.py:5239
+#: bzrlib/builtins.py:5272
 msgid ""
 "This command will produce a target tree in a format that supports\n"
 "rich roots, like 'rich-root' or 'rich-root-pack'.  These formats cannot be\n"
 "converted into earlier formats like 'dirstate-tags'."
 msgstr ""
 
-#: bzrlib/builtins.py:5243
+#: bzrlib/builtins.py:5276
 msgid ""
 "The TREE argument should be a subdirectory of a working tree.  That\n"
 "subdirectory will be converted into an independent tree, with its own\n"
 "branch.  Commits in the top-level tree will not apply to the new subtree."
 msgstr ""
 
-#: bzrlib/builtins.py:5364
+#: bzrlib/builtins.py:5397
 msgid "Mail or create a merge-directive for submitting changes."
 msgstr ""
 
-#: bzrlib/builtins.py:5366
+#: bzrlib/builtins.py:5399
 msgid "A merge directive provides many things needed for requesting merges:"
 msgstr ""
 
-#: bzrlib/builtins.py:5368
+#: bzrlib/builtins.py:5401
 msgid "* A machine-readable description of the merge to perform"
 msgstr ""
 
-#: bzrlib/builtins.py:5370
+#: bzrlib/builtins.py:5403
 msgid "* An optional patch that is a preview of the changes requested"
 msgstr ""
 
-#: bzrlib/builtins.py:5372
+#: bzrlib/builtins.py:5405
 msgid ""
 "* An optional bundle of revision data, so that the changes can be applied\n"
 "  directly from the merge directive, without retrieving data from a\n"
 "  branch."
 msgstr ""
 
-#: bzrlib/builtins.py:5376
+#: bzrlib/builtins.py:5409
 msgid ""
 "`bzr send` creates a compact data set that, when applied using bzr\n"
 "merge, has the same effect as merging from the source branch.  "
 msgstr ""
 
-#: bzrlib/builtins.py:5379
+#: bzrlib/builtins.py:5412
 msgid ""
 "By default the merge directive is self-contained and can be applied to any\n"
 "branch containing submit_branch in its ancestory without needing access to\n"
 "the source branch."
 msgstr ""
 
-#: bzrlib/builtins.py:5383
+#: bzrlib/builtins.py:5416
 msgid ""
 "If --no-bundle is specified, then Bazaar doesn't send the contents of the\n"
 "revisions, but only a structured request to merge from the\n"
@@ -2809,7 +2814,7 @@
 "included if known, so that people can check it later."
 msgstr ""
 
-#: bzrlib/builtins.py:5389
+#: bzrlib/builtins.py:5422
 msgid ""
 "The submit branch defaults to the parent of the source branch, but can be\n"
 "overridden.  Both submit branch and public branch will be remembered in\n"
@@ -2818,16 +2823,16 @@
 "be changed using --from."
 msgstr ""
 
-#: bzrlib/builtins.py:5395
+#: bzrlib/builtins.py:5428
 msgid ""
 "Both the submit branch and the public branch follow the usual behavior with\n"
 "respect to --remember: If there is no default location set, the first send\n"
-"will set it (use --no-remember to avoid settting it). After that, you can\n"
+"will set it (use --no-remember to avoid setting it). After that, you can\n"
 "omit the location to use the default.  To change the default, use\n"
 "--remember. The value will only be saved if the location can be accessed."
 msgstr ""
 
-#: bzrlib/builtins.py:5401
+#: bzrlib/builtins.py:5434
 msgid ""
 "In order to calculate those changes, bzr must analyse the submit branch.\n"
 "Therefore it is most efficient for the submit branch to be a local mirror.\n"
@@ -2835,20 +2840,20 @@
 "in the merge directive."
 msgstr ""
 
-#: bzrlib/builtins.py:5406
+#: bzrlib/builtins.py:5439
 msgid ""
 "The default behaviour is to send the merge directive by mail, unless -o is\n"
 "given, in which case it is sent to a file."
 msgstr ""
 
-#: bzrlib/builtins.py:5409
+#: bzrlib/builtins.py:5442
 msgid ""
 "Mail is sent using your preferred mail program.  This should be transparent\n"
 "on Windows (it uses MAPI).  On Unix, it requires the xdg-email utility.\n"
 "If the preferred client can't be found (or used), your editor will be used."
 msgstr ""
 
-#: bzrlib/builtins.py:5413
+#: bzrlib/builtins.py:5446
 msgid ""
 "To use a specific mail program, set the mail_client configuration option.\n"
 "(For Thunderbird 1.5, this works around some bugs.)  Supported values for\n"
@@ -2860,7 +2865,7 @@
 "supported clients."
 msgstr ""
 
-#: bzrlib/builtins.py:5420
+#: bzrlib/builtins.py:5453
 msgid ""
 "If mail is being sent, a to address is required.  This can be supplied\n"
 "either on the commandline, by setting the submit_to configuration\n"
@@ -2868,7 +2873,7 @@
 "in the submit branch."
 msgstr ""
 
-#: bzrlib/builtins.py:5425
+#: bzrlib/builtins.py:5458
 msgid ""
 "Two formats are currently supported: \"4\" uses revision bundle format 4 "
 "and\n"
@@ -2878,13 +2883,13 @@
 "format 1.  It is compatible with Bazaar 0.12 - 0.18."
 msgstr ""
 
-#: bzrlib/builtins.py:5431
+#: bzrlib/builtins.py:5464
 msgid ""
 "The merge directives created by bzr send may be applied using bzr merge or\n"
 "bzr pull by specifying a file containing a merge directive as the location."
 msgstr ""
 
-#: bzrlib/builtins.py:5434
+#: bzrlib/builtins.py:5467
 msgid ""
 "bzr send makes extensive use of public locations to map local locations "
 "into\n"
@@ -2893,90 +2898,90 @@
 msgstr ""
 
 # help of 'output' option of 'send' command
-#: bzrlib/builtins.py:5458
+#: bzrlib/builtins.py:5491
 msgid "Write merge directive to this file or directory; use - for stdout."
 msgstr ""
 
 # help of 'strict' option of 'send' command
-#: bzrlib/builtins.py:5462
+#: bzrlib/builtins.py:5495
 msgid ""
 "Refuse to send if there are uncommitted changes in the working tree, --no-"
 "strict disables the check."
 msgstr ""
 
 # help of 'mail-to' option of 'send' command
-#: bzrlib/builtins.py:5464
+#: bzrlib/builtins.py:5497
 msgid "Mail the request to this address."
 msgstr ""
 
 # help of 'body' option of 'send' command
-#: bzrlib/builtins.py:5468
+#: bzrlib/builtins.py:5501
 msgid "Body for the email."
 msgstr ""
 
 # help of 'no-bundle' option of 'send' command
-#: bzrlib/builtins.py:5521
+#: bzrlib/builtins.py:5554
 msgid "Do not include a bundle in the merge directive."
 msgstr ""
 
 # help of 'no-patch' option of 'send' command
-#: bzrlib/builtins.py:5522
+#: bzrlib/builtins.py:5555
 msgid "Do not include a preview patch in the merge directive."
 msgstr ""
 
 # help of 'remember' option of 'send' command
-#: bzrlib/builtins.py:5525
+#: bzrlib/builtins.py:5558
 msgid "Remember submit and public branch."
 msgstr ""
 
 # help of 'from' option of 'send' command
-#: bzrlib/builtins.py:5527
+#: bzrlib/builtins.py:5560
 msgid ""
 "Branch to generate the submission from, rather than the one containing the "
 "working directory."
 msgstr ""
 
 # title of 'format' option of 'send' command
-#: bzrlib/builtins.py:5537
+#: bzrlib/builtins.py:5570
 msgid "format"
 msgstr ""
 
 # help of 'format' option of 'send' command
-#: bzrlib/builtins.py:5538
+#: bzrlib/builtins.py:5571
 msgid "Use the specified output format."
 msgstr ""
 
-#: bzrlib/builtins.py:5560
+#: bzrlib/builtins.py:5593
 msgid "Create, remove or modify a tag naming a revision."
 msgstr ""
 
-#: bzrlib/builtins.py:5562
+#: bzrlib/builtins.py:5595
 msgid ""
 "Tags give human-meaningful names to revisions.  Commands that take a -r\n"
 "(--revision) option can be given -rtag:X, where X is any previously\n"
 "created tag."
 msgstr ""
 
-#: bzrlib/builtins.py:5566
+#: bzrlib/builtins.py:5599
 msgid ""
 "Tags are stored in the branch.  Tags are copied from one branch to another\n"
 "along when you branch, push, pull or merge."
 msgstr ""
 
-#: bzrlib/builtins.py:5569
+#: bzrlib/builtins.py:5602
 msgid ""
 "It is an error to give a tag name that already exists unless you pass\n"
 "--force, in which case the tag is moved to point to the new revision."
 msgstr ""
 
-#: bzrlib/builtins.py:5572
+#: bzrlib/builtins.py:5605
 msgid ""
 "To rename a tag (change the name but keep it on the same revsion), run "
 "``bzr\n"
 "tag new-name -r tag:old-name`` and then ``bzr tag --delete oldname``."
 msgstr ""
 
-#: bzrlib/builtins.py:5575
+#: bzrlib/builtins.py:5608
 msgid ""
 "If no tag name is specified it will be determined through the \n"
 "'automatic_tag_name' hook. This can e.g. be used to automatically tag\n"
@@ -2985,53 +2990,53 @@
 msgstr ""
 
 # help of 'delete' option of 'tag' command
-#: bzrlib/builtins.py:5585
+#: bzrlib/builtins.py:5618
 msgid "Delete this tag rather than placing it."
 msgstr ""
 
 # help of 'directory' option of 'tag' command
-#: bzrlib/builtins.py:5588
+#: bzrlib/builtins.py:5621
 msgid "Branch in which to place the tag."
 msgstr ""
 
 # help of 'force' option of 'tag' command
-#: bzrlib/builtins.py:5590
+#: bzrlib/builtins.py:5623
 msgid "Replace existing tags."
 msgstr ""
 
-#: bzrlib/builtins.py:5629
+#: bzrlib/builtins.py:5672
 msgid "List tags."
 msgstr ""
 
-#: bzrlib/builtins.py:5631
+#: bzrlib/builtins.py:5674
 msgid ""
 "This command shows a table of tag names and the revisions they reference."
 msgstr ""
 
 # help of 'directory' option of 'tags' command
-#: bzrlib/builtins.py:5637
+#: bzrlib/builtins.py:5680
 msgid "Branch whose tags should be displayed."
 msgstr ""
 
 # help of 'sort' option of 'tags' command
-#: bzrlib/builtins.py:5639
+#: bzrlib/builtins.py:5682
 msgid "Sort tags by different criteria."
 msgstr ""
 
 # title of 'sort' option of 'tags' command
-#: bzrlib/builtins.py:5639
+#: bzrlib/builtins.py:5682
 msgid "Sorting"
 msgstr ""
 
-#: bzrlib/builtins.py:5684
+#: bzrlib/builtins.py:5727
 msgid "Reconfigure the type of a bzr directory."
 msgstr ""
 
-#: bzrlib/builtins.py:5686
+#: bzrlib/builtins.py:5729
 msgid "A target configuration must be specified."
 msgstr ""
 
-#: bzrlib/builtins.py:5688
+#: bzrlib/builtins.py:5731
 msgid ""
 "For checkouts, the bind-to location will be auto-detected if not specified.\n"
 "The order of preference is\n"
@@ -3043,42 +3048,42 @@
 msgstr ""
 
 # title of 'target_type' option of 'reconfigure' command
-#: bzrlib/builtins.py:5702
+#: bzrlib/builtins.py:5745
 msgid "Target type"
 msgstr ""
 
 # help of 'target_type' option of 'reconfigure' command
-#: bzrlib/builtins.py:5703
+#: bzrlib/builtins.py:5746
 msgid "The type to reconfigure the directory to."
 msgstr ""
 
 # help of 'bind-to' option of 'reconfigure' command
-#: bzrlib/builtins.py:5718
+#: bzrlib/builtins.py:5761
 msgid "Branch to bind checkout to."
 msgstr ""
 
 # help of 'force' option of 'reconfigure' command
-#: bzrlib/builtins.py:5720
+#: bzrlib/builtins.py:5763
 msgid "Perform reconfiguration even if local changes will be lost."
 msgstr ""
 
 # help of 'stacked-on' option of 'reconfigure' command
-#: bzrlib/builtins.py:5723
+#: bzrlib/builtins.py:5766
 msgid "Reconfigure a branch to be stacked on another branch."
 msgstr ""
 
 # help of 'unstacked' option of 'reconfigure' command
-#: bzrlib/builtins.py:5727
+#: bzrlib/builtins.py:5770
 msgid ""
 "Reconfigure a branch to be unstacked.  This may require copying substantial "
 "data into it."
 msgstr ""
 
-#: bzrlib/builtins.py:5775
+#: bzrlib/builtins.py:5818
 msgid "Set the branch of a checkout and update."
 msgstr ""
 
-#: bzrlib/builtins.py:5777
+#: bzrlib/builtins.py:5820
 msgid ""
 "For lightweight checkouts, this changes the branch being referenced.\n"
 "For heavyweight checkouts, this checks that there are no local commits\n"
@@ -3086,17 +3091,17 @@
 "of the new location and binds to it."
 msgstr ""
 
-#: bzrlib/builtins.py:5782
+#: bzrlib/builtins.py:5825
 msgid ""
 "In both cases, the working tree is updated and uncommitted changes\n"
 "are merged. The user can commit or revert these as they desire."
 msgstr ""
 
-#: bzrlib/builtins.py:5785
+#: bzrlib/builtins.py:5828
 msgid "Pending merges need to be committed or reverted before using switch."
 msgstr ""
 
-#: bzrlib/builtins.py:5787
+#: bzrlib/builtins.py:5830
 msgid ""
 "The path to the branch to switch to can be specified relative to the parent\n"
 "directory of the current branch. For example, if you are currently in a\n"
@@ -3104,7 +3109,7 @@
 "/path/to/newbranch."
 msgstr ""
 
-#: bzrlib/builtins.py:5792
+#: bzrlib/builtins.py:5835
 msgid ""
 "Bound branches use the nickname of its master branch unless it is set\n"
 "locally, in which case switching will update the local nickname to be\n"
@@ -3112,20 +3117,20 @@
 msgstr ""
 
 # help of 'force' option of 'switch' command
-#: bzrlib/builtins.py:5800
+#: bzrlib/builtins.py:5843
 msgid "Switch even if local commits will be lost."
 msgstr ""
 
 # help of 'create-branch' option of 'switch' command
-#: bzrlib/builtins.py:5803
+#: bzrlib/builtins.py:5846
 msgid "Create the target branch from this one before switching to it."
 msgstr ""
 
-#: bzrlib/builtins.py:5872
+#: bzrlib/builtins.py:5915
 msgid "Manage filtered views."
 msgstr ""
 
-#: bzrlib/builtins.py:5874
+#: bzrlib/builtins.py:5917
 msgid ""
 "Views provide a mask over the tree so that users can focus on\n"
 "a subset of a tree when doing their work. After creating a view,\n"
@@ -3135,7 +3140,7 @@
 "must be within the current view."
 msgstr ""
 
-#: bzrlib/builtins.py:5881
+#: bzrlib/builtins.py:5924
 msgid ""
 "In most cases, a view has a short life-span: it is created to make\n"
 "a selected change and is deleted once that change is committed.\n"
@@ -3143,7 +3148,7 @@
 "and switch between them."
 msgstr ""
 
-#: bzrlib/builtins.py:5886
+#: bzrlib/builtins.py:5929
 msgid ""
 "To disable the current view without deleting it, you can switch to\n"
 "the pseudo view called ``off``. This can be useful when you need\n"
@@ -3151,131 +3156,131 @@
 "want to switch back to your view after that."
 msgstr ""
 
-#: bzrlib/builtins.py:5891
+#: bzrlib/builtins.py:5934
 msgid ""
 ":Examples:\n"
 "  To define the current view::"
 msgstr ""
 
-#: bzrlib/builtins.py:5894
+#: bzrlib/builtins.py:5937
 msgid "    bzr view file1 dir1 ..."
 msgstr ""
 
-#: bzrlib/builtins.py:5896
+#: bzrlib/builtins.py:5939
 msgid "  To list the current view::"
 msgstr ""
 
-#: bzrlib/builtins.py:5898
+#: bzrlib/builtins.py:5941
 msgid "    bzr view"
 msgstr ""
 
-#: bzrlib/builtins.py:5900
+#: bzrlib/builtins.py:5943
 msgid "  To delete the current view::"
 msgstr ""
 
-#: bzrlib/builtins.py:5902
+#: bzrlib/builtins.py:5945
 msgid "    bzr view --delete"
 msgstr ""
 
-#: bzrlib/builtins.py:5904
+#: bzrlib/builtins.py:5947
 msgid "  To disable the current view without deleting it::"
 msgstr ""
 
-#: bzrlib/builtins.py:5906
+#: bzrlib/builtins.py:5949
 msgid "    bzr view --switch off"
 msgstr ""
 
-#: bzrlib/builtins.py:5908
+#: bzrlib/builtins.py:5951
 msgid "  To define a named view and switch to it::"
 msgstr ""
 
-#: bzrlib/builtins.py:5910
+#: bzrlib/builtins.py:5953
 msgid "    bzr view --name view-name file1 dir1 ..."
 msgstr ""
 
-#: bzrlib/builtins.py:5912
+#: bzrlib/builtins.py:5955
 msgid "  To list a named view::"
 msgstr ""
 
-#: bzrlib/builtins.py:5914
+#: bzrlib/builtins.py:5957
 msgid "    bzr view --name view-name"
 msgstr ""
 
-#: bzrlib/builtins.py:5916
+#: bzrlib/builtins.py:5959
 msgid "  To delete a named view::"
 msgstr ""
 
-#: bzrlib/builtins.py:5918
+#: bzrlib/builtins.py:5961
 msgid "    bzr view --name view-name --delete"
 msgstr ""
 
-#: bzrlib/builtins.py:5920
+#: bzrlib/builtins.py:5963
 msgid "  To switch to a named view::"
 msgstr ""
 
-#: bzrlib/builtins.py:5922
+#: bzrlib/builtins.py:5965
 msgid "    bzr view --switch view-name"
 msgstr ""
 
-#: bzrlib/builtins.py:5924
+#: bzrlib/builtins.py:5967
 msgid "  To list all views defined::"
 msgstr ""
 
-#: bzrlib/builtins.py:5926
+#: bzrlib/builtins.py:5969
 msgid "    bzr view --all"
 msgstr ""
 
-#: bzrlib/builtins.py:5928
+#: bzrlib/builtins.py:5971
 msgid "  To delete all views::"
 msgstr ""
 
-#: bzrlib/builtins.py:5930
+#: bzrlib/builtins.py:5973
 msgid "    bzr view --delete --all"
 msgstr ""
 
 # help of 'all' option of 'view' command
-#: bzrlib/builtins.py:5937
+#: bzrlib/builtins.py:5980
 msgid "Apply list or delete action to all views."
 msgstr ""
 
 # help of 'delete' option of 'view' command
-#: bzrlib/builtins.py:5940
+#: bzrlib/builtins.py:5983
 msgid "Delete the view."
 msgstr ""
 
 # help of 'name' option of 'view' command
-#: bzrlib/builtins.py:5943
+#: bzrlib/builtins.py:5986
 msgid "Name of the view to define, list or delete."
 msgstr ""
 
 # help of 'switch' option of 'view' command
-#: bzrlib/builtins.py:5947
+#: bzrlib/builtins.py:5990
 msgid "Name of the view to switch to."
 msgstr ""
 
-#: bzrlib/builtins.py:6047
+#: bzrlib/builtins.py:6090
 msgid "Remove a branch."
 msgstr ""
 
-#: bzrlib/builtins.py:6049
+#: bzrlib/builtins.py:6092
 msgid ""
 "This will remove the branch from the specified location but \n"
 "will keep any working tree or repository in place."
 msgstr ""
 
-#: bzrlib/builtins.py:6054
+#: bzrlib/builtins.py:6097
 msgid "  Remove the branch at repo/trunk::"
 msgstr ""
 
-#: bzrlib/builtins.py:6056
+#: bzrlib/builtins.py:6099
 msgid "    bzr remove-branch repo/trunk"
 msgstr ""
 
-#: bzrlib/builtins.py:6072
+#: bzrlib/builtins.py:6115
 msgid "Temporarily set aside some changes from the current tree."
 msgstr ""
 
-#: bzrlib/builtins.py:6074
+#: bzrlib/builtins.py:6117
 msgid ""
 "Shelve allows you to temporarily put changes you've made \"on the shelf\",\n"
 "ie. out of the way, until a later time when you can bring them back from\n"
@@ -3284,11 +3289,11 @@
 "will they survive its deletion."
 msgstr ""
 
-#: bzrlib/builtins.py:6080
+#: bzrlib/builtins.py:6123
 msgid "If shelve --list is specified, previously-shelved changes are listed."
 msgstr ""
 
-#: bzrlib/builtins.py:6082
+#: bzrlib/builtins.py:6125
 msgid ""
 "Shelve is intended to help separate several sets of changes that have\n"
 "been inappropriately mingled.  If you just want to get rid of all changes\n"
@@ -3296,35 +3301,35 @@
 "shelve all text changes at once, use shelve --all."
 msgstr ""
 
-#: bzrlib/builtins.py:6087
+#: bzrlib/builtins.py:6130
 msgid ""
 "If filenames are specified, only the changes to those files will be\n"
 "shelved. Other files will be left untouched."
 msgstr ""
 
-#: bzrlib/builtins.py:6090
+#: bzrlib/builtins.py:6133
 msgid ""
 "If a revision is specified, changes since that revision will be shelved."
 msgstr ""
 
-#: bzrlib/builtins.py:6092
+#: bzrlib/builtins.py:6135
 msgid ""
 "You can put multiple items on the shelf, and by default, 'unshelve' will\n"
 "restore the most recently shelved changes."
 msgstr ""
 
-#: bzrlib/builtins.py:6095
+#: bzrlib/builtins.py:6138
 msgid ""
 "For complicated changes, it is possible to edit the changes in a separate\n"
 "editor program to decide what the file remaining in the working copy\n"
 "should look like.  To do this, add the configuration option"
 msgstr ""
 
-#: bzrlib/builtins.py:6099
+#: bzrlib/builtins.py:6142
 msgid "    change_editor = PROGRAM @new_path @old_path"
 msgstr ""
 
-#: bzrlib/builtins.py:6101
+#: bzrlib/builtins.py:6144
 msgid ""
 "where @new_path is replaced with the path of the new version of the \n"
 "file and @old_path is replaced with the path of the old version of \n"
@@ -3334,35 +3339,35 @@
 msgstr ""
 
 # help of 'all' option of 'shelve' command
-#: bzrlib/builtins.py:6113
+#: bzrlib/builtins.py:6156
 msgid "Shelve all changes."
 msgstr ""
 
 # help of 'writer' option of 'shelve' command
-#: bzrlib/builtins.py:6115
+#: bzrlib/builtins.py:6158
 msgid "Method to use for writing diffs."
 msgstr ""
 
 # title of 'writer' option of 'shelve' command
-#: bzrlib/builtins.py:6115
+#: bzrlib/builtins.py:6158
 msgid "writer"
 msgstr ""
 
 # help of 'list' option of 'shelve' command
-#: bzrlib/builtins.py:6119
+#: bzrlib/builtins.py:6162
 msgid "List shelved changes."
 msgstr ""
 
 # help of 'destroy' option of 'shelve' command
-#: bzrlib/builtins.py:6121
+#: bzrlib/builtins.py:6164
 msgid "Destroy removed changes instead of shelving them."
 msgstr ""
 
-#: bzrlib/builtins.py:6161
+#: bzrlib/builtins.py:6204
 msgid "Restore shelved changes."
 msgstr ""
 
-#: bzrlib/builtins.py:6163
+#: bzrlib/builtins.py:6206
 msgid ""
 "By default, the most recently shelved changes are restored. However if you\n"
 "specify a shelf by id those changes will be restored instead.  This works\n"
@@ -3370,60 +3375,60 @@
 msgstr ""
 
 # help of 'action' option of 'unshelve' command
-#: bzrlib/builtins.py:6172
+#: bzrlib/builtins.py:6215
 msgid "The action to perform."
 msgstr ""
 
-#: bzrlib/builtins.py:6194
+#: bzrlib/builtins.py:6237
 msgid "Remove unwanted files from working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:6196
+#: bzrlib/builtins.py:6239
 msgid ""
 "By default, only unknown files, not ignored files, are deleted.  Versioned\n"
 "files are never deleted."
 msgstr ""
 
-#: bzrlib/builtins.py:6199
+#: bzrlib/builtins.py:6242
 msgid ""
 "Another class is 'detritus', which includes files emitted by bzr during\n"
 "normal operations and selftests.  (The value of these files decreases with\n"
 "time.)"
 msgstr ""
 
-#: bzrlib/builtins.py:6203
+#: bzrlib/builtins.py:6246
 msgid ""
 "If no options are specified, unknown files are deleted.  Otherwise, option\n"
 "flags are respected, and may be combined."
 msgstr ""
 
-#: bzrlib/builtins.py:6206
+#: bzrlib/builtins.py:6249
 msgid "To check what clean-tree will do, use --dry-run."
 msgstr ""
 
 # help of 'ignored' option of 'clean-tree' command
-#: bzrlib/builtins.py:6209
+#: bzrlib/builtins.py:6252
 msgid "Delete all ignored files."
 msgstr ""
 
 # help of 'detritus' option of 'clean-tree' command
-#: bzrlib/builtins.py:6210
+#: bzrlib/builtins.py:6253
 msgid ""
 "Delete conflict files, merge and revert backups, and failed selftest dirs."
 msgstr ""
 
 # help of 'unknown' option of 'clean-tree' command
-#: bzrlib/builtins.py:6213
+#: bzrlib/builtins.py:6256
 msgid "Delete files unknown to bzr (default)."
 msgstr ""
 
 # help of 'dry-run' option of 'clean-tree' command
-#: bzrlib/builtins.py:6214
+#: bzrlib/builtins.py:6257
 msgid "Show files to delete instead of deleting them."
 msgstr ""
 
 # help of 'force' option of 'clean-tree' command
-#: bzrlib/builtins.py:6216
+#: bzrlib/builtins.py:6259
 msgid "Do not prompt before deleting."
 msgstr ""
 
@@ -3594,26 +3599,26 @@
 msgid "All commits signed with verifiable keys"
 msgstr ""
 
-#: bzrlib/config.py:3118
+#: bzrlib/config.py:3277
 msgid "Display, set or remove a configuration option."
 msgstr ""
 
-#: bzrlib/config.py:3120
+#: bzrlib/config.py:3279
 msgid "Display the active value for a given option."
 msgstr ""
 
-#: bzrlib/config.py:3122
+#: bzrlib/config.py:3281
 msgid ""
 "If --all is specified, NAME is interpreted as a regular expression and all\n"
 "matching options are displayed mentioning their scope. The active value\n"
 "that bzr will take into account is the first one displayed for each option."
 msgstr ""
 
-#: bzrlib/config.py:3126
+#: bzrlib/config.py:3285
 msgid "If no NAME is given, --all .* is implied."
 msgstr ""
 
-#: bzrlib/config.py:3128
+#: bzrlib/config.py:3287
 msgid ""
 "Setting a value is achieved by using name=value without spaces. The value\n"
 "is set in the most relevant scope and can be checked by displaying the\n"
@@ -3621,17 +3626,17 @@
 msgstr ""
 
 # help of 'scope' option of 'config' command
-#: bzrlib/config.py:3139
+#: bzrlib/config.py:3298
 msgid "Reduce the scope to the specified configuration file"
 msgstr ""
 
 # help of 'all' option of 'config' command
-#: bzrlib/config.py:3143
+#: bzrlib/config.py:3302
 msgid "Display all the defined values for the matching options."
 msgstr ""
 
 # help of 'remove' option of 'config' command
-#: bzrlib/config.py:3145
+#: bzrlib/config.py:3304
 msgid "Remove the option from the configuration file"
 msgstr ""
 
@@ -3690,244 +3695,244 @@
 msgid "action"
 msgstr ""
 
-#: bzrlib/errors.py:208
+#: bzrlib/errors.py:215
 msgid "The tree builder is already building a tree."
 msgstr ""
 
-#: bzrlib/errors.py:229
+#: bzrlib/errors.py:236
 msgid "The dirstate file (%(state)s) appears to be corrupt: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:248
+#: bzrlib/errors.py:255
 msgid ""
 "The API for \"%(api)s\" is not compatible with \"%(wanted)s\". It supports "
 "versions \"%(minimum)s\" to \"%(current)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:260
+#: bzrlib/errors.py:267
 msgid "The transport '%(transport)s' is only accessible within this process."
 msgstr ""
 
-#: bzrlib/errors.py:278
+#: bzrlib/errors.py:285
 msgid "Invalid revision number %(revno)s"
 msgstr ""
 
-#: bzrlib/errors.py:287
+#: bzrlib/errors.py:294
 msgid "Invalid revision-id {%(revision_id)s} in %(branch)s"
 msgstr ""
 
-#: bzrlib/errors.py:298
+#: bzrlib/errors.py:305
 msgid "Reserved revision-id {%(revision_id)s}"
 msgstr ""
 
-#: bzrlib/errors.py:312
+#: bzrlib/errors.py:319
 msgid "There is no public branch set for \"%(branch_url)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:322
+#: bzrlib/errors.py:329
 msgid ""
 "No help could be found for '%(topic)s'. Please use 'bzr help topics' to "
 "obtain a list of topics."
 msgstr ""
 
-#: bzrlib/errors.py:331
+#: bzrlib/errors.py:338
 msgid "The file id \"%(file_id)s\" is not present in the tree %(tree)s."
 msgstr ""
 
-#: bzrlib/errors.py:341
+#: bzrlib/errors.py:348
 msgid ""
 "The file id \"%(file_id)s\" is not present in the repository %(repository)r"
 msgstr ""
 
-#: bzrlib/errors.py:350
+#: bzrlib/errors.py:357
 msgid "The branch '%(branch)s' is not stacked."
 msgstr ""
 
-#: bzrlib/errors.py:364
+#: bzrlib/errors.py:371
 msgid "No WorkingTree exists for \"%(base)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:373
+#: bzrlib/errors.py:380
 msgid "Not currently building a tree."
 msgstr ""
 
-#: bzrlib/errors.py:378
+#: bzrlib/errors.py:385
 msgid "%(url)s is not a local path."
 msgstr ""
 
-#: bzrlib/errors.py:406
+#: bzrlib/errors.py:413
 msgid "%(not_locked)r is not write locked but needs to be."
 msgstr ""
 
-#: bzrlib/errors.py:414
+#: bzrlib/errors.py:421
 msgid "Error in command line options"
 msgstr ""
 
-#: bzrlib/errors.py:419
+#: bzrlib/errors.py:426
 msgid "%(value)s is not an index of type %(_type)s."
 msgstr ""
 
-#: bzrlib/errors.py:429
+#: bzrlib/errors.py:436
 msgid "Error in data for index %(value)s."
 msgstr ""
 
-#: bzrlib/errors.py:438
+#: bzrlib/errors.py:445
 msgid "The key '%(key)s' is already in index '%(index)s'."
 msgstr ""
 
-#: bzrlib/errors.py:448
+#: bzrlib/errors.py:455
 msgid "The key '%(key)s' is not a valid key."
 msgstr ""
 
-#: bzrlib/errors.py:457
+#: bzrlib/errors.py:464
 msgid "Could not parse options for index %(value)s."
 msgstr ""
 
-#: bzrlib/errors.py:466
+#: bzrlib/errors.py:473
 msgid "The value '%(value)s' is not a valid value."
 msgstr ""
 
-#: bzrlib/errors.py:494
+#: bzrlib/errors.py:501
 msgid "Generic path error: %(path)r%(extra)s)"
 msgstr ""
 
-#: bzrlib/errors.py:507
+#: bzrlib/errors.py:514
 msgid "No such file: %(path)r%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:512
+#: bzrlib/errors.py:519
 msgid "File exists: %(path)r%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:518
+#: bzrlib/errors.py:525
 msgid ""
 "Could not rename %(source)s => %(dest)s because both files exist. (Use --"
 "after to tell bzr about a rename that has already happened)%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:534
+#: bzrlib/errors.py:541
 msgid "\"%(path)s\" is not a directory %(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:539
+#: bzrlib/errors.py:546
 msgid "\"%(path)s\" is not in the working directory %(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:544
+#: bzrlib/errors.py:551
 msgid "Directory not empty: \"%(path)s\"%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:549
+#: bzrlib/errors.py:556
 msgid "Hard-linking \"%(path)s\" is not supported"
 msgstr ""
 
-#: bzrlib/errors.py:564
+#: bzrlib/errors.py:571
 msgid "Device or resource busy: \"%(path)s\"%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:569
+#: bzrlib/errors.py:576
 msgid "Permission denied: \"%(path)s\"%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:574
+#: bzrlib/errors.py:581
 msgid "Invalid url supplied to transport: \"%(path)s\"%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:579
+#: bzrlib/errors.py:586
 msgid "Invalid URL join request: %(reason)s: %(base)r + %(join_args)r"
 msgstr ""
 
-#: bzrlib/errors.py:590
+#: bzrlib/errors.py:597
 msgid "URLs differ by more than path: %(from_)r and %(to)r"
 msgstr ""
 
-#: bzrlib/errors.py:612
+#: bzrlib/errors.py:619
 msgid "The %(type)s hook '%(hook)s' is unknown in this version of bzrlib."
 msgstr ""
 
-#: bzrlib/errors.py:622
+#: bzrlib/errors.py:629
 msgid "Unsupported protocol for url \"%(path)s\"%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:630
+#: bzrlib/errors.py:637
 msgid ""
 "The branch '%(url)s'(%(format)s) is not a stackable format. You will need to "
 "upgrade the branch to permit branch stacking."
 msgstr ""
 
-#: bzrlib/errors.py:641
+#: bzrlib/errors.py:648
 msgid "The branch '%(branch_url)s' cannot be stacked on '%(target_url)s'."
 msgstr ""
 
-#: bzrlib/errors.py:651
+#: bzrlib/errors.py:658
 msgid ""
 "The repository '%(url)s'(%(format)s) is not a stackable format. You will "
 "need to upgrade the repository to permit branch stacking."
 msgstr ""
 
-#: bzrlib/errors.py:662
+#: bzrlib/errors.py:669
 msgid "Error reading from %(path)r."
 msgstr ""
 
-#: bzrlib/errors.py:681
+#: bzrlib/errors.py:688
 msgid "Path \"%(path)s\" is not a child of path \"%(base)s\"%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:697
+#: bzrlib/errors.py:704
 msgid "Path \"%(path)s\" is not unicode normalized"
 msgstr ""
 
-#: bzrlib/errors.py:705
+#: bzrlib/errors.py:712
 msgid "Not a branch: \"%(path)s\"%(detail)s."
 msgstr ""
 
-#: bzrlib/errors.py:747
+#: bzrlib/errors.py:754
 msgid "No submit branch available for branch \"%(path)s\""
 msgstr ""
 
-#: bzrlib/errors.py:756
+#: bzrlib/errors.py:763
 msgid "Already a branch: \"%(path)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:762
+#: bzrlib/errors.py:769
 msgid ""
 "Directory contains a branch, but no working tree (use bzr checkout if you "
 "wish to build a working tree): \"%(path)s\""
 msgstr ""
 
-#: bzrlib/errors.py:767
+#: bzrlib/errors.py:774
 msgid ""
 "\"%(function)s\" called on an AtomicFile after it was closed: \"%(path)s\""
 msgstr ""
 
-#: bzrlib/errors.py:777
+#: bzrlib/errors.py:784
 msgid ""
 "Parent not accessible given base \"%(base)s\" and relative path \"%(path)s\""
 msgstr ""
 
-#: bzrlib/errors.py:787
+#: bzrlib/errors.py:794
 msgid "No repository present: \"%(path)s\""
 msgstr ""
 
-#: bzrlib/errors.py:795
+#: bzrlib/errors.py:802
 msgid "File \"%(path)s\" is not in branch %(branch_base)s."
 msgstr ""
 
-#: bzrlib/errors.py:807
+#: bzrlib/errors.py:814
 msgid ""
 "Unsupported branch format: %(format)s\n"
 "Please run 'bzr upgrade'"
 msgstr ""
 
-#: bzrlib/errors.py:813
+#: bzrlib/errors.py:820
 msgid "Unknown %(kind)s format: %(format)r"
 msgstr ""
 
-#: bzrlib/errors.py:822
+#: bzrlib/errors.py:829
 msgid "Format %(format)s is not compatible with .bzr version %(bzrdir)s."
 msgstr ""
 
-#: bzrlib/errors.py:835
+#: bzrlib/errors.py:842
 msgid ""
 "%(target)s\n"
 "is not compatible with\n"
@@ -3935,452 +3940,452 @@
 "%(details)s"
 msgstr ""
 
-#: bzrlib/errors.py:851
+#: bzrlib/errors.py:858
 msgid "Revision is not compatible with %(repo_format)s"
 msgstr ""
 
-#: bzrlib/errors.py:861
+#: bzrlib/errors.py:868
 msgid "%(context_info)s%(path)s is already versioned."
 msgstr ""
 
-#: bzrlib/errors.py:882
+#: bzrlib/errors.py:889
 msgid "%(context_info)s%(path)s is not versioned."
 msgstr ""
 
-#: bzrlib/errors.py:903
+#: bzrlib/errors.py:910
 msgid "Path(s) are not versioned: %(paths_as_string)s"
 msgstr ""
 
-#: bzrlib/errors.py:914
+#: bzrlib/errors.py:921
 msgid "Path(s) do not exist: %(paths_as_string)s%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:933
+#: bzrlib/errors.py:940
 msgid "Cannot operate on \"%(filename)s\" of unsupported kind \"%(kind)s\""
 msgstr ""
 
-#: bzrlib/errors.py:941
+#: bzrlib/errors.py:948
 msgid ""
 "Filename %(filename)r is not valid in your current filesystem encoding "
 "%(fs_encoding)s"
 msgstr ""
 
-#: bzrlib/errors.py:952
+#: bzrlib/errors.py:959
 msgid "Cannot operate on \"%(filename)s\" because it is a control file"
 msgstr ""
 
-#: bzrlib/errors.py:970
+#: bzrlib/errors.py:977
 msgid "The lock for '%(lock_description)s' is in use and cannot be broken."
 msgstr ""
 
-#: bzrlib/errors.py:1009
+#: bzrlib/errors.py:1016
 msgid "Cannot lock %(lock)s: %(why)s"
 msgstr ""
 
-#: bzrlib/errors.py:1019
+#: bzrlib/errors.py:1026
 msgid ""
 "A transaction related operation was attempted after the transaction finished."
 msgstr ""
 
-#: bzrlib/errors.py:1046
+#: bzrlib/errors.py:1053
 msgid "Cannot lock: transport is read only: %(transport)s"
 msgstr ""
 
-#: bzrlib/errors.py:1054
+#: bzrlib/errors.py:1061
 msgid "Could not acquire lock \"%(lock)s\": %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:1065
+#: bzrlib/errors.py:1072
 msgid "Lock was broken while still open: %(lock)s - check storage consistency!"
 msgstr ""
 
-#: bzrlib/errors.py:1076
+#: bzrlib/errors.py:1083
 msgid ""
 "Lock was released and re-acquired before being broken: %(lock)s: held by "
 "%(holder)r, wanted to break %(target)r"
 msgstr ""
 
-#: bzrlib/errors.py:1088
+#: bzrlib/errors.py:1095
 msgid ""
 "Lock is apparently held, but corrupted: %(corruption_info)s\n"
 "Use 'bzr break-lock' to clear it"
 msgstr ""
 
-#: bzrlib/errors.py:1101
+#: bzrlib/errors.py:1108
 msgid "Lock not held: %(lock)s"
 msgstr ""
 
-#: bzrlib/errors.py:1130
+#: bzrlib/errors.py:1137
 msgid "No changes to commit"
 msgstr ""
 
-#: bzrlib/errors.py:1135
+#: bzrlib/errors.py:1142
 msgid ""
 "Selected-file commit of merges is not supported yet: files %(files_str)s"
 msgstr ""
 
-#: bzrlib/errors.py:1145
+#: bzrlib/errors.py:1152
 msgid ""
 "Excluding paths during commit is not supported by repository at %(repository)"
 "r."
 msgstr ""
 
-#: bzrlib/errors.py:1154
+#: bzrlib/errors.py:1161
 msgid ""
 "The specified commit message contains characters unsupported by the current "
 "encoding."
 msgstr ""
 
-#: bzrlib/errors.py:1160
+#: bzrlib/errors.py:1167
 msgid "Upgrade URL cannot work with readonly URLs."
 msgstr ""
 
-#: bzrlib/errors.py:1165
+#: bzrlib/errors.py:1172
 msgid "The branch format %(format)s is already at the most recent format."
 msgstr ""
 
-#: bzrlib/errors.py:1188
+#: bzrlib/errors.py:1195
 msgid "Option --change does not accept revision ranges"
 msgstr ""
 
-#: bzrlib/errors.py:1193
+#: bzrlib/errors.py:1200
 msgid "No namespace registered for string: %(spec)r"
 msgstr ""
 
-#: bzrlib/errors.py:1212
+#: bzrlib/errors.py:1219
 msgid ""
 "Requested revision: '%(spec)s' does not exist in branch: %(branch_url)s"
 "%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:1226
+#: bzrlib/errors.py:1233
 msgid "%(branch)s is missing %(object_type)s {%(object_id)s}"
 msgstr ""
 
-#: bzrlib/errors.py:1231
+#: bzrlib/errors.py:1238
 msgid ""
 "Operation denied because it would change the main history, which is not "
 "permitted by the append_revisions_only setting on branch \"%(location)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:1242
+#: bzrlib/errors.py:1249
 msgid ""
 "These branches have diverged. Use the missing command to see how.\n"
 "Use the merge command to reconcile them."
 msgstr ""
 
-#: bzrlib/errors.py:1262
+#: bzrlib/errors.py:1269
 msgid ""
 "Branches have no common ancestor, and no merge base revision was specified."
 msgstr ""
 
-#: bzrlib/errors.py:1268
+#: bzrlib/errors.py:1275
 msgid ""
 "Selected merge cannot perform reverse cherrypicks.  Try merge3 or diff3."
 msgstr ""
 
-#: bzrlib/errors.py:1274
+#: bzrlib/errors.py:1281
 msgid "Revisions have no common ancestor: %(revision_a)s %(revision_b)s"
 msgstr ""
 
-#: bzrlib/errors.py:1283
+#: bzrlib/errors.py:1290
 msgid ""
 "Revisions are not derived from the same root: %(revision_a)s %(revision_b)s."
 msgstr ""
 
-#: bzrlib/errors.py:1292
+#: bzrlib/errors.py:1299
 msgid "Revision %(rev_id)s is not an ancestor of %(not_ancestor_id)s"
 msgstr ""
 
-#: bzrlib/errors.py:1312
+#: bzrlib/errors.py:1319
 msgid "Branch %(branch)s has no commits."
 msgstr ""
 
-#: bzrlib/errors.py:1330
+#: bzrlib/errors.py:1337
 msgid ""
 "Bound branch %(branch)s is out of date with master branch %(master)s."
 "%(extra_help)s"
 msgstr ""
 
-#: bzrlib/errors.py:1342
+#: bzrlib/errors.py:1349
 msgid ""
 "Cannot commit to branch %(branch)s. It is bound to %(master)s, which is "
 "bound to %(remote)s."
 msgstr ""
 
-#: bzrlib/errors.py:1354
+#: bzrlib/errors.py:1361
 msgid "Cannot pull --overwrite to a branch which is bound %(branch)s"
 msgstr ""
 
-#: bzrlib/errors.py:1363
+#: bzrlib/errors.py:1370
 msgid ""
 "Unable to connect to target of bound branch %(branch)s => %(target)s: "
 "%(error)s"
 msgstr ""
 
-#: bzrlib/errors.py:1375
+#: bzrlib/errors.py:1382
 msgid "Error in processing weave: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:1384
+#: bzrlib/errors.py:1391
 msgid "Revision {%(revision_id)s} already present in %(weave)s"
 msgstr ""
 
-#: bzrlib/errors.py:1395
+#: bzrlib/errors.py:1402
 msgid "Revision {%(revision_id)s} not present in %(weave)s"
 msgstr ""
 
-#: bzrlib/errors.py:1405
+#: bzrlib/errors.py:1412
 msgid "Weave invariant violated: %(what)s"
 msgstr ""
 
-#: bzrlib/errors.py:1414
+#: bzrlib/errors.py:1421
 msgid "Parents are mismatched between two revisions. %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:1436
+#: bzrlib/errors.py:1443
 msgid ""
 "Weaves differ on text content. Revision: {%(revision_id)s}, %(weave_a)s, "
 "%(weave_b)s"
 msgstr ""
 
-#: bzrlib/errors.py:1448
+#: bzrlib/errors.py:1455
 msgid "Versioned file error"
 msgstr ""
 
-#: bzrlib/errors.py:1453
+#: bzrlib/errors.py:1460
 msgid "Revision {%(revision_id)s} not present in \"%(file_id)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:1463
+#: bzrlib/errors.py:1470
 msgid "Revision {%(revision_id)s} already present in \"%(file_id)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:1473
+#: bzrlib/errors.py:1480
 msgid "Text did not match its checksum: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:1598
+#: bzrlib/errors.py:1605
 msgid "Export format %(format)r not supported"
 msgstr ""
 
-#: bzrlib/errors.py:1607
+#: bzrlib/errors.py:1614
 msgid "Transport error: %(msg)s %(orig_error)s"
 msgstr ""
 
-#: bzrlib/errors.py:1633
+#: bzrlib/errors.py:1640
 msgid "Generic bzr smart protocol error: %(details)s"
 msgstr ""
 
-#: bzrlib/errors.py:1641
+#: bzrlib/errors.py:1648
 msgid "Received bad protocol version marker: %(marker)r"
 msgstr ""
 
-#: bzrlib/errors.py:1672
+#: bzrlib/errors.py:1679
 msgid "Transport operation not possible: %(msg)s %(orig_error)s"
 msgstr ""
 
-#: bzrlib/errors.py:1677
+#: bzrlib/errors.py:1684
 msgid "Connection error: %(msg)s %(orig_error)s"
 msgstr ""
 
-#: bzrlib/errors.py:1682
+#: bzrlib/errors.py:1689
 msgid "%(msg)s %(host)s%(port)s%(orig_error)s"
 msgstr ""
 
-#: bzrlib/errors.py:1703
+#: bzrlib/errors.py:1710
 msgid "Connection closed: %(msg)s %(orig_error)s"
 msgstr ""
 
-#: bzrlib/errors.py:1708
+#: bzrlib/errors.py:1715
 msgid "Invalid range access in %(path)s at %(offset)s: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:1718
+#: bzrlib/errors.py:1725
 msgid "Invalid http response for %(path)s: %(msg)s%(orig_error)s"
 msgstr ""
 
-#: bzrlib/errors.py:1733
+#: bzrlib/errors.py:1740
 msgid "Invalid http range %(range)r for %(path)s: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:1747
+#: bzrlib/errors.py:1754
 msgid "HTTP MIME Boundary missing for %(path)s: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:1755
+#: bzrlib/errors.py:1762
 msgid "Invalid http Content-type \"%(ctype)s\" for %(path)s: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:1764
+#: bzrlib/errors.py:1771
 msgid "%(source)s is%(permanently)s redirected to %(target)s"
 msgstr ""
 
-#: bzrlib/errors.py:1778
+#: bzrlib/errors.py:1785
 msgid "Too many redirections"
 msgstr ""
 
-#: bzrlib/errors.py:1783
+#: bzrlib/errors.py:1790
 msgid "Working tree has conflicts."
 msgstr ""
 
-#: bzrlib/errors.py:1787
+#: bzrlib/errors.py:1794
 msgid "Config file %(filename)s is not UTF-8 encoded\n"
 msgstr ""
 
-#: bzrlib/errors.py:1796
+#: bzrlib/errors.py:1803
 msgid ""
 "Error(s) parsing config file %(filename)s:\n"
 "%(errors)s"
 msgstr ""
 
-#: bzrlib/errors.py:1807
+#: bzrlib/errors.py:1814
 msgid "Bad value \"%(value)s\" for option \"%(name)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:1815
+#: bzrlib/errors.py:1822
 msgid "%(username)r does not seem to contain a reasonable email address"
 msgstr ""
 
-#: bzrlib/errors.py:1824
+#: bzrlib/errors.py:1831
 msgid "Failed to GPG sign data with command \"%(command_line)s\""
 msgstr ""
 
-#: bzrlib/errors.py:1832
+#: bzrlib/errors.py:1839
 msgid "Failed to verify GPG signature data with error \"%(error)s\""
 msgstr ""
 
-#: bzrlib/errors.py:1840
+#: bzrlib/errors.py:1847
 msgid "Unable to import library \"%(library)s\": %(error)s"
 msgstr ""
 
-#: bzrlib/errors.py:1848
+#: bzrlib/errors.py:1855
 msgid "python-gpgme is not installed, it is needed to verify signatures"
 msgstr ""
 
-#: bzrlib/errors.py:1856
+#: bzrlib/errors.py:1863
 msgid ""
 "The working tree for %(basedir)s has changed since the last commit, but "
 "weave merge requires that it be unchanged"
 msgstr ""
 
-#: bzrlib/errors.py:1866
+#: bzrlib/errors.py:1873
 msgid ""
 "Can't reprocess and show base, because reprocessing obscures the "
 "relationship of conflicting lines to the base"
 msgstr ""
 
-#: bzrlib/errors.py:1872
+#: bzrlib/errors.py:1879
 msgid "Cycle in graph %(graph)r"
 msgstr ""
 
-#: bzrlib/errors.py:1900
+#: bzrlib/errors.py:1907
 msgid "File %(filename)s is not conflicted."
 msgstr ""
 
-#: bzrlib/errors.py:1922
+#: bzrlib/errors.py:1929
 msgid "No bundle was found in \"%(filename)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:1931
+#: bzrlib/errors.py:1938
 msgid "Unable to handle bundle version %(version)s: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:1941
+#: bzrlib/errors.py:1948
 msgid "Branch %(base)s is missing revision %(text_revision)s of %(file_id)s"
 msgstr ""
 
-#: bzrlib/errors.py:1954
+#: bzrlib/errors.py:1961
 msgid "File id {%(file_id)s} already exists in inventory as %(entry)s"
 msgstr ""
 
-#: bzrlib/errors.py:1964
+#: bzrlib/errors.py:1971
 msgid "Key %(key)s is already present in map"
 msgstr ""
 
-#: bzrlib/errors.py:1969
+#: bzrlib/errors.py:1976
 msgid "The prefix %(prefix)s is in the help search path twice."
 msgstr ""
 
-#: bzrlib/errors.py:1977
+#: bzrlib/errors.py:1984
 msgid "Tree transform is malformed %(conflicts)r"
 msgstr ""
 
-#: bzrlib/errors.py:1979
+#: bzrlib/errors.py:1986
 msgid ""
 "No final name for trans_id %(trans_id)r\n"
 "file-id: %(file_id)r\n"
 "root trans-id: %(root_trans_id)r\n"
 msgstr ""
 
-#: bzrlib/errors.py:2011
+#: bzrlib/errors.py:2018
 msgid "Attempt to reuse a transform that has already been applied."
 msgstr ""
 
-#: bzrlib/errors.py:2016
+#: bzrlib/errors.py:2023
 msgid "Moving the root directory is not supported at this time"
 msgstr ""
 
-#: bzrlib/errors.py:2021
+#: bzrlib/errors.py:2028
 msgid "Failed to rename %(from_path)s to %(to_path)s: %(why)s"
 msgstr ""
 
-#: bzrlib/errors.py:2032
+#: bzrlib/errors.py:2039
 msgid ""
 "Could not move %(from_path)s%(operator)s %(to_path)s%(_has_extra)s%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:2068
+#: bzrlib/errors.py:2075
 msgid ""
 "Could not rename %(from_path)s%(operator)s %(to_path)s%(_has_extra)s%(extra)s"
 msgstr ""
 
-#: bzrlib/errors.py:2077
+#: bzrlib/errors.py:2084
 msgid ""
 "Can't safely remove modified or unknown files:\n"
 "%(changes_as_text)sUse --keep to not delete them, or --force to delete them "
 "regardless."
 msgstr ""
 
-#: bzrlib/errors.py:2114
+#: bzrlib/errors.py:2121
 msgid "Unable to import paramiko (required for sftp support): %(error)s"
 msgstr ""
 
-#: bzrlib/errors.py:2122
+#: bzrlib/errors.py:2129
 msgid "Nothing to merge."
 msgstr ""
 
-#: bzrlib/errors.py:2127
+#: bzrlib/errors.py:2134
 msgid "Format %(format)s cannot be initialised by this version of bzr."
 msgstr ""
 
-#: bzrlib/errors.py:2136
+#: bzrlib/errors.py:2143
 msgid ""
 "Cannot convert from format %(from_format)s to format %(format)s.    "
 "%(problem)s"
 msgstr ""
 
-#: bzrlib/errors.py:2148
+#: bzrlib/errors.py:2155
 msgid "Could not find an appropriate Differ for file \"%(path)s\""
 msgstr ""
 
-#: bzrlib/errors.py:2156
+#: bzrlib/errors.py:2163
 msgid "%(exe_name)s could not be found on this machine"
 msgstr ""
 
-#: bzrlib/errors.py:2164
+#: bzrlib/errors.py:2171
 msgid "Diff is not installed on this machine: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:2172
+#: bzrlib/errors.py:2179
 msgid "Diff3 is not installed on this machine."
 msgstr ""
 
-#: bzrlib/errors.py:2178
+#: bzrlib/errors.py:2185
 msgid "The content being inserted is already present."
 msgstr ""
 
-#: bzrlib/errors.py:2183
+#: bzrlib/errors.py:2190
 msgid ""
 "This tree contains left-over files from a failed operation.\n"
 "    Please examine %(limbo_dir)s to see if it contains any files you wish "
@@ -4388,14 +4393,14 @@
 "    keep, and delete it when you are done."
 msgstr ""
 
-#: bzrlib/errors.py:2194
+#: bzrlib/errors.py:2201
 msgid ""
 "This tree contains left-over files from a failed operation.\n"
 "    Please examine %(pending_deletion)s to see if it contains any files you\n"
 "    wish to keep, and delete it when you are done."
 msgstr ""
 
-#: bzrlib/errors.py:2204
+#: bzrlib/errors.py:2211
 msgid ""
 "Unable to delete transform temporary directory %(limbo_dir)s.\n"
 "    Please examine %(limbo_dir)s to see if it contains any files you wish "
@@ -4403,487 +4408,497 @@
 "    keep, and delete it when you are done."
 msgstr ""
 
-#: bzrlib/errors.py:2215
+#: bzrlib/errors.py:2222
 msgid ""
 "Unable to delete transform temporary directory %(pending_deletion)s.  Please "
 "examine %(pending_deletion)s to see if it contains any files you wish to "
 "keep, and delete it when you are done."
 msgstr ""
 
-#: bzrlib/errors.py:2225
+#: bzrlib/errors.py:2232
 msgid "Working tree is out of date, please run 'bzr update'.%(more)s"
 msgstr ""
 
-#: bzrlib/errors.py:2239
+#: bzrlib/errors.py:2246
 msgid "Public branch \"%(public_location)s\" lacks revision \"%(revstring)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:2252
+#: bzrlib/errors.py:2259
 msgid "Error in merge modified format"
 msgstr ""
 
-#: bzrlib/errors.py:2257
+#: bzrlib/errors.py:2264
 msgid "Format error in conflict listings"
 msgstr ""
 
-#: bzrlib/errors.py:2261
+#: bzrlib/errors.py:2268
 msgid ""
 "Inconsistency in dirstate file %(dirstate_path)s.\n"
 "Error: %(description)s"
 msgstr ""
 
-#: bzrlib/errors.py:2272
+#: bzrlib/errors.py:2279
 msgid ""
 "An error has been detected in the repository %(repo_path)s.\n"
 "Please run bzr reconcile on this repository."
 msgstr ""
 
-#: bzrlib/errors.py:2283
+#: bzrlib/errors.py:2290
 msgid ""
 "An inconsistent delta was supplied involving %(path)r, %(file_id)r\n"
 "reason: %(reason)s"
 msgstr ""
 
-#: bzrlib/errors.py:2296
+#: bzrlib/errors.py:2303
 msgid ""
 "An inconsistent delta was supplied: %(delta)r\n"
 "reason: %(reason)s"
 msgstr ""
 
-#: bzrlib/errors.py:2308
+#: bzrlib/errors.py:2315
 msgid "To use this feature you must upgrade your branch at %(path)s."
 msgstr ""
 
-#: bzrlib/errors.py:2317
+#: bzrlib/errors.py:2324
 msgid "To use this feature you must upgrade your repository at %(path)s."
 msgstr ""
 
-#: bzrlib/errors.py:2322
+#: bzrlib/errors.py:2329
 msgid ""
 "To use this feature you must upgrade your branch at %(path)s to a format "
 "which supports rich roots."
 msgstr ""
 
-#: bzrlib/errors.py:2328
+#: bzrlib/errors.py:2335
 msgid "Cannot perform local-only commits on unbound branches."
 msgstr ""
 
-#: bzrlib/errors.py:2333
+#: bzrlib/errors.py:2340
 msgid "The method %(mname)s is not supported on objects of type %(tname)s."
 msgstr ""
 
-#: bzrlib/errors.py:2354
+#: bzrlib/errors.py:2361
+msgid "Ghost tags not supported by format %(format)r."
+msgstr ""
+
+#: bzrlib/errors.py:2369
 msgid "File is binary but should be text."
 msgstr ""
 
-#: bzrlib/errors.py:2359
+#: bzrlib/errors.py:2374
 msgid "The path %(path)s is not permitted on this platform"
 msgstr ""
 
-#: bzrlib/errors.py:2368
+#: bzrlib/errors.py:2383
 msgid ""
 "Testament did not match expected value.\n"
 "       For revision_id {%(revision_id)s}, expected {%(expected)s}, measured\n"
 "       {%(measured)s}"
 msgstr ""
 
-#: bzrlib/errors.py:2380
+#: bzrlib/errors.py:2395
 msgid "Not a bzr revision-bundle: %(text)r"
 msgstr ""
 
-#: bzrlib/errors.py:2389
+#: bzrlib/errors.py:2404
 msgid "Bad bzr revision-bundle: %(text)r"
 msgstr ""
 
-#: bzrlib/errors.py:2398
+#: bzrlib/errors.py:2413
 msgid "Malformed bzr revision-bundle header: %(text)r"
 msgstr ""
 
-#: bzrlib/errors.py:2403
+#: bzrlib/errors.py:2418
 msgid "Malformed patches in bzr revision-bundle: %(text)r"
 msgstr ""
 
-#: bzrlib/errors.py:2408
+#: bzrlib/errors.py:2423
 msgid "Malformed footer in bzr revision-bundle: %(text)r"
 msgstr ""
 
-#: bzrlib/errors.py:2413
+#: bzrlib/errors.py:2428
 msgid "End of line marker was not \\n in bzr revision-bundle"
 msgstr ""
 
-#: bzrlib/errors.py:2423
+#: bzrlib/errors.py:2438
 msgid "Bundle format %(bundle_format)s is incompatible with %(other)s"
 msgstr ""
 
-#: bzrlib/errors.py:2433
+#: bzrlib/errors.py:2448
 msgid "Root class for inventory serialization errors"
 msgstr ""
 
-#: bzrlib/errors.py:2437
+#: bzrlib/errors.py:2452
 msgid ""
 "The inventory was not in the expected format:\n"
 " %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:2446
+#: bzrlib/errors.py:2461
 msgid "This operation requires rich root data storage"
 msgstr ""
 
-#: bzrlib/errors.py:2459
+#: bzrlib/errors.py:2474
 msgid "Unrecognised value for BZR_SSH environment variable: %(vendor)s"
 msgstr ""
 
-#: bzrlib/errors.py:2468
+#: bzrlib/errors.py:2483
 msgid ""
 "Don't know how to handle SSH connections. Please set BZR_SSH environment "
 "variable."
 msgstr ""
 
-#: bzrlib/errors.py:2475
+#: bzrlib/errors.py:2490
 msgid ""
 "Could not determine revno for {%(revision_id)s} because its ancestry shows a "
 "ghost at {%(ghost_revision_id)s}"
 msgstr ""
 
-#: bzrlib/errors.py:2485
+#: bzrlib/errors.py:2500
 msgid "Ghost revision {%(revision_id)s} cannot be used here."
 msgstr ""
 
-#: bzrlib/errors.py:2536
+#: bzrlib/errors.py:2551
 msgid ""
 "A merge directive must provide either a bundle or a public branch location."
 msgstr ""
 
-#: bzrlib/errors.py:2543
+#: bzrlib/errors.py:2558
 msgid "Bad merge directive payload %(start)r"
 msgstr ""
 
-#: bzrlib/errors.py:2553
+#: bzrlib/errors.py:2568
 msgid "Preview patch does not match requested changes."
 msgstr ""
 
-#: bzrlib/errors.py:2559
+#: bzrlib/errors.py:2574
 msgid "Patch_type was %(patch_type)s, but no patch was supplied."
 msgstr ""
 
-#: bzrlib/errors.py:2569
+#: bzrlib/errors.py:2584
 msgid ""
 "Your branch does not have all of the revisions required in order to merge "
 "this merge directive and the target location specified in the merge "
 "directive is not a branch: %(location)s."
 msgstr ""
 
-#: bzrlib/errors.py:2581
+#: bzrlib/errors.py:2596
 msgid "Unsupported entry kind %(kind)s"
 msgstr ""
 
-#: bzrlib/errors.py:2589
+#: bzrlib/errors.py:2604
 msgid "Can't subsume %(other_tree)s into %(tree)s. %(reason)s"
 msgstr ""
 
-#: bzrlib/errors.py:2599
+#: bzrlib/errors.py:2614
 msgid "Subsume target %(other_tree)s needs to be upgraded."
 msgstr ""
 
-#: bzrlib/errors.py:2618
+#: bzrlib/errors.py:2633
 msgid "No such tag: %(tag_name)s"
 msgstr ""
 
-#: bzrlib/errors.py:2626
+#: bzrlib/errors.py:2641
 msgid "Tags not supported by %(branch)s; you may be able to use bzr upgrade."
 msgstr ""
 
-#: bzrlib/errors.py:2635
+#: bzrlib/errors.py:2650
 msgid "Tag %(tag_name)s already exists."
 msgstr ""
 
-#: bzrlib/errors.py:2643
+#: bzrlib/errors.py:2658
 msgid ""
 "Did not understand bug identifier %(bug_id)s: %(reason)s. See \"bzr help bugs"
 "\" for more information on this feature."
 msgstr ""
 
-#: bzrlib/errors.py:2653
+#: bzrlib/errors.py:2668
 msgid ""
 "The URL for bug tracker \"%(abbreviation)s\" doesn't contain {id}: %(url)s"
 msgstr ""
 
-#: bzrlib/errors.py:2663
+#: bzrlib/errors.py:2678
 msgid ""
 "Cannot find registered bug tracker called %(abbreviation)s on %(branch)s"
 msgstr ""
 
-#: bzrlib/errors.py:2673
+#: bzrlib/errors.py:2688
 msgid "Invalid line in bugs property: '%(line)s'"
 msgstr ""
 
-#: bzrlib/errors.py:2681
+#: bzrlib/errors.py:2696
 msgid "Invalid bug status: '%(status)s'"
 msgstr ""
 
-#: bzrlib/errors.py:2689
+#: bzrlib/errors.py:2704
 msgid "Could not understand response from smart server: %(response_tuple)r"
 msgstr ""
 
-#: bzrlib/errors.py:2728
+#: bzrlib/errors.py:2743
 msgid "Server sent an unexpected error: %(error_tuple)r"
 msgstr ""
 
-#: bzrlib/errors.py:2747
+#: bzrlib/errors.py:2762
 msgid "Unrecognised container format: %(container_format)r"
 msgstr ""
 
-#: bzrlib/errors.py:2755
+#: bzrlib/errors.py:2770
 msgid "Unexpected end of container stream"
 msgstr ""
 
-#: bzrlib/errors.py:2760
+#: bzrlib/errors.py:2775
 msgid "Unknown record type: %(record_type)r"
 msgstr ""
 
-#: bzrlib/errors.py:2768
+#: bzrlib/errors.py:2783
 msgid "Invalid record: %(reason)s"
 msgstr ""
 
-#: bzrlib/errors.py:2776
+#: bzrlib/errors.py:2791
 msgid "Container has data after end marker: %(excess)r"
 msgstr ""
 
-#: bzrlib/errors.py:2784
+#: bzrlib/errors.py:2799
 msgid "Container has multiple records with the same name: %(name)s"
 msgstr ""
 
-#: bzrlib/errors.py:2797
+#: bzrlib/errors.py:2812
 msgid "Corrupt or incompatible data stream: %(reason)s"
 msgstr ""
 
-#: bzrlib/errors.py:2805
+#: bzrlib/errors.py:2820
 msgid "SMTP error: %(error)s"
 msgstr ""
 
-#: bzrlib/errors.py:2813
+#: bzrlib/errors.py:2828
 msgid "No message supplied."
 msgstr ""
 
-#: bzrlib/errors.py:2818
+#: bzrlib/errors.py:2833
 msgid "No mail-to address (--mail-to) or output (-o) specified."
 msgstr ""
 
-#: bzrlib/errors.py:2823
+#: bzrlib/errors.py:2838
 msgid "Unknown mail client: %(mail_client)s"
 msgstr ""
 
-#: bzrlib/errors.py:2831
+#: bzrlib/errors.py:2846
 msgid ""
 "Unable to find mail client with the following names: "
 "%(mail_command_list_string)s"
 msgstr ""
 
-#: bzrlib/errors.py:2841
+#: bzrlib/errors.py:2856
 msgid "SMTP connection to %(host)s refused"
 msgstr ""
 
-#: bzrlib/errors.py:2850
+#: bzrlib/errors.py:2865
 msgid "Please specify smtp_server.  No server at default %(host)s."
 msgstr ""
 
-#: bzrlib/errors.py:2864
+#: bzrlib/errors.py:2879
 msgid ""
 "'%(display_url)s' is not in sync with %(target_url)s.  See bzr help sync-for-"
 "reconfigure."
 msgstr ""
 
-#: bzrlib/errors.py:2876
+#: bzrlib/errors.py:2891
 msgid "'%(display_url)s' is already a branch."
 msgstr ""
 
-#: bzrlib/errors.py:2881
+#: bzrlib/errors.py:2896
 msgid "'%(display_url)s' is already a tree."
 msgstr ""
 
-#: bzrlib/errors.py:2886
+#: bzrlib/errors.py:2901
 msgid "'%(display_url)s' is already a checkout."
 msgstr ""
 
-#: bzrlib/errors.py:2891
+#: bzrlib/errors.py:2906
 msgid "'%(display_url)s' is already a lightweight checkout."
 msgstr ""
 
-#: bzrlib/errors.py:2896
+#: bzrlib/errors.py:2911
 msgid "'%(display_url)s' is already using a shared repository."
 msgstr ""
 
-#: bzrlib/errors.py:2901
+#: bzrlib/errors.py:2916
 msgid "'%(display_url)s' is already standalone."
 msgstr ""
 
-#: bzrlib/errors.py:2906
+#: bzrlib/errors.py:2921
 msgid "Shared repository '%(display_url)s' already creates working trees."
 msgstr ""
 
-#: bzrlib/errors.py:2912
+#: bzrlib/errors.py:2927
 msgid ""
 "Shared repository '%(display_url)s' already doesn't create working trees."
 msgstr ""
 
-#: bzrlib/errors.py:2918
+#: bzrlib/errors.py:2933
 msgid "Requested reconfiguration of '%(display_url)s' is not supported."
 msgstr ""
 
-#: bzrlib/errors.py:2923
+#: bzrlib/errors.py:2938
 msgid "No location could be found to bind to at %(display_url)s."
 msgstr ""
 
-#: bzrlib/errors.py:2928
+#: bzrlib/errors.py:2943
 msgid ""
 "Working tree \"%(display_url)s\" has uncommitted changes (See bzr status)."
 "%(more)s"
 msgstr ""
 
-#: bzrlib/errors.py:2947
+#: bzrlib/errors.py:2962
 msgid ""
 "Working tree \"%(display_url)s\" has shelved changes (See bzr shelve --list)."
 "%(more)s"
 msgstr ""
 
-#: bzrlib/errors.py:2953
+#: bzrlib/errors.py:2968
 msgid "Variable {%(name)s} is not available."
 msgstr ""
 
-#: bzrlib/errors.py:2961
+#: bzrlib/errors.py:2976
 msgid "No template specified."
 msgstr ""
 
-#: bzrlib/errors.py:2966
+#: bzrlib/errors.py:2981
 msgid "Unable to create symlink %(path_str)son this platform"
 msgstr ""
 
-#: bzrlib/errors.py:2981
+#: bzrlib/errors.py:2996
 msgid ""
 "Unsupported timezone format \"%(timezone)s\", options are \"utc\", \"original"
 "\", \"local\"."
 msgstr ""
 
-#: bzrlib/errors.py:3015
+#: bzrlib/errors.py:3030
 msgid ""
 "Unable to encode %(kind)s path %(path)r in user encoding %(user_encoding)s"
 msgstr ""
 
-#: bzrlib/errors.py:3027
+#: bzrlib/errors.py:3042
 msgid "The \"%(config_id)s\" configuration does not exist."
 msgstr ""
 
-#: bzrlib/errors.py:3035
+#: bzrlib/errors.py:3050
 msgid "The \"%(option_name)s\" configuration option does not exist."
 msgstr ""
 
-#: bzrlib/errors.py:3043
+#: bzrlib/errors.py:3058
 msgid "The alias \"%(alias_name)s\" does not exist."
 msgstr ""
 
-#: bzrlib/errors.py:3057
+#: bzrlib/errors.py:3072
 msgid "\"%(alias_name)s\" is not a valid location alias."
 msgstr ""
 
-#: bzrlib/errors.py:3065
+#: bzrlib/errors.py:3080
 msgid "No %(alias_name)s location assigned."
 msgstr ""
 
-#: bzrlib/errors.py:3073
+#: bzrlib/errors.py:3088
 msgid "Cannot bind address \"%(host)s:%(port)i\": %(orig_error)s."
 msgstr ""
 
-#: bzrlib/errors.py:3083
+#: bzrlib/errors.py:3098
 msgid "Unknown rules detected: %(unknowns_str)s."
 msgstr ""
 
-#: bzrlib/errors.py:3096
+#: bzrlib/errors.py:3111
 msgid ""
 "Hook '%(hook_name)s' during %(hook_stage)s failed:\n"
 "%(traceback_text)s%(exc_value)s"
 msgstr ""
 
-#: bzrlib/errors.py:3119
+#: bzrlib/errors.py:3134
 msgid "Tip change rejected: %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:3127
+#: bzrlib/errors.py:3142
 msgid "Shelf corrupt."
 msgstr ""
 
-#: bzrlib/errors.py:3132
+#: bzrlib/errors.py:3147
 msgid "Corruption while decompressing repository file%(orig_error)s"
 msgstr ""
 
-#: bzrlib/errors.py:3144
+#: bzrlib/errors.py:3159
 msgid "No changes are shelved with id \"%(shelf_id)d\"."
 msgstr ""
 
-#: bzrlib/errors.py:3152
+#: bzrlib/errors.py:3167
 msgid "\"%(invalid_id)s\" is not a valid shelf id, try a number instead."
 msgstr ""
 
-#: bzrlib/errors.py:3160
+#: bzrlib/errors.py:3175
 msgid "An attempt to access a url outside the server jail was made: '%(url)s'."
 msgstr ""
 
-#: bzrlib/errors.py:3168
+#: bzrlib/errors.py:3183
 msgid "The user aborted the operation."
 msgstr ""
 
-#: bzrlib/errors.py:3173
+#: bzrlib/errors.py:3188
 msgid "Branching '%(url)s'(%(format)s) must create a working tree."
 msgstr ""
 
-#: bzrlib/errors.py:3183
+#: bzrlib/errors.py:3198
 msgid "No such view: %(view_name)s."
 msgstr ""
 
-#: bzrlib/errors.py:3193
+#: bzrlib/errors.py:3208
 msgid ""
 "Views are not supported by %(tree)s; use 'bzr upgrade' to change your tree "
 "to a later format."
 msgstr ""
 
-#: bzrlib/errors.py:3202
+#: bzrlib/errors.py:3217
 msgid ""
 "Specified file \"%(file_name)s\" is outside the current view: %(view_str)s"
 msgstr ""
 
-#: bzrlib/errors.py:3269
+#: bzrlib/errors.py:3284
 msgid "%(bzrdir)r does not support co-located branches."
 msgstr ""
 
-#: bzrlib/errors.py:3275
+#: bzrlib/errors.py:3290
 msgid ""
 "Unable to determine your name.\n"
 "Please, set your name with the 'whoami' command.\n"
 "E.g. bzr whoami \"Your Name <name@example.com>\""
 msgstr ""
 
-#: bzrlib/errors.py:3284
+#: bzrlib/errors.py:3299
 msgid "Invalid pattern(s) found. %(msg)s"
 msgstr ""
 
-#: bzrlib/errors.py:3292
+#: bzrlib/errors.py:3307
 msgid ""
 "Branch \"%(branch_url)s\" appears to be bound to itself. Please use `bzr "
 "unbind` to fix."
 msgstr ""
 
-#: bzrlib/errors.py:3303
+#: bzrlib/errors.py:3318
 msgid "Loop involving %(refs)r while expanding \"%(string)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:3312
+#: bzrlib/errors.py:3327
 msgid "Option %(name)s is not defined while expanding \"%(string)s\"."
 msgstr ""
 
-#: bzrlib/errors.py:3321
+#: bzrlib/errors.py:3336
 msgid ""
 "No compatible object available for operations from %(source)r to %(target)r."
 msgstr ""
 
+#: bzrlib/errors.py:3346
+msgid ""
+"VFS requests over the smart server are not allowed. Encountered: %(method)s, "
+"%(arguments)s."
+msgstr ""
+
 #: bzrlib/gpg.py:126 bzrlib/gpg.py:464
 msgid "{0} commits with valid signatures"
 msgstr ""
@@ -5294,3 +5309,5720 @@
 #: bzrlib/plugins/launchpad/__init__.py:388
 msgid "  bzr lp-find-proposal -r annotate:README:1"
 msgstr ""
+
+#: dummy/help_topics/authentication/summary.txt:1
+msgid "Information on configuring authentication"
+msgstr ""
+
+#: dummy/help_topics/basic/detail.txt:1
+msgid ""
+"Bazaar 2.5.0dev1 -- a free distributed version-control tool\n"
+"http://bazaar.canonical.com/"
+msgstr ""
+
+#: dummy/help_topics/basic/detail.txt:4
+msgid ""
+"Basic commands:\n"
+"  bzr init           makes this directory a versioned branch\n"
+"  bzr branch         make a copy of another branch"
+msgstr ""
+
+#: dummy/help_topics/basic/detail.txt:8
+msgid ""
+"  bzr add            make files or directories versioned\n"
+"  bzr ignore         ignore a file or pattern\n"
+"  bzr mv             move or rename a versioned file"
+msgstr ""
+
+#: dummy/help_topics/basic/detail.txt:12
+msgid ""
+"  bzr status         summarize changes in working copy\n"
+"  bzr diff           show detailed diffs"
+msgstr ""
+
+#: dummy/help_topics/basic/detail.txt:15
+msgid ""
+"  bzr merge          pull in changes from another branch\n"
+"  bzr commit         save some or all changes\n"
+"  bzr send           send changes via email"
+msgstr ""
+
+#: dummy/help_topics/basic/detail.txt:19
+msgid ""
+"  bzr log            show history of changes\n"
+"  bzr check          validate storage"
+msgstr ""
+
+#: dummy/help_topics/basic/detail.txt:22
+msgid ""
+"  bzr help init      more help on e.g. init command\n"
+"  bzr help commands  list all commands\n"
+"  bzr help topics    list all help topics\n"
+msgstr ""
+
+#: dummy/help_topics/basic/summary.txt:1
+msgid "Basic commands"
+msgstr ""
+
+#: dummy/help_topics/branches/detail.txt:1
+msgid "Branches"
+msgstr ""
+
+#: dummy/help_topics/branches/detail.txt:3
+msgid ""
+"A branch consists of the state of a project, including all of its\n"
+"history. All branches have a repository associated (which is where the\n"
+"branch history is stored), but multiple branches may share the same\n"
+"repository (a shared repository). Branches can be copied and merged."
+msgstr ""
+
+#: dummy/help_topics/branches/detail.txt:8
+msgid ""
+"In addition, one branch may be bound to another one.  Binding to another\n"
+"branch indicates that commits which happen in this branch must also \n"
+"happen in the other branch.  Bazaar ensures consistency by not allowing \n"
+"commits when the two branches are out of date.  In order for a commit \n"
+"to succeed, it may be necessary to update the current branch using \n"
+"``bzr update``."
+msgstr ""
+
+#: dummy/help_topics/branches/detail.txt:15
+msgid "Related commands::"
+msgstr ""
+
+#: dummy/help_topics/branches/detail.txt:17
+msgid ""
+"  init    Change a directory into a versioned branch.\n"
+"  branch  Create a new branch that is a copy of an existing branch.\n"
+"  merge   Perform a three-way merge.\n"
+"  bind    Bind a branch to another one.\n"
+msgstr ""
+
+#: dummy/help_topics/branches/summary.txt:1
+msgid "Information on what a branch is"
+msgstr ""
+
+#: dummy/help_topics/bugs/summary.txt:1
+msgid "Bug tracker settings"
+msgstr ""
+
+#: dummy/help_topics/checkouts/detail.txt:1
+msgid "Checkouts"
+msgstr ""
+
+#: dummy/help_topics/checkouts/detail.txt:3
+msgid ""
+"Checkouts are source trees that are connected to a branch, so that when\n"
+"you commit in the source tree, the commit goes into that branch.  They\n"
+"allow you to use a simpler, more centralized workflow, ignoring some of\n"
+"Bazaar's decentralized features until you want them. Using checkouts\n"
+"with shared repositories is very similar to working with SVN or CVS, but\n"
+"doesn't have the same restrictions.  And using checkouts still allows\n"
+"others working on the project to use whatever workflow they like."
+msgstr ""
+
+#: dummy/help_topics/checkouts/detail.txt:11
+msgid ""
+"A checkout is created with the bzr checkout command (see \"help checkout"
+"\").\n"
+"You pass it a reference to another branch, and it will create a local copy\n"
+"for you that still contains a reference to the branch you created the\n"
+"checkout from (the master branch). Then if you make any commits they will "
+"be\n"
+"made on the other branch first. This creates an instant mirror of your work, "
+"or\n"
+"facilitates lockstep development, where each developer is working together,\n"
+"continuously integrating the changes of others."
+msgstr ""
+
+#: dummy/help_topics/checkouts/detail.txt:19
+msgid ""
+"However the checkout is still a first class branch in Bazaar terms, so that\n"
+"you have the full history locally.  As you have a first class branch you "
+"can\n"
+"also commit locally if you want, for instance due to the temporary loss af "
+"a\n"
+"network connection. Use the --local option to commit to do this. All the "
+"local\n"
+"commits will then be made on the master branch the next time you do a non-"
+"local\n"
+"commit."
+msgstr ""
+
+#: dummy/help_topics/checkouts/detail.txt:26
+msgid ""
+"If you are using a checkout from a shared branch you will periodically want "
+"to\n"
+"pull in all the changes made by others. This is done using the \"update\"\n"
+"command. The changes need to be applied before any non-local commit, but\n"
+"Bazaar will tell you if there are any changes and suggest that you use this\n"
+"command when needed."
+msgstr ""
+
+#: dummy/help_topics/checkouts/detail.txt:32
+msgid ""
+"It is also possible to create a \"lightweight\" checkout by passing the\n"
+"--lightweight flag to checkout. A lightweight checkout is even closer to an\n"
+"SVN checkout in that it is not a first class branch, it mainly consists of "
+"the\n"
+"working tree. This means that any history operations must query the master\n"
+"branch, which could be slow if a network connection is involved. Also, as "
+"you\n"
+"don't have a local branch, then you cannot commit locally."
+msgstr ""
+
+#: dummy/help_topics/checkouts/detail.txt:39
+msgid ""
+"Lightweight checkouts work best when you have fast reliable access to the\n"
+"master branch. This means that if the master branch is on the same disk or "
+"LAN\n"
+"a lightweight checkout will be faster than a heavyweight one for any "
+"commands\n"
+"that modify the revision history (as only one copy of the branch needs to\n"
+"be updated). Heavyweight checkouts will generally be faster for any command\n"
+"that uses the history but does not change it, but if the master branch is "
+"on\n"
+"the same disk then there won't be a noticeable difference."
+msgstr ""
+
+#: dummy/help_topics/checkouts/detail.txt:47
+msgid ""
+"Another possible use for a checkout is to use it with a treeless repository\n"
+"containing your branches, where you maintain only one working tree by\n"
+"switching the master branch that the checkout points to when you want to\n"
+"work on a different branch."
+msgstr ""
+
+#: dummy/help_topics/checkouts/detail.txt:52
+msgid ""
+"Obviously to commit on a checkout you need to be able to write to the "
+"master\n"
+"branch. This means that the master branch must be accessible over a "
+"writeable\n"
+"protocol , such as sftp://, and that you have write permissions at the "
+"other\n"
+"end. Checkouts also work on the local file system, so that all that matters "
+"is\n"
+"file permissions."
+msgstr ""
+
+#: dummy/help_topics/checkouts/detail.txt:58
+msgid ""
+"You can change the master of a checkout by using the \"switch\" command "
+"(see\n"
+"\"help switch\").  This will change the location that the commits are sent "
+"to.\n"
+"The \"bind\" command can also be used to turn a normal branch into a heavy\n"
+"checkout. If you would like to convert your heavy checkout into a normal\n"
+"branch so that every commit is local, you can use the \"unbind\" command. To "
+"see\n"
+"whether or not a branch is bound or not you can use the \"info\" command. If "
+"the\n"
+"branch is bound it will tell you the location of the bound branch."
+msgstr ""
+
+#: dummy/help_topics/checkouts/detail.txt:68
+msgid ""
+"  checkout    Create a checkout. Pass --lightweight to get a lightweight\n"
+"              checkout\n"
+"  update      Pull any changes in the master branch in to your checkout\n"
+"  commit      Make a commit that is sent to the master branch. If you have\n"
+"              a heavy checkout then the --local option will commit to the\n"
+"              checkout without sending the commit to the master\n"
+"  switch      Change the master branch that the commits in the checkout "
+"will\n"
+"              be sent to\n"
+"  bind        Turn a standalone branch into a heavy checkout so that any\n"
+"              commits will be sent to the master branch\n"
+"  unbind      Turn a heavy checkout into a standalone branch so that any\n"
+"              commits are only made locally\n"
+"  info        Displays whether a branch is bound or unbound. If the branch "
+"is\n"
+"              bound, then it will also display the location of the bound "
+"branch\n"
+msgstr ""
+
+#: dummy/help_topics/checkouts/summary.txt:1
+msgid "Information on what a checkout is"
+msgstr ""
+
+#: dummy/help_topics/commands/summary.txt:1
+msgid "Basic help for all commands"
+msgstr ""
+
+#: dummy/help_topics/configuration/summary.txt:1
+msgid "Details on the configuration settings available"
+msgstr ""
+
+#: dummy/help_topics/conflict-types/summary.txt:1
+msgid "Types of conflicts and what to do about them"
+msgstr ""
+
+#: dummy/help_topics/content-filters/summary.txt:1
+msgid "Conversion of content into/from working trees"
+msgstr ""
+
+#: dummy/help_topics/criss-cross/detail.txt:1
+msgid "Criss-Cross"
+msgstr ""
+
+#: dummy/help_topics/criss-cross/detail.txt:3
+msgid ""
+"A criss-cross in the branch history can cause the default merge technique\n"
+"to emit more conflicts than would normally be expected."
+msgstr ""
+
+#: dummy/help_topics/criss-cross/detail.txt:6
+msgid ""
+"In complex merge cases, ``bzr merge --lca`` or ``bzr merge --weave`` may "
+"give\n"
+"better results.  You may wish to ``bzr revert`` the working tree and merge\n"
+"again.  Alternatively, use ``bzr remerge`` on particular conflicted files."
+msgstr ""
+
+#: dummy/help_topics/criss-cross/detail.txt:10
+msgid ""
+"Criss-crosses occur in a branch's history if two branches merge the same "
+"thing\n"
+"and then merge one another, or if two branches merge one another at the "
+"same\n"
+"time.  They can be avoided by having each branch only merge from or into a\n"
+"designated central branch (a \"star topology\")."
+msgstr ""
+
+#: dummy/help_topics/criss-cross/detail.txt:15
+msgid ""
+"Criss-crosses cause problems because of the way merge works.  Bazaar's "
+"default\n"
+"merge is a three-way merger; in order to merge OTHER into THIS, it must\n"
+"find a basis for comparison, BASE.  Using BASE, it can determine whether\n"
+"differences between THIS and OTHER are due to one side adding lines, or\n"
+"from another side removing lines."
+msgstr ""
+
+#: dummy/help_topics/criss-cross/detail.txt:21
+msgid ""
+"Criss-crosses mean there is no good choice for a base.  Selecting the "
+"recent\n"
+"merge points could cause one side's changes to be silently discarded.\n"
+"Selecting older merge points (which Bazaar does) mean that extra conflicts\n"
+"are emitted."
+msgstr ""
+
+#: dummy/help_topics/criss-cross/detail.txt:26
+msgid ""
+"The ``weave`` merge type is not affected by this problem because it uses\n"
+"line-origin detection instead of a basis revision to determine the cause of\n"
+"differences.\n"
+msgstr ""
+
+#: dummy/help_topics/criss-cross/summary.txt:1
+msgid "Information on criss-cross merging"
+msgstr ""
+
+#: dummy/help_topics/current-formats/summary.txt:1
+msgid "Current storage formats"
+msgstr ""
+
+#: dummy/help_topics/debug-flags/summary.txt:1
+msgid "Options to show or record debug information"
+msgstr ""
+
+#: dummy/help_topics/diverged-branches/summary.txt:1
+msgid "How to fix diverged branches"
+msgstr ""
+
+#: dummy/help_topics/env-variables/detail.txt:1
+msgid "Environment Variables"
+msgstr ""
+
+#: dummy/help_topics/env-variables/detail.txt:3
+msgid ""
+"=================== "
+"===========================================================\n"
+"BZRPATH             Path where bzr is to look for shell plugin external\n"
+"                    commands.\n"
+"BZR_EMAIL           E-Mail address of the user. Overrides EMAIL.\n"
+"EMAIL               E-Mail address of the user.\n"
+"BZR_EDITOR          Editor for editing commit messages. Overrides EDITOR.\n"
+"EDITOR              Editor for editing commit messages.\n"
+"BZR_PLUGIN_PATH     Paths where bzr should look for plugins.\n"
+"BZR_DISABLE_PLUGINS Plugins that bzr should not load.\n"
+"BZR_PLUGINS_AT      Plugins to load from a directory not in "
+"BZR_PLUGIN_PATH.\n"
+"BZR_HOME            Directory holding .bazaar config dir. Overrides HOME.\n"
+"BZR_HOME (Win32)    Directory holding bazaar config dir. Overrides APPDATA "
+"and\n"
+"                    HOME.\n"
+"BZR_REMOTE_PATH     Full name of remote 'bzr' command (for bzr+ssh:// "
+"URLs).\n"
+"BZR_SSH             Path to SSH client, or one of paramiko, openssh, "
+"sshcorp,\n"
+"                    plink or lsh.\n"
+"BZR_LOG             Location of .bzr.log (use '/dev/null' to suppress log).\n"
+"BZR_LOG (Win32)     Location of .bzr.log (use 'NUL' to suppress log).\n"
+"BZR_COLUMNS         Override implicit terminal width.\n"
+"BZR_CONCURRENCY     Number of processes that can be run concurrently "
+"(selftest)\n"
+"BZR_PROGRESS_BAR    Override the progress display. Values are 'none' or "
+"'text'.\n"
+"BZR_PDB             Control whether to launch a debugger on error.\n"
+"BZR_SIGQUIT_PDB     Control whether SIGQUIT behaves normally or invokes a\n"
+"                    breakin debugger.\n"
+"=================== "
+"===========================================================\n"
+msgstr ""
+
+#: dummy/help_topics/env-variables/summary.txt:1
+msgid "Environment variable names and values"
+msgstr ""
+
+#: dummy/help_topics/eol/summary.txt:1
+msgid "Information on end-of-line handling"
+msgstr ""
+
+#: dummy/help_topics/files/detail.txt:1
+msgid "Files"
+msgstr ""
+
+#: dummy/help_topics/files/detail.txt:3
+msgid ""
+":On Unix:   ~/.bazaar/bazaar.conf\n"
+":On Windows: C:\\\\Documents and Settings\\\\username\\\\Application Data\\"
+"\\bazaar\\\\2.0\\\\bazaar.conf"
+msgstr ""
+
+#: dummy/help_topics/files/detail.txt:6
+msgid ""
+"Contains the user's default configuration. The section ``[DEFAULT]`` is\n"
+"used to define general configuration that will be applied everywhere.\n"
+"The section ``[ALIASES]`` can be used to create command aliases for\n"
+"commonly used options."
+msgstr ""
+
+#: dummy/help_topics/files/detail.txt:11
+msgid "A typical config file might look something like::"
+msgstr ""
+
+#: dummy/help_topics/files/detail.txt:13
+msgid ""
+"  [DEFAULT]\n"
+"  email=John Doe <jdoe@isp.com>"
+msgstr ""
+
+#: dummy/help_topics/files/detail.txt:16
+msgid ""
+"  [ALIASES]\n"
+"  commit = commit --strict\n"
+"  log10 = log --short -r -10..-1\n"
+msgstr ""
+
+#: dummy/help_topics/files/summary.txt:1
+msgid "Information on configuration and log files"
+msgstr ""
+
+#: dummy/help_topics/formats/detail.txt:1
+msgid "Storage Formats"
+msgstr ""
+
+#: dummy/help_topics/formats/detail.txt:3
+msgid ""
+"To ensure that older clients do not access data incorrectly,\n"
+"Bazaar's policy is to introduce a new storage format whenever\n"
+"new features requiring new metadata are added. New storage\n"
+"formats may also be introduced to improve performance and\n"
+"scalability."
+msgstr ""
+
+#: dummy/help_topics/formats/detail.txt:9
+msgid ""
+"The newest format, 2a, is highly recommended. If your\n"
+"project is not using 2a, then you should suggest to the\n"
+"project owner to upgrade."
+msgstr ""
+
+#: dummy/help_topics/formats/detail.txt:13
+msgid ""
+"\n"
+".. note::"
+msgstr ""
+
+#: dummy/help_topics/formats/detail.txt:16
+msgid ""
+"   Some of the older formats have two variants:\n"
+"   a plain one and a rich-root one. The latter include an additional\n"
+"   field about the root of the tree. There is no performance cost\n"
+"   for using a rich-root format but you cannot easily merge changes\n"
+"   from a rich-root format into a plain format. As a consequence,\n"
+"   moving a project to a rich-root format takes some co-ordination\n"
+"   in that all contributors need to upgrade their repositories\n"
+"   around the same time. 2a and all future formats will be\n"
+"   implicitly rich-root."
+msgstr ""
+
+#: dummy/help_topics/formats/detail.txt:26
+msgid ""
+"See :doc:`current-formats-help` for the complete list of\n"
+"currently supported formats. See :doc:`other-formats-help` for\n"
+"descriptions of any available experimental and deprecated formats.\n"
+msgstr ""
+
+#: dummy/help_topics/formats/summary.txt:1
+msgid "Information on choosing a storage format"
+msgstr ""
+
+#: dummy/help_topics/global-options/detail.txt:1
+msgid "Global Options"
+msgstr ""
+
+#: dummy/help_topics/global-options/detail.txt:3
+msgid ""
+"These options may be used with any command, and may appear in front of any\n"
+"command.  (e.g. ``bzr --profile help``)."
+msgstr ""
+
+#: dummy/help_topics/global-options/detail.txt:6
+msgid ""
+"--version      Print the version number. Must be supplied before the "
+"command.\n"
+"--no-aliases   Do not process command aliases when running this command.\n"
+"--builtin      Use the built-in version of a command, not the plugin "
+"version.\n"
+"               This does not suppress other plugin effects.\n"
+"--no-plugins   Do not process any plugins.\n"
+"--no-l10n      Do not translate messages.\n"
+"--concurrency  Number of processes that can be run concurrently (selftest)."
+msgstr ""
+
+#: dummy/help_topics/global-options/detail.txt:14
+msgid ""
+"--profile      Profile execution using the hotshot profiler.\n"
+"--lsprof       Profile execution using the lsprof profiler.\n"
+"--lsprof-file  Profile execution using the lsprof profiler, and write the\n"
+"               results to a specified file.  If the filename ends with \".txt"
+"\",\n"
+"               text format will be used.  If the filename either starts "
+"with\n"
+"               \"callgrind.out\" or end with \".callgrind\", the output will "
+"be\n"
+"               formatted for use with KCacheGrind. Otherwise, the output\n"
+"               will be a pickle.\n"
+"--coverage     Generate line coverage report in the specified directory."
+msgstr ""
+
+#: dummy/help_topics/global-options/detail.txt:24
+msgid ""
+"See http://doc.bazaar.canonical.com/developers/profiling.html for more\n"
+"information on profiling."
+msgstr ""
+
+#: dummy/help_topics/global-options/detail.txt:27
+msgid ""
+"A number of debug flags are also available to assist troubleshooting and\n"
+"development.  See :doc:`debug-flags-help`.\n"
+msgstr ""
+
+#: dummy/help_topics/global-options/summary.txt:1
+msgid "Options that control how Bazaar runs"
+msgstr ""
+
+#: dummy/help_topics/hidden-commands/summary.txt:1
+msgid "All hidden commands"
+msgstr ""
+
+#: dummy/help_topics/hooks/summary.txt:1
+msgid "Points at which custom processing can be added"
+msgstr ""
+
+#: dummy/help_topics/launchpad/detail.txt:1
+msgid "Integration with Launchpad.net"
+msgstr ""
+
+#: dummy/help_topics/launchpad/detail.txt:3
+msgid ""
+"Launchpad.net provides free Bazaar branch hosting with integrated bug and\n"
+"specification tracking."
+msgstr ""
+
+#: dummy/help_topics/launchpad/detail.txt:6
+msgid ""
+"The bzr client (through the plugin called 'launchpad') has special\n"
+"features to communicate with Launchpad:"
+msgstr ""
+
+#: dummy/help_topics/launchpad/detail.txt:9
+msgid ""
+"    * The launchpad-login command tells Bazaar your Launchpad user name. "
+"This\n"
+"      is then used by the 'lp:' transport to download your branches using\n"
+"      bzr+ssh://."
+msgstr ""
+
+#: dummy/help_topics/launchpad/detail.txt:13
+msgid ""
+"    * The 'lp:' transport uses Launchpad as a directory service: for "
+"example\n"
+"      'lp:bzr' and 'lp:python' refer to the main branches of the relevant\n"
+"      projects and may be branched, logged, etc. You can also use the 'lp:'\n"
+"      transport to refer to specific branches, e.g. lp:~bzr/bzr/trunk."
+msgstr ""
+
+#: dummy/help_topics/launchpad/detail.txt:18
+msgid ""
+"    * The 'lp:' bug tracker alias can expand launchpad bug numbers to their\n"
+"      URLs for use with 'bzr commit --fixes', e.g. 'bzr commit --fixes "
+"lp:12345'\n"
+"      will record a revision property that marks that revision as fixing\n"
+"      Launchpad bug 12345. When you push that branch to Launchpad it will\n"
+"      automatically be linked to the bug report."
+msgstr ""
+
+#: dummy/help_topics/launchpad/detail.txt:24
+msgid ""
+"    * The register-branch command tells Launchpad about the url of a\n"
+"      public branch.  Launchpad will then mirror the branch, display\n"
+"      its contents and allow it to be attached to bugs and other\n"
+"      objects."
+msgstr ""
+
+#: dummy/help_topics/launchpad/detail.txt:29
+msgid "For more information see http://help.launchpad.net/\n"
+msgstr ""
+
+#: dummy/help_topics/launchpad/summary.txt:1
+msgid "Using Bazaar with Launchpad.net"
+msgstr ""
+
+#: dummy/help_topics/location-alias/summary.txt:1
+msgid "Aliases for remembered locations"
+msgstr ""
+
+#: dummy/help_topics/log-formats/summary.txt:1
+msgid "Details on the logging formats available"
+msgstr ""
+
+#: dummy/help_topics/other-formats/summary.txt:1
+msgid "Experimental and deprecated storage formats"
+msgstr ""
+
+#: dummy/help_topics/patterns/summary.txt:1
+msgid "Information on the pattern syntax"
+msgstr ""
+
+#: dummy/help_topics/repositories/detail.txt:1
+msgid "Repositories"
+msgstr ""
+
+#: dummy/help_topics/repositories/detail.txt:3
+msgid ""
+"Repositories in Bazaar are where committed information is stored. There is\n"
+"a repository associated with every branch."
+msgstr ""
+
+#: dummy/help_topics/repositories/detail.txt:6
+msgid ""
+"Repositories are a form of database. Bzr will usually maintain this for\n"
+"good performance automatically, but in some situations (e.g. when doing\n"
+"very many commits in a short time period) you may want to ask bzr to\n"
+"optimise the database indices. This can be done by the 'bzr pack' command."
+msgstr ""
+
+#: dummy/help_topics/repositories/detail.txt:11
+msgid ""
+"By default just running 'bzr init' will create a repository within the new\n"
+"branch but it is possible to create a shared repository which allows "
+"multiple\n"
+"branches to share their information in the same location. When a new branch "
+"is\n"
+"created it will first look to see if there is a containing shared repository "
+"it\n"
+"can use."
+msgstr ""
+
+#: dummy/help_topics/repositories/detail.txt:17
+msgid ""
+"When two branches of the same project share a repository, there is\n"
+"generally a large space saving. For some operations (e.g. branching\n"
+"within the repository) this translates in to a large time saving."
+msgstr ""
+
+#: dummy/help_topics/repositories/detail.txt:21
+msgid ""
+"To create a shared repository use the init-repository command (or the alias\n"
+"init-repo). This command takes the location of the repository to create. "
+"This\n"
+"means that 'bzr init-repository repo' will create a directory named 'repo',\n"
+"which contains a shared repository. Any new branches that are created in "
+"this\n"
+"directory will then use it for storage."
+msgstr ""
+
+#: dummy/help_topics/repositories/detail.txt:27
+msgid ""
+"It is a good idea to create a repository whenever you might create more\n"
+"than one branch of a project. This is true for both working areas where you\n"
+"are doing the development, and any server areas that you use for hosting\n"
+"projects. In the latter case, it is common to want branches without working\n"
+"trees. Since the files in the branch will not be edited directly there is "
+"no\n"
+"need to use up disk space for a working tree. To create a repository in "
+"which\n"
+"the branches will not have working trees pass the '--no-trees' option to\n"
+"'init-repository'."
+msgstr ""
+
+#: dummy/help_topics/repositories/detail.txt:38
+msgid ""
+"  init-repository   Create a shared repository. Use --no-trees to create "
+"one\n"
+"                    in which new branches won't get a working tree.\n"
+msgstr ""
+
+#: dummy/help_topics/repositories/summary.txt:1
+msgid "Basic information on shared repositories."
+msgstr ""
+
+#: dummy/help_topics/revisionspec/summary.txt:1
+msgid "Explain how to use --revision"
+msgstr ""
+
+#: dummy/help_topics/rules/summary.txt:1
+msgid "Information on defining rule-based preferences"
+msgstr ""
+
+#: dummy/help_topics/standalone-trees/detail.txt:1
+msgid "Standalone Trees"
+msgstr ""
+
+#: dummy/help_topics/standalone-trees/detail.txt:3
+msgid ""
+"A standalone tree is a working tree with an associated repository. It\n"
+"is an independently usable branch, with no dependencies on any other.\n"
+"Creating a standalone tree (via bzr init) is the quickest way to put\n"
+"an existing project under version control."
+msgstr ""
+
+#: dummy/help_topics/standalone-trees/detail.txt:8
+msgid "Related Commands::"
+msgstr ""
+
+#: dummy/help_topics/standalone-trees/detail.txt:10
+msgid "  init    Make a directory into a versioned branch.\n"
+msgstr ""
+
+#: dummy/help_topics/standalone-trees/summary.txt:1
+msgid "Information on what a standalone tree is"
+msgstr ""
+
+#: dummy/help_topics/standard-options/detail.txt:1
+msgid "Standard Options"
+msgstr ""
+
+#: dummy/help_topics/standard-options/detail.txt:3
+msgid "Standard options are legal for all commands."
+msgstr ""
+
+#: dummy/help_topics/standard-options/detail.txt:5
+msgid ""
+"--help, -h     Show help message.\n"
+"--verbose, -v  Display more information.\n"
+"--quiet, -q    Only display errors and warnings."
+msgstr ""
+
+#: dummy/help_topics/standard-options/detail.txt:9
+msgid "Unlike global options, standard options can be used in aliases.\n"
+msgstr ""
+
+#: dummy/help_topics/standard-options/summary.txt:1
+msgid "Options that can be used with any command"
+msgstr ""
+
+#: dummy/help_topics/status-flags/detail.txt:1
+msgid "Status Flags"
+msgstr ""
+
+#: dummy/help_topics/status-flags/detail.txt:3
+msgid ""
+"Status flags are used to summarise changes to the working tree in a concise\n"
+"manner.  They are in the form::"
+msgstr ""
+
+#: dummy/help_topics/status-flags/detail.txt:6
+msgid "   xxx   <filename>"
+msgstr ""
+
+#: dummy/help_topics/status-flags/detail.txt:8
+msgid "where the columns' meanings are as follows."
+msgstr ""
+
+#: dummy/help_topics/status-flags/detail.txt:10
+msgid "Column 1 - versioning/renames::"
+msgstr ""
+
+#: dummy/help_topics/status-flags/detail.txt:12
+msgid ""
+"  + File versioned\n"
+"  - File unversioned\n"
+"  R File renamed\n"
+"  ? File unknown\n"
+"  X File nonexistent (and unknown to bzr)\n"
+"  C File has conflicts\n"
+"  P Entry for a pending merge (not a file)"
+msgstr ""
+
+#: dummy/help_topics/status-flags/detail.txt:20
+msgid "Column 2 - contents::"
+msgstr ""
+
+#: dummy/help_topics/status-flags/detail.txt:22
+msgid ""
+"  N File created\n"
+"  D File deleted\n"
+"  K File kind changed\n"
+"  M File modified"
+msgstr ""
+
+#: dummy/help_topics/status-flags/detail.txt:27
+msgid "Column 3 - execute::"
+msgstr ""
+
+#: dummy/help_topics/status-flags/detail.txt:29
+msgid "  * The execute bit was changed\n"
+msgstr ""
+
+#: dummy/help_topics/status-flags/summary.txt:1
+msgid "Help on status flags"
+msgstr ""
+
+#: dummy/help_topics/sync-for-reconfigure/detail.txt:1
+msgid "Branches Out of Sync"
+msgstr ""
+
+#: dummy/help_topics/sync-for-reconfigure/detail.txt:3
+msgid ""
+"When reconfiguring a checkout, tree or branch into a lightweight checkout,\n"
+"a local branch must be destroyed.  (For checkouts, this is the local branch\n"
+"that serves primarily as a cache.)  If the branch-to-be-destroyed does not\n"
+"have the same last revision as the new reference branch for the lightweight\n"
+"checkout, data could be lost, so Bazaar refuses."
+msgstr ""
+
+#: dummy/help_topics/sync-for-reconfigure/detail.txt:9
+msgid "How you deal with this depends on *why* the branches are out of sync."
+msgstr ""
+
+#: dummy/help_topics/sync-for-reconfigure/detail.txt:11
+msgid ""
+"If you have a checkout and have done local commits, you can get back in "
+"sync\n"
+"by running \"bzr update\" (and possibly \"bzr commit\")."
+msgstr ""
+
+#: dummy/help_topics/sync-for-reconfigure/detail.txt:14
+msgid ""
+"If you have a branch and the remote branch is out-of-date, you can push\n"
+"the local changes using \"bzr push\".  If the local branch is out of date, "
+"you\n"
+"can do \"bzr pull\".  If both branches have had changes, you can merge, "
+"commit\n"
+"and then push your changes.  If you decide that some of the changes aren't\n"
+"useful, you can \"push --overwrite\" or \"pull --overwrite\" instead.\n"
+msgstr ""
+
+#: dummy/help_topics/sync-for-reconfigure/summary.txt:1
+msgid "Steps to resolve \"out-of-sync\" when reconfiguring"
+msgstr ""
+
+#: dummy/help_topics/topics/summary.txt:1
+msgid "Topics list"
+msgstr ""
+
+#: dummy/help_topics/url-special-chars/summary.txt:1
+msgid "Special character handling in URLs"
+msgstr ""
+
+#: dummy/help_topics/urlspec/summary.txt:1
+msgid "Supported transport protocols"
+msgstr ""
+
+#: dummy/help_topics/working-trees/detail.txt:1
+msgid "Working Trees"
+msgstr ""
+
+#: dummy/help_topics/working-trees/detail.txt:3
+msgid ""
+"A working tree is the contents of a branch placed on disk so that you can\n"
+"see the files and edit them. The working tree is where you make changes to "
+"a\n"
+"branch, and when you commit the current state of the working tree is the\n"
+"snapshot that is recorded in the commit."
+msgstr ""
+
+#: dummy/help_topics/working-trees/detail.txt:8
+msgid ""
+"When you push a branch to a remote system, a working tree will not be\n"
+"created. If one is already present the files will not be updated. The\n"
+"branch information will be updated and the working tree will be marked\n"
+"as out-of-date. Updating a working tree remotely is difficult, as there\n"
+"may be uncommitted changes or the update may cause content conflicts that "
+"are\n"
+"difficult to deal with remotely."
+msgstr ""
+
+#: dummy/help_topics/working-trees/detail.txt:15
+msgid ""
+"If you have a branch with no working tree you can use the 'checkout' "
+"command\n"
+"to create a working tree. If you run 'bzr checkout .' from the branch it "
+"will\n"
+"create the working tree. If the branch is updated remotely, you can update "
+"the\n"
+"working tree by running 'bzr update' in that directory."
+msgstr ""
+
+#: dummy/help_topics/working-trees/detail.txt:20
+msgid ""
+"If you have a branch with a working tree that you do not want the 'remove-"
+"tree'\n"
+"command will remove the tree if it is safe. This can be done to avoid the\n"
+"warning about the remote working tree not being updated when pushing to the\n"
+"branch. It can also be useful when working with a '--no-trees' repository\n"
+"(see 'bzr help repositories')."
+msgstr ""
+
+#: dummy/help_topics/working-trees/detail.txt:26
+msgid ""
+"If you want to have a working tree on a remote machine that you push to you\n"
+"can either run 'bzr update' in the remote branch after each push, or use "
+"some\n"
+"other method to update the tree during the push. There is an 'rspush' "
+"plugin\n"
+"that will update the working tree using rsync as well as doing a push. "
+"There\n"
+"is also a 'push-and-update' plugin that automates running 'bzr update' via "
+"SSH\n"
+"after each push."
+msgstr ""
+
+#: dummy/help_topics/working-trees/detail.txt:33
+msgid "Useful commands::"
+msgstr ""
+
+#: dummy/help_topics/working-trees/detail.txt:35
+msgid ""
+"  checkout     Create a working tree when a branch does not have one.\n"
+"  remove-tree  Removes the working tree from a branch when it is safe to do "
+"so.\n"
+"  update       When a working tree is out of sync with its associated "
+"branch\n"
+"               this will update the tree to match the branch.\n"
+msgstr ""
+
+#: dummy/help_topics/working-trees/summary.txt:1
+msgid "Information on working trees"
+msgstr ""
+
+#: en/help_topics/authentication.txt:1
+msgid ""
+"Authentication Settings\n"
+"======================="
+msgstr ""
+
+#: en/help_topics/authentication.txt:4
+msgid ""
+"\n"
+"Intent\n"
+"------"
+msgstr ""
+
+#: en/help_topics/authentication.txt:8
+msgid ""
+"Many different authentication policies can be described in the\n"
+"``authentication.conf`` file but a particular user should need only a few\n"
+"definitions to cover his needs without having to specify a user and a "
+"password\n"
+"for every branch he uses."
+msgstr ""
+
+#: en/help_topics/authentication.txt:13
+msgid ""
+"The definitions found in this file are used to find the credentials to use "
+"for\n"
+"a given url. The same credentials can generally be used for as many branches "
+"as\n"
+"possible by grouping their declaration around the remote servers that need\n"
+"them. It's even possible to declare credentials that will be used by "
+"different\n"
+"servers."
+msgstr ""
+
+#: en/help_topics/authentication.txt:19
+msgid ""
+"The intent is to make this file as small as possible to minimize maintenance."
+msgstr ""
+
+#: en/help_topics/authentication.txt:21
+msgid ""
+"Once the relevant credentials are declared in this file you may use branch "
+"urls\n"
+"without embedding passwords (security hazard) or even users (enabling "
+"sharing\n"
+"of your urls with others)."
+msgstr ""
+
+#: en/help_topics/authentication.txt:25
+msgid "Instead of using::"
+msgstr ""
+
+#: en/help_topics/authentication.txt:27
+msgid "  bzr branch ftp://joe:secret@host.com/path/to/my/branch"
+msgstr ""
+
+#: en/help_topics/authentication.txt:29
+msgid "you simply use::"
+msgstr ""
+
+#: en/help_topics/authentication.txt:31
+msgid "  bzr branch ftp://host.com/path/to/my/branch"
+msgstr ""
+
+#: en/help_topics/authentication.txt:33
+msgid "provided you have created the following ``authentication.conf`` file::"
+msgstr ""
+
+#: en/help_topics/authentication.txt:35
+msgid ""
+"  [myprojects]\n"
+"  scheme=ftp\n"
+"  host=host.com\n"
+"  user=joe\n"
+"  password=secret\n"
+"  "
+msgstr ""
+
+#: en/help_topics/authentication.txt:42
+msgid ""
+"Authentication definitions\n"
+"--------------------------"
+msgstr ""
+
+#: en/help_topics/authentication.txt:45
+msgid ""
+"There are two kinds of authentication used by the various schemes supported "
+"by\n"
+"bzr:"
+msgstr ""
+
+#: en/help_topics/authentication.txt:48
+msgid "1. user and password"
+msgstr ""
+
+#: en/help_topics/authentication.txt:50
+msgid ""
+"``FTP`` needs a (``user``, ``password``) to authenticate against a ``host``\n"
+"``SFTP`` can use either a password or a host key to authenticate. However,\n"
+"ssh agents are a better, more secure solution. So we have chosen to not "
+"provide\n"
+"our own less secure method."
+msgstr ""
+
+#: en/help_topics/authentication.txt:55
+msgid "2. user, realm and password"
+msgstr ""
+
+#: en/help_topics/authentication.txt:57
+msgid ""
+"``HTTP`` and ``HTTPS`` needs a (``user, realm, password``) to authenticate\n"
+"against a host. But, by using ``.htaccess`` files, for example, it is "
+"possible\n"
+"to define several (``user, realm, password``) for a given ``host``. So what "
+"is\n"
+"really needed is (``user``, ``password``, ``host``, ``path``). The ``realm`` "
+"is\n"
+"not taken into account in the definitions, but will displayed if bzr "
+"prompts\n"
+"you for a password."
+msgstr ""
+
+#: en/help_topics/authentication.txt:64
+msgid ""
+"``HTTP proxy`` can be handled as ``HTTP`` (or ``HTTPS``) by explicitly\n"
+"specifying the appropriate port."
+msgstr ""
+
+#: en/help_topics/authentication.txt:67
+msgid ""
+"To take all schemes into account, the password will be deduced from a set "
+"of\n"
+"authentication definitions (``scheme``, ``host``, ``port``, ``path``, "
+"``user``,\n"
+"``password``)."
+msgstr ""
+
+#: en/help_topics/authentication.txt:71
+msgid ""
+"  * ``scheme``: can be empty (meaning the rest of the definition can be "
+"used\n"
+"    for any scheme), ``SFTP`` and ``bzr+ssh`` should not be used here, "
+"``ssh``\n"
+"    should be used instead since this is the real scheme regarding\n"
+"    authentication,"
+msgstr ""
+
+#: en/help_topics/authentication.txt:76
+msgid "  * ``host``: can be empty (to act as a default for any host),"
+msgstr ""
+
+#: en/help_topics/authentication.txt:78
+msgid ""
+"  * ``port`` can be empty (useful when an host provides several servers for "
+"the\n"
+"    same scheme), only numerical values are allowed, this should be used "
+"only\n"
+"    when the server uses a port different than the scheme standard port,"
+msgstr ""
+
+#: en/help_topics/authentication.txt:82
+msgid "  * ``path``: can be empty (FTP or SFTP will never user it),"
+msgstr ""
+
+#: en/help_topics/authentication.txt:84
+msgid ""
+"  * ``user``: can be empty (``bzr`` will defaults to python's\n"
+"    ``getpass.get_user()``),"
+msgstr ""
+
+#: en/help_topics/authentication.txt:87
+msgid ""
+"  * ``password``: can be empty if you prefer to always be prompted for your\n"
+"    password."
+msgstr ""
+
+#: en/help_topics/authentication.txt:90
+msgid ""
+"Multiple definitions can be provided and, for a given URL, bzr will select "
+"a\n"
+"(``user`` [, ``password``]) based on the following rules :"
+msgstr ""
+
+#: en/help_topics/authentication.txt:93
+msgid " 1. the first match wins,"
+msgstr ""
+
+#: en/help_topics/authentication.txt:95
+msgid " 2. empty fields match everything,"
+msgstr ""
+
+#: en/help_topics/authentication.txt:97
+msgid ""
+" 3. ``scheme`` matches even if decorators are used in the requested URL,"
+msgstr ""
+
+#: en/help_topics/authentication.txt:99
+msgid ""
+" 4. ``host`` matches exactly or act as a domain if it starts with '.'\n"
+"    (``project.bzr.sf.net`` will match ``.bzr.sf.net`` but ``projectbzr.sf."
+"net``\n"
+"    will not match ``bzr.sf.net``)."
+msgstr ""
+
+#: en/help_topics/authentication.txt:103
+msgid ""
+" 5. ``port`` matches if included in the requested URL (exact matches only)"
+msgstr ""
+
+#: en/help_topics/authentication.txt:105
+msgid ""
+" 6. ``path`` matches if included in the requested URL (and by rule #2 "
+"above,\n"
+"    empty paths will match any provided path)."
+msgstr ""
+
+#: en/help_topics/authentication.txt:110
+msgid ""
+"File format\n"
+"-----------"
+msgstr ""
+
+#: en/help_topics/authentication.txt:113
+msgid ""
+"The general rules for :doc:`configuration files <configuration-help>`\n"
+"apply except for the variable policies."
+msgstr ""
+
+#: en/help_topics/authentication.txt:116
+msgid "Each section describes an authentication definition."
+msgstr ""
+
+#: en/help_topics/authentication.txt:118
+msgid ""
+"The section name is an arbitrary string, only the ``DEFAULT`` value is "
+"reserved\n"
+"and should appear as the *last* section."
+msgstr ""
+
+#: en/help_topics/authentication.txt:121
+msgid "Each section should define:"
+msgstr ""
+
+#: en/help_topics/authentication.txt:123
+msgid "* ``user``: the login to be used,"
+msgstr ""
+
+#: en/help_topics/authentication.txt:125
+msgid "Each section could define:"
+msgstr ""
+
+#: en/help_topics/authentication.txt:127
+msgid "* ``host``: the remote server,"
+msgstr ""
+
+#: en/help_topics/authentication.txt:129
+msgid "* ``port``: the port the server is listening,"
+msgstr ""
+
+#: en/help_topics/authentication.txt:131
+msgid "* ``path``: the branch location,"
+msgstr ""
+
+#: en/help_topics/authentication.txt:133
+msgid "* ``password``: the password."
+msgstr ""
+
+#: en/help_topics/authentication.txt:135
+msgid ""
+"\n"
+"Examples\n"
+"--------"
+msgstr ""
+
+#: en/help_topics/authentication.txt:139
+msgid ""
+"\n"
+"Personal projects hosted outside\n"
+"~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/authentication.txt:143
+msgid ""
+"All connections are done with the same ``user`` (the remote one for which "
+"the\n"
+"default bzr one is not appropriate) and the password is always prompted "
+"with\n"
+"some exceptions::"
+msgstr ""
+
+#: en/help_topics/authentication.txt:147
+msgid ""
+"        # Pet projects on hobby.net\n"
+"        [hobby]\n"
+"        host=r.hobby.net\n"
+"        user=jim\n"
+"        password=obvious1234\n"
+"        \n"
+"        # Home server\n"
+"        [home]\n"
+"        scheme=https\n"
+"        host=home.net\n"
+"        user=joe\n"
+"        password=1essobV10us\n"
+"        \n"
+"        [DEFAULT]\n"
+"        # Our local user is barbaz, on all remote sites we're known as "
+"foobar\n"
+"        user=foobar"
+msgstr ""
+
+#: en/help_topics/authentication.txt:164
+msgid ""
+"\n"
+"Source hosting provider\n"
+"~~~~~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/authentication.txt:168
+msgid "In the shp.net (fictitious) domain, each project has its own site::"
+msgstr ""
+
+#: en/help_topics/authentication.txt:170
+msgid ""
+"        [shpnet domain]\n"
+"        # we use sftp, but ssh is the scheme used for authentication\n"
+"        scheme=ssh\n"
+"        # The leading '.' ensures that 'shp.net' alone doesn't match\n"
+"        host=.shp.net\n"
+"        user=joe\n"
+"        # bzr don't support supplying a password for sftp,\n"
+"        # consider using an ssh agent if you don't want to supply\n"
+"        # a password interactively. (pageant, ssh-agent, etc)"
+msgstr ""
+
+#: en/help_topics/authentication.txt:180
+msgid ""
+"HTTPS, SFTP servers and their proxy\n"
+"~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/authentication.txt:183
+msgid ""
+"At company.com, the server hosting release and integration branches is "
+"behind a\n"
+"proxy, and the two branches use different authentication policies::"
+msgstr ""
+
+#: en/help_topics/authentication.txt:186
+msgid ""
+"        [reference code]\n"
+"        scheme=https\n"
+"        host=dev.company.com\n"
+"        path=/dev\n"
+"        user=user1\n"
+"        password=pass1"
+msgstr ""
+
+#: en/help_topics/authentication.txt:193
+msgid ""
+"        # development branches on dev server\n"
+"        [dev]\n"
+"        scheme=ssh # bzr+ssh and sftp are available here\n"
+"        host=dev.company.com\n"
+"        path=/dev/integration\n"
+"        user=user2\n"
+"        \n"
+"        # proxy\n"
+"        [proxy]\n"
+"        scheme=http\n"
+"        host=proxy.company.com\n"
+"        port=3128\n"
+"        user=proxyuser1\n"
+"        password=proxypass1"
+msgstr ""
+
+#: en/help_topics/authentication.txt:208
+msgid ""
+"\n"
+"Planned enhancements\n"
+"--------------------"
+msgstr ""
+
+#: en/help_topics/authentication.txt:212
+msgid ""
+"The following are not yet implemented but planned as parts of a work in\n"
+"progress:"
+msgstr ""
+
+#: en/help_topics/authentication.txt:215
+msgid "* add a  ``password_encoding`` field allowing:"
+msgstr ""
+
+#: en/help_topics/authentication.txt:217
+msgid ""
+"  - storing the passwords in various obfuscating encodings (base64 for one),"
+msgstr ""
+
+#: en/help_topics/authentication.txt:219
+msgid "  - delegate password storage to plugins (.netrc for example)."
+msgstr ""
+
+#: en/help_topics/authentication.txt:221
+msgid ""
+"* update the credentials when the user is prompted for user or password,"
+msgstr ""
+
+#: en/help_topics/authentication.txt:223
+msgid "* add a ``verify_certificates`` field for ``HTTPS``."
+msgstr ""
+
+#: en/help_topics/authentication.txt:225
+msgid ""
+"The ``password_encoding`` and ``verify_certificates`` fields are recognized "
+"but\n"
+"ignored in the actual implementation.\n"
+msgstr ""
+
+#: en/help_topics/bugs.txt:1
+msgid "Bug Tracker Settings"
+msgstr ""
+
+#: en/help_topics/bugs.txt:3
+msgid ""
+"When making a commit, metadata about bugs fixed by that change can be\n"
+"recorded by using the ``--fixes`` option. For each bug marked as fixed, an\n"
+"entry is included in the 'bugs' revision property stating '<url> <status>'.\n"
+"(The only ``status`` value currently supported is ``fixed.``)"
+msgstr ""
+
+#: en/help_topics/bugs.txt:8
+msgid ""
+"The ``--fixes`` option allows you to specify a bug tracker and a bug "
+"identifier\n"
+"rather than a full URL. This looks like::"
+msgstr ""
+
+#: en/help_topics/bugs.txt:11
+msgid "    bzr commit --fixes <tracker>:<id>"
+msgstr ""
+
+#: en/help_topics/bugs.txt:13
+msgid "or::"
+msgstr ""
+
+#: en/help_topics/bugs.txt:15
+msgid "    bzr commit --fixes <id>"
+msgstr ""
+
+#: en/help_topics/bugs.txt:17
+msgid ""
+"where \"<tracker>\" is an identifier for the bug tracker, and \"<id>\" is "
+"the\n"
+"identifier for that bug within the bugtracker, usually the bug number.\n"
+"If \"<tracker>\" is not specified the ``bugtracker`` set in the branch\n"
+"or global configuration is used."
+msgstr ""
+
+#: en/help_topics/bugs.txt:22
+msgid ""
+"Bazaar knows about a few bug trackers that have many users. If\n"
+"you use one of these bug trackers then there is no setup required to\n"
+"use this feature, you just need to know the tracker identifier to use.\n"
+"These are the bugtrackers that are built in:"
+msgstr ""
+
+#: en/help_topics/bugs.txt:27
+msgid ""
+"  ============================ ============ ============\n"
+"  URL                          Abbreviation Example\n"
+"  ============================ ============ ============\n"
+"  https://bugs.launchpad.net/  lp           lp:12345\n"
+"  http://bugs.debian.org/      deb          deb:12345\n"
+"  http://bugzilla.gnome.org/   gnome        gnome:12345\n"
+"  ============================ ============ ============"
+msgstr ""
+
+#: en/help_topics/bugs.txt:35
+msgid ""
+"For the bug trackers not listed above configuration is required.\n"
+"Support for generating the URLs for any project using Bugzilla or Trac\n"
+"is built in, along with a template mechanism for other bugtrackers with\n"
+"simple URL schemes. If your bug tracker can't be described by one\n"
+"of the schemes described below then you can write a plugin to support\n"
+"it."
+msgstr ""
+
+#: en/help_topics/bugs.txt:42
+msgid ""
+"If you use Bugzilla or Trac, then you only need to set a configuration\n"
+"variable which contains the base URL of the bug tracker. These options\n"
+"can go into ``bazaar.conf``, ``branch.conf`` or into a branch-specific\n"
+"configuration section in ``locations.conf``.  You can set up these values\n"
+"for each of the projects you work on."
+msgstr ""
+
+#: en/help_topics/bugs.txt:48
+msgid ""
+"Note: As you provide a short name for each tracker, you can specify one or\n"
+"more bugs in one or more trackers at commit time if you wish."
+msgstr ""
+
+#: en/help_topics/bugs.txt:51
+msgid ""
+"Launchpad\n"
+"---------"
+msgstr ""
+
+#: en/help_topics/bugs.txt:54
+msgid "Use ``bzr commit --fixes lp:2`` to record that this commit fixes bug 2."
+msgstr ""
+
+#: en/help_topics/bugs.txt:56
+msgid ""
+"bugzilla_<tracker>_url\n"
+"----------------------"
+msgstr ""
+
+#: en/help_topics/bugs.txt:59
+msgid ""
+"If present, the location of the Bugzilla bug tracker referred to by\n"
+"<tracker>. This option can then be used together with ``bzr commit\n"
+"--fixes`` to mark bugs in that tracker as being fixed by that commit. For\n"
+"example::"
+msgstr ""
+
+#: en/help_topics/bugs.txt:64
+msgid "    bugzilla_squid_url = http://bugs.squid-cache.org"
+msgstr ""
+
+#: en/help_topics/bugs.txt:66
+msgid ""
+"would allow ``bzr commit --fixes squid:1234`` to mark Squid's bug 1234 as\n"
+"fixed."
+msgstr ""
+
+#: en/help_topics/bugs.txt:69
+msgid ""
+"trac_<tracker>_url\n"
+"------------------"
+msgstr ""
+
+#: en/help_topics/bugs.txt:72
+msgid ""
+"If present, the location of the Trac instance referred to by\n"
+"<tracker>. This option can then be used together with ``bzr commit\n"
+"--fixes`` to mark bugs in that tracker as being fixed by that commit. For\n"
+"example::"
+msgstr ""
+
+#: en/help_topics/bugs.txt:77
+msgid "    trac_twisted_url = http://www.twistedmatrix.com/trac"
+msgstr ""
+
+#: en/help_topics/bugs.txt:79
+msgid ""
+"would allow ``bzr commit --fixes twisted:1234`` to mark Twisted's bug 1234 "
+"as\n"
+"fixed."
+msgstr ""
+
+#: en/help_topics/bugs.txt:82
+msgid ""
+"bugtracker_<tracker>_url\n"
+"------------------------"
+msgstr ""
+
+#: en/help_topics/bugs.txt:85
+msgid ""
+"If present, the location of a generic bug tracker instance referred to by\n"
+"<tracker>. The location must contain an ``{id}`` placeholder,\n"
+"which will be replaced by a specific bug ID. This option can then be used\n"
+"together with ``bzr commit --fixes`` to mark bugs in that tracker as being\n"
+"fixed by that commit. For example::"
+msgstr ""
+
+#: en/help_topics/bugs.txt:91
+msgid "    bugtracker_python_url = http://bugs.python.org/issue{id}"
+msgstr ""
+
+#: en/help_topics/bugs.txt:93
+msgid ""
+"would allow ``bzr commit --fixes python:1234`` to mark bug 1234 in Python's\n"
+"Roundup bug tracker as fixed, or::"
+msgstr ""
+
+#: en/help_topics/bugs.txt:96
+msgid ""
+"    bugtracker_cpan_url = http://rt.cpan.org/Public/Bug/Display.html?id={id}"
+msgstr ""
+
+#: en/help_topics/bugs.txt:98
+msgid ""
+"would allow ``bzr commit --fixes cpan:1234`` to mark bug 1234 in CPAN's\n"
+"RT bug tracker as fixed, or::"
+msgstr ""
+
+#: en/help_topics/bugs.txt:101
+msgid "    bugtracker_hudson_url = http://issues.hudson-ci.org/browse/{id}"
+msgstr ""
+
+#: en/help_topics/bugs.txt:103
+msgid ""
+"would allow ``bzr commit --fixes hudson:HUDSON-1234`` to mark bug "
+"HUDSON-1234\n"
+"in Hudson's JIRA bug tracker as fixed.\n"
+msgstr ""
+
+#: en/help_topics/commands.txt:1
+msgid ""
+"add                Add specified files or directories.\n"
+"alias              Set/unset and display aliases.\n"
+"annotate           Show the origin of each line in a file.\n"
+"bash-completion    Generate a shell function for bash command line "
+"completion.\n"
+"                   [bash_completion]\n"
+"bd-do              Run a command in an exported package, copying the result\n"
+"                   back. [builddeb]\n"
+"bind               Convert the current branch into a checkout of the "
+"supplied\n"
+"                   branch.\n"
+"branch             Create a new branch that is a copy of an existing "
+"branch.\n"
+"branch-history     Display the development history of a branch. [bzrtools]\n"
+"branches           Scan a location for branches [bzrtools]\n"
+"break-lock         Break a dead lock.\n"
+"bug-url            Print full URL to a specific bug, or open it in your\n"
+"                   browser. [qbzr]\n"
+"builddeb           Builds a Debian package from a branch. [builddeb]\n"
+"cat                Write the contents of a file as of a given revision to\n"
+"                   standard output.\n"
+"cbranch            Create a new checkout, associated with a new repository\n"
+"                   branch. [bzrtools]\n"
+"cdiff              A color version of bzr's diff [bzrtools]\n"
+"check              Validate working tree structure, branch consistency and\n"
+"                   repository history.\n"
+"checkout           Create a new checkout of an existing branch.\n"
+"clean-tree         Remove unwanted files from working tree.\n"
+"commit             Commit changes into a new revision.\n"
+"config             Display, set or remove a configuration option.\n"
+"conflict-diff      Compare a conflicted file against BASE. [bzrtools]\n"
+"conflicts          List files with conflicts.\n"
+"create-mirror      Create a mirror of another branch. [bzrtools]\n"
+"deleted            List files deleted in the working tree.\n"
+"dep3-patch         Format the changes in a branch as a DEP-3 patch. "
+"[builddeb]\n"
+"dh-make            Helps you create a new package. [builddeb]\n"
+"diff               Show differences in the working tree, between revisions "
+"or\n"
+"                   branches.\n"
+"explorer           Desktop application for Bazaar. [explorer]\n"
+"export             Export current or past revision to a destination "
+"directory\n"
+"                   or archive.\n"
+"fetch-ghosts       Attempt to retrieve ghosts from another branch. "
+"[bzrtools]\n"
+"graph-ancestry     Produce ancestry graphs using dot. [bzrtools]\n"
+"grep               Print lines matching PATTERN for specified files and\n"
+"                   revisions. [grep]\n"
+"heads              Show all revisions in a repository not having "
+"descendants.\n"
+"                   [bzrtools]\n"
+"help               Show help on a command or other topic.\n"
+"ignore             Ignore specified files or patterns.\n"
+"ignored            List ignored files and the patterns that matched them.\n"
+"import             Import sources from a directory, tarball or zip file\n"
+"                   [bzrtools]\n"
+"import-dsc         Import a series of source packages. [builddeb]\n"
+"import-upstream    Imports an upstream tarball. [builddeb]\n"
+"info               Show information about a working tree, branch or "
+"repository.\n"
+"init               Make a directory into a versioned branch.\n"
+"init-repository    Create a shared repository for branches to share storage\n"
+"                   space.\n"
+"init-workspace     Start a new workspace. [explorer]\n"
+"join               Combine a tree into its containing tree.\n"
+"launchpad-login    Show or set the Launchpad user ID. [launchpad]\n"
+"launchpad-mirror   Ask Launchpad to mirror a branch now. [launchpad]\n"
+"launchpad-open     Open a Launchpad branch page in your web browser.\n"
+"                   [launchpad]\n"
+"link-tree          Hardlink matching files to another tree. [bzrtools]\n"
+"log                Show historical log for a branch or subset of a branch.\n"
+"lp-find-proposal   Find the proposal to merge this revision. [launchpad]\n"
+"lp-propose-merge   Propose merging a branch on Launchpad. [launchpad]\n"
+"ls                 List files in a tree.\n"
+"mark-uploaded      Mark that this branch has been uploaded, prior to "
+"pushing\n"
+"                   it. [builddeb]\n"
+"merge              Perform a three-way merge.\n"
+"merge-package      Merges source packaging branch into target packaging "
+"branch.\n"
+"                   [builddeb]\n"
+"merge-upstream     Merges a new upstream version into the current branch.\n"
+"                   [builddeb]\n"
+"missing            Show unmerged/unpulled revisions between two branches.\n"
+"mkdir              Create a new versioned directory.\n"
+"multi-pull         Pull all the branches under a location, e.g. a "
+"repository.\n"
+"                   [bzrtools]\n"
+"mv                 Move or rename a file.\n"
+"nick               Print or set the branch nickname.\n"
+"pack               Compress the data within a repository.\n"
+"patch              Apply a named patch to the current tree. [bzrtools]\n"
+"plugins            List the installed plugins.\n"
+"pull               Turn this branch into a mirror of another branch.\n"
+"push               Update a mirror of this branch.\n"
+"qadd               GUI for adding files or directories. [qbzr]\n"
+"qannotate          Show the origin of each line in a file. [qbzr]\n"
+"qbind              Convert the current branch into a checkout of the "
+"supplied\n"
+"                   branch. [qbzr]\n"
+"qbranch            Create a new copy of a branch. [qbzr]\n"
+"qbrowse            Show inventory or working tree. [qbzr]\n"
+"qcat               View the contents of a file as of a given revision. "
+"[qbzr]\n"
+"qcommit            GUI for committing revisions. [qbzr]\n"
+"qconfig            Configure Bazaar and QBzr. [qbzr]\n"
+"qconflicts         Show conflicts. [qbzr]\n"
+"qdiff              Show differences in working tree in a GUI window. [qbzr]\n"
+"qexport            Export current or past revision to a destination "
+"directory\n"
+"                   or archive. [qbzr]\n"
+"qgetnew            Creates a new working tree (either a checkout or full\n"
+"                   branch). [qbzr]\n"
+"qgetupdates        Fetches external changes into the working tree. [qbzr]\n"
+"qinfo              Shows information about the current location. [qbzr]\n"
+"qinit              Initializes a new branch or shared repository. [qbzr]\n"
+"qinit-workspace    Start a new workspace using a GUI. [explorer]\n"
+"qlog               Show log of a repository, branch, file, or directory in a "
+"Qt\n"
+"                   window. [qbzr]\n"
+"qmerge             Perform a three-way merge. [qbzr]\n"
+"qplugins           Show information about installed plugins. [qbzr]\n"
+"qpull              Turn this branch into a mirror of another branch. [qbzr]\n"
+"qpush              Update a mirror of this branch. [qbzr]\n"
+"qrevert            Revert changes files. [qbzr]\n"
+"qrun               Run arbitrary bzr command. [qbzr]\n"
+"qsend              Mail or create a merge-directive for submitting changes.\n"
+"                   [qbzr]\n"
+"qshelve            Shelve selected changes away. [qbzr]\n"
+"qswitch            Set the branch of a checkout and update. [qbzr]\n"
+"qtag               Edit tags. [qbzr]\n"
+"qunbind            Convert the current checkout into a regular branch. "
+"[qbzr]\n"
+"quncommit          Move the tip of a branch to an earlier revision. [qbzr]\n"
+"qunshelve          Restore shalved changes. [qbzr]\n"
+"qupdate            Update working tree with latest changes in the branch.\n"
+"                   [qbzr]\n"
+"qverify-signatures Shows digital signature statuses for branch commits "
+"[qbzr]\n"
+"qversion           Show version/system information. [qbzr]\n"
+"qviewer            Simple file viewer. [qbzr]\n"
+"reconcile          Reconcile bzr metadata in a branch.\n"
+"reconfigure        Reconfigure the type of a bzr directory.\n"
+"register-branch    Register a branch with launchpad.net. [launchpad]\n"
+"remerge            Redo a merge.\n"
+"remove             Remove files or directories.\n"
+"remove-branch      Remove a branch.\n"
+"remove-tree        Remove the working tree from a given branch/checkout.\n"
+"renames            Show list of renamed files.\n"
+"resolve            Mark a conflict as resolved.\n"
+"revert             Revert files to a previous revision.\n"
+"revno              Show current revision number.\n"
+"root               Show the tree root directory.\n"
+"rspush             Upload this branch to another location using rsync.\n"
+"                   [bzrtools]\n"
+"send               Mail or create a merge-directive for submitting changes.\n"
+"serve              Run the bzr server.\n"
+"shelf1             Perform various operations on your shelved patches. See "
+"also\n"
+"                   shelve1. [bzrtools]\n"
+"shell              Begin an interactive shell tailored for bzr. [bzrtools]\n"
+"shelve             Temporarily set aside some changes from the current "
+"tree.\n"
+"shelve1            Temporarily set aside some changes from the current "
+"tree.\n"
+"                   [bzrtools]\n"
+"sign-my-commits    Sign all commits by a given committer.\n"
+"split              Split a subdirectory of a tree into a separate tree.\n"
+"status             Display status summary.\n"
+"switch             Set the branch of a checkout and update.\n"
+"tag                Create, remove or modify a tag naming a revision.\n"
+"tags               List tags.\n"
+"testament          Show testament (signing-form) of a revision.\n"
+"trees              Scan a location for trees [bzrtools]\n"
+"unbind             Convert the current checkout into a regular branch.\n"
+"uncommit           Remove the last committed revision.\n"
+"unshelve           Restore shelved changes.\n"
+"unshelve1          Restore shelved changes. [bzrtools]\n"
+"update             Update a tree to have the latest code committed to its\n"
+"                   branch.\n"
+"upgrade            Upgrade a repository, branch or working tree to a newer\n"
+"                   format.\n"
+"verify-signatures  Verify all commit signatures.\n"
+"version            Show version of bzr.\n"
+"version-info       Show version information about this tree.\n"
+"view               Manage filtered views.\n"
+"whoami             Show or set bzr user id.\n"
+"zap                Remove a lightweight checkout, if it can be done safely.\n"
+"                   [bzrtools]\n"
+msgstr ""
+
+#: en/help_topics/configuration.txt:1
+msgid ""
+"Configuration Settings\n"
+"======================="
+msgstr ""
+
+#: en/help_topics/configuration.txt:4
+msgid ""
+"Environment settings\n"
+"---------------------"
+msgstr ""
+
+#: en/help_topics/configuration.txt:7
+msgid ""
+"While most configuration is handled by configuration files, some options\n"
+"which may be semi-permanent can also be controlled through the environment."
+msgstr ""
+
+#: en/help_topics/configuration.txt:10
+msgid ""
+"BZR_EMAIL\n"
+"~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:13
+msgid "Override the email id used by Bazaar.  Typical format::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:15
+msgid "  \"John Doe <jdoe@example.com>\""
+msgstr ""
+
+#: en/help_topics/configuration.txt:17
+msgid "See also the ``email`` configuration option."
+msgstr ""
+
+#: en/help_topics/configuration.txt:19
+msgid ""
+"BZR_PROGRESS_BAR\n"
+"~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:22
+msgid ""
+"Override the progress display.  Possible values are \"none\" or \"text\".  "
+"If\n"
+"the value is \"none\" then no progress bar is displayed.  The value \"text\" "
+"draws\n"
+"the ordinary command line progress bar."
+msgstr ""
+
+#: en/help_topics/configuration.txt:26
+msgid ""
+"BZR_SIGQUIT_PDB\n"
+"~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:29
+msgid "Control whether SIGQUIT behaves normally or invokes a breakin debugger."
+msgstr ""
+
+#: en/help_topics/configuration.txt:31
+msgid ""
+"* 0 = Standard SIGQUIT behavior (normally, exit with a core dump)\n"
+"* 1 = Invoke breakin debugger (default)"
+msgstr ""
+
+#: en/help_topics/configuration.txt:34
+msgid ""
+"BZR_HOME\n"
+"~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:37
+msgid "Override the home directory used by Bazaar."
+msgstr ""
+
+#: en/help_topics/configuration.txt:39
+msgid ""
+"BZR_SSH\n"
+"~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:42
+msgid "Select a different SSH implementation."
+msgstr ""
+
+#: en/help_topics/configuration.txt:44
+msgid ""
+"BZR_PDB\n"
+"~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:47
+msgid "Control whether to launch a debugger on error."
+msgstr ""
+
+#: en/help_topics/configuration.txt:49
+msgid ""
+"* 0 = Standard behavior\n"
+"* 1 = Launch debugger"
+msgstr ""
+
+#: en/help_topics/configuration.txt:52
+msgid ""
+"BZR_REMOTE_PATH\n"
+"~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:55
+msgid "Path to the Bazaar executable to use when using the bzr+ssh protocol."
+msgstr ""
+
+#: en/help_topics/configuration.txt:57
+msgid "See also the ``bzr_remote_path`` configuration option."
+msgstr ""
+
+#: en/help_topics/configuration.txt:59
+msgid ""
+"BZR_EDITOR\n"
+"~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:62
+msgid "Path to the editor Bazaar should use for commit messages, etc."
+msgstr ""
+
+#: en/help_topics/configuration.txt:64
+msgid ""
+"BZR_LOG\n"
+"~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:67
+msgid ""
+"Location of the Bazaar log file. You can check the current location by\n"
+"running ``bzr version``."
+msgstr ""
+
+#: en/help_topics/configuration.txt:70
+msgid ""
+"The log file contains debug information that is useful for diagnosing or\n"
+"reporting problems with Bazaar."
+msgstr ""
+
+#: en/help_topics/configuration.txt:73
+msgid ""
+"Setting this to ``NUL`` on Windows or ``/dev/null`` on other platforms\n"
+"will disable logging."
+msgstr ""
+
+#: en/help_topics/configuration.txt:76
+msgid ""
+"\n"
+"BZR_PLUGIN_PATH\n"
+"~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:80
+msgid ""
+"The path to the plugins directory that Bazaar should use.\n"
+"If not set, Bazaar will search for plugins in:"
+msgstr ""
+
+#: en/help_topics/configuration.txt:83
+msgid "* the user specific plugin directory (containing the ``user`` plugins),"
+msgstr ""
+
+#: en/help_topics/configuration.txt:85
+msgid "* the bzrlib directory (containing the ``core`` plugins),"
+msgstr ""
+
+#: en/help_topics/configuration.txt:87
+msgid ""
+"* the site specific plugin directory if applicable (containing\n"
+"  the ``site`` plugins)."
+msgstr ""
+
+#: en/help_topics/configuration.txt:90
+msgid ""
+"If ``BZR_PLUGIN_PATH`` is set in any fashion, it will change the\n"
+"the way the plugin are searched. "
+msgstr ""
+
+#: en/help_topics/configuration.txt:93
+msgid ""
+"As for the ``PATH`` variables, if multiple directories are\n"
+"specified in ``BZR_PLUGIN_PATH`` they should be separated by the\n"
+"platform specific appropriate character (':' on Unix,\n"
+"';' on windows)"
+msgstr ""
+
+#: en/help_topics/configuration.txt:98
+msgid ""
+"By default if ``BZR_PLUGIN_PATH`` is set, it replaces searching\n"
+"in ``user``.  However it will continue to search in ``core`` and\n"
+"``site`` unless they are explicitly removed."
+msgstr ""
+
+#: en/help_topics/configuration.txt:102
+msgid ""
+"If you need to change the order or remove one of these\n"
+"directories, you should use special values:"
+msgstr ""
+
+#: en/help_topics/configuration.txt:105
+msgid ""
+"* ``-user``, ``-core``, ``-site`` will remove the corresponding\n"
+"  path from the default values,"
+msgstr ""
+
+#: en/help_topics/configuration.txt:108
+msgid ""
+"* ``+user``, ``+core``, ``+site`` will add the corresponding path\n"
+"  before the remaining default values (and also remove it from\n"
+"  the default values)."
+msgstr ""
+
+#: en/help_topics/configuration.txt:112
+msgid ""
+"Note that the special values 'user', 'core' and 'site' should be\n"
+"used literally, they will be substituted by the corresponding,\n"
+"platform specific, values."
+msgstr ""
+
+#: en/help_topics/configuration.txt:116
+msgid ""
+"The examples below use ':' as the separator, windows users\n"
+"should use ';'."
+msgstr ""
+
+#: en/help_topics/configuration.txt:119
+msgid "Overriding the default user plugin directory::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:121
+msgid "  BZR_PLUGIN_PATH='/path/to/my/other/plugins'"
+msgstr ""
+
+#: en/help_topics/configuration.txt:123
+msgid "Disabling the site directory while retaining the user directory::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:125
+msgid "  BZR_PLUGIN_PATH='-site:+user'"
+msgstr ""
+
+#: en/help_topics/configuration.txt:127
+msgid "Disabling all plugins (better achieved with --no-plugins)::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:129
+msgid "  BZR_PLUGIN_PATH='-user:-core:-site'"
+msgstr ""
+
+#: en/help_topics/configuration.txt:131
+msgid "Overriding the default site plugin directory::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:133
+msgid "  BZR_PLUGIN_PATH='/path/to/my/site/plugins:-site':+user"
+msgstr ""
+
+#: en/help_topics/configuration.txt:135
+msgid ""
+"BZR_DISABLE_PLUGINS\n"
+"~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:138
+msgid ""
+"Under special circumstances (mostly when trying to diagnose a\n"
+"bug), it's better to disable a plugin (or several) rather than\n"
+"uninstalling them completely. Such plugins can be specified in\n"
+"the ``BZR_DISABLE_PLUGINS`` environment variable."
+msgstr ""
+
+#: en/help_topics/configuration.txt:143
+msgid ""
+"In that case, ``bzr`` will stop loading the specified plugins and\n"
+"will raise an import error if they are explicitly imported (by\n"
+"another plugin that depends on them for example)."
+msgstr ""
+
+#: en/help_topics/configuration.txt:147
+msgid "Disabling ``myplugin`` and ``yourplugin`` is achieved by::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:149
+msgid "  BZR_DISABLE_PLUGINS='myplugin:yourplugin'"
+msgstr ""
+
+#: en/help_topics/configuration.txt:151
+msgid ""
+"BZR_PLUGINS_AT\n"
+"~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:154
+msgid ""
+"When adding a new feature or working on a bug in a plugin,\n"
+"developers often need to use a specific version of a given\n"
+"plugin. Since python requires that the directory containing the\n"
+"code is named like the plugin itself this make it impossible to\n"
+"use arbitrary directory names (using a two-level directory scheme\n"
+"is inconvenient). ``BZR_PLUGINS_AT`` allows such directories even\n"
+"if they don't appear in ``BZR_PLUGIN_PATH`` ."
+msgstr ""
+
+#: en/help_topics/configuration.txt:162
+msgid ""
+"Plugins specified in this environment variable takes precedence\n"
+"over the ones in ``BZR_PLUGIN_PATH``."
+msgstr ""
+
+#: en/help_topics/configuration.txt:165
+msgid ""
+"The variable specified a list of ``plugin_name@plugin path``,\n"
+"``plugin_name`` being the name of the plugin as it appears in\n"
+"python module paths, ``plugin_path`` being the path to the\n"
+"directory containing the plugin code itself\n"
+"(i.e. ``plugins/myplugin`` not ``plugins``).  Use ':' as the list\n"
+"separator, use ';' on windows."
+msgstr ""
+
+#: en/help_topics/configuration.txt:172
+msgid ""
+"Example:\n"
+"~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:175
+msgid ""
+"Using a specific version of ``myplugin``:\n"
+"``BZR_PLUGINS_AT='myplugin@/home/me/bugfixes/123456-myplugin``"
+msgstr ""
+
+#: en/help_topics/configuration.txt:178
+msgid ""
+"BZRPATH\n"
+"~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:181
+msgid "The path where Bazaar should look for shell plugin external commands."
+msgstr ""
+
+#: en/help_topics/configuration.txt:183
+msgid ""
+"\n"
+"http_proxy, https_proxy\n"
+"~~~~~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:187
+msgid "Specifies the network proxy for outgoing connections, for example::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:189
+msgid ""
+"  http_proxy=http://proxy.example.com:3128/ \n"
+"  https_proxy=http://proxy.example.com:3128/"
+msgstr ""
+
+#: en/help_topics/configuration.txt:192
+msgid ""
+"\n"
+"Configuration files\n"
+"-------------------"
+msgstr ""
+
+#: en/help_topics/configuration.txt:196
+msgid ""
+"Location\n"
+"~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:199
+msgid ""
+"Configuration files are located in ``$HOME/.bazaar`` on Unix and\n"
+"``C:\\Documents and Settings\\<username>\\Application Data\\Bazaar\\2.0`` "
+"on\n"
+"Windows. (You can check the location for your system by using\n"
+"``bzr version``.)"
+msgstr ""
+
+#: en/help_topics/configuration.txt:204
+msgid "There are three primary configuration files in this location:"
+msgstr ""
+
+#: en/help_topics/configuration.txt:206
+msgid "* ``bazaar.conf`` describes default configuration options,"
+msgstr ""
+
+#: en/help_topics/configuration.txt:208
+msgid ""
+"* ``locations.conf`` describes configuration information for\n"
+"  specific branch locations,"
+msgstr ""
+
+#: en/help_topics/configuration.txt:211
+msgid ""
+"* ``authentication.conf`` describes credential information for\n"
+"  remote servers."
+msgstr ""
+
+#: en/help_topics/configuration.txt:214
+msgid ""
+"Each branch can also contain a configuration file that sets values specific\n"
+"to that branch. This file is found at ``.bzr/branch/branch.conf`` within "
+"the\n"
+"branch. This file is visible to all users of a branch, if you wish to "
+"override\n"
+"one of the values for a branch with a setting that is specific to you then "
+"you\n"
+"can do so in ``locations.conf``."
+msgstr ""
+
+#: en/help_topics/configuration.txt:220
+msgid ""
+"General format\n"
+"~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:223
+msgid ""
+"An ini file has three types of contructs: section headers, section\n"
+"variables and comments."
+msgstr ""
+
+#: en/help_topics/configuration.txt:226
+msgid ""
+"Comments\n"
+"^^^^^^^^"
+msgstr ""
+
+#: en/help_topics/configuration.txt:229
+msgid ""
+"A comment is any line that starts with a \"#\" (sometimes called a \"hash\n"
+"mark\", \"pound sign\" or \"number sign\"). Comment lines are ignored by\n"
+"Bazaar when parsing ini files."
+msgstr ""
+
+#: en/help_topics/configuration.txt:233
+msgid ""
+"Section headers\n"
+"^^^^^^^^^^^^^^^"
+msgstr ""
+
+#: en/help_topics/configuration.txt:236
+msgid ""
+"A section header is a word enclosed in brackets that starts at the begining\n"
+"of a line.  A typical section header looks like this::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:239
+msgid "    [DEFAULT]"
+msgstr ""
+
+#: en/help_topics/configuration.txt:241
+msgid ""
+"The only valid section headers for bazaar.conf currently are [DEFAULT] and\n"
+"[ALIASES].  Section headers are case sensitive. The default section provides "
+"for\n"
+"setting variables which can be overridden with the branch config file."
+msgstr ""
+
+#: en/help_topics/configuration.txt:245
+msgid ""
+"For ``locations.conf``, the variables from the section with the\n"
+"longest matching section header are used to the exclusion of other\n"
+"potentially valid section headers. A section header uses the path for\n"
+"the branch as the section header. Some examples include::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:250
+msgid ""
+"    [http://mybranches.isp.com/~jdoe/branchdir]\n"
+"    [/home/jdoe/branches/]"
+msgstr ""
+
+#: en/help_topics/configuration.txt:253
+msgid ""
+"\n"
+"Section variables\n"
+"^^^^^^^^^^^^^^^^^"
+msgstr ""
+
+#: en/help_topics/configuration.txt:257
+msgid ""
+"A section variable resides within a section. A section variable contains a\n"
+"variable name, an equals sign and a value.  For example::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:260
+msgid ""
+"    email            = John Doe <jdoe@isp.com>\n"
+"    gpg_signing_key  = Amy Pond <amy@example.com>"
+msgstr ""
+
+#: en/help_topics/configuration.txt:263
+msgid ""
+"A variable can reference other variables **in the same configuration file** "
+"by\n"
+"enclosing them in curly brackets::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:266
+msgid ""
+"    my_branch_name = feature_x\n"
+"    my_server      = bzr+ssh://example.com\n"
+"    push_location   = {my_server}/project/{my_branch_name}"
+msgstr ""
+
+#: en/help_topics/configuration.txt:270
+msgid ""
+"\n"
+"Variable policies\n"
+"^^^^^^^^^^^^^^^^^"
+msgstr ""
+
+#: en/help_topics/configuration.txt:274
+msgid ""
+"Variables defined in a section affect the named directory or URL plus\n"
+"any locations they contain.  Policies can be used to change how a\n"
+"variable value is interpreted for contained locations.  Currently\n"
+"there are three policies available:"
+msgstr ""
+
+#: en/help_topics/configuration.txt:279
+msgid ""
+" none:\n"
+"   the value is interpreted the same for contained locations.  This is\n"
+"   the default behaviour.\n"
+" norecurse:\n"
+"   the value is only used for the exact location specified by the\n"
+"   section name.\n"
+" appendpath:\n"
+"   for contained locations, any additional path components are\n"
+"   appended to the value."
+msgstr ""
+
+#: en/help_topics/configuration.txt:289
+msgid ""
+"Policies are specified by keys with names of the form \"$var:policy\".\n"
+"For example, to define the push location for a tree of branches, the\n"
+"following could be used::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:293
+msgid ""
+"  [/top/location]\n"
+"  push_location = sftp://example.com/location\n"
+"  push_location:policy = appendpath"
+msgstr ""
+
+#: en/help_topics/configuration.txt:297
+msgid ""
+"With this configuration, the push location for ``/top/location/branch1``\n"
+"would be ``sftp://example.com/location/branch1``."
+msgstr ""
+
+#: en/help_topics/configuration.txt:300
+msgid ""
+"\n"
+"The main configuration file, bazaar.conf\n"
+"~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:304
+msgid ""
+"``bazaar.conf`` allows two sections: ``[DEFAULT]`` and ``[ALIASES]``.\n"
+"The default section contains the default\n"
+"configuration options for all branches. The default section can be\n"
+"overriden by providing a branch-specific section in ``locations.conf``."
+msgstr ""
+
+#: en/help_topics/configuration.txt:309
+msgid "A typical ``bazaar.conf`` section often looks like the following::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:311
+msgid ""
+"    [DEFAULT]\n"
+"    email             = John Doe <jdoe@isp.com>\n"
+"    editor            = /usr/bin/vim\n"
+"    create_signatures = when-required"
+msgstr ""
+
+#: en/help_topics/configuration.txt:316
+msgid ""
+"\n"
+"The branch location configuration file, locations.conf\n"
+"~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:320
+msgid ""
+"``locations.conf`` allows one to specify overriding settings for\n"
+"a specific branch. The format is almost identical to the default section in\n"
+"bazaar.conf with one significant change: The section header, instead of "
+"saying\n"
+"default, will be the path to a branch that you wish to override a value\n"
+"for. The '?' and '*' wildcards are supported::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:326
+msgid ""
+"    [/home/jdoe/branches/nethack]\n"
+"    email = Nethack Admin <nethack@nethack.com>"
+msgstr ""
+
+#: en/help_topics/configuration.txt:329
+msgid ""
+"    [http://hypothetical.site.com/branches/devel-branch]\n"
+"    create_signatures = always"
+msgstr ""
+
+#: en/help_topics/configuration.txt:332
+msgid ""
+"The authentication configuration file, authentication.conf\n"
+"~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:335
+msgid ""
+"``authentication.conf`` allows one to specify credentials for\n"
+"remote servers. This can be used for all the supported transports and any "
+"part\n"
+"of bzr that requires authentication (smtp for example)."
+msgstr ""
+
+#: en/help_topics/configuration.txt:339
+msgid ""
+"The syntax of the file obeys the same rules as the others except for the\n"
+"variable policies which don't apply."
+msgstr ""
+
+#: en/help_topics/configuration.txt:342
+msgid ""
+"For more information on the possible uses of the authentication "
+"configuration\n"
+"file see :doc:`authentication-help`."
+msgstr ""
+
+#: en/help_topics/configuration.txt:345
+msgid ""
+"\n"
+"Common variable options\n"
+"-----------------------"
+msgstr ""
+
+#: en/help_topics/configuration.txt:349
+msgid ""
+"debug_flags\n"
+"~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:352
+msgid ""
+"A comma-separated list of debugging options to turn on.  The same values\n"
+"can be used as with the -D command-line option (see `help global-options`).\n"
+"For example::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:356
+msgid "    debug_flags = hpss"
+msgstr ""
+
+#: en/help_topics/configuration.txt:360
+msgid "    debug_flags = hpss,evil"
+msgstr ""
+
+#: en/help_topics/configuration.txt:362
+msgid ""
+"email\n"
+"~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:365
+msgid ""
+"The email address to use when committing a branch. Typically takes the form\n"
+"of::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:368
+msgid "    email = Full Name <account@hostname.tld>"
+msgstr ""
+
+#: en/help_topics/configuration.txt:370
+msgid ""
+"editor\n"
+"~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:373
+msgid ""
+"The path of the editor that you wish to use if *bzr commit* is run without\n"
+"a commit message. This setting is trumped by the environment variable\n"
+"``BZR_EDITOR``, and overrides the ``VISUAL`` and ``EDITOR`` environment\n"
+"variables."
+msgstr ""
+
+#: en/help_topics/configuration.txt:378
+msgid ""
+"log_format\n"
+"~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:381
+msgid ""
+"The default log format to use. Standard log formats are ``long``, ``short``\n"
+"and ``line``. Additional formats may be provided by plugins. The default\n"
+"value is ``long``."
+msgstr ""
+
+#: en/help_topics/configuration.txt:385
+msgid ""
+"check_signatures\n"
+"~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:388
+msgid ""
+"Reserved for future use.  These options will allow a policy for branches to\n"
+"require signatures."
+msgstr ""
+
+#: en/help_topics/configuration.txt:391
+msgid ""
+"require\n"
+"    The gnupg signature for revisions must be present and must be valid."
+msgstr ""
+
+#: en/help_topics/configuration.txt:394
+msgid ""
+"ignore\n"
+"    Do not check gnupg signatures of revisions."
+msgstr ""
+
+#: en/help_topics/configuration.txt:397
+msgid ""
+"check-available\n"
+"    (default) If gnupg signatures for revisions are present, check them.\n"
+"    Bazaar will fail if it finds a bad signature, but will not fail if\n"
+"    no signature is present."
+msgstr ""
+
+#: en/help_topics/configuration.txt:402
+msgid ""
+"create_signatures\n"
+"~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:405
+msgid ""
+"Defines the behaviour of signing revisions on commits.  By default bzr will "
+"not\n"
+"sign new commits."
+msgstr ""
+
+#: en/help_topics/configuration.txt:408
+msgid ""
+"always\n"
+"    Sign every new revision that is committed.  If the signing fails then "
+"the\n"
+"    commit will not be made."
+msgstr ""
+
+#: en/help_topics/configuration.txt:412
+msgid ""
+"when-required\n"
+"    Reserved for future use."
+msgstr ""
+
+#: en/help_topics/configuration.txt:415
+msgid ""
+"never\n"
+"    Reserved for future use."
+msgstr ""
+
+#: en/help_topics/configuration.txt:418
+msgid ""
+"In future it is planned that ``when-required`` will sign newly\n"
+"committed revisions only when the branch requires them.  ``never`` will "
+"refuse\n"
+"to sign newly committed revisions, even if the branch requires signatures."
+msgstr ""
+
+#: en/help_topics/configuration.txt:422
+msgid ""
+"dirstate.fdatasync\n"
+"~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:425
+msgid ""
+"If true (default), working tree metadata changes are flushed through the\n"
+"OS buffers to physical disk.  This is somewhat slower, but means data\n"
+"should not be lost if the machine crashes.  See also repository.fdatasync."
+msgstr ""
+
+#: en/help_topics/configuration.txt:429
+msgid ""
+"gpg_signing_key\n"
+"~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:432
+msgid ""
+"The GnuPG user identity to use when signing commits.  Can be an e-mail\n"
+"address, key fingerprint or full key ID.  When unset or when set to\n"
+"\"default\" Bazaar will use the user e-mail set with ``whoami``."
+msgstr ""
+
+#: en/help_topics/configuration.txt:436
+msgid ""
+"recurse\n"
+"~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:439
+msgid ""
+"Only useful in ``locations.conf``. Defines whether or not the\n"
+"configuration for this section applies to subdirectories:"
+msgstr ""
+
+#: en/help_topics/configuration.txt:442
+msgid ""
+"true\n"
+"    (default) This section applies to subdirectories as well."
+msgstr ""
+
+#: en/help_topics/configuration.txt:445
+msgid ""
+"false\n"
+"    This section only applies to the branch at this directory and not\n"
+"    branches below it."
+msgstr ""
+
+#: en/help_topics/configuration.txt:449
+msgid ""
+"gpg_signing_command\n"
+"~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:452
+msgid ""
+"(Default: \"gpg\"). Which program should be used to sign and check "
+"revisions.\n"
+"For example::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:455
+msgid "    gpg_signing_command = /usr/bin/gnpg"
+msgstr ""
+
+#: en/help_topics/configuration.txt:457
+msgid ""
+"The specified command must accept the options \"--clearsign\" and \"-u "
+"<email>\"."
+msgstr ""
+
+#: en/help_topics/configuration.txt:459
+msgid ""
+"bzr_remote_path\n"
+"~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:462
+msgid ""
+"(Default: \"bzr\").  The path to the command that should be used to run the "
+"smart\n"
+"server for bzr.  This value may only be specified in locations.conf, because:"
+msgstr ""
+
+#: en/help_topics/configuration.txt:465
+msgid ""
+"- it's needed before branch.conf is accessible\n"
+"- allowing remote branch.conf files to specify commands would be a security\n"
+"  risk"
+msgstr ""
+
+#: en/help_topics/configuration.txt:469
+msgid "It is overridden by the BZR_REMOTE_PATH environment variable."
+msgstr ""
+
+#: en/help_topics/configuration.txt:471
+msgid ""
+"smtp_server\n"
+"~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:474
+msgid ""
+"(Default: \"localhost\"). SMTP server to use when Bazaar needs to send\n"
+"email, eg. with ``merge-directive --mail-to``, or the bzr-email plugin."
+msgstr ""
+
+#: en/help_topics/configuration.txt:477
+msgid ""
+"smtp_username, smtp_password\n"
+"~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:480
+msgid ""
+"User and password to authenticate to the SMTP server. If smtp_username\n"
+"is set, and smtp_password is not, Bazaar will prompt for a password.\n"
+"These settings are only needed if the SMTP server requires authentication\n"
+"to send mail."
+msgstr ""
+
+#: en/help_topics/configuration.txt:485
+msgid ""
+"locks.steal_dead\n"
+"~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:488
+msgid ""
+"If set to true, bzr will automatically break locks held by processes from\n"
+"the same machine and user that are no longer alive.  Otherwise, it will\n"
+"print a message and you can break the lock manually, if you are satisfied\n"
+"the object is no longer in use."
+msgstr ""
+
+#: en/help_topics/configuration.txt:493
+msgid ""
+"mail_client\n"
+"~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:496
+msgid ""
+"A mail client to use for sending merge requests.\n"
+"By default, bzr will try to use ``mapi`` on Windows.  On other platforms, "
+"it\n"
+"will try ``xdg-email``. If either of these fails, it will fall back to\n"
+"``editor``."
+msgstr ""
+
+#: en/help_topics/configuration.txt:501
+msgid "Supported values for specific clients:"
+msgstr ""
+
+#: en/help_topics/configuration.txt:503
+msgid ""
+":claws: Use Claws.  This skips a dialog for attaching files.\n"
+":evolution: Use Evolution.\n"
+":kmail: Use KMail.\n"
+":mutt: Use Mutt.\n"
+":thunderbird: Use Mozilla Thunderbird or Icedove.  For Thunderbird/Icedove "
+"1.5,\n"
+"    this works around some bugs that xdg-email doesn't handle."
+msgstr ""
+
+#: en/help_topics/configuration.txt:510
+msgid "Supported generic values are:"
+msgstr ""
+
+#: en/help_topics/configuration.txt:512
+msgid ""
+":default: See above.\n"
+":editor: Use your editor to compose the merge request.  This also uses\n"
+"    your commit id, (see ``bzr whoami``), smtp_server and (optionally)\n"
+"    smtp_username and smtp_password.\n"
+":mapi: Use your preferred e-mail client on Windows.\n"
+":xdg-email: Use xdg-email to run your preferred mail program"
+msgstr ""
+
+#: en/help_topics/configuration.txt:519
+msgid ""
+"repository.fdatasync\n"
+"~~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:522
+msgid ""
+"If true (default), repository changes are flushed through the OS buffers\n"
+"to physical disk.  This is somewhat slower, but means data should not be\n"
+"lost if the machine crashes.  See also dirstate.fdatasync."
+msgstr ""
+
+#: en/help_topics/configuration.txt:526
+msgid ""
+"submit_branch\n"
+"~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:529
+msgid ""
+"The branch you intend to submit your current work to.  This is "
+"automatically\n"
+"set by ``bzr send``, and is also used by the ``submit:`` revision spec.  "
+"This\n"
+"should usually be set on a per-branch or per-location basis."
+msgstr ""
+
+#: en/help_topics/configuration.txt:533
+msgid ""
+"public_branch\n"
+"~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:536
+msgid ""
+"A publically-accessible version of this branch (implying that this version "
+"is\n"
+"not publically-accessible).  Used (and set) by ``bzr send``."
+msgstr ""
+
+#: en/help_topics/configuration.txt:539
+msgid ""
+"suppress_warnings\n"
+"~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:542
+msgid ""
+"A list of strings, each string represent a warning that can be emitted by\n"
+"bzr. Mentioning a warning in this list tells bzr to not emit it."
+msgstr ""
+
+#: en/help_topics/configuration.txt:545
+msgid "Valid values:"
+msgstr ""
+
+#: en/help_topics/configuration.txt:547
+msgid ""
+"* ``format_deprecation``:\n"
+"    whether the format deprecation warning is shown on repositories that "
+"are\n"
+"    using deprecated formats."
+msgstr ""
+
+#: en/help_topics/configuration.txt:551
+msgid ""
+"default_format\n"
+"~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:554
+msgid ""
+"A format name for the default format used when creating branches.  See "
+"``bzr\n"
+"help formats`` for possible values."
+msgstr ""
+
+#: en/help_topics/configuration.txt:557
+msgid ""
+"\n"
+"Unicode options\n"
+"---------------"
+msgstr ""
+
+#: en/help_topics/configuration.txt:561
+msgid ""
+"output_encoding\n"
+"~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:564
+msgid ""
+"A Python unicode encoding name for text output from bzr, such as log\n"
+"information.  Values include: utf8, cp850, ascii, iso-8859-1.  The default\n"
+"is the terminal encoding prefered by the operating system."
+msgstr ""
+
+#: en/help_topics/configuration.txt:568
+msgid ""
+"\n"
+"Branch type specific options\n"
+"----------------------------"
+msgstr ""
+
+#: en/help_topics/configuration.txt:572
+msgid ""
+"These options apply only to branches that use the ``dirstate-tags`` or\n"
+"later format.  They\n"
+"are usually set in ``.bzr/branch/branch.conf`` automatically, but may be\n"
+"manually set in ``locations.conf`` or ``bazaar.conf``."
+msgstr ""
+
+#: en/help_topics/configuration.txt:577
+msgid ""
+"append_revisions_only\n"
+"~~~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:580
+msgid ""
+"If set to \"True\" then revisions can only be appended to the log, not\n"
+"removed.  A branch with this setting enabled can only pull from another\n"
+"branch if the other branch's log is a longer version of its own.  This is\n"
+"normally set by ``bzr init --append-revisions-only``. If you set it\n"
+"manually, use either 'True' or 'False' (case-sensitive) to maintain\n"
+"compatibility with previous bzr versions (older than 2.2)."
+msgstr ""
+
+#: en/help_topics/configuration.txt:587
+msgid ""
+"parent_location\n"
+"~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:590
+msgid ""
+"If present, the location of the default branch for pull or merge.  This "
+"option\n"
+"is normally set when creating a branch, the first ``pull`` or by ``pull\n"
+"--remember``."
+msgstr ""
+
+#: en/help_topics/configuration.txt:594
+msgid ""
+"push_location\n"
+"~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:597
+msgid ""
+"If present, the location of the default branch for push.  This option\n"
+"is normally set by the first ``push`` or ``push --remember``."
+msgstr ""
+
+#: en/help_topics/configuration.txt:600
+msgid ""
+"push_strict\n"
+"~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:603
+msgid ""
+"If present, defines the ``--strict`` option default value for checking\n"
+"uncommitted changes before pushing."
+msgstr ""
+
+#: en/help_topics/configuration.txt:606
+msgid ""
+"dpush_strict\n"
+"~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:609
+msgid ""
+"If present, defines the ``--strict`` option default value for checking\n"
+"uncommitted changes before pushing into a different VCS without any\n"
+"custom bzr metadata."
+msgstr ""
+
+#: en/help_topics/configuration.txt:613
+msgid ""
+"bound_location\n"
+"~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:616
+msgid ""
+"The location that commits should go to when acting as a checkout.\n"
+"This option is normally set by ``bind``."
+msgstr ""
+
+#: en/help_topics/configuration.txt:619
+msgid ""
+"bound\n"
+"~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:622
+msgid ""
+"If set to \"True\", the branch should act as a checkout, and push each "
+"commit to\n"
+"the bound_location.  This option is normally set by ``bind``/``unbind``."
+msgstr ""
+
+#: en/help_topics/configuration.txt:625
+msgid ""
+"send_strict\n"
+"~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:628
+msgid ""
+"If present, defines the ``--strict`` option default value for checking\n"
+"uncommitted changes before sending a merge directive."
+msgstr ""
+
+#: en/help_topics/configuration.txt:631
+msgid ""
+"add.maximum_file_size\n"
+"~~~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:634
+msgid ""
+"Defines the maximum file size the command line \"add\" operation will allow\n"
+"in recursive mode, with files larger than this value being skipped. You "
+"may \n"
+"specify this value as an integer (in which case it is interpreted as "
+"bytes), \n"
+"or you may specify the value using SI units, i.e. 10KB, 20MB, 1G. A value of "
+"0 \n"
+"will disable skipping."
+msgstr ""
+
+#: en/help_topics/configuration.txt:640
+msgid ""
+"External Merge Tools\n"
+"--------------------"
+msgstr ""
+
+#: en/help_topics/configuration.txt:643
+msgid ""
+"bzr.mergetool.<name>\n"
+"~~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:646
+msgid ""
+"Defines an external merge tool called <name> with the given command-line.\n"
+"Arguments containing spaces should be quoted using single or double quotes. "
+"The\n"
+"executable may omit its path if it can be found on the PATH."
+msgstr ""
+
+#: en/help_topics/configuration.txt:650
+msgid ""
+"The following markers can be used in the command-line to substitute "
+"filenames\n"
+"involved in the merge conflict::"
+msgstr ""
+
+#: en/help_topics/configuration.txt:653
+msgid ""
+"  {base}      file.BASE\n"
+"  {this}      file.THIS\n"
+"  {other}     file.OTHER\n"
+"  {result}    output file\n"
+"  {this_temp} temp copy of file.THIS, used to overwrite output file if "
+"merge\n"
+"              succeeds."
+msgstr ""
+
+#: en/help_topics/configuration.txt:662
+msgid "  bzr.mergetool.kdiff3 = kdiff3 {base} {this} {other} -o {result}"
+msgstr ""
+
+#: en/help_topics/configuration.txt:664
+msgid ""
+"bzr.default_mergetool\n"
+"~~~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/configuration.txt:667
+msgid ""
+"Specifies which external merge tool (as defined above) should be selected "
+"by\n"
+"default in tools such as ``bzr qconflicts``."
+msgstr ""
+
+#: en/help_topics/configuration.txt:672
+msgid "  bzr.default_mergetool = kdiff3\n"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:1
+msgid ""
+"Conflict Types\n"
+"=============="
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:4
+msgid ""
+"Some operations, like merge, revert and pull, modify the contents of your\n"
+"working tree.  These modifications are programmatically generated, and so "
+"they\n"
+"may conflict with the current state of your working tree. "
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:8
+msgid ""
+"When conflicts are present in your working tree (as shown by ``bzr\n"
+"conflicts``), you should resolve them and then inform bzr that the "
+"conflicts\n"
+"have been resolved."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:12
+msgid ""
+"Resolving conflicts is sometimes not obvious. Either because the user that\n"
+"should resolve them is not the one responsible for their occurrence, as is "
+"the\n"
+"case when merging other people's work or because some conflicts are "
+"presented\n"
+"in a way that is not easy to understand."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:17
+msgid ""
+"Bazaar tries to avoid conflicts ; its aim is to ask you to resolve the\n"
+"conflict if and only if there's an actual conceptual conflict in the source\n"
+"tree.  Because Bazaar doesn't understand the real meaning of the files "
+"being\n"
+"versioned, it can, when faced with ambiguities, fall short in either "
+"direction\n"
+"trying to resolve the conflict itself. Many kinds of changes can be "
+"combined\n"
+"programmatically, but sometimes only a human can determine the right thing "
+"to\n"
+"do."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:25
+msgid ""
+"When Bazaar generates a conflict, it adds information into the working tree "
+"to\n"
+"present the conflicting versions, and it's up to you to find the correct\n"
+"resolution."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:29
+msgid "Whatever the conflict is, resolving it is roughly done in two steps:"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:31
+msgid ""
+"1. Modify the working tree content so that the conflicted item is now in "
+"the\n"
+"   state you want to keep, then"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:34
+msgid ""
+"2. Inform Bazaar that the conflict is now solved and ask to cleanup any\n"
+"   remaining generated information (``bzr resolve <item>``)."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:37
+msgid ""
+"For most conflict types, there are some obvious ways to modify the working\n"
+"tree and put it into the desired state. For some types of conflicts, Bazaar\n"
+"itself already made a choice, when possible."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:41
+msgid ""
+"Yet, whether Bazaar makes a choice or not, there are some other simple but\n"
+"different ways to resolve the conflict."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:44
+msgid ""
+"Each type of conflict is explained below, and the action which must be done "
+"to\n"
+"resolve the conflict is outlined."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:47
+msgid ""
+"Various actions are available depending on the kind of conflict, for some "
+"of\n"
+"these actions, Bazaar can provide some help. In the end you should at least\n"
+"inform Bazaar that you're done with the conflict with::"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:51
+msgid "  ``bzr resolve FILE --action=done'"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:53
+msgid ""
+"Note that this is the default action when a single file is involved so you "
+"can\n"
+"simply use::"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:56
+msgid "   ``bzr resolve FILE``"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:58
+msgid "See ``bzr help resolve`` for more details."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:60
+msgid ""
+"Text conflicts\n"
+"--------------"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:63
+msgid "Typical message::"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:65
+msgid "  Text conflict in FILE"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:67
+msgid ""
+"These are produced when a text merge cannot completely reconcile two sets "
+"of\n"
+"text changes.  Bazaar will emit files for each version with the extensions\n"
+"THIS, OTHER, and BASE.  THIS is the version of the file from the target "
+"tree,\n"
+"i.e. the tree that you are merging changes into.  OTHER is the version that "
+"you\n"
+"are merging into the target.  BASE is an older version that is used as a "
+"basis\n"
+"for comparison."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:74
+msgid ""
+"In the main copy of the file, Bazaar will include all the changes that it\n"
+"could reconcile, and any un-reconciled conflicts are surrounded by\n"
+"\"herringbone\" markers like ``<<<<<<<``."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:78
+msgid ""
+"Say the initial text is \"The project leader released it.\", and THIS "
+"modifies it\n"
+"to \"Martin Pool released it.\", while OTHER modifies it to \"The project "
+"leader\n"
+"released Bazaar.\"  A conflict would look like this::"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:82
+msgid ""
+"  <<<<<<< TREE\n"
+"  Martin Pool released it.\n"
+"  =======\n"
+"  The project leader released Bazaar.\n"
+"  >>>>>>> MERGE-SOURCE"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:88
+msgid "The correct resolution would be \"Martin Pool released Bazaar.\""
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:90
+msgid ""
+"You can handle text conflicts either by editing the main copy of the file,\n"
+"or by invoking external tools on the THIS, OTHER and BASE versions.  It's\n"
+"worth mentioning that resolving text conflicts rarely involves picking one\n"
+"set of changes over the other (but see below when you encounter these\n"
+"cases).  More often, the two sets of changes must be intelligently combined."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:96
+msgid ""
+"If you edit the main copy, be sure to remove the herringbone markers.  When\n"
+"you are done editing, the file should look like it never had a conflict, and "
+"be\n"
+"ready to commit."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:100
+msgid ""
+"When you have resolved text conflicts, just run ``bzr resolve --auto``, and\n"
+"Bazaar will auto-detect which conflicts you have resolved."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:103
+msgid ""
+"When the conflict is resolved, Bazaar deletes the previously generated\n"
+"``.BASE``, ``.THIS`` and ``.OTHER`` files if they are still present in the\n"
+"working tree."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:107
+msgid ""
+"\n"
+"When you want to pick one set of changes over the other, you can use ``bzr\n"
+"resolve`` with one of the following actions:"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:111
+msgid ""
+"* ``--action=take-this`` will issue ``mv FILE.THIS FILE``,\n"
+"* ``--action=take-other`` will issue ``mv FILE.OTHER FILE``."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:114
+msgid ""
+"Note that if you have modified ``FILE.THIS`` or ``FILE.OTHER``, these\n"
+"modifications will be taken into account."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:117
+msgid ""
+"Content conflicts\n"
+"-----------------"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:122
+msgid "  Contents conflict in FILE"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:124
+msgid ""
+"This conflict happens when there are conflicting changes in the working "
+"tree\n"
+"and the merge source, but the conflicted items are not text files.  They "
+"may\n"
+"be binary files, or symlinks, or directories.  It can even happen with "
+"files\n"
+"that are deleted on one side, and modified on the other."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:129
+msgid ""
+"Like text conflicts, Bazaar will emit THIS, OTHER and BASE files.  (They may "
+"be\n"
+"regular files, symlinks or directories).  But it will not include a \"main "
+"copy\"\n"
+"of the file with herringbone conflict markers.  It will appear that the "
+"\"main\n"
+"copy\" has been renamed to THIS or OTHER."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:134
+msgid ""
+"To resolve that kind of conflict, you should rebuild FILE from either "
+"version\n"
+"or a combination of both."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:137
+msgid "``bzr resolve`` recognizes the following actions:"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:139
+msgid ""
+"* ``--action=take-this`` will issue ``bzr mv FILE.THIS FILE``,\n"
+"* ``--action=take-other`` will issue ``bzr mv FILE.OTHER FILE``,\n"
+"* ``--action=done`` will just mark the conflict as resolved."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:143
+msgid ""
+"Any action will also delete the previously generated ``.BASE``, ``.THIS`` "
+"and\n"
+"``.OTHER`` files if they are still present in the working tree."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:146
+msgid ""
+"Bazaar cannot auto-detect when conflicts of this kind have been resolved."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:148
+msgid ""
+"Tag conflicts\n"
+"-------------"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:153
+msgid ""
+"  Conflicting tags:\n"
+"      version-0.1"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:156
+msgid ""
+"When pulling from or pushing to another branch, Bazaar informs you about "
+"tags\n"
+"that conflict between the two branches; that is the same tag points to two\n"
+"different revisions.  You need not resolve these conflicts, but subsequent\n"
+"uses of pull or push will result in the same message."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:161
+msgid ""
+"To resolve the conflict, you must apply the correct tags to either the "
+"target\n"
+"branch or the source branch as appropriate.  Use \"bzr tags --show-ids -d\n"
+"SOURCE_URL\" to see the tags in the source branch.  If you want to make the\n"
+"target branch's tags match the source branch, then in the target branch do\n"
+"``bzr tag --force -r revid:REVISION_ID CONFLICTING_TAG`` for each of the\n"
+"CONFLICTING_TAGs, where REVISION_ID comes from the list of tags in the "
+"source\n"
+"branch.  You need not call \"bzr resolve\" after doing this.  To resolve in\n"
+"favor of the target branch, you need to similarly use ``tag --force`` in "
+"the\n"
+"source branch.  (Note that pulling or pushing using --overwrite will "
+"overwrite\n"
+"all tags as well.)"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:172
+msgid ""
+"Duplicate paths\n"
+"---------------"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:177
+msgid "  Conflict adding file FILE.  Moved existing file to FILE.moved."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:179
+msgid ""
+"Sometimes Bazaar will attempt to create a file using a pathname that has\n"
+"already been used.  The existing file will be renamed to \"FILE.moved\".  "
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:187
+msgid ""
+"* ``--action=take-this`` will issue ``bzr rm FILE ; bzr mv FILE.moved "
+"FILE``,\n"
+"* ``--action=take-other`` will issue ``bzr rm FILE.moved``,\n"
+"* ``--action=done`` will just mark the conflict as resolved."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:191
+msgid ""
+"Note that you must get rid of FILE.moved before using ``--action=done``."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:195
+msgid ""
+"Unversioned parent\n"
+"------------------"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:200
+msgid "    Conflict because FILE is not versioned, but has versioned children."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:202
+msgid ""
+"Sometimes Bazaar will attempt to create a file whose parent directory is "
+"not\n"
+"versioned.  This happens when the directory has been deleted in the target,\n"
+"but has a new child in the source, or vice versa.  In this situation, "
+"Bazaar\n"
+"will version the parent directory as well.  Resolving this issue depends\n"
+"very much on the particular scenario.  You may wish to rename or delete "
+"either\n"
+"the file or the directory.  When you are satisfied, you can run \"bzr "
+"resolve\n"
+"FILE\" to mark the conflict as resolved."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:210
+msgid ""
+"Missing parent\n"
+"--------------"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:215
+msgid "  Conflict adding files to FILE.  Created directory."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:217
+msgid ""
+"This happens when a directory has been deleted in the target, but has new\n"
+"children in the source.  This is similar to the \"unversioned parent\" "
+"conflict,\n"
+"except that the parent directory does not *exist*, instead of just being\n"
+"unversioned.  In this situation, Bazaar will create the missing parent.\n"
+"Resolving this issue depends very much on the particular scenario."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:223
+msgid ""
+"To resolve that kind of conflict, you should either remove or rename the\n"
+"children or the directory or a combination of both."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:228
+msgid ""
+"* ``--action=take-this`` will issue ``bzr rm directory`` including the\n"
+"  children,\n"
+"* ``--action=take-other`` will acknowledge Bazaar choice to keep the "
+"children\n"
+"  and restoring the directory,\n"
+"* ``--action=done`` will just mark the conflict as resolved."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:236
+msgid ""
+"Deleting parent\n"
+"---------------"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:241
+msgid "  Conflict: can't delete DIR because it is not empty.  Not deleting."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:243
+msgid ""
+"This is the opposite of \"missing parent\".  A directory is deleted in the\n"
+"source, but has new children in the target (either because a directory\n"
+"deletion is merged or because the merge introduce new children).  Bazaar\n"
+"will retain the directory.  Resolving this issue depends very much on the\n"
+"particular scenario."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:254
+msgid ""
+"* ``--action=take-this`` will acknowledge Bazaar choice to keep the "
+"directory,"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:256
+msgid ""
+"* ``--action=take-other`` will issue ``bzr rm directory`` including the \n"
+"  children,"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:259
+msgid "* ``--action=done`` will just mark the conflict as resolved."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:261
+msgid ""
+"Note that when merging a directory deletion, if unversioned files are\n"
+"present, they become potential orphans has they don't have a directory\n"
+"parent anymore."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:265
+msgid ""
+"Handling such orphans, *before* the conflict is created, is controlled by\n"
+"setting the ``bzr.transform.orphan_policy`` configuration option."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:268
+msgid "There are two possible values for this option:"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:270
+msgid ""
+"* ``conflict`` (the default): will leave the orphans in place and\n"
+"  generate a conflicts,"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:273
+msgid ""
+"* ``move``: will move the orphans to a ``bzr-orphans`` directory at the "
+"root\n"
+"  of the working tree with names like ``<file>.~#~``."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:278
+msgid ""
+"Path conflict\n"
+"-------------"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:283
+msgid "  Path conflict: PATH1 / PATH2"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:285
+msgid ""
+"This happens when the source and target have each modified the name or "
+"parent\n"
+"directory of a file.  Bazaar will use the path elements from the source."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:288
+msgid ""
+"To resolve that kind of conflict, you just have to decide what name should "
+"be\n"
+"retained for the file involved."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:293
+msgid ""
+"* ``--action=take-this`` will revert Bazaar choice and keep ``PATH1`` by\n"
+"  issuing ``bzr mv PATH2 PATH1``,\n"
+"* ``--action=take-other`` will acknowledge Bazaar choice of keeping "
+"``PATH2``,\n"
+"* ``--action=done`` will just mark the conflict as resolved."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:300
+msgid ""
+"Parent loop\n"
+"-----------"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:305
+msgid "  Conflict moving FILE into DIRECTORY.  Cancelled move."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:307
+msgid ""
+"This happens when the source and the target have each moved directories, so\n"
+"that, if the change could be applied, a directory would be contained by "
+"itself.\n"
+"For example::"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:311
+msgid ""
+"  $ bzr init\n"
+"  $ bzr mkdir white\n"
+"  $ bzr mkdir black\n"
+"  $ bzr commit -m \"BASE\"\n"
+"  $ bzr branch . ../other\n"
+"  $ bzr mv white black\n"
+"  $ bzr commit -m \"THIS\"\n"
+"  $ bzr mv ../other/black ../other/white\n"
+"  $ bzr commit ../other -m \"OTHER\"\n"
+"  $ bzr merge ../other"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:322
+msgid ""
+"In this situation, Bazaar will cancel the move, and leave ``white`` in\n"
+"``black``.  To resolve that kind of conflict, you just have to decide what\n"
+"name should be retained for the directories involved."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:328
+msgid ""
+"* ``--action=take-this`` will acknowledge Bazaar choice of leaving "
+"``white`` \n"
+"  in ``black``,\n"
+"* ``--action=take-other`` will revert Bazaar choice and move ``black`` in\n"
+"   ``white`` by issuing ``bzr mv black/white white ; bzr mv black white``,\n"
+"* ``--action=done`` will just mark the conflict as resolved."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:336
+msgid ""
+"Non-directory parent\n"
+"--------------------"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:341
+msgid ""
+"  Conflict: foo.new is not a directory, but has files in it.\n"
+"  Created directory."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:344
+msgid ""
+"This happens when one side has added files to a directory, and the other "
+"side\n"
+"has changed the directory into a file or symlink.  For example::"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:347
+msgid ""
+"  $ bzr init\n"
+"  $ bzr mkdir foo\n"
+"  $ bzr commit -m \"BASE\"\n"
+"  $ bzr branch . ../other\n"
+"  $ rmdir foo\n"
+"  $ touch foo\n"
+"  $ bzr commit -m \"THIS\"\n"
+"  $ bzr mkdir ../other/foo/bar\n"
+"  $ bzr commit ../other -m \"OTHER\"\n"
+"  $ bzr merge ../other"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:358
+msgid ""
+"To resolve that kind of conflict, you have to decide what name should be\n"
+"retained for the file, directory or symlink involved."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:363
+msgid ""
+"* ``--action=take-this`` will issue ``bzr rm --force foo.new`` and \n"
+"  ``bzr add foo``,\n"
+"* ``--action=take-other`` will issue ``bzr rm --force foo`` and \n"
+"  ``bzr mv foo.new foo``,\n"
+"* ``--action=done`` will just mark the conflict as resolved."
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:371
+msgid ""
+"MalformedTransform\n"
+"------------------"
+msgstr ""
+
+#: en/help_topics/conflict-types.txt:374
+msgid ""
+"It is possible (though very rare) for Bazaar to raise a MalformedTransform\n"
+"exception.  This means that Bazaar encountered a filesystem conflict that it "
+"was\n"
+"unable to resolve.  This usually indicates a bug.  Please let us know if "
+"you\n"
+"encounter this.  Our bug tracker is at https://launchpad.net/bzr/+bugs\n"
+msgstr ""
+
+#: en/help_topics/content-filters.txt:1
+msgid ""
+"Content Filters\n"
+"==============="
+msgstr ""
+
+#: en/help_topics/content-filters.txt:4
+msgid ""
+"Content formats\n"
+"---------------"
+msgstr ""
+
+#: en/help_topics/content-filters.txt:7
+msgid ""
+"Bazaar's content filtering allows you to store files in a different\n"
+"format from the copy in your working tree.  This lets you, or your\n"
+"co-developers, use Windows development tools that expect CRLF files\n"
+"on projects that use other line-ending conventions. Among other things,\n"
+"content filters also let Unix developers more easily work on projects\n"
+"using Windows line-ending conventions, keyword expansion/compression,\n"
+"and trailing spaces on lines in text files to be implicitly stripped\n"
+"when committed."
+msgstr ""
+
+#: en/help_topics/content-filters.txt:16
+msgid "To generalize, there are two content formats supported by Bazaar:"
+msgstr ""
+
+#: en/help_topics/content-filters.txt:18
+msgid ""
+"* a canonical format - how files are stored internally\n"
+"* a convenience format - how files are created in a working tree."
+msgstr ""
+
+#: en/help_topics/content-filters.txt:21
+msgid ""
+"\n"
+"Format conversion\n"
+"-----------------"
+msgstr ""
+
+#: en/help_topics/content-filters.txt:25
+msgid ""
+"The conversion between these formats is done by content filters.\n"
+"A content filter has two parts:"
+msgstr ""
+
+#: en/help_topics/content-filters.txt:28
+msgid ""
+"* a read converter - converts from convenience to canonical format\n"
+"* a write converter - converts from canonical to convenience format."
+msgstr ""
+
+#: en/help_topics/content-filters.txt:31
+msgid ""
+"Many of these converters will provide *round-trip* conversion,\n"
+"i.e. applying the read converter followed by the write converter\n"
+"gives back the original content. However, others may provide an\n"
+"asymmetric conversion. For example, a read converter might strip\n"
+"trailing whitespace off lines in source code while the matching\n"
+"write converter might pass content through unchanged."
+msgstr ""
+
+#: en/help_topics/content-filters.txt:38
+msgid ""
+"\n"
+"Enabling content filters\n"
+"------------------------"
+msgstr ""
+
+#: en/help_topics/content-filters.txt:42
+msgid ""
+"Content filters are typically provided by plugins, so the first step\n"
+"in using them is to install the relevant plugins and read their\n"
+"documentation. Some plugins may be very specific about which files\n"
+"they filter, e.g. only files ending in ``.java`` or ``.php``.\n"
+"In other cases, the plugin may leave it in the user's hands to\n"
+"define which files are to be filtered. This is typically done\n"
+"using rule-based preferences. See ``bzr help rules`` for general\n"
+"information about defining these."
+msgstr ""
+
+#: en/help_topics/content-filters.txt:51
+msgid ""
+"\n"
+"Impact on commands\n"
+"------------------"
+msgstr ""
+
+#: en/help_topics/content-filters.txt:55
+msgid ""
+"Read converters are only applied to commands that read content from\n"
+"a working tree, e.g. status, diff and commit. For example, ``bzr diff``\n"
+"will apply read converters to files in the working tree, then compare\n"
+"the results to the content last committed."
+msgstr ""
+
+#: en/help_topics/content-filters.txt:60
+msgid ""
+"Write converters are only applied by commands that **create files in a\n"
+"working tree**, e.g. branch, checkout, update. If you wish to see the\n"
+"canonical format of a file or tree, use ``bzr cat`` or ``bzr export``\n"
+"respectively."
+msgstr ""
+
+#: en/help_topics/content-filters.txt:65
+msgid ""
+"Note: ``bzr commit`` does not implicitly apply write converters after\n"
+"comitting files. If this makes sense for a given plugin providing\n"
+"a content filter, the plugin can usually achieve this effect by using a\n"
+"``start_commit`` or ``post_commit`` hook say. See :doc:`hooks-help`\n"
+"for more information on hooks."
+msgstr ""
+
+#: en/help_topics/content-filters.txt:71
+msgid ""
+"\n"
+"Refreshing your working tree\n"
+"----------------------------"
+msgstr ""
+
+#: en/help_topics/content-filters.txt:75
+msgid ""
+"For performance reasons, Bazaar caches the timestamps of files in\n"
+"a working tree, and assumes files are unchanged if their timestamps\n"
+"match the cached values. As a consequence, there are times when\n"
+"you may need to explicitly ask for content filtering to be reapplied\n"
+"in one or both directions, e.g. after installing or reconfiguring\n"
+"plugins providing it."
+msgstr ""
+
+#: en/help_topics/content-filters.txt:82
+msgid "Here are some general guidelines for doing this:"
+msgstr ""
+
+#: en/help_topics/content-filters.txt:84
+msgid ""
+" * To reapply read converters, ``touch`` files, i.e. update their\n"
+"   timestamp. Operations like ``bzr status`` should then reapply the\n"
+"   relevant read converters and compare the end result with the\n"
+"   canonical format."
+msgstr ""
+
+#: en/help_topics/content-filters.txt:89
+msgid ""
+" * To reapply write converters, ensure there are no local changes,\n"
+"   delete the relevant files and run ``bzr revert`` on those files."
+msgstr ""
+
+#: en/help_topics/content-filters.txt:92
+msgid ""
+"Note: In the future, it is likely that additional options will be added\n"
+"to commands to make this refreshing process faster and safer.\n"
+msgstr ""
+
+#: en/help_topics/current-formats.txt:1
+msgid "Current Storage Formats"
+msgstr ""
+
+#: en/help_topics/current-formats.txt:3
+msgid ""
+":2a:\n"
+"    (native) (default) First format for bzr 2.0 series. Uses group-\n"
+"    compress storage. Provides rich roots which are a one-way\n"
+"    transition."
+msgstr ""
+
+#: en/help_topics/current-formats.txt:8
+msgid ""
+":pack-0.92:\n"
+"    (native) New in 0.92: Pack-based format with data compatible with\n"
+"    dirstate-tags format repositories. Interoperates with bzr\n"
+"    repositories before 0.92 but cannot be read by bzr < 0.92."
+msgstr ""
+
+#: en/help_topics/current-formats.txt:13
+msgid ""
+":1.14:\n"
+"    (native) A working-tree format that supports content filtering."
+msgstr ""
+
+#: en/help_topics/current-formats.txt:16
+msgid ""
+":1.14-rich-root:\n"
+"    (native) A variant of 1.14 that supports rich-root data (needed\n"
+"    for bzr-svn and bzr-git)."
+msgstr ""
+
+#: en/help_topics/current-formats.txt:20
+msgid ""
+"\n"
+"See :doc:`formats-help` for more about storage formats."
+msgstr ""
+
+#: en/help_topics/debug-flags.txt:1
+msgid ""
+"Debug Flags\n"
+"==========="
+msgstr ""
+
+#: en/help_topics/debug-flags.txt:4
+msgid ""
+"These flags can be passed on the bzr command line or (without the ``-D``\n"
+"prefix) put in the ``debug_flags`` variable in ``bazaar.conf``."
+msgstr ""
+
+#: en/help_topics/debug-flags.txt:7
+msgid ""
+"-Dauth            Trace authentication sections used.\n"
+"-Dbytes           Print out how many bytes were transferred\n"
+"-Ddirstate        Trace dirstate activity (verbose!)\n"
+"-Derror           Instead of normal error handling, always print a "
+"traceback\n"
+"                  on error.\n"
+"-Devil            Capture call sites that do expensive or badly-scaling\n"
+"                  operations.\n"
+"-Dfetch           Trace history copying between repositories.\n"
+"-Dfilters         Emit information for debugging content filtering.\n"
+"-Dforceinvdeltas  Force use of inventory deltas during generic streaming "
+"fetch.\n"
+"-Dgraph           Trace graph traversal.\n"
+"-Dhashcache       Log every time a working file is read to determine its "
+"hash.\n"
+"-Dhooks           Trace hook execution.\n"
+"-Dhpss            Trace smart protocol requests and responses.\n"
+"-Dhpssdetail      More hpss details.\n"
+"-Dhpssvfs         Traceback on vfs access to Remote objects.\n"
+"-Dhttp            Trace http connections, requests and responses.\n"
+"-Dindex           Trace major index operations.\n"
+"-Dknit            Trace knit operations.\n"
+"-Dlock            Trace when lockdir locks are taken or released.\n"
+"-Dprogress        Trace progress bar operations.\n"
+"-Dmem_dump        Dump memory to a file upon an out of memory error.\n"
+"-Dmerge           Emit information for debugging merges.\n"
+"-Dno_apport       Don't use apport to report crashes.\n"
+"-Dno_activity \t  Don't show transport activity indicator in progress bar.\n"
+"-Dpack            Emit information about pack operations.\n"
+"-Drelock          Emit a message every time a branch or repository object "
+"is\n"
+"                  unlocked then relocked the same way.\n"
+"-Dsftp            Trace SFTP internals.\n"
+"-Dstatic_tuple    Error when a tuple is used where a StaticTuple is "
+"expected\n"
+"-Dstream          Trace fetch streams.\n"
+"-Dstrict_locks    Trace when OS locks are potentially used in a non-"
+"portable\n"
+"                  manner.\n"
+"-Dunlock          Some errors during unlock are treated as warnings.\n"
+"-DIDS_never       Never use InterDifferingSerializer when fetching.\n"
+"-DIDS_always      Always use InterDifferingSerializer to fetch if "
+"appropriate\n"
+"                  for the format, even for non-local fetches.\n"
+msgstr ""
+
+#: en/help_topics/diverged-branches.txt:1
+msgid ""
+"Diverged Branches\n"
+"================="
+msgstr ""
+
+#: en/help_topics/diverged-branches.txt:4
+msgid ""
+"When Bazaar tries to push one branch onto another, it requires that the\n"
+"destination branch must be ready to receive the source branch.  If this "
+"isn't\n"
+"the case, then we say that the branches have ``diverged``.  Branches are\n"
+"considered diverged if the destination branch's most recent commit is one "
+"that\n"
+"has not been merged (directly or indirectly) by the source branch.  To "
+"recover\n"
+"from diverged branches, one must merge the missing revisions into the "
+"source\n"
+"branch."
+msgstr ""
+
+#: en/help_topics/diverged-branches.txt:12
+msgid ""
+"This situation commonly arises when using a centralized workflow with local\n"
+"commits.  If someone else has committed new work to the mainline since your\n"
+"last pull and you have local commits that have not yet been pushed to the\n"
+"mainline, then your local branch and the mainline have diverged."
+msgstr ""
+
+#: en/help_topics/diverged-branches.txt:17
+msgid ""
+"Discovering What Has Diverged\n"
+"-----------------------------"
+msgstr ""
+
+#: en/help_topics/diverged-branches.txt:20
+msgid ""
+"The ``bzr missing`` command is used to find out what revisions are in "
+"another\n"
+"branch that are not present in the current branch, and vice-versa.  It shows "
+"a\n"
+"summary of  which extra revisions exist in each branch.  If you want to see "
+"the\n"
+"precise effects of those revisions, you can use ``bzr diff --"
+"old=other_branch``\n"
+"to show the differences between other_branch and your current branch."
+msgstr ""
+
+#: en/help_topics/diverged-branches.txt:26
+msgid ""
+"A Solution\n"
+"----------"
+msgstr ""
+
+#: en/help_topics/diverged-branches.txt:29
+msgid ""
+"The solution is to merge the revisions from the mainline into your local\n"
+"branch.  To do so, use ``bzr merge`` to get the new revisions from the\n"
+"mainline.  This merge may result in conflicts if the other developer's "
+"changes\n"
+"overlap with your changes.  These conflicts should be resolved before\n"
+"continuing. After any conflicts have been resolved, or even if there were "
+"no\n"
+"conflicts, Bazaar requires that you explicitly commit these new revisions\n"
+"to your local branch.  This requirement gives you an opportunity to test "
+"the\n"
+"resulting working tree for correctness, since the merged revisions could "
+"have\n"
+"made arbitrary changes.  After testing, you should commit the merge using\n"
+"``bzr commit``.  This clears up the diverged branches situation.  Your "
+"local\n"
+"branch can now be pushed to the mainline.\n"
+msgstr ""
+
+#: en/help_topics/eol.txt:1
+msgid ""
+"End of Line Conversion\n"
+"======================"
+msgstr ""
+
+#: en/help_topics/eol.txt:4
+msgid ""
+"EOL conversion is provided as a content filter where Bazaar internally\n"
+"stores a canonical format but outputs a convenience format. See\n"
+"``bzr help content-filters`` for general information about using these."
+msgstr ""
+
+#: en/help_topics/eol.txt:8
+msgid ""
+"Note: Content filtering is only supported in recently added formats,\n"
+"e.g. 1.14. Be sure that both the repository *and* the branch are\n"
+"in a recent format. (Just setting the format on the repository\n"
+"is not enough.) If content filtering does not appear to be working, use\n"
+"'bzr info -v' to confirm that the branch is using \"Working tree format 5\"\n"
+"or later."
+msgstr ""
+
+#: en/help_topics/eol.txt:15
+msgid ""
+"EOL conversion needs to be enabled for selected file patterns using\n"
+"rules. See ``bzr help rules`` for general information on defining rules.\n"
+"Currently, rules are only supported in $BZR_HOME/.bazaar/rules (or\n"
+"%BZR_HOME%/bazaar/2.0/rules on Windows). Branch specific rules will be\n"
+"supported in a future verison of Bazaar."
+msgstr ""
+
+#: en/help_topics/eol.txt:21
+msgid ""
+"To configure which files to filter, set ``eol`` to one of the values below.\n"
+"(If a value is not set, ``exact`` is the default.)"
+msgstr ""
+
+#: en/help_topics/eol.txt:24
+msgid ""
+" ========== ===================================== ======================\n"
+" Value      Checkout end-of-lines as              Commit end-of-lines as\n"
+" ========== ===================================== ======================\n"
+" ``native`` ``crlf`` on Windows, ``lf`` otherwise ``lf``\n"
+" ---------- ------------------------------------- ----------------------\n"
+" ``lf``     ``lf``                                ``lf``\n"
+" ---------- ------------------------------------- ----------------------\n"
+" ``crlf``   ``crlf``                              ``lf``\n"
+" ---------- ------------------------------------- ----------------------\n"
+" ``exact``  No conversion                         Exactly as in file\n"
+" ========== ===================================== ======================"
+msgstr ""
+
+#: en/help_topics/eol.txt:36
+msgid ""
+"Note: For safety reasons, no conversion is applied to any file where a null\n"
+"byte is detected in the file."
+msgstr ""
+
+#: en/help_topics/eol.txt:39
+msgid ""
+"For users working on a cross-platform project, here is a suggested rule\n"
+"to use as a starting point::"
+msgstr ""
+
+#: en/help_topics/eol.txt:42
+msgid ""
+"  [name *]\n"
+"  eol = native"
+msgstr ""
+
+#: en/help_topics/eol.txt:45
+msgid ""
+"If you have binary files that do not contain a null byte though, be\n"
+"sure to add ``eol = exact`` rules for those as well. You can do this\n"
+"by giving more explicit patterns earlier in the rules file. For example::"
+msgstr ""
+
+#: en/help_topics/eol.txt:49
+msgid ""
+"  [name *.png]\n"
+"  eol = exact"
+msgstr ""
+
+#: en/help_topics/eol.txt:55
+msgid ""
+"If your working tree is on a network drive shared by users on different\n"
+"operating systems, you typically want to force certain conventions for\n"
+"certain files. In that way, if a file is created with the wrong line\n"
+"endings or line endings get mixed during editing, it gets committed\n"
+"correctly and gets checked out correctly. For example::"
+msgstr ""
+
+#: en/help_topics/eol.txt:61
+msgid ""
+"  [name *.bat]\n"
+"  eol = crlf"
+msgstr ""
+
+#: en/help_topics/eol.txt:64
+msgid ""
+"  [name *.sh]\n"
+"  eol = lf"
+msgstr ""
+
+#: en/help_topics/eol.txt:70
+msgid ""
+"If you take the care to create files with their required endings, you can\n"
+"achieve *almost* the same thing by using ``eol = exact``. It is slightly\n"
+"safer to use ``lf`` and ``crlf`` though because edits accidentally\n"
+"introducing mixed line endings will be corrected during commit for files\n"
+"with those settings."
+msgstr ""
+
+#: en/help_topics/eol.txt:76
+msgid ""
+"If you have sample test data that deliberately has text files with mixed\n"
+"newline conventions, you can ask for those to be left alone like this::"
+msgstr ""
+
+#: en/help_topics/eol.txt:79
+msgid ""
+"  [name test_data/]\n"
+"  eol = exact"
+msgstr ""
+
+#: en/help_topics/eol.txt:85
+msgid ""
+"Note that ``exact`` does not imply the file is binary but it does mean\n"
+"that no conversion of end-of-lines will be done. (Bazaar currently relies\n"
+"of content analysis to detect binary files for commands like ``diff``.\n"
+"In the future, a ``binary = true`` rule may be added but it is not\n"
+"supported yet.)"
+msgstr ""
+
+#: en/help_topics/eol.txt:91
+msgid ""
+"If you have an existing repository with text files already stored using\n"
+"Windows newline conventions (``crlf``), then you may want to keep using "
+"that\n"
+"convention in the repository. Forcing certain files to this convention\n"
+"may also help users who do not have rules configured. To do this, set\n"
+"``eol`` to one of the values below."
+msgstr ""
+
+#: en/help_topics/eol.txt:97
+msgid ""
+" ============================ ======================== "
+"======================\n"
+" Value                        Checkout end-of-lines as Commit end-of-lines "
+"as\n"
+" ============================ ======================== "
+"======================\n"
+" ``native-with-crlf-in-repo`` ``crlf`` on Windows,     ``crlf``\n"
+"                              ``lf`` otherwise\n"
+" ---------------------------- ------------------------ "
+"----------------------\n"
+" ``lf-with-crlf-in-repo``     ``lf``                   ``crlf``\n"
+" ---------------------------- ------------------------ "
+"----------------------\n"
+" ``crlf-with-crlf-in-repo``   ``crlf``                 ``crlf``\n"
+" ============================ ======================== ======================"
+msgstr ""
+
+#: en/help_topics/eol.txt:108
+msgid ""
+"For users working on an existing project that uses Windows newline\n"
+"conventions in their Bazaar repository, this rule is suggested as a\n"
+"starting point::"
+msgstr ""
+
+#: en/help_topics/eol.txt:112
+msgid ""
+"  [name *]\n"
+"  eol = native-with-crlf-in-repo"
+msgstr ""
+
+#: en/help_topics/eol.txt:115
+msgid ""
+"For new projects, it is recommended that end-of-lines be stored as ``lf``\n"
+"and that users stick to the basic settings, i.e. ``native``, ``lf``,\n"
+"``crlf`` and ``exact``."
+msgstr ""
+
+#: en/help_topics/eol.txt:119
+msgid ""
+"Note: Bazaar's EOL conversion will convert the content of files but\n"
+"never reject files because a given line ending or mixed line endings\n"
+"are found. A precommit hook should be used if you wish to validate\n"
+"(and not just convert) content before committing.\n"
+msgstr ""
+
+#: en/help_topics/hidden-commands.txt:1
+msgid ""
+"added                  List files added in working tree.\n"
+"ancestry               List all revisions merged into this branch.\n"
+"assert-fail            Test reporting of assertion failures\n"
+"bundle-info            Output interesting stats about a bundle\n"
+"bundle-revisions       Create a merge-directive for submitting changes.\n"
+"cat-revision           Write out metadata for a revision.\n"
+"dpush                  Push into a different VCS without any custom bzr\n"
+"                       metadata.\n"
+"dump-btree             Dump the contents of a btree index file to stdout.\n"
+"export-pot             Export command helps and error messages in po "
+"format.\n"
+"file-id                Print file_id of a particular file or directory.\n"
+"file-path              Print path of file_ids to a file or directory.\n"
+"find-merge-base        Find and print a base revision for merging two "
+"branches.\n"
+"hooks                  Show hooks.\n"
+"inventory              Show inventory of the current working copy or a\n"
+"                       revision.\n"
+"is-ignored             Check if a path is ignored. [qbzr]\n"
+"is-versioned           Check if a path is versioned. [qbzr]\n"
+"local-time-offset      Show the offset in seconds from GMT to local time.\n"
+"lookup-revision        Lookup the revision-id from a revision-number\n"
+"merge-directive        Generate a merge directive for auto-merge tools.\n"
+"modified               List files modified in working tree.\n"
+"qcheckout-ala-explorer Checkout a branch. The checkout is always "
+"lightweight.\n"
+"                       [explorer]\n"
+"qhelp                  Shows a help window [qbzr]\n"
+"qmain                  The QBzr main application. [qbzr]\n"
+"qsubprocess            Run some bzr command as subprocess. [qbzr]\n"
+"re-sign                Create a digital signature for an existing revision.\n"
+"reference              list, view and set branch locations for nested "
+"trees.\n"
+"relpath                Show path of a file relative to root\n"
+"repair-workingtree     Reset the working tree state file.\n"
+"revision-history       Display the list of revision ids on a branch.\n"
+"revision-info          Show revision number and revision id for a given\n"
+"                       revision identifier.\n"
+"rocks                  Statement of optimism.\n"
+"selftest               Run internal test suite.\n"
+"shell-complete         Show appropriate completions for context.\n"
+"test-script            Run a shell-like test from a file.\n"
+"touching-revisions     Return revision-ids which affected a particular "
+"file.\n"
+"unknowns               List unknown files.\n"
+"wait-until-signalled   Test helper for\n"
+"                       test_start_and_stop_bzr_subprocess_send_signal.\n"
+msgstr ""
+
+#: en/help_topics/hooks.txt:1
+msgid ""
+"\n"
+"Hooks\n"
+"====="
+msgstr ""
+
+#: en/help_topics/hooks.txt:5
+msgid ""
+"Introduction\n"
+"------------"
+msgstr ""
+
+#: en/help_topics/hooks.txt:8
+msgid "A hook of type *xxx* of class *yyy* needs to be registered using::"
+msgstr ""
+
+#: en/help_topics/hooks.txt:10
+msgid "  yyy.hooks.install_named_hook(\"xxx\", ...)"
+msgstr ""
+
+#: en/help_topics/hooks.txt:12
+msgid ""
+"See :doc:`Using hooks<../user-guide/hooks>` in the User Guide for examples."
+msgstr ""
+
+#: en/help_topics/hooks.txt:14
+msgid ""
+"The class that contains each hook is given before the hooks it supplies. "
+"For\n"
+"instance, BranchHooks as the class is the hooks class for\n"
+"`bzrlib.branch.Branch.hooks`."
+msgstr ""
+
+#: en/help_topics/hooks.txt:18
+msgid ""
+"Each description also indicates whether the hook runs on the client (the\n"
+"machine where bzr was invoked) or the server (the machine addressed by\n"
+"the branch URL).  These may be, but are not necessarily, the same machine."
+msgstr ""
+
+#: en/help_topics/hooks.txt:22
+msgid ""
+"Plugins (including hooks) are run on the server if all of these is true:"
+msgstr ""
+
+#: en/help_topics/hooks.txt:24
+msgid ""
+"  * The connection is via a smart server (accessed with a URL starting with\n"
+"    \"bzr://\", \"bzr+ssh://\" or \"bzr+http://\", or accessed via a "
+"\"http://\"\n"
+"    URL when a smart server is available via HTTP)."
+msgstr ""
+
+#: en/help_topics/hooks.txt:28
+msgid ""
+"  * The hook is either server specific or part of general infrastructure "
+"rather\n"
+"    than client specific code (such as commit)."
+msgstr ""
+
+#: en/help_topics/hooks.txt:31
+msgid ""
+"\n"
+"BranchHooks\n"
+"-----------"
+msgstr ""
+
+#: en/help_topics/hooks.txt:35
+msgid ""
+"automatic_tag_name\n"
+"~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:38
+msgid "Introduced in: 2.2"
+msgstr ""
+
+#: en/help_topics/hooks.txt:40
+msgid ""
+"Called to determine an automatic tag name for a revision.\n"
+"automatic_tag_name is called with (branch, revision_id) and should\n"
+"return a tag name or None if no tag name could be determined. The\n"
+"first non-None tag name returned will be used."
+msgstr ""
+
+#: en/help_topics/hooks.txt:45
+msgid ""
+"open\n"
+"~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:48
+msgid "Introduced in: 1.8"
+msgstr ""
+
+#: en/help_topics/hooks.txt:50
+msgid ""
+"Called with the Branch object that has been opened after a branch is\n"
+"opened."
+msgstr ""
+
+#: en/help_topics/hooks.txt:53
+msgid ""
+"post_branch_init\n"
+"~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:58
+msgid ""
+"Called after new branch initialization completes. post_branch_init is\n"
+"called with a bzrlib.branch.BranchInitHookParams. Note that init,\n"
+"branch and checkout (both heavyweight and lightweight) will all\n"
+"trigger this hook."
+msgstr ""
+
+#: en/help_topics/hooks.txt:63
+msgid ""
+"post_change_branch_tip\n"
+"~~~~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:66
+msgid "Introduced in: 1.4"
+msgstr ""
+
+#: en/help_topics/hooks.txt:68
+msgid ""
+"Called in bzr client and server after a change to the tip of a branch\n"
+"is made. post_change_branch_tip is called with a\n"
+"bzrlib.branch.ChangeBranchTipParams. Note that push, pull, commit,\n"
+"uncommit will all trigger this hook."
+msgstr ""
+
+#: en/help_topics/hooks.txt:73
+msgid ""
+"post_commit\n"
+"~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:76
+msgid "Introduced in: 0.15"
+msgstr ""
+
+#: en/help_topics/hooks.txt:78
+msgid ""
+"Called in the bzr client after a commit has completed. post_commit is\n"
+"called with (local, master, old_revno, old_revid, new_revno,\n"
+"new_revid). old_revid is NULL_REVISION for the first commit to a\n"
+"branch."
+msgstr ""
+
+#: en/help_topics/hooks.txt:83
+msgid ""
+"post_pull\n"
+"~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:88
+msgid ""
+"Called after a pull operation completes. post_pull is called with a\n"
+"bzrlib.branch.PullResult object and only runs in the bzr client."
+msgstr ""
+
+#: en/help_topics/hooks.txt:91
+msgid ""
+"post_push\n"
+"~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:96
+msgid ""
+"Called after a push operation completes. post_push is called with a\n"
+"bzrlib.branch.BranchPushResult object and only runs in the bzr client."
+msgstr ""
+
+#: en/help_topics/hooks.txt:99
+msgid ""
+"post_switch\n"
+"~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:104
+msgid ""
+"Called after a checkout switches branch. post_switch is called with a\n"
+"bzrlib.branch.SwitchHookParams."
+msgstr ""
+
+#: en/help_topics/hooks.txt:107
+msgid ""
+"post_uncommit\n"
+"~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:112
+msgid ""
+"Called in the bzr client after an uncommit completes. post_uncommit is\n"
+"called with (local, master, old_revno, old_revid, new_revno,\n"
+"new_revid) where local is the local branch or None, master is the\n"
+"target branch, and an empty branch receives new_revno of 0, new_revid\n"
+"of None."
+msgstr ""
+
+#: en/help_topics/hooks.txt:118
+msgid ""
+"pre_change_branch_tip\n"
+"~~~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:121
+msgid "Introduced in: 1.6"
+msgstr ""
+
+#: en/help_topics/hooks.txt:123
+msgid ""
+"Called in bzr client and server before a change to the tip of a branch\n"
+"is made. pre_change_branch_tip is called with a\n"
+"bzrlib.branch.ChangeBranchTipParams. Note that push, pull, commit,\n"
+"uncommit will all trigger this hook."
+msgstr ""
+
+#: en/help_topics/hooks.txt:128
+msgid ""
+"pre_commit\n"
+"~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:131
+msgid "Introduced in: 0.91"
+msgstr ""
+
+#: en/help_topics/hooks.txt:133
+msgid ""
+"Called after a commit is calculated but before it is completed.\n"
+"pre_commit is called with (local, master, old_revno, old_revid,\n"
+"future_revno, future_revid, tree_delta, future_tree). old_revid is\n"
+"NULL_REVISION for the first commit to a branch, tree_delta is a\n"
+"TreeDelta object describing changes from the basis revision. hooks\n"
+"MUST NOT modify this delta.  future_tree is an in-memory tree obtained\n"
+"from CommitBuilder.revision_tree() and hooks MUST NOT modify this\n"
+"tree."
+msgstr ""
+
+#: en/help_topics/hooks.txt:142
+msgid ""
+"set_rh\n"
+"~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:147
+msgid ""
+"Invoked whenever the revision history has been set via\n"
+"set_revision_history. The api signature is (branch, revision_history),\n"
+"and the branch will be write-locked. The set_rh hook can be expensive\n"
+"for bzr to trigger, a better hook to use is\n"
+"Branch.post_change_branch_tip."
+msgstr ""
+
+#: en/help_topics/hooks.txt:153
+msgid ""
+"transform_fallback_location\n"
+"~~~~~~~~~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:156
+msgid "Introduced in: 1.9"
+msgstr ""
+
+#: en/help_topics/hooks.txt:158
+msgid ""
+"Called when a stacked branch is activating its fallback locations.\n"
+"transform_fallback_location is called with (branch, url), and should\n"
+"return a new url. Returning the same url allows it to be used as-is,\n"
+"returning a different one can be used to cause the branch to stack on\n"
+"a closer copy of that fallback_location. Note that the branch cannot\n"
+"have history accessing methods called on it during this hook because\n"
+"the fallback locations have not been activated. When there are\n"
+"multiple hooks installed for transform_fallback_location, all are\n"
+"called with the url returned from the previous hook.The order is\n"
+"however undefined."
+msgstr ""
+
+#: en/help_topics/hooks.txt:169
+msgid ""
+"BzrDirHooks\n"
+"-----------"
+msgstr ""
+
+#: en/help_topics/hooks.txt:172
+msgid ""
+"post_repo_init\n"
+"~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:177
+msgid ""
+"Invoked after a repository has been initialized. post_repo_init is\n"
+"called with a bzrlib.bzrdir.RepoInitHookParams."
+msgstr ""
+
+#: en/help_topics/hooks.txt:180
+msgid ""
+"pre_open\n"
+"~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:183
+msgid "Introduced in: 1.14"
+msgstr ""
+
+#: en/help_topics/hooks.txt:185
+msgid ""
+"Invoked before attempting to open a BzrDir with the transport that the\n"
+"open will use."
+msgstr ""
+
+#: en/help_topics/hooks.txt:188
+msgid ""
+"CommandHooks\n"
+"------------"
+msgstr ""
+
+#: en/help_topics/hooks.txt:191
+msgid ""
+"extend_command\n"
+"~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:194
+msgid "Introduced in: 1.13"
+msgstr ""
+
+#: en/help_topics/hooks.txt:196
+msgid ""
+"Called after creating a command object to allow modifications such as\n"
+"adding or removing options, docs etc. Called with the new\n"
+"bzrlib.commands.Command object."
+msgstr ""
+
+#: en/help_topics/hooks.txt:200
+msgid ""
+"get_command\n"
+"~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:203
+msgid "Introduced in: 1.17"
+msgstr ""
+
+#: en/help_topics/hooks.txt:205
+msgid ""
+"Called when creating a single command. Called with (cmd_or_None,\n"
+"command_name). get_command should either return the cmd_or_None\n"
+"parameter, or a replacement Command object that should be used for the\n"
+"command. Note that the Command.hooks hooks are core infrastructure.\n"
+"Many users will prefer to use bzrlib.commands.register_command or\n"
+"plugin_cmds.register_lazy."
+msgstr ""
+
+#: en/help_topics/hooks.txt:212
+msgid ""
+"get_missing_command\n"
+"~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:217
+msgid ""
+"Called when creating a single command if no command could be found.\n"
+"Called with (command_name). get_missing_command should either return\n"
+"None, or a Command object to be used for the command."
+msgstr ""
+
+#: en/help_topics/hooks.txt:221
+msgid ""
+"list_commands\n"
+"~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:226
+msgid ""
+"Called when enumerating commands. Called with a set of cmd_name\n"
+"strings for all the commands found so far. This set  is safe to mutate\n"
+"- e.g. to remove a command. list_commands should return the updated\n"
+"set of command names."
+msgstr ""
+
+#: en/help_topics/hooks.txt:231
+msgid ""
+"_ConfigHooks\n"
+"------------"
+msgstr ""
+
+#: en/help_topics/hooks.txt:234
+msgid ""
+"get\n"
+"~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:237
+msgid "Introduced in: 2.4"
+msgstr ""
+
+#: en/help_topics/hooks.txt:239
+msgid ""
+"Invoked when a config option is read. The signature is (stack, name,\n"
+"value)."
+msgstr ""
+
+#: en/help_topics/hooks.txt:242
+msgid ""
+"load\n"
+"~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:247
+msgid "Invoked when a config store is loaded. The signature is (store)."
+msgstr ""
+
+#: en/help_topics/hooks.txt:249
+msgid ""
+"remove\n"
+"~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:254
+msgid ""
+"Invoked when a config option is removed. The signature is (stack,\n"
+"name)."
+msgstr ""
+
+#: en/help_topics/hooks.txt:257
+msgid ""
+"save\n"
+"~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:262
+msgid "Invoked when a config store is saved. The signature is (store)."
+msgstr ""
+
+#: en/help_topics/hooks.txt:264
+msgid ""
+"set\n"
+"~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:269
+msgid ""
+"Invoked when a config option is set. The signature is (stack, name,\n"
+"value)."
+msgstr ""
+
+#: en/help_topics/hooks.txt:272
+msgid ""
+"InfoHooks\n"
+"---------"
+msgstr ""
+
+#: en/help_topics/hooks.txt:275
+msgid ""
+"repository\n"
+"~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:278
+msgid "Introduced in: 1.15"
+msgstr ""
+
+#: en/help_topics/hooks.txt:280
+msgid ""
+"Invoked when displaying the statistics for a repository. repository is\n"
+"called with a statistics dictionary as returned by the repository and\n"
+"a file-like object to write to."
+msgstr ""
+
+#: en/help_topics/hooks.txt:284
+msgid ""
+"LockHooks\n"
+"---------"
+msgstr ""
+
+#: en/help_topics/hooks.txt:287
+msgid ""
+"lock_acquired\n"
+"~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:292
+msgid "Called with a bzrlib.lock.LockResult when a physical lock is acquired."
+msgstr ""
+
+#: en/help_topics/hooks.txt:294
+msgid ""
+"lock_broken\n"
+"~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:299
+msgid "Called with a bzrlib.lock.LockResult when a physical lock is broken."
+msgstr ""
+
+#: en/help_topics/hooks.txt:301
+msgid ""
+"lock_released\n"
+"~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:306
+msgid "Called with a bzrlib.lock.LockResult when a physical lock is released."
+msgstr ""
+
+#: en/help_topics/hooks.txt:308
+msgid ""
+"MergeHooks\n"
+"----------"
+msgstr ""
+
+#: en/help_topics/hooks.txt:311
+msgid ""
+"merge_file_content\n"
+"~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:314
+msgid "Introduced in: 2.1"
+msgstr ""
+
+#: en/help_topics/hooks.txt:316
+msgid ""
+"Called with a bzrlib.merge.Merger object to create a per file merge\n"
+"object when starting a merge. Should return either None or a subclass\n"
+"of ``bzrlib.merge.AbstractPerFileMerger``. Such objects will then be\n"
+"called per file that needs to be merged (including when one side has\n"
+"deleted the file and the other has changed it). See the\n"
+"AbstractPerFileMerger API docs for details on how it is used by merge."
+msgstr ""
+
+#: en/help_topics/hooks.txt:323
+msgid ""
+"MergeDirectiveHooks\n"
+"-------------------"
+msgstr ""
+
+#: en/help_topics/hooks.txt:326
+msgid ""
+"merge_request_body\n"
+"~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:329
+msgid "Introduced in: 1.15.0"
+msgstr ""
+
+#: en/help_topics/hooks.txt:331
+msgid ""
+"Called with a MergeRequestBodyParams when a body is needed for a merge\n"
+"request.  Callbacks must return a body.  If more than one callback is\n"
+"registered, the output of one callback is provided to the next."
+msgstr ""
+
+#: en/help_topics/hooks.txt:335
+msgid ""
+"MessageEditorHooks\n"
+"------------------"
+msgstr ""
+
+#: en/help_topics/hooks.txt:338
+msgid ""
+"commit_message_template\n"
+"~~~~~~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:341
+msgid "Introduced in: 1.10"
+msgstr ""
+
+#: en/help_topics/hooks.txt:343
+msgid ""
+"Called when a commit message is being generated.\n"
+"commit_message_template is called with the bzrlib.commit.Commit object\n"
+"and the message that is known so far. commit_message_template must\n"
+"return a new message to use (which could be the same as it was given).\n"
+"When there are multiple hooks registered for commit_message_template,\n"
+"they are chained with the result from the first passed into the\n"
+"second, and so on."
+msgstr ""
+
+#: en/help_topics/hooks.txt:351
+msgid ""
+"set_commit_message\n"
+"~~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:356
+msgid ""
+"Set a fixed commit message. set_commit_message is called with the\n"
+"bzrlib.commit.Commit object (so you can also change e.g. revision\n"
+"properties by editing commit.builder._revprops) and the message so\n"
+"far. set_commit_message must return the message to use or None if it\n"
+"should use the message editor as normal."
+msgstr ""
+
+#: en/help_topics/hooks.txt:362
+msgid ""
+"MutableTreeHooks\n"
+"----------------"
+msgstr ""
+
+#: en/help_topics/hooks.txt:368
+msgid "Introduced in: 2.0"
+msgstr ""
+
+#: en/help_topics/hooks.txt:370
+msgid ""
+"Called after a commit is performed on a tree. The hook is called with\n"
+"a bzrlib.mutabletree.PostCommitHookParams object. The mutable tree the\n"
+"commit was performed on is available via the mutable_tree attribute of\n"
+"that object."
+msgstr ""
+
+#: en/help_topics/hooks.txt:375
+msgid ""
+"start_commit\n"
+"~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:380
+msgid ""
+"Called before a commit is performed on a tree. The start commit hook\n"
+"is able to change the tree before the commit takes place. start_commit\n"
+"is called with the bzrlib.mutabletree.MutableTree that the commit is\n"
+"being performed on."
+msgstr ""
+
+#: en/help_topics/hooks.txt:385
+msgid ""
+"SmartClientHooks\n"
+"----------------"
+msgstr ""
+
+#: en/help_topics/hooks.txt:388
+msgid ""
+"call\n"
+"~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:391
+msgid "Introduced in: unknown"
+msgstr ""
+
+#: en/help_topics/hooks.txt:393
+msgid ""
+"Called when the smart client is submitting a request to the smart\n"
+"server. Called with a bzrlib.smart.client.CallHookParams object.\n"
+"Streaming request bodies, and responses, are not accessible."
+msgstr ""
+
+#: en/help_topics/hooks.txt:397
+msgid ""
+"SmartServerHooks\n"
+"----------------"
+msgstr ""
+
+#: en/help_topics/hooks.txt:400
+msgid ""
+"server_exception\n"
+"~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:405
+msgid ""
+"Called by the bzr server when an exception occurs. server_exception is\n"
+"called with the sys.exc_info() tuple return true for the hook if the\n"
+"exception has been handled, in which case the server will exit\n"
+"normally."
+msgstr ""
+
+#: en/help_topics/hooks.txt:410
+msgid ""
+"server_started\n"
+"~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:413
+msgid "Introduced in: 0.16"
+msgstr ""
+
+#: en/help_topics/hooks.txt:415
+msgid ""
+"Called by the bzr server when it starts serving a directory.\n"
+"server_started is called with (backing urls, public url), where\n"
+"backing_url is a list of URLs giving the server-specific directory\n"
+"locations, and public_url is the public URL for the directory being\n"
+"served."
+msgstr ""
+
+#: en/help_topics/hooks.txt:421
+msgid ""
+"server_started_ex\n"
+"~~~~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:426
+msgid ""
+"Called by the bzr server when it starts serving a directory.\n"
+"server_started is called with (backing_urls, server_obj)."
+msgstr ""
+
+#: en/help_topics/hooks.txt:429
+msgid ""
+"server_stopped\n"
+"~~~~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:434
+msgid ""
+"Called by the bzr server when it stops serving a directory.\n"
+"server_stopped is called with the same parameters as the\n"
+"server_started hook: (backing_urls, public_url)."
+msgstr ""
+
+#: en/help_topics/hooks.txt:438
+msgid ""
+"StatusHooks\n"
+"-----------"
+msgstr ""
+
+#: en/help_topics/hooks.txt:441
+msgid ""
+"post_status\n"
+"~~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:444
+msgid "Introduced in: 2.3"
+msgstr ""
+
+#: en/help_topics/hooks.txt:446
+msgid ""
+"Called with argument StatusHookParams after Bazaar has displayed the\n"
+"status. StatusHookParams has the attributes (old_tree, new_tree,\n"
+"to_file, versioned, show_ids, short, verbose). The last four arguments\n"
+"correspond to the command line options specified by the user for the\n"
+"status command. to_file is the output stream for writing."
+msgstr ""
+
+#: en/help_topics/hooks.txt:452
+msgid ""
+"pre_status\n"
+"~~~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:457
+msgid ""
+"Called with argument StatusHookParams before Bazaar displays the\n"
+"status. StatusHookParams has the attributes (old_tree, new_tree,\n"
+"to_file, versioned, show_ids, short, verbose). The last four arguments\n"
+"correspond to the command line options specified by the user for the\n"
+"status command. to_file is the output stream for writing."
+msgstr ""
+
+#: en/help_topics/hooks.txt:463
+msgid ""
+"RioVersionInfoBuilderHooks\n"
+"--------------------------"
+msgstr ""
+
+#: en/help_topics/hooks.txt:466
+msgid ""
+"revision\n"
+"~~~~~~~~"
+msgstr ""
+
+#: en/help_topics/hooks.txt:471
+msgid ""
+"Invoked when adding information about a revision to the RIO stanza\n"
+"that is printed. revision is called with a revision object and a RIO\n"
+"stanza.\n"
+msgstr ""
+
+#: en/help_topics/location-alias.txt:1
+msgid ""
+"Location aliases\n"
+"================"
+msgstr ""
+
+#: en/help_topics/location-alias.txt:4
+msgid ""
+"Bazaar defines several aliases for locations associated with a branch.  "
+"These\n"
+"can be used with most commands that expect a location, such as `bzr push`."
+msgstr ""
+
+#: en/help_topics/location-alias.txt:7
+msgid "The aliases are::"
+msgstr ""
+
+#: en/help_topics/location-alias.txt:9
+msgid ""
+"  :parent    the parent of this branch\n"
+"  :submit    the submit branch for this branch\n"
+"  :public    the public location of this branch\n"
+"  :bound     the branch this branch is bound to, for bound branches\n"
+"  :push      the saved location used for `bzr push` with no arguments\n"
+"  :this      this branch"
+msgstr ""
+
+#: en/help_topics/location-alias.txt:16
+msgid "For example, to push to the parent location::"
+msgstr ""
+
+#: en/help_topics/location-alias.txt:18
+msgid "    bzr push :parent"
+msgstr ""
+
+#: en/help_topics/log-formats.txt:1
+msgid ""
+"Log Formats\n"
+"==========="
+msgstr ""
+
+#: en/help_topics/log-formats.txt:4
+msgid ""
+"A log format controls how information about each revision is displayed.\n"
+"The standard log formats are compared below::"
+msgstr ""
+
+#: en/help_topics/log-formats.txt:7
+msgid ""
+"  Feature                 long           short         line\n"
+"  ----------------------  -------------  ------------  -------------------\n"
+"  design goal             detailed view  concise view  1 revision per line\n"
+"  committer               name+email     name only     name only\n"
+"  author                  name+email     -             -\n"
+"  date-time format        full           date only     date only\n"
+"  commit message          full           full          top line\n"
+"  tags                    yes            yes           yes\n"
+"  merges indicator        -              yes           -\n"
+"  status/delta            optional       optional      -\n"
+"  diff/patch              optional       optional      -\n"
+"  revision-id             optional       optional      -\n"
+"  branch nick             yes            -             -\n"
+"  foreign vcs properties  yes            yes           -\n"
+"  preferred levels        all            1             1\n"
+"  digital signature       optional       -             -"
+msgstr ""
+
+#: en/help_topics/log-formats.txt:24
+msgid ""
+"The default format is ``long``. To change this, define the ``log_format``\n"
+"setting in the ``[DEFAULT]`` section of ``bazaar.conf`` like this (say)::"
+msgstr ""
+
+#: en/help_topics/log-formats.txt:27
+msgid ""
+"  [DEFAULT]\n"
+"  log_format = short"
+msgstr ""
+
+#: en/help_topics/log-formats.txt:30
+msgid ""
+"Alternatively, to change the log format used for a given query, use the\n"
+"--long, --short or --line options."
+msgstr ""
+
+#: en/help_topics/log-formats.txt:33
+msgid ""
+"If one of the standard log formats does not meet your needs, additional\n"
+"formats can be provided by plugins.\n"
+msgstr ""
+
+#: en/help_topics/other-formats.txt:1
+msgid "Other Storage Formats"
+msgstr ""
+
+#: en/help_topics/other-formats.txt:3
+msgid "No experimental formats are available."
+msgstr ""
+
+#: en/help_topics/other-formats.txt:5
+msgid ""
+"\n"
+"No deprecated formats are available."
+msgstr ""
+
+#: en/help_topics/patterns.txt:1
+msgid ""
+"Patterns\n"
+"========"
+msgstr ""
+
+#: en/help_topics/patterns.txt:4
+msgid ""
+"Bazaar uses patterns to match files at various times. For example,\n"
+"the ``add`` command skips over files that match ignore patterns\n"
+"and preferences can be associated with files using rule patterns.\n"
+"The pattern syntax is described below."
+msgstr ""
+
+#: en/help_topics/patterns.txt:9
+msgid ""
+"Trailing slashes on patterns are ignored. If the pattern contains a\n"
+"slash or is a regular expression, it is compared to the whole path\n"
+"from the branch root. Otherwise, it is compared to only the last\n"
+"component of the path. To match a file only in the root directory,\n"
+"prepend ``./``. Patterns specifying absolute paths are not allowed."
+msgstr ""
+
+#: en/help_topics/patterns.txt:15
+msgid "Patterns may include globbing wildcards such as::"
+msgstr ""
+
+#: en/help_topics/patterns.txt:17
+msgid ""
+"  ? - Matches any single character except '/'\n"
+"  * - Matches 0 or more characters except '/'\n"
+"  /**/ - Matches 0 or more directories in a path\n"
+"  [a-z] - Matches a single character from within a group of characters"
+msgstr ""
+
+#: en/help_topics/patterns.txt:22
+msgid ""
+"Patterns may also be `Python regular expressions`_. Regular expression\n"
+"patterns are identified by a ``RE:`` prefix followed by the regular\n"
+"expression.  Regular expression patterns may not include named or\n"
+"numbered groups."
+msgstr ""
+
+#: en/help_topics/patterns.txt:27
+msgid ""
+"Case insensitive ignore patterns can be specified with regular expressions\n"
+"by using the ``i`` (for ignore case) flag in the pattern."
+msgstr ""
+
+#: en/help_topics/patterns.txt:30
+msgid "For example, a case insensitive match for ``foo`` may be specified as::"
+msgstr ""
+
+#: en/help_topics/patterns.txt:32
+msgid "  RE:(?i)foo"
+msgstr ""
+
+#: en/help_topics/patterns.txt:34
+msgid ""
+"Ignore patterns may be prefixed with ``!``, which means that a filename\n"
+"matched by that pattern will not be ignored."
+msgstr ""
+
+#: en/help_topics/patterns.txt:37
+msgid ".. _Python regular expressions: http://docs.python.org/library/re.html"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:1
+msgid "Revision Identifiers"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:3
+msgid ""
+"A revision identifier refers to a specific state of a branch's history.  It\n"
+"can be expressed in several ways.  It can begin with a keyword to\n"
+"unambiguously specify a given lookup type; some examples are 'last:1',\n"
+"'before:yesterday' and 'submit:'."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:8
+msgid ""
+"Alternately, it can be given without a keyword, in which case it will be\n"
+"checked as a revision number, a tag, a revision id, a date specification, or "
+"a\n"
+"branch specification, in that order.  For example, 'date:today' could be\n"
+"written as simply 'today', though if you have a tag called 'today' that "
+"will\n"
+"be found first."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:14
+msgid ""
+"If 'REV1' and 'REV2' are revision identifiers, then 'REV1..REV2' denotes a\n"
+"revision range. Examples: '3647..3649', 'date:yesterday..-1' and\n"
+"'branch:/path/to/branch1/..branch:/branch2' (note that there are no quotes "
+"or\n"
+"spaces around the '..')."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:19
+msgid ""
+"Ranges are interpreted differently by different commands. To the \"log\" "
+"command,\n"
+"a range is a sequence of log messages, but to the \"diff\" command, the "
+"range\n"
+"denotes a change between revisions (and not a sequence of changes).  In\n"
+"addition, \"log\" considers a closed range whereas \"diff\" and \"merge\" "
+"consider it\n"
+"to be open-ended, that is, they include one end but not the other.  For "
+"example:\n"
+"\"bzr log -r 3647..3649\" shows the messages of revisions 3647, 3648 and "
+"3649,\n"
+"while \"bzr diff -r 3647..3649\" includes the changes done in revisions 3648 "
+"and\n"
+"3649, but not 3647."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:28
+msgid "The keywords used as revision selection methods are the following:"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:30
+msgid ""
+":revid:\n"
+"\tSelects a revision using the revision id.\n"
+":submit:\n"
+"\tSelects a common ancestor with the submit branch.\n"
+":ancestor:\n"
+"\tSelects a common ancestor with a second branch.\n"
+":date:\n"
+"\tSelects a revision on the basis of a datestamp.\n"
+":branch:\n"
+"\tSelects the last revision of a specified branch.\n"
+":tag:\n"
+"\tSelects a revision identified by a tag name.\n"
+":package:\n"
+"\tSelects the revision corresponding to a version of a package.\n"
+":revno:\n"
+"\tSelects a revision using a number.\n"
+":before:\n"
+"\tSelects the parent of the revision specified.\n"
+":annotate:\n"
+"\tSelect the revision that last modified the specified line.\n"
+":mainline:\n"
+"\tSelect mainline revision that merged the specified revision.\n"
+":last:\n"
+"\tSelects the nth revision from the end."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:55
+msgid "In addition, plugins can provide other keywords."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:57
+msgid "A detailed description of each keyword is given below."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:59
+msgid ":revid:"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:61
+msgid ""
+"    Supply a specific revision id, that can be used to specify any\n"
+"    revision id in the ancestry of the branch.\n"
+"    Including merges, and pending merges.\n"
+"    Examples::"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:66
+msgid ""
+"      revid:aaaa@bbbb-123456789 -> Select revision 'aaaa@bbbb-123456789'"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:68
+msgid ":submit:"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:70
+msgid ""
+"    Diffing against this shows all the changes that were made in this "
+"branch,\n"
+"    and is a good predictor of what merge will do.  The submit branch is\n"
+"    used by the bundle and merge directive commands.  If no submit branch\n"
+"    is specified, the parent branch is used instead."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:75
+msgid ""
+"    The common ancestor is the last revision that existed in both\n"
+"    branches. Usually this is the branch point, but it could also be\n"
+"    a revision that was merged."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:79
+msgid "    Examples::"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:81
+msgid "      $ bzr diff -r submit:"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:83
+msgid ":ancestor:"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:85
+msgid "    Supply the path to a branch to select the common ancestor."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:91
+msgid ""
+"    This is frequently used with 'diff' to return all of the changes\n"
+"    that your branch introduces, while excluding the changes that you\n"
+"    have not merged from the remote branch."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:97
+msgid ""
+"      ancestor:/path/to/branch\n"
+"      $ bzr diff -r ancestor:../../mainline/branch"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:100
+msgid ":date:"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:102
+msgid ""
+"    Supply a datestamp to select the first revision that matches the date.\n"
+"    Date can be 'yesterday', 'today', 'tomorrow' or a YYYY-MM-DD string.\n"
+"    Matches the first entry after a given date (either at midnight or\n"
+"    at a specified time)."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:107
+msgid "    One way to display all the changes since yesterday would be::"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:109
+msgid "        bzr log -r date:yesterday.."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:113
+msgid ""
+"      date:yesterday            -> select the first revision since "
+"yesterday\n"
+"      date:2006-08-14,17:10:14  -> select the first revision after\n"
+"                                   August 14th, 2006 at 5:10pm."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:117
+msgid ":branch:"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:119
+msgid "    Supply the path to a branch to select its last revision."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:123
+msgid "      branch:/path/to/branch"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:125
+msgid ":tag:"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:127
+msgid "    Tags are stored in the branch and created by the 'tag' command."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:129
+msgid ":package:"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:131
+msgid ""
+"    Given a package version number this revision specifier will allow you\n"
+"    specify the revision corresponding to the upload of that version of\n"
+"    the package."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:135
+msgid ":revno:"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:137
+msgid ""
+"    Use an integer to specify a revision in the history of the branch.\n"
+"    Optionally a branch can be specified.  A negative number will count\n"
+"    from the end of the branch (-1 is the last revision, -2 the previous\n"
+"    one). If the negative number is larger than the branch's history, the\n"
+"    first revision is returned.\n"
+"    Examples::"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:144
+msgid ""
+"      revno:1                   -> return the first revision of this branch\n"
+"      revno:3:/path/to/branch   -> return the 3rd revision of\n"
+"                                   the branch '/path/to/branch'\n"
+"      revno:-1                  -> The last revision in a branch.\n"
+"      -2:http://other/branch    -> The second to last revision in the\n"
+"                                   remote branch.\n"
+"      -1000000                  -> Most likely the first revision, unless\n"
+"                                   your history is very long."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:153
+msgid ":before:"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:155
+msgid ""
+"    Supply any revision spec to return the parent of that revision.  This "
+"is\n"
+"    mostly useful when inspecting revisions that are not in the revision "
+"history\n"
+"    of a branch."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:159
+msgid ""
+"    It is an error to request the parent of the null revision (before:0)."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:163
+msgid ""
+"      before:1913    -> Return the parent of revno 1913 (revno 1912)\n"
+"      before:revid:aaaa@bbbb-1234567890  -> return the parent of revision\n"
+"                                            aaaa@bbbb-1234567890\n"
+"      bzr diff -r before:1913..1913\n"
+"            -> Find the changes between revision 1913 and its parent "
+"(1912).\n"
+"               (What changes did revision 1913 introduce).\n"
+"               This is equivalent to:  bzr diff -c 1913"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:171
+msgid ":annotate:"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:173
+msgid ""
+"    Select the revision that last modified the specified line.  Line is\n"
+"    specified as path:number.  Path is a relative path to the file.  "
+"Numbers\n"
+"    start at 1, and are relative to the current version, not the last-\n"
+"    committed version of the file."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:178
+msgid ":mainline:"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:180
+msgid ""
+"    Select the revision that merged the specified revision into mainline."
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:182
+msgid ":last:"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:184
+msgid ""
+"    Supply a positive number to get the nth revision from the end.\n"
+"    This is the same as supplying negative numbers to the 'revno:' spec.\n"
+"    Examples::"
+msgstr ""
+
+#: en/help_topics/revisionspec.txt:188
+msgid ""
+"      last:1        -> return the last revision\n"
+"      last:3        -> return the revision 2 before the end.\n"
+msgstr ""
+
+#: en/help_topics/rules.txt:1
+msgid ""
+"Rules\n"
+"====="
+msgstr ""
+
+#: en/help_topics/rules.txt:7
+msgid ""
+"Rules are defined in ini file format where the sections are file glob\n"
+"patterns and the contents of each section are the preferences for files\n"
+"matching that pattern(s). For example::"
+msgstr ""
+
+#: en/help_topics/rules.txt:11
+msgid ""
+"    [name *.bat]\n"
+"    eol = native"
+msgstr ""
+
+#: en/help_topics/rules.txt:14
+msgid ""
+"    [name *.html *.xml]\n"
+"    keywords = xml_escape"
+msgstr ""
+
+#: en/help_topics/rules.txt:17
+msgid ""
+"Preferences like these are useful for commands and plugins wishing to\n"
+"provide custom behaviour for selected files.  For more information on \n"
+"end of line conversion see :doc:`eol-help`.\n"
+"Keyword support is provided by the `keywords plugin\n"
+"<http://doc.bazaar.canonical.com/plugins/en/keywords-plugin.html>`_."
+msgstr ""
+
+#: en/help_topics/rules.txt:23
+msgid ""
+"Files\n"
+"-----"
+msgstr ""
+
+#: en/help_topics/rules.txt:26
+msgid ""
+"Default rules for all branches are defined in the optional file\n"
+"``BZR_HOME/rules``. "
+msgstr ""
+
+#: en/help_topics/rules.txt:29
+msgid ""
+"Rule Patterns\n"
+"-------------"
+msgstr ""
+
+#: en/help_topics/rules.txt:32
+msgid ""
+"Patterns are ordered and searching stops as soon as one matches.\n"
+"As a consequence, more explicit patterns should be placed towards\n"
+"the top of the file. Rule patterns use exactly the same conventions\n"
+"as ignore patterns. See :doc:`patterns-help` for details."
+msgstr ""
+
+#: en/help_topics/rules.txt:37
+msgid ".. note::"
+msgstr ""
+
+#: en/help_topics/rules.txt:39
+msgid ""
+"   Patterns containing square brackets or spaces should be\n"
+"   surrounded in quotes to ensure they are correctly parsed.\n"
+msgstr ""
+
+#: en/help_topics/topics.txt:1
+msgid ""
+"authentication       Information on configuring authentication\n"
+"basic                Basic commands\n"
+"branches             Information on what a branch is\n"
+"bugs                 Bug tracker settings\n"
+"checkouts            Information on what a checkout is\n"
+"commands             Basic help for all commands\n"
+"configuration        Details on the configuration settings available\n"
+"conflict-types       Types of conflicts and what to do about them\n"
+"content-filters      Conversion of content into/from working trees\n"
+"criss-cross          Information on criss-cross merging\n"
+"current-formats      Current storage formats\n"
+"debug-flags          Options to show or record debug information\n"
+"diverged-branches    How to fix diverged branches\n"
+"env-variables        Environment variable names and values\n"
+"eol                  Information on end-of-line handling\n"
+"files                Information on configuration and log files\n"
+"formats              Information on choosing a storage format\n"
+"global-options       Options that control how Bazaar runs\n"
+"hidden-commands      All hidden commands\n"
+"hooks                Points at which custom processing can be added\n"
+"launchpad            Using Bazaar with Launchpad.net\n"
+"location-alias       Aliases for remembered locations\n"
+"log-formats          Details on the logging formats available\n"
+"other-formats        Experimental and deprecated storage formats\n"
+"patterns             Information on the pattern syntax\n"
+"repositories         Basic information on shared repositories.\n"
+"revisionspec         Explain how to use --revision\n"
+"rules                Information on defining rule-based preferences\n"
+"standalone-trees     Information on what a standalone tree is\n"
+"standard-options     Options that can be used with any command\n"
+"status-flags         Help on status flags\n"
+"sync-for-reconfigure Steps to resolve \"out-of-sync\" when reconfiguring\n"
+"topics               Topics list\n"
+"url-special-chars    Special character handling in URLs\n"
+"urlspec              Supported transport protocols\n"
+"working-trees        Information on working trees\n"
+msgstr ""
+
+#: en/help_topics/url-special-chars.txt:1
+msgid ""
+"Special character handling in URLs\n"
+"=================================="
+msgstr ""
+
+#: en/help_topics/url-special-chars.txt:4
+msgid "Bazaar allows locations to be specified in multiple ways, either:"
+msgstr ""
+
+#: en/help_topics/url-special-chars.txt:6
+msgid " * Fully qualified URLs"
+msgstr ""
+
+#: en/help_topics/url-special-chars.txt:8
+msgid " * File system paths, relative or absolute"
+msgstr ""
+
+#: en/help_topics/url-special-chars.txt:10
+msgid ""
+"Internally bzr treats all locations as URLs. For any file system paths\n"
+"that are specified it will automatically determine the appropriate URL\n"
+"representation, and escape special characters where necessary."
+msgstr ""
+
+#: en/help_topics/url-special-chars.txt:14
+msgid ""
+"There are a few characters which have special meaning in URLs and need "
+"careful\n"
+"handling to avoid ambiguities. Characters can be escaped with a % and a hex\n"
+"value in URLs. Any non-ASCII characters in a file path will automatically "
+"be\n"
+"urlencoded when the path is converted to a URL."
+msgstr ""
+
+#: en/help_topics/url-special-chars.txt:19
+msgid ""
+"URLs represent non-ASCII characters in an encoding defined by the server, "
+"but\n"
+"usually UTF-8.  The % escapes should be of the UTF-8 bytes.  Bazaar tries to "
+"be\n"
+"generous in what it accepts as a URL and to print them in a way that\n"
+"will be readable."
+msgstr ""
+
+#: en/help_topics/url-special-chars.txt:24
+msgid ""
+"For example, if you have a directory named '/tmp/%2False' these are all "
+"valid\n"
+"ways of accessing the content (0x2F, or 47, is the ASCII code for forward "
+"slash)::"
+msgstr ""
+
+#: en/help_topics/url-special-chars.txt:27
+msgid ""
+"  cd /tmp\n"
+"  bzr log /tmp/%2False\n"
+"  bzr log %2False\n"
+"  bzr log file:///tmp/%252False\n"
+"  bzr log file://localhost/tmp/%252False\n"
+"  bzr log file:%252False"
+msgstr ""
+
+#: en/help_topics/url-special-chars.txt:34
+msgid "These are valid but do not refer to the same file::"
+msgstr ""
+
+#: en/help_topics/url-special-chars.txt:36
+msgid ""
+"  bzr log file:///tmp/%2False (refers to a file called /tmp/\\/alse)\n"
+"  bzr log %252False (refers to a file called /tmp/%252False)"
+msgstr ""
+
+#: en/help_topics/url-special-chars.txt:39
+msgid ""
+"Comma also has special meaning in URLs, because it denotes `segment "
+"parameters`_"
+msgstr ""
+
+#: en/help_topics/url-special-chars.txt:41
+msgid ""
+"_`segment parameters`: http://www.ietf.org/rfc/rfc3986.txt (section 3.3)"
+msgstr ""
+
+#: en/help_topics/url-special-chars.txt:43
+msgid ""
+"Comma is also special in any file system paths that are specified. To use a "
+"literal\n"
+"comma in a file system path, specify a URL and URL encode the comma::"
+msgstr ""
+
+#: en/help_topics/url-special-chars.txt:46
+msgid ""
+"  bzr log foo,branch=bla # path \"foo\" with the segment parameter \"branch"
+"\" set to \"bla\"\n"
+"  bzr log file:foo%2Cbranch=bla # path \"foo,branch=bla\"\n"
+"  bzr log file:foo,branch=bla # path \"foo\" with segment parameter \"branch"
+"\" set to \"bla\"\n"
+msgstr ""
+
+#: en/help_topics/urlspec.txt:1
+msgid "URL Identifiers"
+msgstr ""
+
+#: en/help_topics/urlspec.txt:3
+msgid "Supported URL prefixes::"
+msgstr ""
+
+#: en/help_topics/urlspec.txt:5
+msgid ""
+"  aftp://             Access using active FTP.\n"
+"  bzr://              Fast access using the Bazaar smart server.\n"
+"  bzr+ssh://          Fast access using the Bazaar smart server over SSH.\n"
+"  file://             Access using the standard filesystem (default)\n"
+"  ftp://              Access using passive FTP.\n"
+"  http://             Read-only access of branches exported on the web.\n"
+"  https://            Read-only access of branches exported on the web using "
+"SSL.\n"
+"  sftp://             Access using SFTP (most SSH servers provide SFTP)."
+msgstr ""
+
+#: en/help_topics/urlspec.txt:14
+msgid "Supported modifiers::"
+msgstr ""
+
+#: en/help_topics/urlspec.txt:16
+msgid "  gio+                Access using any GIO supported protocols."
+msgstr ""
+
+#: en/help_topics/urlspec.txt:18
+msgid "Bazaar supports all of the standard parts within the URL::"
+msgstr ""
+
+#: en/help_topics/urlspec.txt:20
+msgid "  <protocol>://[user[:password]@]host[:port]/[path]"
+msgstr ""
+
+#: en/help_topics/urlspec.txt:22
+msgid "allowing URLs such as::"
+msgstr ""
+
+#: en/help_topics/urlspec.txt:24
+msgid "  http://bzruser:BadPass@bzr.example.com:8080/bzr/trunk"
+msgstr ""
+
+#: en/help_topics/urlspec.txt:26
+msgid ""
+"For bzr+ssh:// and sftp:// URLs, Bazaar also supports paths that begin\n"
+"with '~' as meaning that the rest of the path should be interpreted\n"
+"relative to the remote user's home directory.  For example if the user\n"
+"``remote`` has a  home directory of ``/home/remote`` on the server\n"
+"shell.example.com, then::"
+msgstr ""
+
+#: en/help_topics/urlspec.txt:32
+msgid "  bzr+ssh://remote@shell.example.com/~/myproject/trunk"
+msgstr ""
+
+#: en/help_topics/urlspec.txt:34
+msgid "would refer to ``/home/remote/myproject/trunk``."
+msgstr ""
+
+#: en/help_topics/urlspec.txt:36
+msgid ""
+"Many commands that accept URLs also accept location aliases too.\n"
+"See :doc:`location-alias-help` and :doc:`url-special-chars-help`.\n"
+msgstr ""

=== modified file 'setup.py'
--- setup.py	2011-08-25 11:02:37 +0000
+++ setup.py	2011-08-30 14:44:42 +0000
@@ -202,7 +202,9 @@
     from distutils.command.build_ext import build_ext
 else:
     have_pyrex = True
-    pyrex_version_info = tuple(map(int, pyrex_version.split('.')))
+    import re
+    _version = re.match("^[0-9.]+", pyrex_version).group(0)
+    pyrex_version_info = tuple(map(int, _version.split('.')))
 
 
 class build_ext_if_possible(build_ext):

